/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(cNa){function UMa(dNa){dNa.set=(function(eNa,fNa){this[eNa]=fNa});dNa.get=(function(eNa){return this[eNa]});return dNa}var a;var b=new ArrayBuffer(16);var c=new Int32Array(b);var d=new Float32Array(b);var e=new Float64Array(b);function VMa(gNa){return c[gNa]}function WMa(gNa,hNa){c[gNa]=hNa}function XMa(){return e[0]}function YMa(hNa){e[0]=hNa}function ZMa(hNa){d[2]=hNa}function _Ma(){return d[2]}function $Ma(iNa){var f=iNa.a;var g=f.buffer;f.grow=bNa;var h=new Int8Array(g);var i=new Int16Array(g);var j=new Int32Array(g);var k=new Uint8Array(g);var l=new Uint16Array(g);var m=new Uint32Array(g);var n=new Float32Array(g);var o=new Float64Array(g);var p=Math.imul;var q=Math.fround;var r=Math.abs;var s=Math.clz32;var t=Math.min;var u=Math.max;var v=Math.floor;var w=Math.ceil;var x=Math.trunc;var y=Math.sqrt;var z=iNa.abort;var A=NaN;var B=Infinity;var C=iNa.b;var D=iNa.c;var E=iNa.d;var F=iNa.e;var G=iNa.f;var H=iNa.g;var I=iNa.h;var J=iNa.i;var K=iNa.j;var L=iNa.k;var M=iNa.l;var N=iNa.m;var O=iNa.n;var P=iNa.o;var Q=iNa.p;var R=iNa.q;var S=iNa.r;var T=iNa.s;var U=iNa.t;var V=iNa.u;var W=iNa.v;var X=iNa.w;var Y=iNa.x;var Z=iNa.y;var _=iNa.z;var $=iNa.A;var aa=iNa.B;var ba=iNa.C;var ca=iNa.D;var da=iNa.E;var ea=iNa.F;var fa=iNa.G;var ga=iNa.H;var ha=iNa.I;var ia=iNa.J;var ja=iNa.K;var ka=iNa.L;var la=iNa.M;var ma=iNa.N;var na=iNa.O;var oa=iNa.P;var pa=iNa.Q;var qa=iNa.R;var ra=iNa.S;var sa=iNa.T;var ta=iNa.U;var ua=iNa.V;var va=iNa.W;var wa=iNa.X;var xa=iNa.Y;var ya=iNa.Z;var za=iNa._;var Aa=iNa.$;var Ba=iNa.aa;var Ca=iNa.ba;var Da=iNa.ca;var Ea=iNa.da;var Fa=iNa.ea;var Ga=iNa.fa;var Ha=iNa.ga;var Ia=iNa.ha;var Ja=iNa.ia;var Ka=iNa.ja;var La=iNa.ka;var Ma=iNa.la;var Na=iNa.ma;var Oa=iNa.na;var Pa=iNa.oa;var Qa=iNa.pa;var Ra=iNa.qa;var Sa=iNa.ra;var Ta=iNa.sa;var Ua=iNa.ta;var Va=iNa.ua;var Wa=iNa.va;var Xa=iNa.wa;var Ya=iNa.xa;var Za=5707120;var _a=0;var $a=0;var ab=0;
// EMSCRIPTEN_START_FUNCS
function TGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,J=0,M=0,O=0;d=Za-608|0;Za=d;rc(b);e=d+416|0;g=pFa(b,e);if(!g){UP(e)}a:{b:{c:{if(!g){break c}if(!vQ(d+416|0)){break c}if(!yb(b,Wc(uQ(d+416|0),ab))){break c}if(!c){f=1;break c}od(a,32);h[d+415|0]=0;r=Qc(d+400|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{if(j[d+416>>2]==778924148){j[114626]=0;F(621,a|0,16777216);e=j[114626];j[114626]=0;if((e|0)==1){break b}j[114626]=0;e=H(255,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}j[114626]=0;E(256,b|0,e-4|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break b}j[114626]=0;y=H(390,b|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break J}break b}K:{L:{M:{N:{if((k[d+456|0]|k[d+457|0]<<8)>>>0<2185|(k[d+456|0]|k[d+457|0]<<8)>>>0>4095){break N}j[114626]=0;e=H(255,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}j[114626]=0;E(256,b|0,e-4|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break b}j[114626]=0;y=H(390,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break b}if(y>>>0<256){break N}j[114626]=0;e=H(255,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}if(e>>>0<=y>>>0){break N}j[114626]=0;e=E(256,b|0,y|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}if(!e){break N}j[114626]=0;e=E(622,b|0,13434)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}if(!e){break N}j[114626]=0;F(621,a|0,16777216);e=j[114626];j[114626]=0;if((e|0)==1){break b}if((k[d+456|0]|k[d+457|0]<<8)>>>0>=4096){j[114626]=0;b=E(623,d+224|0,13438)|0;c=j[114626];j[114626]=0;if((c|0)==1){break I}j[114626]=0;F(624,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(b);f=0;break d}f=D()|0;C()|0;gb(b);break a}if((k[d+456|0]|k[d+457|0]<<8)>>>0<2194){break N}j[114626]=0;e=E(623,d+224|0,13534)|0;f=j[114626];j[114626]=0;if((f|0)==1){break M}j[114626]=0;F(624,a|0,e|0);f=j[114626];j[114626]=0;if((f|0)==1){break L}gb(e)}if(j[a+480180>>2]!=32){break J}if(((k[d+456|0]|k[d+457|0]<<8)&61440)!=20480){break K}j[a+1074304>>2]=((k[d+456|0]|k[d+457|0]<<8)&4095)<<16;if(j[d+476>>2]!=1414548815){break J}h[d+415|0]=1;break J}f=D()|0;C()|0;break a}f=D()|0;C()|0;gb(e);break a}if(!((k[d+456|0]|k[d+457|0]<<8)!=2184?(k[d+458|0]|k[d+459|0]<<8)!=2184:0)){h[d+415|0]=1;j[a+1074304>>2]=18284544;break J}if(!((k[d+456|0]|k[d+457|0]<<8)!=535|(k[d+458|0]|k[d+459|0]<<8)!=512|(k[d+476|0]|k[d+477|0]<<8|(k[d+478|0]<<16|k[d+479|0]<<24)))){j[114626]=0;e=K(625,d+480|0,255,64)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}O:{if(e){j[a+1074304>>2]=18219008;j[114626]=0;e=E(2,d+224|0,13680)|0;f=j[114626];j[114626]=0;if((f|0)!=1){break O}f=D()|0;C()|0;break a}j[a+1074304>>2]=18284544;j[114626]=0;e=E(2,d+224|0,13708)|0;f=j[114626];j[114626]=0;if((f|0)==1){break H}}ob(r,e);gb(e);h[d+415|0]=1;break J}if(!((k[d+456|0]|k[d+457|0]<<8)!=532|(k[d+458|0]|k[d+459|0]<<8)!=514|(k[d+476|0]|k[d+477|0]<<8|(k[d+478|0]<<16|k[d+479|0]<<24)))){j[a+1074304>>2]=17367040;j[114626]=0;e=E(2,d+224|0,13744)|0;f=j[114626];j[114626]=0;if((f|0)!=1){ob(r,e);gb(e);h[d+415|0]=1;break J}f=D()|0;C()|0;break a}if((k[d+456|0]|k[d+457|0]<<8)!=768|(k[d+458|0]|k[d+459|0]<<8)!=768|(k[d+476|0]|k[d+477|0]<<8|(k[d+478|0]<<16|k[d+479|0]<<24)|(k[d+448|0]|k[d+449|0]<<8)!=256)){break J}if(k[d+469|0]|k[d+468|0]!=128){break J}j[a+1074304>>2]=18285088;h[d+415|0]=1}j[a+480208>>2]=j[a+480208>>2]&-17|(k[d+460|0]|k[d+461|0]<<8)<<1&16;j[a+480208>>2]=j[a+480208>>2]&-5|(k[d+460|0]|k[d+461|0]<<8)>>>2&4;j[a+480208>>2]=j[a+480208>>2]&-9|(k[d+460|0]|k[d+461|0]<<8)>>>2&8;j[a+480208>>2]=j[a+480208>>2]&-32769|(k[d+460|0]|k[d+461|0]<<8)<<3&32768;j[114626]=0;I(626,d+328|0,3,d+416|4);e=j[114626];j[114626]=0;if((e|0)==1){break G}j[114626]=0;F(415,d+224|0,d+328|0);e=j[114626];j[114626]=0;if((e|0)==1){break G}ob(a+1304400|0,d+224|0);gb(d+224|0);if(!(!(k[d+462|0]&4)|(m[a+1074304>>2]<18285314?j[a+1074304>>2]:0))){j[a+480216>>2]=k[d+446|0];j[a+480220>>2]=k[d+447|0]}e=k[d+464|0];j[a+480200>>2]=e>>>0>128?256:e<<1;if(k[d+466|0]){j[a+480196>>2]=k[d+466|0]}h[d+224|0]=31;e=k[d+467|0];j[114626]=0;h[d+328|0]=e;e=E(453,d+224|0,d+328|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}j[a+480204>>2]=p(k[e|0],1e4);e=k[d+465|0];j[114626]=0;h[d+224|0]=e;h[d+328|0]=128;e=E(391,d+224|0,d+328|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break f}j[a+480228>>2]=k[e|0];f=0;while(1){q=(d+416|0)+f|0;g=q- -64|0;P:{if(k[g|0]==255){break P}j[114626]=0;o=(f<<5)+a|0;e=o+480280|0;N(432,e|0);n=j[114626];j[114626]=0;if((n|0)==1){break F}M=o+480286|0,O=kd(k[q+128|0],0,64),i[M>>1]=O;if(h[g|0]<=-1){j[e>>2]=j[e>>2]|1024}g=k[g|0]&127;if(g>>>0<=64){i[o+480284>>1]=g<<2;break P}if((g|0)!=100){break P}j[e>>2]=j[e>>2]|256}f=f+1|0;if((f|0)!=64){continue}break}j[114626]=0;E(256,b|0,192)|0;e=j[114626];j[114626]=0;if((e|0)==1){break b}Q:{if(!(j[a+480180>>2]!=16777216|(k[d+456|0]|k[d+457|0]<<8)>>>0<2187|(k[d+456|0]|k[d+457|0]<<8)>>>0>2189)){f=0;j[114626]=0;e=H(357,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break E}if(e){break d}j[114626]=0;e=H(390,b|0)|0;g=j[114626];j[114626]=0;R:{if((g|0)==1){break R}if(e>>>0>l[j[19859]+12>>1]){break d}g=Fb(a+484360|0);j[114626]=0;e=U(627,g|0,b|0,e|0,65535,65535)|0;g=j[114626];j[114626]=0;if((g|0)==1){break R}if(!e){break d}break Q}f=D()|0;C()|0;break a}e=Fb(a+484360|0);f=k[d+448|0]|k[d+449|0]<<8;j[114626]=0;U(581,e|0,b|0,f|0,255,254)|0;e=j[114626];j[114626]=0;if((e|0)==1){break b}}x=jp(d+384|0);w=jp(d+368|0);t=jp(d+352|0);e=k[d+450|0]|k[d+451|0]<<8;f=0;j[114626]=0;e=K(628,b|0,x|0,e|0)|0;g=j[114626];j[114626]=0;S:{if((g|0)==1){break S}if(!e){break C}e=k[d+452|0]|k[d+453|0]<<8;j[114626]=0;e=K(628,b|0,w|0,e|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break S}if(!e){break C}e=k[d+454|0]|k[d+455|0]<<8;j[114626]=0;e=K(628,b|0,t|0,e|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break S}if(!e){break C}j[d+348>>2]=-1;M=d,O=Lb(x),j[M+224>>2]=O;M=d,O=Mb(x),j[M+328>>2]=O;if(!rb(d+224|0,d+328|0)){break D}while(1){e=j[d+224>>2];e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);if(!(!e|e>>>0>=m[d+348>>2])){j[d+348>>2]=e}Id(d+224|0);if(rb(d+224|0,d+328|0)){continue}break}break D}f=D()|0;C()|0;break g}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}M=d,O=Lb(w),j[M+224>>2]=O;M=d,O=Mb(w),j[M+328>>2]=O;if(rb(d+224|0,d+328|0)){while(1){e=j[d+224>>2];e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);if(!(!e|e>>>0>=m[d+348>>2])){j[d+348>>2]=e}Id(d+224|0);if(rb(d+224|0,d+328|0)){continue}break}}M=d,O=Lb(t),j[M+224>>2]=O;M=d,O=Mb(t),j[M+328>>2]=O;if(rb(d+224|0,d+328|0)){while(1){e=j[d+224>>2];e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);if(!(!e|e>>>0>=m[d+348>>2])){j[d+348>>2]=e}Id(d+224|0);if(rb(d+224|0,d+328|0)){continue}break}}T:{U:{if(h[d+462|0]&1){e=k[d+472|0]|k[d+473|0]<<8|(k[d+474|0]<<16|k[d+475|0]<<24);j[114626]=0;j[d+224>>2]=e;e=E(629,d+348|0,d+224|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break U}j[d+348>>2]=j[e>>2]}f=0;V:{W:{X:{Y:{if((k[d+458|0]|k[d+459|0]<<8)!=532|(k[d+456|0]|k[d+457|0]<<8?(k[d+456|0]|k[d+457|0]<<8)!=532:0)|(k[d+447|0]|k[d+446|0])){break Y}if(k[d+460|0]&192|(k[d+469|0]|(k[d+476|0]|k[d+477|0]<<8|(k[d+478|0]<<16|k[d+479|0]<<24)))){break Y}Z:{if(!(k[d+452|0]|k[d+453|0]<<8)|(k[d+450|0]|k[d+451|0]<<8)){break Z}if((j[b+8>>2]+(sb(w)<<2)|0)+2>>>0>m[d+348>>2]){break Z}if(k[d+452|0]|k[d+453|0]<<8){e=0;while(1){j[114626]=0;f=H(390,b|0)|0;g=j[114626];j[114626]=0;_:{if((g|0)!=1){if(!f){break _}cg(b,(e<<2)+4|0);break Z}f=D()|0;C()|0;break g}e=e+1|0;if(e>>>0<(k[d+452|0]|k[d+453|0]<<8)>>>0){continue}break}}j[114626]=0;e=E(2,d+224|0,13772)|0;f=j[114626];j[114626]=0;if((f|0)==1){break W}ob(r,e);gb(e)}f=1;if(k[d+456|0]|k[d+457|0]<<8){break Y}j[114626]=0;e=E(2,d+224|0,13785)|0;g=j[114626];j[114626]=0;if((g|0)==1){break X}ob(r,e);gb(e)}$:{aa:{ba:{if(k[d+462|0]&2){j[114626]=0;e=H(357,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break $}j[114626]=0;g=e<<3;o=E(258,b|0,g|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break $}if(!(!o|m[d+348>>2]<g+j[b+8>>2]>>>0)){j[114626]=0;g=a+1304500|0;F(630,g|0,e|0);o=j[114626];j[114626]=0;if((o|0)==1){break $}M=d,O=Lb(g),j[M+328>>2]=O;M=d,O=Mb(g),j[M+312>>2]=O;if(rb(d+328|0,d+312|0)){while(1){g=j[d+328>>2];j[114626]=0;E(631,b|0,d+224|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break aa}j[114626]=0;F(632,d+224|0,g|0);g=j[114626];j[114626]=0;if((g|0)==1){break aa}j[d+328>>2]=j[d+328>>2]+48;if(rb(d+328|0,d+312|0)){continue}break}}if(!(!e&f)){break ba}if(k[d+462|0]&4){j[114626]=0;e=E(2,d+224|0,13796)|0;f=j[114626];j[114626]=0;if((f|0)!=1){ob(r,e);gb(e);break ba}f=D()|0;C()|0;break g}j[114626]=0;e=E(2,d+224|0,13813)|0;f=j[114626];j[114626]=0;if((f|0)!=1){ob(r,e);gb(e);break ba}f=D()|0;C()|0;break g}cg(b,2);break ba}if(!f|(k[d+462|0]|k[d+463|0]<<8)>>>0>1){break ba}j[114626]=0;e=H(357,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break V}if(!e){j[114626]=0;e=E(2,d+224|0,13772)|0;f=j[114626];j[114626]=0;if((f|0)!=1){ob(r,e);gb(e);break ba}f=D()|0;C()|0;break g}cg(b,2)}ca:{if(k[d+462|0]&8?0:!(k[d+460|0]&128)){break ca}j[114626]=0;e=a+901404|0;f=E(633,b|0,e|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break h}if(!f){break ca}j[114626]=0;N(634,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break h}}if((k[d+456|0]|k[d+457|0]<<8)>>>0<=531){j[114626]=0;N(635,a+901404|0);e=j[114626];j[114626]=0;if((e|0)==1){break h}}j[114626]=0;A=H(277,d+328|0)|0;e=j[114626];j[114626]=0;da:{ea:{fa:{ga:{ha:{ia:{ja:{if((e|0)!=1){j[114626]=0;e=E(618,b|0,13819)|0;f=j[114626];j[114626]=0;if((f|0)==1){break ja}if(e){j[114626]=0;e=H(390,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break ia}j[114626]=0;I(341,d+224|0,b|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break ia}Ed(A,d+224|0);jb(d+224|0)}i[a+480188>>1]=1;j[114626]=0;e=E(618,b|0,13824)|0;f=j[114626];j[114626]=0;if((f|0)==1){break ja}if(e){j[114626]=0;e=H(390,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break ha}j[114626]=0;I(341,d+224|0,b|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break ha}j[114626]=0;e=H(255,d+224|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break ga}j[114626]=0;i[d+312>>1]=(e>>>0)/20;e=E(477,13830,d+312|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break ga}e=l[e>>1];i[a+480188>>1]=e;if(e){f=0;while(1){j[114626]=0;K(636,d+224|0,((f<<5)+a|0)+480289|0,20)|0;g=j[114626];j[114626]=0;if((g|0)==1){break ga}f=f+1|0;if((e|0)!=(f|0)){continue}break}}jb(d+224|0)}if(m[b+8>>2]>m[d+348>>2]){break fa}e=j[d+348>>2]-j[b+8>>2]|0;break ea}f=D()|0;C()|0;break g}f=D()|0;C()|0;break i}f=D()|0;C()|0;break i}f=D()|0;C()|0;break i}f=D()|0;C()|0;jb(d+224|0);break i}j[114626]=0;e=H(540,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break da}}j[114626]=0;I(341,d+312|0,b|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break da}j[114626]=0;J=E(637,a|0,d+312|0)|0;e=j[114626];j[114626]=0;ka:{la:{if((e|0)==1){break la}if(!(h[d+462|0]&1)|!(k[d+470|0]|k[d+471|0]<<8)){break ka}e=k[d+472|0]|k[d+473|0]<<8|(k[d+474|0]<<16|k[d+475|0]<<24);j[114626]=0;e=E(256,b|0,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break la}if(!e){break ka}e=k[d+470|0]|k[d+471|0]<<8;j[114626]=0;P(584,a+1304424|0,b|0,e|0,4)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break ka}}f=D()|0;C()|0;break j}i[a+480192>>1]=0;ma:{if(k[d+460|0]&4){e=k[d+450|0]|k[d+451|0]<<8;j[114626]=0;i[d+224>>1]=e;i[d+208>>1]=255;e=E(477,d+224|0,d+208|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break ma}i[a+480192>>1]=l[e>>1]}na:{oa:{if(l[a+480192>>1]){f=0;while(1){e=xb(x,f);pa:{if(!(k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))){break pa}e=xb(x,f);e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);j[114626]=0;e=E(256,b|0,e|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break na}if(!e){break pa}j[114626]=0;e=E(258,b|0,554)|0;g=j[114626];j[114626]=0;if((g|0)==1){break na}if(!e){break pa}j[114626]=0;e=K(454,a|0,f+1&65535,0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break oa}if(!e){break pa}g=k[d+458|0]|k[d+459|0]<<8;j[114626]=0;P(638,a|0,b|0,e|0,g|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break oa}h[e+33|0]=k[d+469|0]}f=f+1|0;if(f>>>0<l[a+480192>>1]){continue}break}}j[d+308>>2]=0;if(k[d+452|0]|k[d+453|0]<<8){e=xb(w,(k[d+452|0]|k[d+453|0]<<8)-1|0);j[d+308>>2]=(k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))+80}e=k[d+452|0]|k[d+453|0]<<8;j[114626]=0;i[d+224>>1]=e;i[d+208>>1]=3999;e=E(477,d+224|0,d+208|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){i[a+480190>>1]=l[e>>1];o=0;qa:{if(l[a+480190>>1]){q=c&2;u=d+244|0;f=0;while(1){e=xb(w,f);ra:{if(!(k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))){break ra}e=xb(w,f);e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);j[114626]=0;e=E(256,b|0,e|0)|0;g=j[114626];j[114626]=0;sa:{ta:{ua:{va:{wa:{xa:{ya:{if((g|0)==1){break ya}if(!e){break ra}j[114626]=0;e=E(639,b|0,d+224|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break ya}if(!e){break ra}j[114626]=0;n=f+1|0;e=p(n,104)+a|0;g=e+484380|0;v=E(640,d+224|0,g|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break xa}j[114626]=0;I(626,d+192|0,3,u|0);s=j[114626];j[114626]=0;if((s|0)==1){break wa}j[114626]=0;F(415,d+208|0,d+192|0);s=j[114626];j[114626]=0;if((s|0)==1){break wa}j[114626]=0;E(369,((n<<5)+a|0)+946300|0,d+208|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break va}gb(d+208|0);j[114626]=0;v=E(256,b|0,v|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break xa}if(!v){break ra}e=l[e+484414>>1];if(!(e&512)){break ua}j[114626]=0;e=E(641,b|0,d+208|0)|0;n=j[114626];j[114626]=0;if((n|0)!=1){if(!e){break ta}j[114626]=0;j[d+16>>2]=j[d+216>>2];e=j[d+212>>2];j[d+8>>2]=j[d+208>>2];j[d+12>>2]=e;I(642,g|0,1,d+8|0);e=j[114626];j[114626]=0;if((e|0)!=1){break ta}}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;gb(d+208|0);break j}if(!(e&16384)){e=k[d+456|0]|k[d+457|0]<<8;j[114626]=0;I(643,d+208|0,d+224|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break k}za:{if(q){e=0;j[114626]=0;K(400,d+208|0,g|0,b|0)|0;n=j[114626];j[114626]=0;if((n|0)!=1){break za}break k}e=1;n=k[d+211|0];if(n>>>0>18){break za}n=1<<n;Aa:{if(!(n&126991)){if(n&396800){break Aa}break za}if(!k[d+208|0]){break za}}e=j[g>>2];j[114626]=0;n=E(644,d+208|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break k}e=0;j[114626]=0;E(338,b|0,n|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break k}}if(k[d+211|0]!=1){break sa}o=j[g>>2]!=0|o;break sa}j[114626]=0;E(645,b|0,d+188|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break l}e=j[d+188>>2];if(!(!q|!e)){e=Db(d+208|0);j[114626]=0;K(481,b|0,e|0,j[d+188>>2])|0;g=j[114626];j[114626]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{if((g|0)!=1){j[114626]=0;g=E(2,d+160|0,13832)|0;v=j[114626];j[114626]=0;if((v|0)==1){break Ja}j[114626]=0;F(219,d+176|0,g|0);v=j[114626];j[114626]=0;if((v|0)==1){break Ia}j[114626]=0;j[d+156>>2]=n;I(13,d+144|0,0,e|0);n=j[114626];j[114626]=0;if((n|0)==1){break Ha}j[114626]=0;L(646,d+192|0,d+176|0,d+156|0,d+144|0);n=j[114626];j[114626]=0;if((n|0)==1){break Ga}j[114626]=0;I(647,a|0,2,d+192|0);n=j[114626];j[114626]=0;if((n|0)==1){break Fa}gb(d+192|0);gb(d+144|0);qb(d+176|0);gb(g);gb(e);break ta}f=D()|0;C()|0;break Ba}f=D()|0;C()|0;break Ba}f=D()|0;C()|0;break Ca}f=D()|0;C()|0;break Da}f=D()|0;C()|0;break Ea}f=D()|0;C()|0;gb(d+192|0)}gb(d+144|0)}qb(d+176|0)}gb(g)}gb(e);break j}j[114626]=0;E(338,b|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break l}}e=0}g=j[b+8>>2];j[114626]=0;j[d+208>>2]=g;g=E(648,d+308|0,d+208|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break qa}j[d+308>>2]=j[g>>2];B=(e|0)!=0}f=f+1|0;if(f>>>0<l[a+480190>>1]){continue}break}}i[d+224>>1]=1;e=l[a+480190>>1];j[114626]=0;i[d+208>>1]=e;e=E(452,d+224|0,d+208|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){i[a+480190>>1]=l[e>>1];Ka:{La:{if(!(o&1)|(k[d+456|0]|k[d+457|0]<<8)!=516|(k[d+462|0]|k[d+463|0]<<8|(k[d+458|0]|k[d+459|0]<<8)!=512)){break La}if(k[d+476|0]|k[d+477|0]<<8|(k[d+478|0]<<16|k[d+479|0]<<24)|((k[d+460|0]|k[d+461|0]<<8)&65527)!=21|(k[d+464|0]!=128|k[d+465|0]!=48)){break La}if(k[d+469|0]|k[d+468|0]!=128|(k[d+470|0]|k[d+471|0]<<8)){break La}g=d+544|0;e=d+480|0;f=1;while(1){f=(k[e|0]|128)!=160?0:f;e=e+1|0;if((g|0)!=(e|0)){continue}break}g=d+608|0;e=d+544|0;while(1){f=k[e|0]==64&f;e=e+1|0;if((g|0)!=(e|0)){continue}break}e=20;while(1){f=!k[(d+e|0)+420|0]&f;e=e+1|0;if(e>>>0<26){continue}break}if(!f){break La}j[114626]=0;e=E(2,d+224|0,13910)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Ka}ob(r,e);gb(e)}j[a+480260>>2]=0;j[a+480264>>2]=2147483647;M=d,O=sb(t),i[M+224>>1]=O;e=j[a+8>>2];j[114626]=0;e=E(477,d+224|0,e+10|0)|0;f=j[114626];j[114626]=0;Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((f|0)!=1){e=l[e>>1];i[d+188>>1]=e;if((sb(t)|0)!=(e|0)){j[114626]=0;F(508,d+208|0,13924);e=j[114626];j[114626]=0;if((e|0)==1){break Ua}e=sb(t);j[114626]=0;j[d+192>>2]=e;L(649,d+128|0,d+208|0,d+192|0,d+188|0);e=j[114626];j[114626]=0;if((e|0)==1){break Ta}j[114626]=0;e=E(650,d+224|0,d+128|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Sa}j[114626]=0;F(624,a|0,e|0);f=j[114626];j[114626]=0;if((f|0)==1){break Ra}gb(e);gb(d+128|0);qb(d+208|0)}if(c&1){break Oa}i[d+188>>1]=0;break Na}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break Pa}f=D()|0;C()|0;break Qa}f=D()|0;C()|0;gb(e)}gb(d+128|0)}qb(d+208|0);break j}if(!l[d+188>>1]){break Na}e=0;while(1){c=xb(t,e);Va:{if(!(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))){break Va}c=xb(t,e);c=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[114626]=0;c=E(256,b|0,c|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Ma}if(!c){break Va}j[114626]=0;c=H(357,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break m}j[114626]=0;o=H(357,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break n}if((o-1&65535)>>>0>1023){break Va}j[114626]=0;f=E(338,b|0,4)|0;g=j[114626];j[114626]=0;if((g|0)==1){break n}if(!f){break Va}j[114626]=0;I(341,d+224|0,b|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break o}c=0;f=l[a+480188>>1];j[114626]=0;g=E(651,d+208|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break q}while(1){Wa:{j[114626]=0;f=E(258,d+224|0,1)|0;q=j[114626];j[114626]=0;Xa:{Ya:{if((q|0)!=1){if(!f){break Wa}j[114626]=0;f=H(387,d+224|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break r}q=f<<24>>24;if(q){break Ya}c=c+1|0;break Xa}break r}Za:{f=q&127;n=f?f-1|0:0;f=n&65535;if(tc(g)>>>0>f>>>0){break Za}j[114626]=0;h[d+192|0]=0;I(652,g|0,f+1|0,d+192|0);u=j[114626];j[114626]=0;if((u|0)!=1){break Za}break r}if((q|0)<=-1){j[114626]=0;q=H(387,d+224|0)|0;u=j[114626];j[114626]=0;if((u|0)==1){break r}M=fc(g,f),O=q,h[M|0]=O}if(!(!(k[fc(g,f)|0]&15)|f>>>0<l[a+480188>>1])){i[a+480188>>1]=n+1}if(h[fc(g,f)|0]&1){j[114626]=0;E(338,d+224|0,1)|0;q=j[114626];j[114626]=0;if((q|0)==1){break r}}if(k[fc(g,f)|0]&2){j[114626]=0;E(338,d+224|0,1)|0;q=j[114626];j[114626]=0;if((q|0)==1){break r}}if(k[fc(g,f)|0]&4){j[114626]=0;E(338,d+224|0,1)|0;q=j[114626];j[114626]=0;if((q|0)==1){break r}}if(!(k[fc(g,f)|0]&8)){break Xa}j[114626]=0;E(338,d+224|0,2)|0;f=j[114626];j[114626]=0;if((f|0)==1){break r}}if(c>>>0<o>>>0){continue}}break}c=j[b+8>>2];j[114626]=0;j[d+192>>2]=c;c=E(648,d+308|0,d+192|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break r}j[d+308>>2]=j[c>>2];Od(g);jb(d+224|0)}e=e+1|0;if(e>>>0<l[d+188>>1]){continue}break}}_a:{$a:{c=j[d+308>>2];if(!c){break $a}j[114626]=0;E(256,b|0,c|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break s}if(!B){break $a}while(1){ab:{j[114626]=0;c=E(258,b|0,4)|0;e=j[114626];j[114626]=0;if((e|0)==1){break ab}if(!c){break $a}j[114626]=0;c=E(618,b|0,14016)|0;e=j[114626];j[114626]=0;if((e|0)==1){break ab}bb:{if(!c){j[114626]=0;c=E(618,b|0,14021)|0;e=j[114626];j[114626]=0;if((e|0)==1){break ab}if(!c){break bb}}j[114626]=0;c=H(390,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break _a}cg(b,8);if(c&-2139062144){break bb}if(c&1616928864){break $a}}j[114626]=0;c=H(357,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break ab}j[114626]=0;E(338,b|0,c|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}f=D()|0;C()|0;break j}j[114626]=0;c=E(653,a|0,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break s}c=c|k[d+415|0];h[d+415|0]=c;if(!(!c|J)){Xs(a+1074308|0);j[a+1074368>>2]=0}j[114626]=0;L(654,a|0,b|0,0,d+415|0);c=j[114626];j[114626]=0;if((c|0)==1){break s}j[114626]=0;u=a+484344|0;F(401,u|0,l[d+188>>1]);c=j[114626];j[114626]=0;if((c|0)==1){break s}i[d+156>>1]=0;if(!l[d+188>>1]){break T}f=0;while(1){cb:{db:{c=xb(t,f&65535);eb:{if(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24)){c=xb(t,l[d+156>>1]);c=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[114626]=0;c=E(256,b|0,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break eb}if(c){break db}}j[114626]=0;c=K(402,u|0,l[d+156>>1],64)|0;e=j[114626];j[114626]=0;if((e|0)==1){break eb}if(!c){j[114626]=0;F(508,d+208|0,14026);c=j[114626];j[114626]=0;fb:{gb:{hb:{ib:{jb:{if((c|0)!=1){j[114626]=0;I(655,d+112|0,d+208|0,d+156|0);c=j[114626];j[114626]=0;if((c|0)==1){break jb}j[114626]=0;c=E(650,d+224|0,d+112|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break ib}j[114626]=0;F(624,a|0,c|0);e=j[114626];j[114626]=0;if((e|0)==1){break hb}gb(c);gb(d+112|0);qb(d+208|0);break T}f=D()|0;C()|0;break j}f=D()|0;C()|0;break fb}f=D()|0;C()|0;break gb}f=D()|0;C()|0;gb(c)}gb(d+112|0)}qb(d+208|0);break j}c=Ib(u,l[d+156>>1]);j[114626]=0;F(656,c|0,A|0);c=j[114626];j[114626]=0;if((c|0)!=1){break cb}}f=D()|0;C()|0;break j}j[114626]=0;c=H(357,b|0)|0;e=j[114626];j[114626]=0;kb:{lb:{if((e|0)!=1){j[114626]=0;v=H(357,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break lb}j[114626]=0;e=E(338,b|0,4)|0;f=j[114626];j[114626]=0;if((f|0)==1){break lb}if(!e){break cb}j[114626]=0;e=K(402,u|0,l[d+156>>1],v|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break lb}if(e){break kb}break cb}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}j[114626]=0;I(341,d+224|0,b|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){c=Ib(u,l[d+156>>1]);j[114626]=0;F(656,c|0,A|0);c=j[114626];j[114626]=0;mb:{if((c|0)!=1){c=l[a+480188>>1];j[114626]=0;n=E(651,d+208|0,c|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){c=l[a+480188>>1];Ug(d+176|0);j[114626]=0;q=K(657,d+192|0,c|0,d+176|0)|0;c=j[114626];j[114626]=0;nb:{if((c|0)!=1){M=d,O=Lb(Ib(u,l[d+156>>1])),j[M+144>>2]=O;s=0;ob:{if(!v){break ob}while(1){j[114626]=0;c=E(258,d+224|0,1)|0;e=j[114626];j[114626]=0;pb:{if((e|0)!=1){qb:{if(!c){break ob}j[114626]=0;c=H(387,d+224|0)|0;e=j[114626];j[114626]=0;rb:{if((e|0)!=1){c=c<<24>>24;if(c){break rb}pQ(d+144|0,l[a+480188>>1]);s=s+1|0;break pb}break qb}sb:{e=c&127;o=e?e-1&65535:0;if(tc(n)>>>0>o>>>0){break sb}j[114626]=0;h[d+176|0]=0;e=o+1|0;I(652,n|0,e|0,d+176|0);f=j[114626];j[114626]=0;if((f|0)==1){break qb}Ug(d+176|0);j[114626]=0;I(658,q|0,e|0,d+176|0);e=j[114626];j[114626]=0;if((e|0)!=1){break sb}break qb}if((c|0)<=-1){j[114626]=0;c=H(387,d+224|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break qb}M=fc(n,o),O=c,h[M|0]=O}Ug(d+176|0);e=d+176|0;if(o>>>0<l[a+480188>>1]){e=wc(d+144|0,o)}if(k[fc(n,o)|0]&16){M=e,O=k[wc(q,o)|0],h[M|0]=O}if(k[fc(n,o)|0]&32){M=e,O=k[wc(q,o)+1|0],h[M+1|0]=O}if(k[fc(n,o)|0]&64){M=e,O=k[wc(q,o)+2|0],h[M+2|0]=O;M=e,O=k[wc(q,o)+4|0],h[M+4|0]=O}if(h[fc(n,o)|0]<=-1){M=e,O=k[wc(q,o)+3|0],h[M+3|0]=O;M=e,O=k[wc(q,o)+5|0],h[M+5|0]=O}if(h[fc(n,o)|0]&1){j[114626]=0;c=H(387,d+224|0)|0;f=j[114626];j[114626]=0;B=e;tb:{ub:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(j[a+480180>>2]&16777216)){break ub}f=c;break tb}break qb}f=253;if((c-121&255)>>>0<132){break tb}f=(c&255)==253?0:c}h[B|0]=f;M=wc(q,o),O=f,h[M|0]=O}if(k[fc(n,o)|0]&2){j[114626]=0;c=H(387,d+224|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break qb}h[e+1|0]=c;M=wc(q,o),O=c,h[M+1|0]=O}if(k[fc(n,o)|0]&4){j[114626]=0;c=H(387,d+224|0)|0;f=j[114626];j[114626]=0;vb:{wb:{if((f|0)!=1){if(c>>>0>64){break wb}h[e+4|0]=c;h[e+2|0]=1;break vb}break qb}if(!(c<<24>>24>-1|c>>>0>192)){h[e+2|0]=2;h[e+4|0]=c^128;break vb}if(c>>>0<=74){h[e+2|0]=5;h[e+4|0]=c-65;break vb}if(c>>>0<=84){h[e+2|0]=6;h[e+4|0]=c-75;break vb}if(c>>>0<=94){h[e+2|0]=3;h[e+4|0]=c-85;break vb}if(c>>>0<=104){h[e+2|0]=4;h[e+4|0]=c-95;break vb}if(c>>>0<=114){h[e+2|0]=13;h[e+4|0]=c-105;break vb}if(c>>>0<=124){h[e+2|0]=12;h[e+4|0]=c-115;break vb}f=c+63|0;if((f&255)>>>0<=9){h[e+4|0]=f;h[e+2|0]=11;break vb}f=c+53|0;g=f&255;if(g>>>0<=9){h[e+4|0]=f;h[e+2|0]=8;if(!g|!j[a+1074304>>2]|m[a+1074304>>2]>18285140){break vb}h[e+2|0]=7;break vb}c=c+33|0;if((c&255)>>>0>9){break vb}h[e+4|0]=c;h[e+2|0]=15}c=k[e+2|0];M=wc(q,o),O=c,h[M+2|0]=O;c=k[e+4|0];M=wc(q,o),O=c,h[M+4|0]=O}if(!(k[fc(n,o)|0]&8)){break pb}j[114626]=0;F(472,d+104|0,d+224|0);c=j[114626];j[114626]=0;if((c|0)!=1){xb:{c=Pc(d+104|0);h[e+3|0]=k[d+104|0];h[e+5|0]=k[c|0];j[114626]=0;F(659,e|0,1);c=j[114626];j[114626]=0;if((c|0)==1){break xb}c=k[e+3|0];M=wc(q,o),O=c,h[M+3|0]=O;c=k[e+5|0];M=wc(q,o),O=c,h[M+5|0]=O;break pb}}}}f=D()|0;C()|0;kl(q);break nb}if(s>>>0<v>>>0){continue}break}}kl(q);Od(n);jb(d+224|0);break cb}f=D()|0;C()|0}Od(n);break mb}f=D()|0;C()|0;break mb}f=D()|0;C()|0}jb(d+224|0);break j}f=D()|0;C()|0;break j}f=l[d+156>>1]+1|0;i[d+156>>1]=f;if(l[d+188>>1]>(f&65535)>>>0){continue}break}break T}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break i}f=D()|0;C()|0;break g}f=D()|0;C()|0;break g}f=D()|0;C()|0;break g}f=D()|0;C()|0;break g}f=D()|0;C()|0;break g}f=D()|0;C()|0;break g}c=a+1074304|0;yb:{zb:{if(!j[a+1074304>>2]){Ab:{if((k[d+456|0]|k[d+457|0]<<8)==2184){j[c>>2]=18284544;f=18284544;break Ab}f=j[c>>2]}if(!f){break zb}}if(!Ec(r)){break zb}j[114626]=0;e=E(2,d+208|0,14078)|0;f=j[114626];j[114626]=0;Bb:{Cb:{Db:{Eb:{Fb:{Gb:{if((f|0)!=1){j[114626]=0;F(242,d+192|0,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break Gb}j[114626]=0;I(3,d+224|0,e|0,d+192|0);f=j[114626];j[114626]=0;if((f|0)==1){break Fb}ob(r,d+224|0);gb(d+224|0);gb(d+192|0);gb(e);if(j[d+476>>2]==1414548815|((k[d+456|0]|k[d+457|0]<<8)&61440)!=20480){break Bb}j[114626]=0;c=E(2,d+224|0,14087)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Db}j[114626]=0;E(192,r|0,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Cb}gb(c);break yb}f=D()|0;C()|0;break j}f=D()|0;C()|0;break Eb}f=D()|0;C()|0;gb(d+192|0)}gb(e);break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;gb(c);break j}if(!yB(c)){break yb}j[114626]=0;c=E(2,d+224|0,14111)|0;e=j[114626];j[114626]=0;Hb:{if((e|0)!=1){j[114626]=0;E(192,r|0,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Hb}gb(c);break yb}f=D()|0;C()|0;break j}f=D()|0;C()|0;gb(c);break j}Ib:{switch((k[d+456|0]|k[d+457|0]<<8)>>>12|0){case 0:if(J){j[114626]=0;c=E(2,d+224|0,14125)|0;e=j[114626];j[114626]=0;if((e|0)!=1){ob(r,c);gb(c);break yb}f=D()|0;C()|0;break j}Jb:{if((k[d+456|0]|k[d+457|0]<<8)!=532|(k[d+458|0]|k[d+459|0]<<8)!=512|(k[d+462|0]|k[d+463|0]<<8|(k[d+460|0]|k[d+461|0]<<8)!=9)){break Jb}if(k[d+447|0]|k[d+446|0]|(k[d+450|0]|k[d+451|0]<<8|((k[d+454|0]|k[d+455|0]<<8)+1|0)!=(k[d+448|0]|k[d+449|0]<<8))){break Jb}if(k[d+464|0]!=128|k[d+465|0]!=100|(k[d+466|0]!=1|k[d+468|0]!=128)){break Jb}if(k[d+469|0]|(k[d+470|0]|k[d+471|0]<<8)|(k[d+472|0]|k[d+473|0]<<8|(k[d+474|0]<<16|k[d+475|0]<<24)|(k[d+476|0]|k[d+477|0]<<8|(k[d+478|0]<<16|k[d+479|0]<<24)))){break Jb}j[114626]=0;c=E(2,d+224|0,14137)|0;e=j[114626];j[114626]=0;if((e|0)!=1){ob(r,c);gb(c);break yb}f=D()|0;C()|0;break j}Kb:{if((k[d+456|0]|k[d+457|0]<<8)!=532|(k[d+458|0]|k[d+459|0]<<8)!=512|(k[d+447|0]|k[d+446|0])){break Kb}if(k[d+476|0]|k[d+477|0]<<8|(k[d+478|0]<<16|k[d+479|0]<<24)){break Kb}j[c>>2]=16777381;j[114626]=0;c=E(2,d+224|0,14156)|0;e=j[114626];j[114626]=0;if((e|0)!=1){ob(r,c);gb(c);h[d+415|0]=1;break yb}f=D()|0;C()|0;break j}if(!((k[d+456|0]|k[d+457|0]<<8)!=532|(k[d+458|0]|k[d+459|0]<<8)!=532|j[d+476>>2]!=1229080643)){j[114626]=0;c=E(2,d+224|0,14179)|0;e=j[114626];j[114626]=0;if((e|0)!=1){ob(r,c);gb(c);j[114626]=0;E(479,a+1074308|0,38)|0;c=j[114626];j[114626]=0;if((c|0)==1){break s}break yb}f=D()|0;C()|0;break j}Lb:{if((k[d+456|0]|k[d+457|0]<<8)!=532|(k[d+458|0]|k[d+459|0]<<8)!=532|(k[d+469|0]|(k[d+462|0]|k[d+463|0]<<8)>>>0>1)){break Lb}if(!l[a+480190>>1]|(k[d+476|0]|k[d+477|0]<<8|(k[d+478|0]<<16|k[d+479|0]<<24)|((k[d+460|0]|k[d+461|0]<<8)&4294)!=4)){break Lb}j[114626]=0;c=E(85,d+224|0,14192)|0;e=j[114626];j[114626]=0;Mb:{Nb:{if((e|0)!=1){j[114626]=0;e=E(660,a+484527|0,c|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Nb}gb(c);if(!e){break Lb}j[114626]=0;c=E(2,d+224|0,14205)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Mb}ob(r,c);gb(c);break yb}f=D()|0;C()|0;break j}f=D()|0;C()|0;gb(c);break j}f=D()|0;C()|0;break j}Ob:{if(k[d+456|0]|k[d+457|0]<<8){break Ob}if(!Ec(r)){break Ob}j[114626]=0;c=E(2,d+224|0,14219)|0;e=j[114626];j[114626]=0;if((e|0)!=1){ob(r,c);gb(c);break yb}f=D()|0;C()|0;break j}if((k[d+458|0]|k[d+459|0]<<8)>>>0>767){break yb}if(!Ec(r)){break yb}Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{if((k[d+458|0]|k[d+459|0]<<8)>>>0>=533){j[114626]=0;c=E(2,d+224|0,14227)|0;e=j[114626];j[114626]=0;if((e|0)!=1){ob(r,c);break Vb}f=D()|0;C()|0;break j}if((k[d+456|0]|k[d+457|0]<<8)>>>0>=533){j[114626]=0;c=E(2,d+88|0,14248)|0;e=j[114626];j[114626]=0;Wb:{Xb:{Yb:{if((e|0)!=1){j[114626]=0;F(219,d+208|0,c|0);e=j[114626];j[114626]=0;if((e|0)==1){break Yb}e=k[d+456|0]|k[d+457|0]<<8;j[114626]=0;j[d+192>>2]=e-532;I(245,d+224|0,d+208|0,d+192|0);e=j[114626];j[114626]=0;if((e|0)==1){break Xb}ob(r,d+224|0);gb(d+224|0);qb(d+208|0);break Vb}f=D()|0;C()|0;break j}f=D()|0;C()|0;break Wb}f=D()|0;C()|0;qb(d+208|0)}gb(c);break j}j[114626]=0;c=E(2,d+72|0,14272)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Ub}j[114626]=0;F(219,d+208|0,c|0);e=j[114626];j[114626]=0;if((e|0)==1){break Tb}j[d+176>>2]=k[d+457|0]&15;e=k[d+456|0];j[114626]=0;j[d+144>>2]=e;F(661,d+192|0,d+144|0);e=j[114626];j[114626]=0;if((e|0)==1){break Sb}j[114626]=0;L(646,d+224|0,d+208|0,d+176|0,d+192|0);e=j[114626];j[114626]=0;if((e|0)==1){break Rb}ob(r,d+224|0);gb(d+224|0);gb(d+192|0);qb(d+208|0)}gb(c);c=a+1304500|0;if(!ad(c)|!(k[d+476|0]|k[d+477|0]<<8|(k[d+478|0]<<16|k[d+479|0]<<24))){break yb}e=k[d+456|0]|k[d+457|0]<<8;f=k[d+476|0]|k[d+477|0]<<8|(k[d+478|0]<<16|k[d+479|0]<<24);j[114626]=0;e=E(662,e|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break v}f=pp(d+224|0);j[f+44>>2]=e;j[114626]=0;F(663,c|0,f|0);c=j[114626];j[114626]=0;if((c|0)!=1){break yb}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break Pb}f=D()|0;C()|0;break Qb}f=D()|0;C()|0;gb(d+192|0)}qb(d+208|0)}gb(c);break j;case 1:c=k[d+456|0]|k[d+457|0]<<8;e=k[d+476|0]|k[d+477|0]<<8|(k[d+478|0]<<16|k[d+479|0]<<24);j[114626]=0;I(664,d+224|0,c|0,e|0);c=j[114626];j[114626]=0;Zb:{if((c|0)!=1){ob(r,d+224|0);gb(d+224|0);if((k[d+456|0]|k[d+457|0]<<8)>>>0>=6092){break Zb}j[114626]=0;E(479,a+1074308|0,7)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break Zb}break s}f=D()|0;C()|0;break j}if((k[d+456|0]|k[d+457|0]<<8)>>>0>=6562){break yb}j[114626]=0;E(479,a+1074308|0,38)|0;c=j[114626];j[114626]=0;if((c|0)==1){break s}break yb;case 4:j[114626]=0;c=E(2,d+56|0,14294)|0;e=j[114626];j[114626]=0;_b:{$b:{ac:{bc:{cc:{if((e|0)!=1){j[114626]=0;F(219,d+208|0,c|0);e=j[114626];j[114626]=0;if((e|0)==1){break cc}j[d+176>>2]=k[d+457|0]&15;e=k[d+456|0];j[114626]=0;j[d+144>>2]=e;F(661,d+192|0,d+144|0);e=j[114626];j[114626]=0;if((e|0)==1){break bc}j[114626]=0;L(646,d+224|0,d+208|0,d+176|0,d+192|0);e=j[114626];j[114626]=0;if((e|0)==1){break ac}ob(r,d+224|0);gb(d+224|0);gb(d+192|0);qb(d+208|0);gb(c);break yb}f=D()|0;C()|0;break j}f=D()|0;C()|0;break _b}f=D()|0;C()|0;break $b}f=D()|0;C()|0;gb(d+192|0)}qb(d+208|0)}gb(c);break j;case 6:j[114626]=0;c=E(2,d+224|0,14125)|0;e=j[114626];j[114626]=0;if((e|0)!=1){ob(r,c);gb(c);break yb}f=D()|0;C()|0;break j;case 7:if(!((k[d+456|0]|k[d+457|0]<<8)!=32767|(k[d+458|0]|k[d+459|0]<<8)!=533)){j[114626]=0;c=E(2,d+224|0,14305)|0;e=j[114626];j[114626]=0;if((e|0)!=1){ob(r,c);gb(c);break yb}f=D()|0;C()|0;break j}j[114626]=0;c=E(2,d+40|0,14314)|0;e=j[114626];j[114626]=0;dc:{ec:{fc:{if((e|0)!=1){j[114626]=0;F(219,d+208|0,c|0);e=j[114626];j[114626]=0;if((e|0)==1){break fc}j[d+192>>2]=k[d+457|0]&15;j[d+176>>2]=(k[d+456|0]|k[d+457|0]<<8)>>>4&15;e=k[d+456|0]|k[d+457|0]<<8;j[114626]=0;j[d+144>>2]=e&15;V(239,d+224|0,d+208|0,d+192|0,d+176|0,d+144|0);e=j[114626];j[114626]=0;if((e|0)==1){break ec}ob(r,d+224|0);gb(d+224|0);qb(d+208|0);gb(c);break yb}f=D()|0;C()|0;break j}f=D()|0;C()|0;break dc}f=D()|0;C()|0;qb(d+208|0)}gb(c);break j;case 13:break Ib;default:break yb}}j[114626]=0;c=E(2,d+224|0,14329)|0;e=j[114626];j[114626]=0;if((e|0)==1){break u}ob(r,c);gb(c)}gc:{if(j[a+480180>>2]!=16777216|(k[d+456|0]|k[d+457|0]<<8)>>>0<2186){break gc}j[114626]=0;c=E(256,b|0,y|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break s}if(!c){break gc}c=k[d+456|0]|k[d+457|0]<<8;j[114626]=0;I(665,a|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break s}}c=j[a+480180>>2];hc:{if((c|0)==16777216){j[114626]=0;E(2,d+224|0,14336)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break hc}f=D()|0;C()|0;break j}j[114626]=0;b=E(2,d+24|0,14272)|0;e=j[114626];j[114626]=0;if((e|0)==1){break B}j[114626]=0;F(219,d+208|0,b|0);e=j[114626];j[114626]=0;if((e|0)==1){break A}j[d+176>>2]=k[d+459|0];e=k[d+458|0];j[114626]=0;j[d+144>>2]=e;F(661,d+192|0,d+144|0);e=j[114626];j[114626]=0;if((e|0)==1){break z}j[114626]=0;L(646,d+224|0,d+208|0,d+176|0,d+192|0);e=j[114626];j[114626]=0;if((e|0)==1){break y}}ob(a+1304436|0,d+224|0);gb(d+224|0);if((c|0)!=16777216){gb(d+192|0);qb(d+208|0);gb(d+24|0)}ic:{if(j[a+480180>>2]==16777216){j[114626]=0;E(2,d+224|0,14349)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break ic}break t}j[114626]=0;E(2,d+224|0,14354)|0;b=j[114626];j[114626]=0;if((b|0)==1){break t}}ob(a+1304448|0,d+224|0);gb(d+224|0);ob(a+1304460|0,r);j[a+1304496>>2]=j[a+1074304>>2]?7:4;jb(d+312|0);jb(A);f=1}li(t);li(w);li(x);break d}f=D()|0;C()|0;break j}f=D()|0;C()|0;break w}f=D()|0;C()|0;break x}f=D()|0;C()|0;gb(d+192|0)}qb(d+208|0)}gb(b);break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;Od(g);break p}f=D()|0;C()|0}jb(d+224|0);break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0;break j}f=D()|0;C()|0}jb(d+312|0)}jb(A);break g}f=D()|0;C()|0}li(t);li(w);li(x);break a}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}gb(r)}Za=d+608|0;return f|0}f=D()|0;C()|0}gb(r);G(f|0);z()}function wCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,M=0,O=0,Q=0,R=0,S=0,T=0,W=0,X=0,Y=0;e=Za-1584|0;Za=e;rc(b);a:{b:{if(!kf(b,e+1576|0)){break b}if(!SO(e+1576|0)){break b}if(!c){f=1;break b}h[e+1575|0]=k[e+1576|3];d=e+1576|4;g=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=-1;if(k[e+1575|0]>=5){d=hf(b);if(!yb(b,d)){break b}}Q=hz(e+1560|0,g);n=j[Q>>2];j[114626]=0;g=K(830,b|0,n|0,g|0)|0;n=j[114626];j[114626]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((n|0)==1){break y}if(!g){break u}if(k[e+1575|0]>=5){j[114626]=0;E(256,b|0,d+12|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break y}}j[114626]=0;F(447,a|0,0);d=j[114626];j[114626]=0;if((d|0)==1){break y}j[114626]=0;N(476,a|0);d=j[114626];j[114626]=0;if((d|0)==1){break y}j[114626]=0;F(831,e+1536|0,Q|0);g=j[114626];j[114626]=0;d=a;z:{A:{B:{C:{if((g|0)==1){break C}j[114626]=0;r=K(832,e+1544|0,e+1536|0,0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break C}j[114626]=0;K(597,r|0,a+1304400|0,-1)|0;g=j[114626];j[114626]=0;if((g|0)==1){break B}j[114626]=0;K(597,r|0,a+1304424|0,-1)|0;g=j[114626];j[114626]=0;if((g|0)==1){break B}j[114626]=0;g=E(833,r|0,e+1112|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break e}if(!g|!k[e+1112|0]|h[e+1112|0]<0){break v}g=e+1121|0;if((k[g|0]|k[g+1|0]<<8)>>>0>255){break v}n=e+1123|0;if((k[n|0]|k[n+1|0]<<8)>>>0>3999){break v}i[a+480188>>1]=k[e+1112|0];q=a+484360|0;o=e+1112|3;Ge(Fb(q),k[o|0]|k[o+1|0]<<8);i[a+480192>>1]=k[g|0]|k[g+1|0]<<8;i[a+480190>>1]=k[n|0]|k[n+1|0]<<8;g=e+1125|0;if(k[g|0]){break A}g=6;break z}d=D()|0;C()|0;break c}d=D()|0;C()|0;break d}g=k[g|0]}j[d+480196>>2]=g;d=a;n=e+1126|0;g=125;D:{if(!k[n|0]){break D}g=k[n|0]}j[d+480204>>2]=p(g,1e4);v=e+1127|0;E:{if(h[v+1|0]&1){j[114626]=0;F(621,a|0,32);d=j[114626];j[114626]=0;if((d|0)!=1){break E}break e}if(k[v|0]&2){j[114626]=0;F(621,a|0,2);d=j[114626];j[114626]=0;if((d|0)==1){break e}break E}if(k[v|0]&128){j[114626]=0;F(621,a|0,1);d=j[114626];j[114626]=0;if((d|0)==1){break e}break E}if(k[v|0]&8){j[114626]=0;F(621,a|0,16);d=j[114626];j[114626]=0;if((d|0)==1){break e}break E}j[114626]=0;F(621,a|0,4);d=j[114626];j[114626]=0;if((d|0)==1){break e}}if(h[v|0]&1){j[a+480208>>2]=j[a+480208>>2]|16}if(!(!(k[v|0]&16)|j[a+480180>>2]!=2)){j[a+480208>>2]=j[a+480208>>2]|65536}if(!(!(k[v|0]&4)|j[a+480180>>2]!=2)){j[a+480208>>2]=j[a+480208>>2]|2}if(!(k[v+1|0]&8|j[a+480180>>2]!=32)){j[a+480208>>2]=j[a+480208>>2]|4}if(!(k[v+1|0]&4|j[a+480180>>2]!=32)){j[a+480208>>2]=j[a+480208>>2]|8}if(k[v+2|0]&32){j[a+480208>>2]=j[a+480208>>2]|32768}if(k[v+2|0]&8){j[114626]=0;K(478,a+1074308|0,5,1)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}}F:{d=j[a+480180>>2];G:{if((d|0)!=2){if((d|0)!=32){break G}d=k[e+1131|0];j[114626]=0;h[e+208|0]=d;h[e+136|0]=128;d=E(391,e+208|0,e+136|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break x}j[a+480200>>2]=k[d|0]<<1;break G}d=k[e+1131|0];j[114626]=0;h[e+208|0]=d;h[e+136|0]=64;d=E(391,e+208|0,e+136|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break F}j[a+480200>>2]=k[d|0]<<2}T=a+480188|0;n=e+1133|0;g=h[n|0];d=a;if(h[n|0]<=-1){g=g+52|0}else{S=zv(+(g|0)*.15500000000000003);H:{if(S<4294967296&S>=0){g=~~S>>>0;break H}g=0}g=g+51|0}j[d+480228>>2]=g;j[114626]=0;i[e+208>>1]=64;d=E(477,T|0,e+208|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){I:{g=l[d>>1];if(g){while(1){d=j[a+480180>>2];if((d|0)==32){d=k[(e+f|0)+1134|0];j[114626]=0;h[e+208|0]=d;h[e+136|0]=64;d=E(391,e+208|0,e+136|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break I}i[((f<<5)+a|0)+480286>>1]=k[d|0];d=j[a+480180>>2]}J:{if((d|0)==4){break J}d=(e+f|0)+1198|0;if(k[d|0]==127){j[((f<<5)+a|0)+480280>>2]=256;break J}if(k[d|0]==255){i[((f<<5)+a|0)+480284>>1]=256;break J}i[((f<<5)+a|0)+480284>>1]=k[d|0]}f=f+1|0;if((g|0)!=(f|0)){continue}break}}d=0;f=0;o=0;while(1){f=k[(e+o|0)+1262|0]!=0|f;o=o+1|0;if((o|0)!=16){continue}break}while(1){f=k[((d<<1)+e|0)+1279|0]!=0|f;d=d+1|0;if((d|0)!=128){continue}break}if(f&1){f=0;while(1){K:{d=(e+f|0)+1262|0;if(k[d|0]){j[114626]=0;F(508,e+136|0,15167);g=j[114626];j[114626]=0;L:{M:{N:{O:{P:{if((g|0)!=1){d=k[d|0];j[114626]=0;j[e+160>>2]=d-1;F(834,e+1096|0,e+160|0);d=j[114626];j[114626]=0;if((d|0)==1){break P}j[114626]=0;I(510,e+208|0,e+136|0,e+1096|0);d=j[114626];j[114626]=0;if((d|0)==1){break O}j[114626]=0;F(511,e+1080|0,((f<<5)+a|0)+901692|0);d=j[114626];j[114626]=0;if((d|0)==1){break N}j[114626]=0;E(470,e+1080|0,e+208|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break N}gb(e+208|0);gb(e+1096|0);qb(e+136|0);break K}d=D()|0;C()|0;break d}d=D()|0;C()|0;break L}d=D()|0;C()|0;break M}d=D()|0;C()|0;gb(e+208|0)}gb(e+1096|0)}qb(e+136|0);break d}j[114626]=0;g=E(85,e+208|0,15175)|0;d=j[114626];j[114626]=0;Q:{if((d|0)!=1){j[114626]=0;F(511,e+136|0,((f<<5)+a|0)+901692|0);d=j[114626];j[114626]=0;if((d|0)==1){break Q}j[114626]=0;E(470,e+136|0,g|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Q}gb(g);break K}d=D()|0;C()|0;break d}d=D()|0;C()|0;gb(g);break d}f=f+1|0;if((f|0)!=16){continue}break}f=0;while(1){d=(e+1112|0)+(f<<1)|0;g=d;R:{if(k[d+167|0]){j[114626]=0;F(508,e+136|0,15176);n=j[114626];j[114626]=0;S:{T:{U:{V:{W:{X:{Y:{if((n|0)!=1){g=k[g+167|0];j[114626]=0;j[e+112>>2]=g-1;F(834,e+1096|0,e+112|0);g=j[114626];j[114626]=0;if((g|0)==1){break Y}d=k[d+166|0];j[114626]=0;h[e+1064|0]=d;F(835,e+1080|0,e+1064|0);d=j[114626];j[114626]=0;if((d|0)==1){break X}j[114626]=0;L(836,e+208|0,e+136|0,e+1096|0,e+1080|0);d=j[114626];j[114626]=0;if((d|0)==1){break W}j[114626]=0;F(511,e+160|0,((f<<5)+a|0)+902204|0);d=j[114626];j[114626]=0;if((d|0)==1){break V}j[114626]=0;E(470,e+160|0,e+208|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break V}gb(e+208|0);gb(e+1080|0);gb(e+1096|0);qb(e+136|0);break R}d=D()|0;C()|0;break d}d=D()|0;C()|0;break S}d=D()|0;C()|0;break T}d=D()|0;C()|0;break U}d=D()|0;C()|0;gb(e+208|0)}gb(e+1080|0)}gb(e+1096|0)}qb(e+136|0);break d}j[114626]=0;g=E(85,e+208|0,15175)|0;d=j[114626];j[114626]=0;Z:{if((d|0)!=1){j[114626]=0;F(511,e+136|0,((f<<5)+a|0)+902204|0);d=j[114626];j[114626]=0;if((d|0)==1){break Z}j[114626]=0;E(470,e+136|0,g|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Z}gb(g);break R}d=D()|0;C()|0;break d}d=D()|0;C()|0;gb(g);break d}f=f+1|0;if((f|0)!=128){continue}break}}d=Fb(q);g=e+1112|1;g=k[g|0]|k[g+1|0]<<8;j[114626]=0;U(581,d|0,r|0,g|0,255,254)|0;d=j[114626];j[114626]=0;_:{$:{aa:{ba:{ca:{da:{if((d|0)!=1){g=e+1112|5;d=k[g|0]|k[g+1|0]<<8;n=k[e+1112|0];j[114626]=0;I(341,e+1096|0,r|0,p(d,n)<<1);d=j[114626];j[114626]=0;if((d|0)==1){break da}d=k[g|0]|k[g+1|0]<<8;j[114626]=0;I(341,e+1080|0,r|0,d<<1);d=j[114626];j[114626]=0;if((d|0)==1){break ca}d=e+1112|7;d=k[d|0]|k[d+1|0]<<8;j[114626]=0;O=E(395,e+1064|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break ba}X=e,Y=Lb(O),j[X+136>>2]=Y;X=e,Y=Mb(O),j[X+160>>2]=Y;if(rb(e+136|0,e+160|0)){while(1){d=j[e+136>>2];j[114626]=0;n=H(390,r|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break aa}j[114626]=0;I(341,e+208|0,r|0,n|0);n=j[114626];j[114626]=0;if((n|0)==1){break $}Ed(d,e+208|0);jb(e+208|0);yf(e+136|0);if(rb(e+136|0,e+160|0)){continue}break}}d=j[a+480180>>2];q=1;s=c&1;if(!s){break _}n=k[g|0]|k[g+1|0]<<8;j[114626]=0;F(401,a+484344|0,n|0);n=j[114626];j[114626]=0;if((n|0)!=1){break _}d=D()|0;C()|0;break h}d=D()|0;C()|0;break d}d=D()|0;C()|0;break d}d=D()|0;C()|0;break f}d=D()|0;C()|0;break g}d=D()|0;C()|0;break h}d=D()|0;C()|0;break h}ea:{fa:{ga:{ha:{ia:{ja:{if(k[g|0]|k[g+1|0]<<8){x=(d|0)==16?14:(d|0)==32?1:13;y=a+484344|0;while(1){j[114626]=0;d=H(357,e+1080|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break ea}j[e+136>>2]=d;ka:{if(!s){break ka}j[114626]=0;d=K(402,y|0,u&65535,d|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break ea}if(!d){break ka}w=0;if(!k[e+1112|0]){break ka}while(1){j[114626]=0;d=H(357,e+1096|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break fa}la:{if(Xc(O)>>>0<=d>>>0){break la}B=_b(O,d);rc(B);d=Ib(y,u);j[114626]=0;f=K(471,d|0,0,w&65535)|0;d=j[114626];j[114626]=0;if((d|0)==1){break i}n=0;if(!j[e+136>>2]){break la}while(1){j[114626]=0;A=H(387,B|0)|0;d=j[114626];j[114626]=0;ma:{na:{if((d|0)!=1){if(!A){break la}Ug(e+208|0);o=0;M=A&15;if(M){break na}break ma}d=D()|0;C()|0;break h}while(1){oa:{j[114626]=0;E(837,B|0,e+160|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break oa}pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{d=k[e+160|0];switch(d-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break ra;case 33:break va;case 30:case 31:break wa;case 29:break xa;case 28:break ya;case 26:break za;case 19:case 20:break Aa;case 17:break Ba;case 15:break Ca;case 14:break Da;case 10:break Ea;case 6:break Fa;case 5:break Ga;case 1:break Ha;case 0:break Ia;default:break Ja}}switch(d-48|0){case 4:break sa;case 1:case 2:break ta;case 0:break ua;default:break ra}}d=k[e+161|0];Ka:{if(d>>>0<=119){h[e+208|0]=d+x;break Ka}La:{switch(d-254|0){case 1:h[e+208|0]=255;break Ka;case 0:h[e+208|0]=254;break Ka;default:break La}}h[e+208|0]=253}j[114626]=0;d=H(611,e+208|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break oa}q=d&q;break pa}h[e+209|0]=k[e+161|0]+1;break pa}Ma:{if(k[e+210|0]){break Ma}d=j[a+480180>>2];if((d|0)!=32){if((d|0)!=4){break Ma}d=k[e+161|0];if(d&15){break Ma}h[e+210|0]=11;h[e+212|0]=d>>>4;break pa}d=0;t=k[e+161|0];while(1){if((t|0)==k[d+20832|0]){h[e+212|0]=d;h[e+210|0]=11;break pa}d=d+1|0;if((d|0)!=10){continue}break}}h[e+211|0]=4;h[e+213|0]=k[e+161|0];break pa}d=k[e+161|0];if(!(k[e+210|0]|d>>>0>9|j[a+480180>>2]!=32)){h[e+212|0]=d;h[e+210|0]=8;break pa}h[e+213|0]=d;h[e+211|0]=5;break pa}Na:{if(k[e+210|0]){break Na}Oa:{d=j[a+480180>>2];if((d|0)!=4){if((d|0)!=32){break Na}d=k[e+161|0];if((d|0)!=255){break Oa}h[e+212|0]=64;h[e+210|0]=2;break pa}d=k[e+161|0];if(d&15){break Na}break qa}if(!(d&3)){break qa}}h[e+211|0]=9;h[e+213|0]=k[e+161|0];break pa}d=k[e+161|0];if(!(k[e+210|0]|d>>>0>64|j[a+480180>>2]==1)){h[e+212|0]=d;h[e+210|0]=1;break pa}h[e+213|0]=d;h[e+211|0]=13;break pa}h[e+211|0]=14;d=k[e+161|0];h[e+213|0]=d;if(j[a+480180>>2]==32){break pa}h[e+213|0]=p((d&240)>>>4|0,10)+(d&15);break pa}d=k[e+161|0];h[e+213|0]=d;if(d>>>0<=31){h[e+211|0]=16;break pa}h[e+211|0]=17;break pa}t=k[e+161|0];if(t>>>0>=16){h[e+212|0]=t>>>4;h[e+210|0]=(d|0)==20?3:5;break pa}h[e+212|0]=t;h[e+210|0]=(d|0)==20?4:6;break pa}d=k[e+161|0];if(d>>>0>=16){h[e+210|0]=10;h[e+212|0]=d>>>4;break pa}h[e+212|0]=d;h[e+210|0]=9;break pa}h[e+211|0]=28;h[e+213|0]=k[e+161|0]|16;break pa}h[e+211|0]=28;h[e+213|0]=k[e+161|0]|32;break pa}h[e+212|0]=k[e+161|0];h[e+210|0]=k[d+15200|0];break pa}h[e+213|0]=k[e+161|0];d=k[e+211|0];h[e+211|0]=(d|0)==4?6:(d|0)==5?7:11;break pa}d=k[e+161|0];h[e+212|0]=(d>>>0)%10;if(d>>>0<=9){h[e+210|0]=5;break pa}if(d>>>0<=19){h[e+210|0]=6;break pa}if(d>>>0<=29){h[e+210|0]=3;break pa}if(d>>>0>39){break pa}h[e+210|0]=4;break pa}h[e+212|0]=k[e+161|0];h[e+210|0]=k[d+15200|0];break pa}d=k[e+161|0]+33|0;if((d&255)>>>0>9){break pa}h[e+212|0]=d;h[e+210|0]=15;break pa}if(d>>>0>55){break pa}h[e+213|0]=k[e+161|0];h[e+211|0]=k[d+15200|0];break pa}h[e+210|0]=2;h[e+212|0]=d>>>2}o=o+1|0;if(M>>>0>(o&255)>>>0){continue}break ma}break}d=D()|0;C()|0;break h}j[114626]=0;j[e+160>>2]=(A>>>4|0)+n;d=E(629,e+160|0,e+136|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break ja}d=j[d>>2];if(d>>>0>n>>>0){while(1){o=j[e+208>>2];h[f|0]=o;h[f+1|0]=o>>>8;h[f+2|0]=o>>>16;h[f+3|0]=o>>>24;o=l[e+212>>1];h[f+4|0]=o;h[f+5|0]=o>>>8;f=p(k[e+1112|0],6)+f|0;n=n+1|0;if((d|0)!=(n|0)){continue}break}n=d}if(m[e+136>>2]>n>>>0){continue}break}}w=w+1|0;if(k[e+1112|0]>(w&65535)>>>0){continue}break}}u=u+1|0;if(u>>>0<(k[g|0]|k[g+1|0]<<8)>>>0){continue}break}}if(!((q^1)&1|l[a+480188>>1]!=4|j[a+480180>>2]!=1)){j[a+480208>>2]=j[a+480208>>2]|8454144}if(j[a+480180>>2]!=4){break ia}o=0;break ha}d=D()|0;C()|0;break h}o=!((k[v|0]|k[v+1|0]<<8|(k[v+2|0]<<16|k[v+3|0]<<24))&512);d=0;if(j[a+480180>>2]!=4){break ga}}d=l[a+480192>>1]}j[114626]=0;A=E(838,e+1048|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){Pa:{Qa:{Ra:{if(l[a+480192>>1]){n=1;d=1;while(1){Sa:{Ta:{Ua:{if(!o){j[114626]=0;f=K(454,a|0,d&65535,0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break Ua}if(f){break Ta}}while(1){j[114626]=0;g=H(387,r|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break k}if(g){continue}break}if(k[e+1575|0]>=5){while(1){j[114626]=0;g=H(387,r|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){d=D()|0;C()|0;break j}if(g){continue}break}}j[114626]=0;E(338,r|0,826)|0;g=j[114626];j[114626]=0;if((g|0)!=1){break Sa}}d=D()|0;C()|0;break j}g=Db(e+136|0);j[114626]=0;K(597,r|0,g|0,-1)|0;q=j[114626];j[114626]=0;if((q|0)==1){break Ra}j[114626]=0;E(369,f+492|0,g|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break Ra}Va:{if(k[e+1575|0]<5){break Va}j[114626]=0;K(597,r|0,g|0,-1)|0;q=j[114626];j[114626]=0;if((q|0)==1){break Ra}j[114626]=0;E(369,f+524|0,g|0)|0;q=j[114626];j[114626]=0;if((q|0)!=1){break Va}break Ra}j[114626]=0;q=E(839,r|0,e+208|0)|0;u=j[114626];j[114626]=0;if((u|0)==1){break Ra}if(!q){break Qa}q=j[a+480180>>2];j[114626]=0;I(840,e+208|0,f|0,q|0);f=j[114626];j[114626]=0;if((f|0)==1){break Ra}if(j[a+480180>>2]==4){n=xb(A,n-1|0);f=l[e+1010>>1]|l[e+1012>>1]<<16;h[n|0]=f;h[n+1|0]=f>>>8;h[n+2|0]=f>>>16;h[n+3|0]=f>>>24}gb(g)}d=d+1|0;n=d&65535;if(n>>>0<=l[a+480192>>1]){continue}break}}if(!o){break Pa}i[a+480192>>1]=0;break Pa}d=D()|0;C()|0;gb(g);break j}gb(g)}d=l[a+480190>>1];j[114626]=0;B=E(841,e+192|0,d|0)|0;d=j[114626];j[114626]=0;w=1;Wa:{Xa:{if((d|0)!=1){w=k[e+1575|0]<=4?!(h[v|0]&1):w;if(l[a+480190>>1]){break Xa}u=c&2;g=0;break Wa}d=D()|0;C()|0;break j}u=c&2;o=1;d=0;n=1;while(1){g=d;y=Db(e+176|0);j[114626]=0;K(597,r|0,y|0,-1)|0;c=j[114626];j[114626]=0;Ya:{Za:{_a:{$a:{ab:{if((c|0)==1){break ab}j[114626]=0;E(369,((o<<5)+a|0)+946300|0,y|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break ab}s=p(o,104);q=s+a|0;if(k[e+1575|0]<5){break $a}j[114626]=0;K(597,r|0,y|0,-1)|0;c=j[114626];j[114626]=0;if((c|0)==1){break ab}j[114626]=0;E(370,q+484423|0,y|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break $a}}d=D()|0;C()|0;break _a}j[114626]=0;c=E(842,r|0,e+208|0)|0;d=j[114626];j[114626]=0;bb:{cb:{db:{eb:{fb:{gb:{hb:{if((d|0)==1){break hb}if(!c){break gb}c=j[a+480180>>2];j[114626]=0;f=q+484380|0;L(843,e+208|0,f|0,c|0,w|0);c=j[114626];j[114626]=0;if((c|0)==1){break hb}d=0;ib:{if(((k[e+228|0]|k[e+229|0]<<8)&61440)!=28672|k[e+1575|0]<5){break ib}j[114626]=0;d=H(844,r|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break ib}d=D()|0;C()|0;break _a}if(!u){break Za}M=k[e+228|0]|k[e+229|0]<<8;t=M&61440;if(!(t|(k[e+243|0]|k[e+244|0]<<8|(k[e+245|0]<<16|k[e+246|0]<<24)))){c=Mc(e+136|0,(k[e+228|0]|k[e+229|0]<<8)&1?16:8,(k[e+228|0]|k[e+229|0]<<8)&1024?3:1,0,0);j[114626]=0;K(400,c|0,f|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break Za}d=D()|0;C()|0;break _a}if(!(((k[e+243|0]|k[e+244|0]<<8|(k[e+245|0]<<16|k[e+246|0]<<24))+o|0)<1|(k[e+243|0]|k[e+244|0]<<8|(k[e+245|0]<<16|k[e+246|0]<<24))>-1)){d=a+484380|0;t=p((k[e+243|0]|k[e+244|0]<<8|(k[e+245|0]<<16|k[e+246|0]<<24))+o|0,104);c=d+t|0;kc(f,j[c>>2]);d=d+s|0;o=l[d+34>>1]&-2|i[c+34>>1]&1;i[d+34>>1]=o;i[d+34>>1]=l[c+34>>1]&64|o&65471;if(!ke(c)){break Za}j[114626]=0;c=H(465,f|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){if(!c){break Za}c=j[q+484400>>2];j[114626]=0;c=H(466,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[(a+t|0)+484400>>2];j[114626]=0;d=H(845,d|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break a}Vb(c,d,ik(f));break Za}d=D()|0;C()|0;break _a}if((k[e+243|0]|k[e+244|0]<<8|(k[e+245|0]<<16|k[e+246|0]<<24))<1){break Za}if(h[e+228|0]&1){c=q+484414|0;i[c>>1]=l[c>>1]|1}if(k[e+229|0]&4){c=q+484414|0;i[c>>1]=l[c>>1]|64}c=k[e+243|0]|k[e+244|0]<<8|(k[e+245|0]<<16|k[e+246|0]<<24);j[114626]=0;I(341,e+160|0,b|0,c|0);s=j[114626];j[114626]=0;jb:{kb:{W=e;lb:{mb:{if((s|0)!=1){s=be(f);c=(t|0)==16384;if((t|0)!=8192?!c:0){break kb}j[114626]=0;x=H(255,e+160|0)|0;R=j[114626];j[114626]=0;if((R|0)==1){break jb}j[e+136>>2]=x;R=j[e+136>>2];x=4/(s>>>0)|0;if(R>>>0>4294967295/(x>>>0)>>>0){break mb}x=p(x,R);break lb}d=D()|0;C()|0;break _a}x=-1}j[W+136>>2]=x;kc(f,x);if(!c){if((t|0)!=8192){break kb}j[114626]=0;c=H(465,f|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break cb}if(!c){break eb}if(h[e+228|0]&1){c=j[q+484400>>2];d=j[f>>2];j[114626]=0;L(846,e+160|0,c|0,d|0,s|0);c=j[114626];j[114626]=0;d=g;if((c|0)!=1){break db}break cb}c=j[q+484400>>2];d=j[f>>2];j[114626]=0;L(847,e+160|0,c|0,d|0,s|0);c=j[114626];j[114626]=0;d=g;if((c|0)==1){break cb}break db}j[114626]=0;c=H(465,f|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break cb}if(!c){break eb}if(h[e+228|0]&1){c=j[q+484400>>2];d=j[f>>2];j[114626]=0;L(848,e+160|0,c|0,d|0,s|0);c=j[114626];j[114626]=0;d=g;if((c|0)==1){break cb}break db}c=j[q+484400>>2];d=j[f>>2];j[114626]=0;L(849,e+160|0,c|0,d|0,s|0);c=j[114626];j[114626]=0;d=g;if((c|0)==1){break cb}break db}if((M&45056)==12288){c=QO(e+136|0,e+160|0,k[e+247|0]|k[e+248|0]<<8,d);d=Fy(B,o-1|0);Ed(d,c);j[d+16>>2]=j[c+16>>2];jb(c);break eb}if((t|0)!=32768){d=1;if((t|0)!=4096){break db}c=Ie(e+136|0,e+160|0);j[114626]=0;E(850,e+128|0,e+160|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){nb:{if(!k[e+133|0]){break nb}d=l[e+130>>1]<<1;if((d&65535)>>>0>(k[e+247|0]|k[e+248|0]<<8)>>>0){break nb}d=(k[e+247|0]|k[e+248|0]<<8)-d|0;h[e+247|0]=d;h[e+248|0]=d>>>8;j[114626]=0;E(256,e+160|0,l[e+128>>1])|0;d=j[114626];j[114626]=0;if((d|0)==1){break fb}j[114626]=0;d=H(540,e+160|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break fb}j[114626]=0;I(341,e+112|0,e+160|0,d|0);d=j[114626];j[114626]=0;if((d|0)==1){break fb}Ed(c,e+112|0);jb(e+112|0)}j[114626]=0;d=n&65535;o=U(851,a|0,d|0,c|0,1,1)|0;t=j[114626];j[114626]=0;if((t|0)==1){break fb}ob:{if(!o){j[114626]=0;o=P(852,a|0,d|0,c|0,1)|0;d=j[114626];j[114626]=0;if((d|0)==1){break fb}d=1;if(!o){break ob}}pb:{if(!(k[e+247|0]|k[e+248|0]<<8)){break pb}d=k[e+247|0]|k[e+248|0]<<8;if(ik(f)>>>0<=d>>>0){break pb}d=k[e+247|0]|k[e+248|0]<<8;o=xn(f);q=q+484400|0;t=j[q>>2];j[114626]=0;t=H(466,t|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break a}q=j[q>>2];j[114626]=0;q=H(466,q|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break a}Bi(t,q+(k[e+247|0]|k[e+248|0]<<8)|0,ik(f)-(k[e+247|0]|k[e+248|0]<<8)|0);j[f>>2]=j[f>>2]-((d>>>0)/(o>>>0)|0)}d=j[e+216>>2];j[e+108>>2]=d;j[e+12>>2]=d;if(m[f>>2]>(k[e+12|0]|k[e+13|0]<<8|(k[e+14|0]<<16|k[e+15|0]<<24))>>>0){j[f>>2]=k[e+12|0]|k[e+13|0]<<8|(k[e+14|0]<<16|k[e+15|0]<<24)}d=g}jb(c);break db}break fb}j[114626]=0;c=E(641,e+160|0,e+136|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){if(!c){break eb}j[114626]=0;j[e+24>>2]=j[e+144>>2];c=j[e+140>>2];j[e+16>>2]=j[e+136>>2];j[e+20>>2]=c;I(642,f|0,1,e+16|0);c=j[114626];j[114626]=0;if((c|0)!=1){break eb}}d=D()|0;C()|0;break bb}d=D()|0;C()|0;break bb}d=D()|0;C()|0;break _a}gb(y);break Wa}d=D()|0;C()|0;jb(c);break bb}d=g}jb(e+160|0);break Ya}d=D()|0;C()|0}jb(e+160|0)}gb(y);break l}d=g}gb(y);n=n+1|0;o=n&65535;if(o>>>0<=l[a+480190>>1]){continue}break}g=d}if(!(!u|!l[a+480190>>1])){d=1;n=1;while(1){c=Fy(B,d-1|0);j[114626]=0;b=H(337,c|0)|0;f=j[114626];j[114626]=0;qb:{rb:{sb:{if((f|0)!=1){if(!b){break qb}tb:{ub:{vb:{b=l[c+18>>1];wb:{if(!b){break wb}b=b+n&65535;if(!b){break wb}if(b>>>0<=l[a+480190>>1]){break vb}}j[114626]=0;H(255,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break ub}break m}b=Fy(B,b-1|0);f=l[c+16>>1];rc(b);o=l[c+16>>1];j[114626]=0;o=E(258,b|0,o|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break m}if(!o){break qb}j[114626]=0;j[e+136>>2]=0;j[e+160>>2]=0;I(853,e+208|0,b|0,f|0);f=j[114626];j[114626]=0;xb:{if((f|0)!=1){j[114626]=0;f=H(412,e+208|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break xb}j[114626]=0;f=H(854,f|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break xb}o=j[e+208>>2];j[114626]=0;o=H(855,o|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break xb}j[114626]=0;w=U(856,f|0,o|0,e+136|0,e+160|0,0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break xb}j[114626]=0;E(338,b|0,j[e+136>>2])|0;b=j[114626];j[114626]=0;if((b|0)==1){break xb}lc(e+208|0);b=1;break tb}d=D()|0;C()|0;break l}d=D()|0;C()|0;lc(e+208|0);break l}rc(c);j[e+136>>2]=0;j[e+160>>2]=0;w=0;b=0}j[114626]=0;F(857,e+208|0,c|0);f=j[114626];j[114626]=0;yb:{zb:{if((f|0)!=1){j[114626]=0;u=H(412,e+208|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break yb}q=j[e+208>>2];if(!b){j[114626]=0;b=H(854,u|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break sb}j[114626]=0;f=H(855,q|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break sb}j[114626]=0;w=U(856,b|0,f|0,e+136|0,e+160|0,0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break sb}j[114626]=0;E(338,c|0,j[e+136>>2])|0;b=j[114626];j[114626]=0;if((b|0)==1){break sb}b=j[e+136>>2];q=q-b|0;u=b+u|0}if(w){break zb}g=1;break rb}d=D()|0;C()|0;break l}j[114626]=0;d=p(d,104)+a|0;b=d+484380|0;H(465,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break sb}y=d+484400|0;t=d+484414|0;o=0;f=j[e+160>>2];while(1){Ab:{if(m[b>>2]<=o>>>0|(!q|(f|0)!=1?f:0)){break Ab}if(!ke(b)){break Ab}j[114626]=0;j[e+112>>2]=0;j[e+176>>2]=0;d=H(854,u|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break sb}j[114626]=0;f=H(855,q|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break sb}j[114626]=0;d=_(858,w|0,d|0,f|0,e+112|0,e+128|0,e+176|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break sb}j[114626]=0;j[e+136>>2]=d;E(338,c|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break sb}f=j[b>>2];j[114626]=0;d=j[e+136>>2];f=H(859,f-o|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break sb}Zj(e+176|0,f);Bb:{if(j[e+176>>2]<1){break Bb}if(j[e+112>>2]!=(be(b)|0)){break Bb}f=0;if(j[e+112>>2]<=0){break Bb}while(1){Cb:{if(h[t|0]&1){s=j[y>>2];x=be(b);M=j[j[e+128>>2]+(f<<2)>>2];j[114626]=0;V(860,s+(p(o,x)<<1)|0,M|0,j[e+112>>2],j[e+176>>2],f|0);s=j[114626];j[114626]=0;if((s|0)!=1){break Cb}break sb}s=j[y>>2];x=be(b);M=j[j[e+128>>2]+(f<<2)>>2];j[114626]=0;V(861,s+p(o,x)|0,M|0,j[e+112>>2],j[e+176>>2],f|0);s=j[114626];j[114626]=0;if((s|0)==1){break sb}}f=f+1|0;if((f|0)<j[e+112>>2]){continue}break}}j[114626]=0;s=j[e+176>>2];f=H(862,w|0)|0;x=j[114626];j[114626]=0;if((x|0)==1){break sb}q=q-d|0;u=d+u|0;j[e+160>>2]=f;o=o+s|0;continue}break}j[114626]=0;N(863,w|0);b=j[114626];j[114626]=0;if((b|0)!=1){break rb}break sb}break sb}d=D()|0;C()|0;break l}d=D()|0;C()|0;lc(e+208|0);break l}lc(e+208|0)}n=n+1|0;d=n&65535;if(d>>>0<=l[a+480190>>1]){continue}break}}Db:{if(j[a+480180>>2]!=4){break Db}f=0;while(1){if(l[a+480192>>1]<=f>>>0){break Db}b=k[xb(A,f)|0];c=k[xb(A,f)+1|0];d=k[xb(A,f)+2|0];n=k[xb(A,f)+3|0];j[114626]=0;f=f+1|0;aa(864,a|0,f&65535,b|0,c|0,d|0,n|0);b=j[114626];j[114626]=0;if((b|0)!=1){continue}break}d=D()|0;C()|0;break l}Eb:{Fb:{Gb:{Hb:{if(!(k[v+2|0]&16)){break Hb}j[114626]=0;b=E(258,r|0,1)|0;c=j[114626];j[114626]=0;if((c|0)==1){break n}if(!b){break Hb}j[114626]=0;b=H(387,r|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break o}if(!(!(b&1)|!l[T>>1])){f=0;while(1){j[114626]=0;b=H(390,r|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break Gb}h[((f<<5)+a|0)+480288|0]=b;f=f+1|0;if(f>>>0<l[a+480188>>1]){continue}break}}while(1){j[114626]=0;b=E(258,r|0,1)|0;c=j[114626];j[114626]=0;Ib:{if((c|0)!=1){if(!b){break Hb}j[114626]=0;b=H(387,r|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break Fb}if(!b){break Hb}j[114626]=0;c=H(390,r|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Eb}j[114626]=0;I(341,e+208|0,r|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break Eb}if(b>>>0>250){break Ib}j[114626]=0;F(667,e+208|0,(p(b,160)+a|0)+906140|0);b=j[114626];j[114626]=0;if((b|0)!=1){break Ib}d=D()|0;C()|0;jb(e+208|0);break l}d=D()|0;C()|0;break l}jb(e+208|0);continue}}n=a+901404|0;u=a+1074304|0;w=a+484344|0;b=Qc(e+112|0);o=0;q=0;Jb:{Kb:{while(1){j[114626]=0;c=E(258,r|0,8)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Jb}if(!c){break Kb}j[114626]=0;c=H(390,r|0)|0;d=j[114626];j[114626]=0;Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{_b:{$b:{if((d|0)!=1){j[114626]=0;d=H(390,r|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break $b}j[114626]=0;I(341,e+136|0,r|0,d|0);d=j[114626];j[114626]=0;if((d|0)==1){break _b}if((c|0)<=1397900629){if((c|0)==1229211981){break Yb}if((c|0)!=1229476432){break Mb}j[114626]=0;c=H(387,e+136|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break r}j[a+480216>>2]=c;j[114626]=0;c=H(387,e+136|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break r}j[a+480220>>2]=c;break Mb}if((c|0)==1397900630){break Zb}if((c|0)!=1414548815){break Mb}j[114626]=0;c=E(618,e+136|0,15275)|0;d=j[114626];j[114626]=0;if((d|0)==1){break r}if(!c){break Wb}j[114626]=0;c=H(390,e+136|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;I(341,e+160|0,e+136|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){break Xb}}d=D()|0;C()|0;break q}d=D()|0;C()|0;break p}d=D()|0;C()|0;break p}d=D()|0;C()|0;break p}ac:{bc:{cc:{c=j[a+480180>>2];switch(c-2|0){case 1:break Mb;case 0:break Nb;case 2:break bc;default:break cc}}if((c|0)==16){break ac}if((c|0)!=32){break Mb}j[114626]=0;o=H(357,e+136|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break r}j[114626]=0;q=H(357,e+136|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break Mb}break r}j[114626]=0;j[e+208>>2]=32;c=H(255,e+136|0)|0;d=j[114626];j[114626]=0;dc:{if((d|0)==1){break dc}j[114626]=0;j[e+160>>2]=c;c=E(33,e+208|0,e+160|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break dc}c=j[c>>2];j[114626]=0;P(865,e+136|0,b|0,4,c|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break Mb}}d=D()|0;C()|0;break q}j[114626]=0;d=H(387,e+136|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break Lb}j[114626]=0;c=E(2,e+96|0,15256)|0;f=j[114626];j[114626]=0;ec:{fc:{gc:{if((f|0)!=1){j[114626]=0;F(219,e+160|0,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break gc}j[114626]=0;j[e+176>>2]=d>>>4;j[e+128>>2]=d&15;L(533,e+208|0,e+160|0,e+176|0,e+128|0);d=j[114626];j[114626]=0;if((d|0)==1){break fc}ob(b,e+208|0);gb(e+208|0);qb(e+160|0);gb(c);break Mb}d=D()|0;C()|0;break q}d=D()|0;C()|0;break ec}d=D()|0;C()|0;qb(e+160|0)}gb(c);break q}j[114626]=0;E(633,e+136|0,n|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break r}j[114626]=0;N(634,n|0);c=j[114626];j[114626]=0;if((c|0)==1){break r}break Mb}j[114626]=0;c=H(255,e+160|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Vb}i[e+208>>1]=c>>>5;c=me(w);j[114626]=0;i[e+176>>1]=c;c=E(477,e+208|0,e+176|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Vb}c=l[c>>1];if(c){d=0;while(1){j[114626]=0;K(866,e+160|0,e+208|0,32)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Vb}f=Ib(w,d);j[114626]=0;E(867,f|0,e+208|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Vb}d=d+1|0;if((c|0)!=(d|0)){continue}break}}jb(e+160|0)}j[114626]=0;c=E(618,e+136|0,15280)|0;d=j[114626];j[114626]=0;if((d|0)==1){break r}if(!c){break Tb}j[114626]=0;c=H(390,e+136|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;I(341,e+208|0,e+136|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){break Ub}}d=D()|0;C()|0;break q}d=D()|0;C()|0;jb(e+160|0);break q}j[114626]=0;c=H(255,e+208|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Sb}i[e+160>>1]=(c>>>0)/20;c=l[a+480188>>1];j[114626]=0;i[e+176>>1]=c;c=E(477,e+160|0,e+176|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Sb}c=l[c>>1];if(c){f=0;while(1){j[114626]=0;K(636,e+208|0,((f<<5)+a|0)+480289|0,20)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Sb}f=f+1|0;if((c|0)!=(f|0)){continue}break}}jb(e+208|0)}j[114626]=0;E(653,a|0,e+136|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break r}j[114626]=0;L(654,a|0,e+136|0,1,0);c=j[114626];j[114626]=0;if((c|0)==1){break r}if((o-2186&65535)>>>0<=117){j[a+480180>>2]=16777216;j[114626]=0;I(665,a|0,e+136|0,o&65535);c=j[114626];j[114626]=0;if((c|0)==1){break r}}if(!j[u>>2]){break Mb}j[114626]=0;c=E(2,e+160|0,15285)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Rb}j[114626]=0;F(242,e+176|0,u|0);d=j[114626];j[114626]=0;if((d|0)==1){break Qb}j[114626]=0;I(3,e+208|0,c|0,e+176|0);d=j[114626];j[114626]=0;if((d|0)==1){break Pb}ob(b,e+208|0);gb(e+208|0);gb(e+176|0);gb(c);break Mb}d=D()|0;C()|0;jb(e+208|0);break q}d=D()|0;C()|0;break q}d=D()|0;C()|0;break Ob}d=D()|0;C()|0;gb(e+176|0)}gb(c);break q}j[114626]=0;o=H(357,e+136|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break r}}jb(e+136|0);continue}break}d=D()|0;C()|0;break q}hc:{ic:{jc:{kc:{if(!((o&65504)!=4864|j[a+480180>>2]!=2?!((j[a+480180>>2]==32?(o-256&65535)>>>0<=275:0)|(j[a+480180>>2]==2?(o-12544&65535)>>>0<=275:0)):0)){j[114626]=0;N(635,n|0);c=j[114626];j[114626]=0;if((c|0)==1){break kc}}if(!(h[v+2|0]&1)){break hc}if(!(j[a+1074304>>2]|!l[a+480192>>1])){f=1;while(1){c=j[(((f&65535)<<2)+a|0)+900380>>2];if(c){j[114626]=0;d=E(374,c|0,2)|0;n=j[114626];j[114626]=0;if((n|0)==1){break jc}n=j[a+480180>>2];j[114626]=0;I(868,d|0,4,n|0);d=j[114626];j[114626]=0;if((d|0)==1){break ic}h[c+19|0]=k[c+19|0]+3>>>2}f=f+1|0;if(l[a+480192>>1]>=(f&65535)>>>0){continue}break}}if(m[a+1074304>>2]<18350080){j[114626]=0;c=a+1074308|0;E(479,c|0,27)|0;d=j[114626];j[114626]=0;if((d|0)==1){break kc}j[114626]=0;E(479,c|0,57)|0;c=j[114626];j[114626]=0;if((c|0)==1){break kc}}if(m[a+1074304>>2]<19070976){j[114626]=0;E(479,a+1074308|0,73)|0;c=j[114626];j[114626]=0;if((c|0)==1){break kc}}if(m[a+1074304>>2]>=19267584){break hc}j[114626]=0;E(479,a+1074308|0,50)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break hc}}d=D()|0;C()|0;break p}d=D()|0;C()|0;break p}d=D()|0;C()|0;break p}lc:{mc:{nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{wc:{xc:{yc:{zc:{Ac:{Bc:{Cc:{if(Ec(b)){j[114626]=0;c=E(2,e+80|0,15294)|0;d=j[114626];j[114626]=0;Dc:{Ec:{Fc:{if((d|0)!=1){j[114626]=0;F(219,e+136|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break Fc}j[114626]=0;I(536,e+208|0,e+136|0,e+1575|0);d=j[114626];j[114626]=0;if((d|0)==1){break Ec}break Cc}d=D()|0;C()|0;break p}d=D()|0;C()|0;break Dc}d=D()|0;C()|0;qb(e+136|0)}gb(c);break p}j[114626]=0;c=E(2,e- -64|0,15302)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Bc}j[114626]=0;F(219,e+136|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break Ac}j[114626]=0;L(451,e+208|0,e+136|0,e+1575|0,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break zc}}ob(b,e+208|0);gb(e+208|0);qb(e+136|0);gb(c);j[114626]=0;c=E(2,e+48|0,15315)|0;d=j[114626];j[114626]=0;if((d|0)==1){break wc}j[114626]=0;F(219,e+136|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break vc}j[114626]=0;I(536,e+208|0,e+136|0,e+1575|0);d=j[114626];j[114626]=0;if((d|0)==1){break uc}ob(a+1304436|0,e+208|0);gb(e+208|0);qb(e+136|0);gb(c);j[114626]=0;c=E(2,e+208|0,15331)|0;d=j[114626];j[114626]=0;if((d|0)==1){break sc}ob(a+1304448|0,c);gb(c);c=j[a+480180>>2];if((c|0)>15){break xc}switch(c-1|0){case 1:break oc;case 3:break pc;case 0:break qc;default:break w}}d=D()|0;C()|0;break p}d=D()|0;C()|0;break yc}d=D()|0;C()|0;qb(e+136|0)}gb(c);break p}if((c|0)==16){break rc}if((c|0)==32){break nc}if((c|0)!=16777216){break w}j[114626]=0;c=E(2,e+208|0,15446)|0;d=j[114626];j[114626]=0;if((d|0)==1){break mc}ob(a+1304484|0,c);gb(c);j[114626]=0;c=E(2,e+208|0,15451)|0;d=j[114626];j[114626]=0;if((d|0)==1){break lc}ob(a+1304472|0,c);gb(c);break w}d=D()|0;C()|0;break p}d=D()|0;C()|0;break tc}d=D()|0;C()|0;qb(e+136|0)}gb(c);break p}d=D()|0;C()|0;break p}j[114626]=0;c=E(2,e+208|0,15335)|0;d=j[114626];j[114626]=0;Gc:{if((d|0)!=1){ob(a+1304484|0,c);gb(c);j[114626]=0;c=E(2,e+208|0,15339)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Gc}ob(a+1304472|0,c);gb(c);break w}d=D()|0;C()|0;break p}d=D()|0;C()|0;break p}j[114626]=0;c=E(2,e+208|0,15352)|0;d=j[114626];j[114626]=0;Hc:{if((d|0)!=1){ob(a+1304484|0,c);gb(c);j[114626]=0;c=E(2,e+208|0,15356)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Hc}ob(a+1304472|0,c);gb(c);break w}d=D()|0;C()|0;break p}d=D()|0;C()|0;break p}j[114626]=0;c=E(2,e+208|0,15368)|0;d=j[114626];j[114626]=0;Ic:{if((d|0)!=1){ob(a+1304484|0,c);gb(c);j[114626]=0;c=E(2,e+208|0,15371)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Ic}ob(a+1304472|0,c);gb(c);break w}d=D()|0;C()|0;break p}d=D()|0;C()|0;break p}j[114626]=0;c=E(2,e+208|0,15385)|0;d=j[114626];j[114626]=0;Jc:{if((d|0)!=1){ob(a+1304484|0,c);gb(c);j[114626]=0;c=E(2,e+208|0,15389)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Jc}ob(a+1304472|0,c);gb(c);break w}d=D()|0;C()|0;break p}d=D()|0;C()|0;break p}j[114626]=0;c=E(2,e+208|0,15405)|0;d=j[114626];j[114626]=0;Kc:{Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{if((d|0)!=1){ob(a+1304484|0,c);gb(c);if(!(q&65535)){break Kc}j[114626]=0;c=E(2,e+32|0,15408)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Qc}j[114626]=0;F(219,e+136|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break Pc}j[114626]=0;j[e+176>>2]=(q&65280)>>>8;j[e+128>>2]=q&255;F(661,e+160|0,e+128|0);d=j[114626];j[114626]=0;if((d|0)==1){break Oc}j[114626]=0;L(646,e+208|0,e+136|0,e+176|0,e+160|0);d=j[114626];j[114626]=0;if((d|0)==1){break Nc}ob(a+1304472|0,e+208|0);gb(e+208|0);gb(e+160|0);qb(e+136|0);gb(c);break w}d=D()|0;C()|0;break p}d=D()|0;C()|0;break p}d=D()|0;C()|0;break Lc}d=D()|0;C()|0;break Mc}d=D()|0;C()|0;gb(e+160|0)}qb(e+136|0)}gb(c);break p}j[114626]=0;c=E(2,e+208|0,15430)|0;d=j[114626];j[114626]=0;if((d|0)!=1){ob(a+1304472|0,c);gb(c);break w}d=D()|0;C()|0;break p}d=D()|0;C()|0;break p}d=D()|0;C()|0;break p}d=D()|0;C()|0;break p}d=D()|0;C()|0;break l}d=D()|0;C()|0;break l}d=D()|0;C()|0;break l}d=D()|0;C()|0;break h}d=D()|0;C()|0;break h}d=D()|0;C()|0;break h}d=D()|0;C()|0;break d}d=D()|0;C()|0;break d}d=D()|0;C()|0;break d}d=D()|0;C()|0;break c}d=D()|0;C()|0;break d}ob(a+1304460|0,b);Rc:{if(j[a+1074304>>2]){j[a+1304496>>2]=7;break Rc}if(j[a+480180>>2]==1){j[a+1304496>>2]=2;break Rc}j[a+1304496>>2]=4}f=1;if(g&1){j[114626]=0;c=E(2,e+208|0,15464)|0;d=j[114626];j[114626]=0;if((d|0)==1){break t}j[114626]=0;I(647,a|0,2,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break s}gb(c)}gb(b);PO(B);OO(A);Sc(O);jb(e+1080|0);jb(e+1096|0)}jb(r)}Od(Q);break b}d=D()|0;C()|0;break p}d=D()|0;C()|0;gb(c);break p}d=D()|0;C()|0}jb(e+136|0)}gb(b);break l}d=D()|0;C()|0;break l}d=D()|0;C()|0;break l}d=D()|0;C()|0}PO(B);break j}d=D()|0;C()|0}OO(A);break h}d=D()|0;C()|0}Sc(O)}jb(e+1080|0)}jb(e+1096|0);break d}d=D()|0;C()|0}jb(r)}Od(Q);G(d|0);z()}Za=e+1584|0;return f|0}a=J(0)|0;C()|0;ib(a);z()}function BDa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,J=0,M=0,O=0,Q=0,R=0,S=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;d=Za-912|0;Za=d;rc(b);a:{if(!mP(b,d+856|0)){break a}if(!oP(d+856|0)){break a}if(!yb(b,Wc(nP(d+856|0),ab))){break a}if(!c){f=1;break a}od(a,8);_h(a);h[d+855|0]=k[d+856|3]-48;e=k[d+864|0]|k[d+865|0]<<8|(k[d+866|0]<<16|k[d+867|0]<<24);xc(b,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24));cd(d+832|0,b,504);j[114626]=0;E(771,b|0,d+544|0)|0;e=j[114626];j[114626]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((e|0)!=1){if(k[d+544|0]&128|k[d+827|0]>63){break b}Ab(d+464|0,0,80);o:{if(!(k[d+888|0]|k[d+889|0]<<8|(k[d+890|0]<<16|k[d+891|0]<<24))){break o}e=k[d+888|0]|k[d+889|0]<<8|(k[d+890|0]<<16|k[d+891|0]<<24);j[114626]=0;e=E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;g=j[114626];j[114626]=0;if((g|0)!=1){if(!e){break o}j[114626]=0;E(772,b|0,d+464|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break o}}f=D()|0;C()|0;break e}j[114626]=0;I(773,d+456|0,b|0,k[d+855|0]);e=j[114626];j[114626]=0;if((e|0)!=1){_=Bf(d+456|0);e=l[d+456>>1];if((e-1&65535)>>>0>126){break b}i[a+480188>>1]=e;S=d+440|0;iDa(S);p:{if(k[d+880|0]|k[d+881|0]<<8|(k[d+882|0]<<16|k[d+883|0]<<24)){e=k[d+880|0]|k[d+881|0]<<8|(k[d+882|0]<<16|k[d+883|0]<<24);j[114626]=0;E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;e=j[114626];j[114626]=0;if((e|0)!=1){e=k[d+827|0];j[114626]=0;K(774,b|0,S|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break p}}f=D()|0;C()|0;break f}if(k[d+827|0]){break c}}e=k[d+827|0];i[a+480192>>1]=e;i[a+480190>>1]=e;$=1;if(k[d+855|0]>=2){$=h[d+808|0]>-1;e=l[a+480192>>1]}if(e&65535){T=c&2;W=$^1;x=d+80|2;X=d+80|7;Y=d+80|6;A=d+80|5;B=d+80|4;u=d+56|4;n=1;s=1;t=1;while(1){j[114626]=0;O=t&65535;e=K(454,a|0,s&65535,O|0)|0;g=j[114626];j[114626]=0;q:{r:{if((g|0)!=1){if(!e){break d}o=j[((n<<2)+a|0)+900380>>2];j[114626]=0;i[d+60>>1]=0;j[d+56>>2]=0;w=H(277,d+152|0)|0;e=j[114626];j[114626]=0;s:{t:{u:{if((e|0)!=1){g=n-1|0;e=xb(S,g);v:{if(!(k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))){break v}e=xb(S,g);e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);j[114626]=0;e=E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;g=j[114626];j[114626]=0;if((g|0)==1){break g}if(!e){break v}j[114626]=0;E(775,b|0,d+56|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break g}e=k[d+56|0]|k[d+57|0]<<8|(k[d+58|0]<<16|k[d+59|0]<<24);j[114626]=0;I(341,d+80|0,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));e=j[114626];j[114626]=0;if((e|0)==1){break g}Ed(w,d+80|0);jb(d+80|0)}g=k[u+1|0]&15;v=(k[u|0]|k[u+1|0]<<8)&128;if(!v){break u}j[114626]=0;F(776,o|0,0);e=j[114626];j[114626]=0;ea=1;if((e|0)!=1){break t}break g}f=D()|0;C()|0;break f}if(g>>>0>=7){break t}e=k[g+14806|0];if(!g){g=e;break r}i[a+480190>>1]=(l[a+480190>>1]+e|0)-1;g=o+108|0;n=o+236|0;M=e-2|0;q=4;while(1){r=q-4|0;f=M<<3;J=r+(f+14864|0)|0;r=k[r+(f+14816|0)|0]+t|0;y=p(q,12);f=0;while(1){Q=f+y|0;ma=Oc(n,Q),na=r,i[ma>>1]=na;Q=Pb(g,Q);h[Q|0]=k[Q|0]+k[J|0];f=f+1|0;if((f|0)!=12){continue}break}r=1;q=q+1|0;if((q|0)!=10){continue}break}g=e;break s}e=1;if((g|0)!=7){g=1;break r}r=0;j[114626]=0;F(777,o|0,-24);e=j[114626];j[114626]=0;g=1;if((e|0)==1){break g}e=1}M=1;break q}f=D()|0;C()|0;break f}r=0;if(v|W){break q}n=o+108|0;q=7;while(1){r=p(q,12);J=p(q,-12)+72|0;f=0;while(1){y=Pb(n,f+r|0);h[y|0]=J+k[y|0];f=f+1|0;if((f|0)!=12){continue}break}q=q+1|0;if((q|0)!=10){continue}break}r=0}j[114626]=0;E(778,d+832|0,d+80|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break g}if(!(!k[B|0]|k[B|0]>16)){h[o+31|0]=k[B|0];M=1}if(!(!k[A|0]|k[A|0]>128)){h[o+30|0]=k[A|0]}if(g){n=0;o=0;while(1){j[114626]=0;f=p(n+O|0,104)+a|0;F(386,f+484380|0,8);n=j[114626];j[114626]=0;if((n|0)==1){break g}n=k[Y|0];j[114626]=0;h[d+408|0]=n;h[d+136|0]=64;n=E(391,d+408|0,d+136|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break g}i[f+484410>>1]=k[n|0]<<2;h[f+484416|0]=k[X|0];o=o+1|0;n=o&65535;if(n>>>0<g>>>0){continue}break}}w:{if(v|!T){break w}v=Mc(d+408|0,8,1,1,0);n=k[x|0]|k[x+1|0]<<8;o=k[d+80|0]|k[d+81|0]<<8;q=k[x|0]|k[x+1|0]<<8;j[114626]=0;f=H(255,w|0)|0;J=j[114626];j[114626]=0;if((J|0)==1){break g}if(k[u+1|0]&16){rz(v);f=f>>>1|0}if(k[u+1|0]&32){lA(v);f=f>>>1|0}if(k[u+1|0]&64){dj(v,2)}f=r?(f>>>0)/((-1<<g^-1)>>>0)|0:f;if(!g){break w}o=(o<<8&16711680|o<<24)>>>16|0;r=o+((q<<8&16711680|q<<24)>>>16|0)|0;J=(n<<8&16711680|n<<24)>>>16|0;n=0;q=0;while(1){n=p(n+O|0,104)+a|0;y=n+484380|0;j[y>>2]=f;j[114626]=0;K(400,v|0,y|0,w|0)|0;y=j[114626];j[114626]=0;if((y|0)==1){break g}o=o<<1;r=r<<1;if(J>>>0>=2){j[n+484388>>2]=r;j[n+484384>>2]=o;n=n+484414|0;i[n>>1]=l[n>>1]|2}f=f<<1;q=q+1|0;n=q&65535;if(n>>>0<g>>>0){continue}break}}jb(w);t=e+t|0;s=s+1|0;n=s&65535;if(n>>>0<=l[a+480192>>1]){continue}break}}e=d+464|4;x:{if(!(k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))|!(k[d+472|0]|k[d+473|0]<<8)){break x}e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);j[114626]=0;e=E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;g=j[114626];j[114626]=0;if((g|0)==1){break h}if(!e){break x}e=k[d+472|0]|k[d+473|0]<<8;i[d+152>>1]=(e<<24|e<<8&16711680)>>>16;e=k[d+827|0];j[114626]=0;i[d+80>>1]=e;e=E(477,d+152|0,d+80|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break i}t=l[e>>1];if(!t){break x}q=d+152|5;u=d+152|3;r=d+152|1;g=d+88|0;w=d+80|4;e=k[d+474|0]|k[d+475|0]<<8;o=(e<<24|e<<8&16711680)>>>16|0;x=o>>>0<19;v=o>>>0<21;A=o>>>0<15;n=0;while(1){j[114626]=0;K(779,b|0,d+152|0,o|0)|0;e=j[114626];j[114626]=0;y:{z:{A:{if((e|0)!=1){n=n+1|0;e=j[((n<<2)+a|0)+900380>>2];if(!k[d+152|0]){break y}M=ep(d+80|0,0,64);ep(w,k[d+152|0]-1&65535,64);B=k[d+152|0];ep(g,B+(k[r|0]?64/k[r|0]|0:0)|0,0);j[114626]=0;j[d+436>>2]=3;j[d+432>>2]=M;f=j[d+436>>2];j[d+8>>2]=j[d+432>>2];j[d+12>>2]=f;f=e+48|0;F(780,f|0,d+8|0);s=j[114626];j[114626]=0;if((s|0)==1){break A}if(k[d+152|0]!=1){break z}ma=d,na=Lb(f),j[ma+80>>2]=na;Cd(d+424|0,d+80|0);j[114626]=0;E(781,f|0,j[d+424>>2])|0;f=j[114626];j[114626]=0;if((f|0)!=1){break z}f=D()|0;C()|0;break f}f=D()|0;C()|0;break f}f=D()|0;C()|0;break f}f=e;if(k[r|0]){s=k[r|0]<<9}else{s=32767}j[f>>2]=s;M=1;h[e+60|0]=k[e+60|0]|1}B:{if(x){break B}j[e+4>>2]=k[d+170|0]+1>>>1;if(v){break B}i[e+28>>1]=k[d+172|0]|k[d+173|0]<<8}e=p(l[Oc(e+236|0,61)>>1],104)+a|0;h[e+484417|0]=k[u|0]<<4;C:{D:{if(!A){f=k[d+162|0]|k[d+163|0]<<8|(k[d+164|0]<<16|k[d+165|0]<<24);j[e+484384>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);f=k[d+166|0]|k[d+167|0]<<8|(k[d+168|0]<<16|k[d+169|0]<<24);s=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);f=k[d+162|0]|k[d+163|0]<<8|(k[d+164|0]<<16|k[d+165|0]<<24);j[e+484388>>2]=s+(f<<8&16711680|f<<24|(f>>>8&65280|f>>>24));break D}if(o>>>0<6){break C}}if(h[q|0]&1){f=e+484414|0;i[f>>1]=l[f>>1]|2}if(k[q|0]&8){f=e+484414|0;i[f>>1]=l[f>>1]|6}if(!(k[q|0]&4)){break C}i[e+484412>>1]=0}if((n|0)!=(t|0)){continue}break}}if(!(k[d+484|0]|k[d+485|0]<<8|(k[d+486|0]<<16|k[d+487|0]<<24))|!(k[d+488|0]|k[d+489|0]<<8)){break j}e=k[d+484|0]|k[d+485|0]<<8|(k[d+486|0]<<16|k[d+487|0]<<24);j[114626]=0;e=E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;g=j[114626];j[114626]=0;if((g|0)==1){break h}if(!e){break j}e=k[d+488|0]|k[d+489|0]<<8;i[d+152>>1]=(e<<24|e<<8&16711680)>>>16;e=k[d+827|0];j[114626]=0;i[d+80>>1]=e;e=E(477,d+152|0,d+80|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){r=l[e>>1];if(!r){break j}e=k[d+490|0]|k[d+491|0]<<8;o=(e<<24|e<<8&16711680)>>>16|0;e=0;E:while(1){F:{j[114626]=0;K(782,b|0,d+152|0,o|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break k}j[114626]=0;I(783,d+56|0,2,d+152|0);g=j[114626];j[114626]=0;if((g|0)==1){break l}j[114626]=0;F(415,d+80|0,d+56|0);g=j[114626];j[114626]=0;if((g|0)==1){break l}e=e+1|0;n=((e<<2)+a|0)+900380|0;g=j[n>>2];j[114626]=0;E(369,g+492|0,d+80|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break m}gb(d+80|0);g=j[n>>2];j[114626]=0;F(784,d+80|0,g|0);g=j[114626];j[114626]=0;if((g|0)==1){break n}ma=d,na=Wm(d+80|0),j[ma+56>>2]=na;ma=d,na=ki(d+80|0),j[ma+408>>2]=na;while(1){j[114626]=0;g=E(785,d+56|0,d+408|0)|0;f=j[114626];j[114626]=0;G:{if((f|0)!=1){if(g){break G}cp(d+80|0);if((e|0)!=(r|0)){continue E}break j}break F}j[114626]=0;g=H(786,d+56|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){f=(l[g>>1]<<5)+a|0;q=f+946324|0;g=j[n>>2];s=j[g+520>>2];j[q>>2]=j[g+516>>2];j[q+4>>2]=s;s=j[g+512>>2];q=f+946316|0;j[q>>2]=j[g+508>>2];j[q+4>>2]=s;s=j[g+504>>2];q=f+946308|0;j[q>>2]=j[g+500>>2];j[q+4>>2]=s;q=j[g+496>>2];f=f+946300|0;j[f>>2]=j[g+492>>2];j[f+4>>2]=q;Os(d+56|0);continue}break}}break}f=D()|0;C()|0;cp(d+80|0);break f}f=D()|0;C()|0;break f}f=D()|0;C()|0;break e}f=D()|0;C()|0;break e}f=D()|0;C()|0;break f}f=D()|0;C()|0;gb(d+80|0);break f}f=D()|0;C()|0;break f}f=D()|0;C()|0;break f}j[114626]=0;N(635,a+901404|0);e=j[114626];j[114626]=0;if((e|0)==1){break h}e=a+901692|0;g=k[14912]|k[14913]<<8|(k[14914]<<16|k[14915]<<24);h[e|0]=g;h[e+1|0]=g>>>8;h[e+2|0]=g>>>16;h[e+3|0]=g>>>24;h[a+901696|0]=k[14916];rc(b);H:{I:{J:{K:{L:{M:{N:{if(!k[_|0]){break N}fa=c&1;x=a+484344|0;A=a+1304424|0;Y=a+1304400|0;J=a+484360|0;ga=d+152|1;o=d+152|4;c=d+32|4;y=d+32|2;Q=d+72|2;ha=d+72|3;u=d+544|2;v=0;W=0;while(1){j[114626]=0;L(787,b|0,d+856|0,d+464|0,d+544|0);e=j[114626];j[114626]=0;O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((e|0)==1){break W}e=W&255;if(e){j[114626]=0;g=H(485,J|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break W}if((g|0)==255){break d}}q=gi(J,e);w=qDa(d+408|0);wp(q);if(k[d+855|0]>1){break U}e=k[u|0]|k[u+1|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0>256|l[a+480188>>1]>16){break S}jP(d+152|0,d+544|0);e=k[u|0]|k[u+1|0]<<8;j[114626]=0;U(788,q|0,d+152|0,(e<<8&16711680|e<<24)>>>16|0,65535,65535)|0;e=j[114626];j[114626]=0;if((e|0)==1){break T}ma=d,na=Lb(q),j[ma+152>>2]=na;ma=d,na=Mb(q),j[ma+80>>2]=na;if(rb(d+152|0,d+80|0)){break V}break Q}f=D()|0;C()|0;break f}while(1){e=j[d+152>>2];i[e>>1]=l[e>>1]+v;je(d+152|0);if(rb(d+152|0,d+80|0)){continue}break}break Q}jP(d+152|0,d+544|0);if(!(k[d+164|0]|k[d+165|0]<<8)){break S}e=k[d+164|0]|k[d+165|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0>64|l[a+480188>>1]>64){break S}s=k[d+172|0]|k[d+173|0]<<8|(k[d+174|0]<<16|k[d+175|0]<<24);if(!(k[d+176|0]|k[d+177|0]<<8)){r=32;break R}e=k[d+176|0]|k[d+177|0]<<8;j[114626]=0;i[d+80>>1]=(e<<8&16711680|e<<24)>>>16;i[d+56>>1]=800;e=E(477,d+80|0,d+56|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){e=l[e>>1];j[114626]=0;r=ig(789,((e<<5)+50>>>0)/100|0,0);e=j[114626];j[114626]=0;if((e|0)!=1){break R}}f=D()|0;C()|0;break H}f=D()|0;C()|0;break H}bp(w);break d}e=k[d+160|0]|k[d+161|0]<<8|(k[d+162|0]<<16|k[d+163|0]<<24);j[114626]=0;e=E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;g=j[114626];j[114626]=0;X:{if((g|0)==1){break X}Y:{if(!e){break Y}f=0;if(!l[a+480188>>1]){break Y}Z:{while(1){_:{j[114626]=0;e=H(387,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break _}j[114626]=0;h[d+80|0]=e;h[d+56|0]=64;e=E(391,d+80|0,d+56|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break Z}i[((f<<5)+a|0)+480286>>1]=k[e|0];f=f+1|0;if(f>>>0<l[a+480188>>1]){continue}break Y}break}f=D()|0;C()|0;break H}f=D()|0;C()|0;break H}$:{aa:{if(!(k[d+168|0]|k[d+169|0]<<8|(k[d+170|0]<<16|k[d+171|0]<<24))){break aa}e=k[d+168|0]|k[d+169|0]<<8|(k[d+170|0]<<16|k[d+171|0]<<24);j[114626]=0;e=E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;g=j[114626];j[114626]=0;if((g|0)==1){break X}if(!e){break aa}f=0;if(!l[a+480188>>1]){break $}while(1){ba:{j[114626]=0;e=H(790,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break ba}ma=((f<<5)+a|0)+480284|0,na=(Gb(e,-16,16)<<3)+128|0,i[ma>>1]=na;f=f+1|0;if(f>>>0<l[a+480188>>1]){continue}break $}break}f=D()|0;C()|0;break H}j[114626]=0;F(449,a|0,1);e=j[114626];j[114626]=0;if((e|0)==1){break X}}e=d+136|0;cDa(e);g=k[o|0]|k[o+1|0]<<8|(k[o+2|0]<<16|k[o+3|0]<<24);j[114626]=0;g=E(256,b|0,g<<8&16711680|g<<24|(g>>>8&65280|g>>>24))|0;f=j[114626];j[114626]=0;ca:{da:{ea:{fa:{ga:{if((f|0)==1){break ga}n=1;f=0;if(!g){break ca}g=k[u|0]|k[u+1|0]<<8;j[114626]=0;g=E(258,b|0,(g<<8&16711680|g<<24)>>>15|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break ga}if(!g){break ca}g=k[u|0]|k[u+1|0]<<8;j[114626]=0;g=K(791,b|0,e|0,(g<<8&16711680|g<<24)>>>16|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break ga}if(!g){break ca}ma=d,na=Lb(e),j[ma+32>>2]=na;ma=d,na=Mb(e),j[ma+128>>2]=na;if(!rb(d+32|0,d+128|0)){break da}while(1){g=k[d+166|0]|k[d+167|0]<<8;n=(g<<24|g<<8&16711680)>>>16|0;g=j[d+32>>2];g=k[g|0]|k[g+1|0]<<8;f=(g<<24|g<<8&16711680)>>>16|0;ha:{if(n>>>0<f>>>0){break ha}g=k[d+152|0]|k[d+153|0]<<8|(k[d+154|0]<<16|k[d+155|0]<<24);j[114626]=0;E(256,b|0,(g<<8&16711680|g<<24|(g>>>8&65280|g>>>24))+(f<<2)|0)|0;g=j[114626];j[114626]=0;ia:{ja:{ka:{la:{ma:{if((g|0)==1){break ma}j[114626]=0;g=H(493,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break ma}j[114626]=0;g=E(256,b|0,g|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break ma}if(!g){break ha}j[114626]=0;g=E(258,b|0,42)|0;f=j[114626];j[114626]=0;if((f|0)==1){break ma}if(!g){break ha}j[114626]=0;E(792,b|0,d+80|0)|0;g=j[114626];j[114626]=0;na:{if((g|0)!=1){if(ad(q)){break na}j[114626]=0;F(793,q|0,65534);g=j[114626];j[114626]=0;if((g|0)!=1){break na}}f=D()|0;C()|0;break ea}g=k[d+120|0]|k[d+121|0]<<8;j[114626]=0;g=(g<<8&16711680|g<<24)>>>16|0;j[d+76>>2]=g;g=E(258,b|0,g|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break la}if(!g){j[114626]=0;g=H(540,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break la}kc(d+76|0,g)}kc(d+76|0,65534);f=bc(q);j[114626]=0;F(794,q|0,f+j[d+76>>2]|0);g=j[114626];j[114626]=0;if((g|0)==1){break ja}n=0;if(!j[d+76>>2]){break ka}while(1){oa:{j[114626]=0;g=H(484,b|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break oa}g=g<<16>>16;if((g|0)>=0){j[114626]=0;F(793,q|0,g+v&65535);g=j[114626];j[114626]=0;if((g|0)==1){break oa}}n=n+1|0;if(n>>>0<m[d+76>>2]){continue}break ka}break}f=D()|0;C()|0;break ea}f=D()|0;C()|0;break ea}f=D()|0;C()|0;break ea}pa:{if(!k[d+80|0]){break pa}j[114626]=0;I(6,d+56|0,2,d+80|0);g=j[114626];j[114626]=0;qa:{if((g|0)!=1){j[114626]=0;F(486,q|0,d+56|0);g=j[114626];j[114626]=0;if((g|0)==1){break qa}gb(d+56|0);break pa}f=D()|0;C()|0;break ea}f=D()|0;C()|0;gb(d+56|0);break ea}if(!(k[d+112|0]|k[d+113|0]<<8|(k[d+114|0]<<16|k[d+115|0]<<24))){break ha}g=k[d+112|0]|k[d+113|0]<<8|(k[d+114|0]<<16|k[d+115|0]<<24);j[114626]=0;g=E(256,b|0,g<<8&16711680|g<<24|(g>>>8&65280|g>>>24))|0;n=j[114626];j[114626]=0;if((n|0)!=1){break ia}}f=D()|0;C()|0;break ea}if(!g){break ha}while(1){ra:{j[114626]=0;g=E(795,b|0,d+72|0)|0;n=j[114626];j[114626]=0;sa:{ta:{if((n|0)!=1){if(!g){break ha}g=k[ha|0];j[114626]=0;I(341,d+56|0,b|0,g|0);g=j[114626];j[114626]=0;if((g|0)==1){break ta}g=k[d+72|0]|k[d+73|0]<<8;j[114626]=0;g=H(796,f+((g<<8&16711680|g<<24)>>>16|0)|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break fa}i[d+54>>1]=g;if((k[d+72|0]|k[d+73|0]<<8)==65535){break ra}g=l[d+54>>1];if(bc(q)>>>0>g>>>0){break sa}jb(d+56|0);break ha}f=D()|0;C()|0;break ea}f=D()|0;C()|0;break ea}ua:{if(k[Q|0]==1){g=65535}else{if(k[Q|0]!=2){break ua}j[114626]=0;g=H(484,d+56|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break fa}j[114626]=0;n=E(797,w|0,d+54|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break fa}i[n>>1]=g;g=65534}ma=ac(q,l[d+54>>1]),na=g,i[ma>>1]=na}jb(d+56|0);continue}break}jb(d+56|0)}je(d+32|0);if(rb(d+32|0,d+128|0)){continue}break}break da}f=D()|0;C()|0;break ea}f=D()|0;C()|0;jb(d+56|0)}hP(e);break H}n=0;f=1}hP(e);if(f){e=r>>>(s>>>25&1)|0;break P}bp(w);if(!n){break d}break O}f=D()|0;C()|0;break H}j[114626]=0;F(449,a|0,1);e=j[114626];j[114626]=0;va:{if((e|0)!=1){f=0;e=32;if(!l[a+480188>>1]){break P}while(1){g=k[(d+f|0)+810|0];j[114626]=0;h[d+152|0]=g;h[d+80|0]=64;g=E(391,d+152|0,d+80|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break va}i[((f<<5)+a|0)+480286>>1]=k[g|0];f=f+1|0;if(f>>>0<l[a+480188>>1]){continue}break}break P}f=D()|0;C()|0;break H}f=D()|0;C()|0;break H}n=k[d+807|0];g=k[d+804|0]|k[d+805|0]<<8;ca=k[d+807|0]&64;aa=k[d+808|0]&32;X=(k[d+808|0]&31)+1|0;ma=a,na=gP((g<<24|g<<8&16711680)>>>16|0,ca>>>6|0,aa>>>5|0,X),j[ma+480204>>2]=na;ma=a,na=kd(k[d+809|0],1,32),j[ma+480196>>2]=na;if(aa){j[a+480216>>2]=X;j[a+480220>>2]=X<<2}wa:{xa:{if(k[d+826|0]){g=k[d+826|0];j[114626]=0;h[d+152|0]=g;h[d+80|0]=64;g=E(391,d+152|0,d+80|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break xa}j[a+480200>>2]=k[g|0]<<2}j[a+480228>>2]=e;j[a+480232>>2]=e;j[a+480208>>2]=j[a+480208>>2]&-3|(k[d+807|0]>>>4^-1)&2;ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{if(!(k[d+508|0]|k[d+509|0]<<8|(k[d+510|0]<<16|k[d+511|0]<<24))){break Ja}e=k[d+508|0]|k[d+509|0]<<8|(k[d+510|0]<<16|k[d+511|0]<<24);j[114626]=0;e=E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;g=j[114626];j[114626]=0;if((g|0)==1){break Ia}if(!e){break Ja}e=k[d+512|0]|k[d+513|0]<<8|(k[d+514|0]<<16|k[d+515|0]<<24);j[114626]=0;K(481,b|0,Y|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;e=j[114626];j[114626]=0;if((e|0)==1){break Ia}if(k[_|0]<2){break Ja}j[114626]=0;I(13,d+152|0,2,Y|0);e=j[114626];j[114626]=0;if((e|0)==1){break Ha}j[114626]=0;F(486,q|0,d+152|0);e=j[114626];j[114626]=0;if((e|0)==1){break Ga}gb(d+152|0)}e=k[d+480|0]|k[d+481|0]<<8|(k[d+482|0]<<16|k[d+483|0]<<24);Ka:{if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0<2){break Ka}e=k[d+476|0]|k[d+477|0]<<8|(k[d+478|0]<<16|k[d+479|0]<<24);j[114626]=0;e=E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;g=j[114626];j[114626]=0;if((g|0)==1){break Ia}if(!e){break Ka}e=k[d+480|0]|k[d+481|0]<<8|(k[d+482|0]<<16|k[d+483|0]<<24);j[114626]=0;P(584,A|0,b|0,(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))-1|0,4)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Ia}}if(!(k[d+520|0]|k[d+521|0]<<8|(k[d+522|0]<<16|k[d+523|0]<<24))){break wa}e=k[d+520|0]|k[d+521|0]<<8|(k[d+522|0]<<16|k[d+523|0]<<24);j[114626]=0;e=E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;g=j[114626];j[114626]=0;if((g|0)==1){break Ia}if(!e){break wa}j[114626]=0;e=E(258,b|0,12)|0;g=j[114626];j[114626]=0;if((g|0)==1){break Ia}if(!e){break wa}j[114626]=0;E(338,b|0,6)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Ia}j[114626]=0;e=H(484,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break Ia}if((e|0)!=1){break wa}j[114626]=0;e=H(493,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break Ea}if(!e){break wa}j[114626]=0;g=E(258,b|0,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Ea}if(g){break Fa}break wa}f=D()|0;C()|0;break H}f=D()|0;C()|0;break H}f=D()|0;C()|0;gb(d+152|0);break H}Nc(d+152|0,A);j[114626]=0;P(584,A|0,b|0,e|0,4)|0;e=j[114626];j[114626]=0;if((e|0)==1){break za}if(!Ec(d+152|0)){j[114626]=0;e=K(798,d+56|0,2,13)|0;g=j[114626];j[114626]=0;if((g|0)==1){break Da}j[114626]=0;I(799,d+80|0,d+152|0,e|0);g=j[114626];j[114626]=0;if((g|0)==1){break Ca}j[114626]=0;I(800,d+40|0,d+80|0,A|0);g=j[114626];j[114626]=0;if((g|0)==1){break Ba}ob(A,d+40|0);gb(d+40|0);gb(d+80|0);gb(e)}gb(d+152|0);break wa}f=D()|0;C()|0;break H}f=D()|0;C()|0;break ya}f=D()|0;C()|0;break Aa}f=D()|0;C()|0;gb(d+80|0)}gb(e);break ya}f=D()|0;C()|0}gb(d+152|0);break H}f=D()|0;C()|0;break H}La:{if(!(k[d+532|0]|k[d+533|0]<<8|(k[d+534|0]<<16|k[d+535|0]<<24))|k[d+855|0]<2){break La}r=0;if(!l[a+480188>>1]){break La}while(1){e=k[d+532|0]|k[d+533|0]<<8|(k[d+534|0]<<16|k[d+535|0]<<24);j[114626]=0;e=E(256,b|0,(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))+(r<<2)|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break I}Ma:{if(!e){break Ma}j[114626]=0;e=H(493,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break I}j[114626]=0;f=E(256,b|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break I}e=0;g=0;if(!f){break Ma}while(1){Na:{j[114626]=0;f=E(258,b|0,8)|0;s=j[114626];j[114626]=0;Oa:{Pa:{Qa:{if((s|0)!=1){if(!f){break Na}j[114626]=0;E(801,b|0,d+152|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Qa}if(!(k[d+152|0]|k[d+153|0]<<8|(k[d+154|0]<<16|k[d+155|0]<<24))){break Na}f=(k[d+152|0]|k[d+153|0]<<8|(k[d+154|0]<<16|k[d+155|0]<<24))&-225;switch((f<<24|f<<8&16711680|(f>>>8&65280|f>>>24))-1|0){case 1:break Oa;case 0:break Pa;default:continue}}f=D()|0;C()|0;break H}f=D()|0;C()|0;break H}e=k[o|0]|k[o+1|0]<<8|(k[o+2|0]<<16|k[o+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);continue}g=k[o|0]|k[o+1|0]<<8|(k[o+2|0]<<16|k[o+3|0]<<24);g=g<<24|g<<8&16711680|(g>>>8&65280|g>>>24);continue}break}if(!e|!g){break Ma}j[114626]=0;e=E(256,b|0,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break J}if(!e){break Ma}j[114626]=0;K(636,b|0,((r<<5)+a|0)+480289|0,g|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break J}}r=r+1|0;if(r>>>0<l[a+480188>>1]){continue}break}}e=k[d+544|0]|k[d+545|0]<<8;j[114626]=0;s=(e<<8&16711680|e<<24)>>>16|0;F(401,x|0,v+s&65535);g=j[114626];j[114626]=0;Ra:{if((g|0)==1){break Ra}Sa:{if(e){ia=n&16;ja=v&65535;ka=s>>>0>1?s:1;g=0;while(1){Ta:{if(!fa){break Ta}e=k[d+872|0]|k[d+873|0]<<8|(k[d+874|0]<<16|k[d+875|0]<<24);j[114626]=0;e=E(256,b|0,(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))+(g<<2)|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Sa}if(!e){break Ta}j[114626]=0;e=H(493,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Sa}j[114626]=0;e=E(256,b|0,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Sa}if(!e){break Ta}B=Db(d+136|0);j[114626]=0;O=H(277,d+80|0)|0;e=j[114626];j[114626]=0;Ua:{Va:{if((e|0)!=1){f=k[d+855|0];if(f){break Va}j[114626]=0;E(802,b|0,d+152|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break L}i[d+128>>1]=k[d+152|0];T=k[ga|0]+1|0;e=48;break Ua}f=D()|0;C()|0;break K}n=h[d+806|0];j[114626]=0;E(803,b|0,d+32|0)|0;e=j[114626];j[114626]=0;Wa:{Xa:{if((e|0)!=1){e=k[d+32|0]|k[d+33|0]<<8;i[d+128>>1]=(e<<24|e<<8&16711680)>>>16;e=k[y|0]|k[y+1|0]<<8;T=((e<<24|e<<8&16711680)>>>16|0)+1|0;e=c;if(!(k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))){break Wa}r=j[b+8>>2];e=k[c|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);j[114626]=0;E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;e=j[114626];j[114626]=0;if((e|0)==1){break L}j[114626]=0;E(804,b|0,d+152|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break L}e=k[o|0]|k[o+1|0]<<8|(k[o+2|0]<<16|k[o+3|0]<<24);j[114626]=0;e=E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;t=j[114626];j[114626]=0;if((t|0)==1){break L}if(!e){break Xa}e=k[d+160|0]|k[d+161|0]<<8|(k[d+162|0]<<16|k[d+163|0]<<24);j[114626]=0;K(481,b|0,B|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;e=j[114626];j[114626]=0;if((e|0)!=1){break Xa}break L}break L}Ya:{if(!(k[d+168|0]|k[d+169|0]<<8|(k[d+170|0]<<16|k[d+171|0]<<24))){break Ya}e=k[d+168|0]|k[d+169|0]<<8|(k[d+170|0]<<16|k[d+171|0]<<24);j[114626]=0;e=E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;t=j[114626];j[114626]=0;if((t|0)==1){break L}if(!e){break Ya}j[114626]=0;e=H(493,b|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break L}j[114626]=0;e=E(256,b|0,e|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break L}if(!e){break Ya}j[114626]=0;I(341,d+56|0,b|0,p(l[d+128>>1],T)|0);e=j[114626];j[114626]=0;if((e|0)==1){break L}Ed(O,d+56|0);jb(d+56|0)}j[114626]=0;E(256,b|0,r|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break L}}e=n+(f>>>0<3?48:24)|0}j[114626]=0;f=g+ja|0;n=K(402,x|0,f&65535,T|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break L}if(n){da=Ib(x,f);j[114626]=0;E(495,da|0,B|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break L}Sf(d+128|0,l[a+480188>>1]);t=0;while(1){j[114626]=0;f=K(471,da|0,t|0,0)|0;n=j[114626];j[114626]=0;Za:{_a:{if((n|0)!=1){r=0;if(l[d+128>>1]){break _a}break Za}break L}while(1){$a:{if(!k[d+855|0]){j[114626]=0;F(805,d+152|0,b|0);n=j[114626];j[114626]=0;if((n|0)!=1){n=Pc(d+152|0);ba=Bf(d+152|0);R=k[d+152|0];h[f+1|0]=R>>>3&16|k[n|0]>>>4|R>>>1&32;h[f+3|0]=k[n|0]&15;h[f+5|0]=k[ba|0];n=R&63;n=n?n+e|0:0;break $a}break L}j[114626]=0;F(595,d+152|0,b|0);n=j[114626];j[114626]=0;ab:{bb:{if((n|0)!=1){R=Pc(d+152|0);ba=Bf(d+152|0);la=pi(d+152|0);j[114626]=0;n=H(387,O|0)|0;Z=j[114626];j[114626]=0;if((Z|0)==1){break L}h[f+4|0]=n;Z=k[d+152|0];n=Z&127;if(!n){break bb}n=e+n|0;break ab}break L}n=0;if((Z|0)!=128){break ab}h[f|0]=254}h[f+1|0]=k[R|0]&63;h[f+3|0]=k[ba|0];h[f+5|0]=k[la|0]}if(n-1>>>0<=119){h[f|0]=n}j[114626]=0;V(806,f|0,(ca|0)!=0|0,(aa|0)!=0|0,X|0,(ia|0)!=0|0);R=j[114626];j[114626]=0;if((R|0)!=1){M=(n|0)>84&$|M;f=f+6|0;r=r+1|0;if(l[d+128>>1]<=(r&65535)>>>0){break Za}continue}break}break L}t=t+1|0;if((T|0)!=(t|0)){continue}break}}jb(O);gb(B)}g=g+1|0;if((ka|0)!=(g|0)){continue}break}}ma=d,na=Wm(w),j[ma+80>>2]=na;ma=d,na=ki(w),j[ma+56>>2]=na;cb:{while(1){j[114626]=0;e=E(807,d+80|0,d+56|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break M}db:{eb:{fb:{gb:{hb:{ib:{if(!e){if(!(k[d+464|0]|k[d+465|0]<<8|(k[d+466|0]<<16|k[d+467|0]<<24))){break ib}e=k[d+464|0]|k[d+465|0]<<8|(k[d+466|0]<<16|k[d+467|0]<<24);j[114626]=0;e=E(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;g=j[114626];j[114626]=0;if((g|0)==1){break Ra}if(!e){break ib}v=s+v|0;bp(w);break O}j[114626]=0;e=H(808,d+80|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break hb}g=l[e>>1];if(!g){f=0;break gb}j[114626]=0;g=E(546,q|0,g-1&65535)|0;f=j[114626];j[114626]=0;if((f|0)==1){break db}f=l[e>>1];if(!g){break gb}j[114626]=0;f=E(809,q|0,f-1&65535)|0;g=j[114626];j[114626]=0;if((g|0)!=1){break fb}break db}bp(w);break N}f=D()|0;C()|0;break H}if(l[e+2>>1]==((f&65535)+1|0)){break eb}j[114626]=0;f=K(810,x|0,1,0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break db}if((f|0)==65535){break eb}ma=ac(q,l[e>>1]),na=f,i[ma>>1]=na}g=Ib(x,f);e=l[e+2>>1];j[114626]=0;e=H(811,e|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break cb}j[114626]=0;e=K(497,d+152|0,12,e|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break cb}e=dn(Fe(e,j[Ib(x,f)+12>>2]-1|0));j[114626]=0;E(498,g|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break cb}s=(s&65535)>>>0>f>>>0?s:f+1|0}j[114626]=0;H(812,d+80|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){continue}break M}break}f=D()|0;C()|0;break H}f=D()|0;C()|0;break H}f=D()|0;C()|0;break H}f=D()|0;C()|0;break H}W=W+1|0;if(k[_|0]>(W&255)>>>0){continue}break}}j[114626]=0;F(488,a+484360|0,0);b=j[114626];j[114626]=0;if((b|0)!=1){if(!(M&1)){o=l[a+480192>>1];if(o){f=1;while(1){b=(((f&65535)<<2)+a|0)+900380|0;c=j[b>>2];if(c){Cb(Ns(c));o=l[a+480192>>1]}j[b>>2]=0;f=f+1|0;if((f&65535)>>>0<=(o&65535)>>>0){continue}break}}i[a+480192>>1]=0}jb:{kb:{lb:{mb:{nb:{ob:{pb:{if(ea){j[114626]=0;b=E(2,d+152|0,14917)|0;c=j[114626];j[114626]=0;if((c|0)==1){break pb}j[114626]=0;I(647,a|0,2,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break ob}gb(b)}o=14964;switch(k[d+855|0]){case 3:break kb;case 2:break lb;case 1:break mb;case 0:break nb;default:break jb}}f=D()|0;C()|0;break f}f=D()|0;C()|0;gb(b);break f}o=l[a+480188>>1]>4?14965:14986;break jb}o=15e3;break jb}o=15018;break jb}o=15036}j[114626]=0;b=E(2,d+16|0,15063)|0;c=j[114626];j[114626]=0;qb:{rb:{sb:{tb:{ub:{if((c|0)!=1){j[114626]=0;F(219,d+80|0,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break ub}j[114626]=0;I(536,d+152|0,d+80|0,d+855|0);c=j[114626];j[114626]=0;if((c|0)==1){break tb}ob(a+1304436|0,d+152|0);gb(d+152|0);qb(d+80|0);gb(b);j[114626]=0;b=E(2,d+152|0,15079)|0;c=j[114626];j[114626]=0;if((c|0)==1){break rb}ob(a+1304448|0,b);gb(b);j[114626]=0;E(238,a+1304460|0,o|0)|0;b=j[114626];j[114626]=0;f=1;if((b|0)==1){break qb}j[a+1304496>>2]=2;break c}f=D()|0;C()|0;break f}f=D()|0;C()|0;break sb}f=D()|0;C()|0;qb(d+80|0)}gb(b);break f}f=D()|0;C()|0;break f}f=D()|0;C()|0;break f}f=D()|0;C()|0;break f}f=D()|0;C()|0;break H}f=D()|0;C()|0;jb(O)}gb(B);break H}f=D()|0;C()|0;break H}f=D()|0;C()|0}bp(w);break f}f=D()|0;C()|0;break f}f=D()|0;C()|0;break f}f=D()|0;C()|0;jb(w)}dP(S)}jb(d+832|0);G(f|0);z()}f=0}dP(S)}jb(d+832|0)}Za=d+912|0;return f|0}function Yr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,n=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,J=0,M=0,O=0,Q=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;g=Za-176|0;Za=g;bpa(a);J=rpa(g+144|0);e=l[d+4>>1];i[J+24>>1]=e;s=j[d>>2];j[J+16>>2]=s;ba=j[d+16>>2];ha=k[d+6|0];na=b+484360|0;if(ha>>>0>=rh(na)>>>0){ha=k[na+16|0]}oa=a;V=gi(na,ha);j[114626]=0;B=E(1327,g+104|0,b|0)|0;a=j[114626];j[114626]=0;a:{if((a|0)!=1){ta=B+4|0;f=j[ta>>2];j[114626]=0;ca=K(1328,g+72|0,b|0,ha|0)|0;a=j[114626];j[114626]=0;b:{if((a|0)!=1){i[f+64>>1]=e;i[f+62>>1]=e;j[f+52>>2]=s;j[f+48>>2]=s;_=g- -64|0;wf(_);qa=Ys(g+56|0);c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{ra=c&7;ua=(ra|0)!=7;n:{if(ua){break n}j[114626]=0;K(1329,_|0,1,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break m}j[114626]=0;K(1329,_|0,2,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break m}j[114626]=0;K(1329,_|0,3,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break m}j[114626]=0;K(1329,_|0,28,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break m}j[114626]=0;K(1329,_|0,35,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break m}j[114626]=0;K(1329,_|0,37,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break m}j[114626]=0;K(1329,_|0,36,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break m}j[114626]=0;K(1329,_|0,38,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break m}j[114626]=0;K(1330,qa|0,12,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break m}j[114626]=0;K(1330,qa|0,13,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break m}if(l[b+480188>>1]){e=B+20|0;a=0;while(1){if(k[((a<<5)+b|0)+480281|0]&4){Ca=yc(e,a),Da=-1,j[Ca+16>>2]=Da}a=a+1|0;if(a>>>0<l[b+480188>>1]){continue}break}}if((ba|0)!=2){break n}a=l[d+12>>1];if(bc(V)>>>0<=a>>>0){break n}a=l[ac(V,a)>>1];j[114626]=0;e=b+484344|0;s=E(442,e|0,a|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break d}if(!s){break n}r=Ib(e,a);s=j[d+8>>2];j[114626]=0;r=E(1331,r|0,s|0)|0;M=j[114626];j[114626]=0;if((M|0)==1){break d}if(!r){break n}a=Ib(e,a);j[114626]=0;a=K(471,a|0,s|0,0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break e}if(!l[b+480188>>1]){break n}s=B+20|0;e=0;while(1){o:{p:{q:{switch(k[a|0]-253|0){case 0:if(l[b+480192>>1]){break p}break;case 1:case 2:break p;default:break q}}j[114626]=0;r=H(553,a|0)|0;M=j[114626];j[114626]=0;if((M|0)==1){break f}if(!r){break o}if(Zr(a)){break o}}Ca=yc(s,e),Da=-1,j[Ca+16>>2]=Da}a=a+6|0;e=e+1|0;if(e>>>0<l[b+480188>>1]){continue}break}}ea=f- -64|0;W=f+48|0;da=f+68|0;wa=f+44|0;sa=B+8|0;ia=c&1;A=B+20|0;O=b+1074308|0;Y=b+484344|0;xa=(ba|0)!=3;va=(ba|0)!=2;M=0;while(1){j[f+48>>2]=j[f+52>>2];a=l[f+64>>1];i[f+62>>1]=a;j[114626]=0;a=E(546,V|0,a|0)|0;e=j[114626];j[114626]=0;r:{if((e|0)!=1){s:{if(!a){break s}if(m[f+48>>2]<m[Ib(Y,l[ac(V,l[f+62>>1])>>1])+12>>2]){break s}j[W>>2]=0;mb(g,O,63);if(kb(g)){a=j[f+56>>2];j[f+56>>2]=0;j[f+48>>2]=a}a=l[f+64>>1]+1|0;i[f+62>>1]=a;i[f+64>>1]=a}if(o[B+32>>3]<o[d+8>>3]|xa){break r}h[J+26|0]=1;break g}a=D()|0;C()|0;break c}e=l[f+62>>1];a=f;t:{if(bc(V)>>>0>e>>>0){e=l[ac(V,l[f+62>>1])>>1];break t}e=65535}i[a+60>>1]=e;j[114626]=0;a=E(442,Y|0,e&65535)|0;e=j[114626];j[114626]=0;if((e|0)==1){break i}if(!(l[f+60>>1]==65535|va|a|l[f+62>>1]!=l[d+12>>1])){h[J+26|0]=1;break g}u:{if(l[f+60>>1]<me(Y)>>>0){break u}while(1){a=f;r=a;v:{w:{if(l[a+60>>1]!=65535){e=l[f+62>>1];if(bc(V)>>>0>e>>>0){break w}}if(l[V+28>>1]==l[f+62>>1]){break u}e=l[V+28>>1];break v}e=l[f+62>>1]+1|0}i[r+62>>1]=e;a=f;x:{if(bc(V)>>>0>(e&65535)>>>0){e=l[ac(V,l[f+62>>1])>>1];break x}e=65535}i[a+60>>1]=e;i[f+64>>1]=l[f+62>>1];j[114626]=0;a=E(442,Y|0,e&65535)|0;e=j[114626];j[114626]=0;if((e|0)==1){break h}y:{if(a){break y}a=l[f+62>>1];j[114626]=0;a=P(1332,ca|0,a|0,0,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break h}if(!a){break y}if(ba>>>0<=1){a=l[f+62>>1];j[J+8>>2]=0;i[J+20>>1]=a;if(!ba){break u}}j[114626]=0;a=P(1333,ca|0,ea|0,W|0,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break i}if(!a){break u}o[J>>3]=o[B+32>>3];j[114626]=0;F(1334,oa|0,J|0);a=j[114626];j[114626]=0;if((a|0)==1){break i}j[J+16>>2]=j[W>>2];i[J+24>>1]=l[ea>>1];j[114626]=0;N(1335,B|0);a=j[114626];j[114626]=0;if((a|0)==1){break i}a=l[f+64>>1];i[f+62>>1]=a;Ca=f,Da=l[ac(V,a)>>1],i[Ca+60>>1]=Da;j[f+52>>2]=j[f+48>>2];break u}if(l[f+60>>1]>=me(Y)>>>0){continue}break}}if(l[ea>>1]==65535){break g}a=l[f+60>>1];j[114626]=0;a=E(442,Y|0,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break i}if(!a){if(l[V+28>>1]==l[f+62>>1]){if(!ba){break g}j[114626]=0;a=P(1333,ca|0,ea|0,W|0,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break i}if(!a){break g}o[J>>3]=o[B+32>>3];j[114626]=0;F(1334,oa|0,J|0);a=j[114626];j[114626]=0;if((a|0)==1){break i}j[J+16>>2]=j[W>>2];i[J+24>>1]=l[ea>>1];j[114626]=0;N(1335,B|0);a=j[114626];j[114626]=0;if((a|0)==1){break i}j[f+52>>2]=j[f+48>>2];continue}i[f+64>>1]=l[f+62>>1]+1;continue}if(m[f+48>>2]>=m[Ib(Y,l[f+60>>1])+12>>2]){j[W>>2]=0}a=l[f+62>>1];if(!((a|0)!=l[d+12>>1]|va|j[W>>2]!=j[d+8>>2])){h[J+26|0]=1;break g}e=j[W>>2];j[114626]=0;a=P(1332,ca|0,a|0,e|0,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break i}if(a){if(ba>>>0<=1){i[J+20>>1]=l[f+62>>1];j[J+8>>2]=j[f+48>>2];if(!ba){break g}}j[114626]=0;a=P(1333,ca|0,ea|0,W|0,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break i}if(!a){break g}o[J>>3]=o[B+32>>3];j[114626]=0;F(1334,oa|0,J|0);a=j[114626];j[114626]=0;if((a|0)==1){break i}j[J+16>>2]=j[W>>2];i[J+24>>1]=l[ea>>1];j[114626]=0;N(1335,B|0);a=j[114626];j[114626]=0;if((a|0)==1){break i}j[f+52>>2]=j[f+48>>2];continue}i[J+22>>1]=l[f+62>>1];a=j[f+48>>2];j[J+12>>2]=a;j[f+52>>2]=a+1;z:{A:{if(a>>>0>=m[Ib(Y,l[f+60>>1])+12>>2]){j[W>>2]=0;break A}if(j[W>>2]){break z}}a=0;if(!l[b+480188>>1]){break z}while(1){S=o[B+32>>3];Ca=yc(A,a),Ea=S,o[Ca>>3]=Ea;e=j[f>>2];Ca=yc(A,a),Da=e,j[Ca+8>>2]=Da;a=a+1|0;if(a>>>0<l[b+480188>>1]){continue}break}}a=Ib(Y,l[f+60>>1]);e=j[f+48>>2];j[114626]=0;a=K(471,a|0,e|0,0)|0;e=j[114626];j[114626]=0;B:{C:{D:{if((e|0)!=1){e=0;$=0;ja=0;if(!l[b+480188>>1]){break C}while(1){E:{mb(g,O,77);F:{if(Ca=kb(g),Da=0,Fa=j[((e<<5)+b|0)+480280>>2]&1024,Fa?Ca:Da){break F}j[114626]=0;s=H(1336,a|0)|0;r=j[114626];j[114626]=0;G:{H:{I:{if((r|0)==1){break I}if(s){J:{if(!ia){break J}s=k[a+1|0];if(s-251>>>0<5|!s){break J}j[114626]=0;s=H(1337,a|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break I}j[114626]=0;r=H(1338,a|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break E}i[g+48>>1]=r;h[g|0]=k[a+1|0];i[g+2>>1]=l[g+48>>1];j[114626]=0;r=E(1339,sa|0,g|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break E}i[r>>1]=s}As((p(e,896)+f|0)+1418|0);break F}s=p(e,896)+f|0;r=s+1422|0;t=k[a+4|0]|k[a+5|0]<<8;h[r|0]=t;h[r+1|0]=t>>>8;s=s+1418|0;r=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);h[s|0]=r;h[s+1|0]=r>>>8;h[s+2|0]=r>>>16;h[s+3|0]=r>>>24;K:{switch(k[a+3|0]-16|0){case 0:s=k[a+5|0];j[114626]=0;I(1340,b|0,f|0,s|0);s=j[114626];j[114626]=0;if((s|0)==1){break I}break F;case 3:break G;case 4:break H;case 1:break K;default:break F}}mb(g,O,5);if(!kb(g)){break F}s=k[a+5|0];if(!s){break F}j[114626]=0;I(1340,b|0,f|0,s|0);s=j[114626];j[114626]=0;if((s|0)!=1){break F}}a=D()|0;C()|0;break c}s=k[a+5|0];r=s&240;if((r|0)==96){ja=(s&15)+ja|0;break F}if((r|0)!=224|$){break F}s=k[a+5|0]&15;if(j[b+480180>>2]&2){$=0;if(!s){break F}}$=s+1|0;break F}s=k[a+5|0];if((s&240)!=224){break F}$=(s&15)+1|0}a=a+6|0;e=e+1|0;if(e>>>0<l[b+480188>>1]){continue}break D}break}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}e=ja;if($){break B}}$=1;ja=e}Q=p(j[f+40>>2]+ja|0,$);L:{if(!l[b+480188>>1]){s=0;ka=0;pa=0;fa=0;la=0;break L}u=Q-1|0;r=Q-$|0;T=p(r,1e4);e=0;la=0;fa=0;pa=0;ka=0;s=0;while(1){M:{X=p(e,896);t=X+f|0;v=t+1418|0;N:{if(jpa(v)){break N}mb(g,O,77);if(Ca=kb(g),Da=0,Fa=j[((e<<5)+b|0)+480280>>2]&1024,Fa?Ca:Da){break N}n=k[t+1423|0];ga=t+1421|0;x=k[ga|0];y=k[v|0];a=t+1419|0;w=k[a|0];if(w){h[t+1429|0]=0;h[t+1433|0]=w;Ca=yc(A,e),Da=255,h[Ca+21|0]=Da}j[114626]=0;w=H(553,v|0)|0;R=j[114626];j[114626]=0;if((R|0)==1){break M}if(w){h[t+1429|0]=y}j[114626]=0;R=H(553,v|0)|0;w=j[114626];j[114626]=0;if((w|0)==1){break M}w=t+608|0;O:{P:{Q:{R:{S:{T:{if(k[a|0]?0:!R){break T}R=t+1433|0;a=k[R|0];if(l[b+480192>>1]){if(a>>>0>l[b+480192>>1]){break T}a=j[((k[R|0]<<2)+b|0)+900380>>2];if(!a){break T}U:{if(!(h[a+15|0]&1)){break U}R=j[a+8>>2];j[114626]=0;I(1341,w|0,R|0,b|0);R=j[114626];j[114626]=0;if((R|0)!=1){break U}a=D()|0;C()|0;break c}if(!Ld(y)){break T}a=l[Oc(a+236|0,y-1|0)>>1]}a=a&65535;if(!a|a>>>0>l[b+480190>>1]){break T}y=p(a,104)+b|0;R=y+484414|0;a=l[R>>1];if(a&32){a=l[y+484408>>1];j[114626]=0;I(1341,w|0,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break S}a=l[R>>1]}if(!(a&512)){break T}a=j[ta>>2];j[114626]=0;N(1342,(a+X|0)+608|0);a=j[114626];j[114626]=0;if((a|0)==1){break S}Ca=yc(A,e),Da=0,j[Ca+16>>2]=Da}V:{W:{X:{X=t+1420|0;a=k[X|0];switch(a-1|0){case 1:break Q;case 2:case 3:break W;case 0:break X;default:break V}}a=k[t+1422|0];Ca=yc(A,e),Da=a,h[Ca+21|0]=Da;break Q}a=k[t+1422|0];if(!a){break Q}h[t+1462|0]=a;break Q}if((a|0)==11){break R}break Q}a=D()|0;C()|0;break c}if(!k[t+1422|0]){break Q}xx(g,b,v,0);a=Rb(g);j[t+1384>>2]=j[g>>2]<<2;if(!k[a|0]){break Q}x=0;break P}Y:{Z:{_:{switch(x-12|0){case 0:a=j[f+48>>2];n=l[f+60>>1];j[114626]=0;a=U(1343,b|0,n|0,a|0,e&65535,0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break M}j[f+56>>2]=0;i[f+64>>1]=a;if(!(j[b+480180>>2]&5?0:pa)){j[f+52>>2]=0}fa=1;if(!ia){la=1;break N}j[t+1412>>2]=0;h[t+1469|0]=0;la=1;break O;case 2:j[114626]=0;a=P(1344,b|0,f|0,e&65535,n|0)|0;v=j[114626];j[114626]=0;if((v|0)==1){break Z}if((a|0)==-1){x=14;break P}j[f+52>>2]=a;if(!la){i[f+64>>1]=l[f+62>>1]+1}pa=1;if(!ia){break N}j[t+1412>>2]=0;h[t+1469|0]=0;break O;case 5:mb(g,O,5);x=17;if(kb(g)){break P}a=j[f+48>>2];v=l[f+60>>1];j[114626]=0;a=U(1343,b|0,v|0,a|0,e&65535,0)|0;v=j[114626];j[114626]=0;$:{aa:{if((v|0)!=1){a=p(a,1e4);if(!ia|!(j[b+480180>>2]&16777250)){break $}if(a>>>0<1e4){break aa}h[t+1463|0]=(a>>>0)/1e4;break $}a=D()|0;C()|0;break c}a=p(k[t+1463|0],1e4)}v=(a>>>0)/1e4|0;ba:{if(a>>>0>319999){break ba}y=p(T,v&15);a=j[f+44>>2];if((v&240)==16){a=a+y|0;break ba}v=a-y|0;a=a>>>0<v>>>0?0:v}j[f+44>>2]=a;a=j[j[b+8>>2]+20>>2];v=j[j[b+8>>2]+24>>2];mb(g,O,8);wn(wa,p(a,1e4),kb(g)?255e4:p(v,1e4));break P;case 8:x=20;ca:{switch((n&240)-144>>>4|0){case 0:if(n>>>0>145){break P}j[t+696>>2]=j[t+696>>2]&-257|((n|0)==145)<<8;break P;case 1:h[t+1464|0]=n&15;break P;case 2:v=e;a=e;if(j[b+480180>>2]==2){v=l[b+480188>>1]-1|0;a=0}if(!(n&15)){fa=0;s=1;v=v&65535;if(v>>>0<(a&65535)>>>0){break P}while(1){S=o[B+32>>3];s=a&65535;Ca=yc(A,s),Ea=S,o[Ca>>3]=Ea;y=j[f>>2];Ca=yc(A,s),Da=y,j[Ca+8>>2]=Da;y=j[f+48>>2];Ca=yc(A,s),Da=y,j[Ca+12>>2]=Da;j[(p(s,896)+f|0)+1412>>2]=j[f+48>>2];s=1;a=a+1|0;if(v>>>0>=(a&65535)>>>0){continue}break}break P}mb(g,O,16);if(!kb(g)){fa=0;ka=1;if(j[b+480180>>2]!=2|(a&65535)>>>0>(v&65535)>>>0){break P}break Y}if((a&65535)>>>0<=(v&65535)>>>0){break Y}fa=0;ka=1;break P;case 6:break ca;default:break P}}h[t+1472|0]=n&15;break P;case 7:x=19;a=n&240;if((a|0)!=240){if((a|0)!=96){break P}if(n&15){Ca=f,Da=j[yc(A,e)+12>>2],j[Ca+56>>2]=Da;ka=1;break P}S=o[B+32>>3];Ca=yc(A,e),Ea=S,o[Ca>>3]=Ea;a=j[f>>2];Ca=yc(A,e),Da=a,j[Ca+8>>2]=Da;a=j[f+48>>2];Ca=yc(A,e),Da=a,j[Ca+12>>2]=Da;j[t+1412>>2]=j[f+48>>2];s=1;break P}h[t+1472|0]=n&15;break P;case 1:case 3:case 4:case 6:break P;default:break _}}if((x|0)!=28){break P}if((n&240)==160){mb(g,O,58);x=28;if(kb(g)){break P}h[t+1464|0]=n&15;break P}x=28;break P}a=D()|0;C()|0;break c}y=j[W>>2]+1|0;while(1){j[(p(a&65535,896)+f|0)+1412>>2]=y;ka=1;fa=0;a=a+1|0;if((a&65535)>>>0<=(v&65535)>>>0){continue}break}}if(!ia){break N}da:{ea:{fa:{ga:{ha:{ia:{ja:{switch(x-2|0){case 0:if(!n){break O}mb(g,O,90);if(!kb(g)){h[t+1440|0]=n}h[t+1439|0]=n;break O;case 1:if(!n){break O}mb(g,O,90);if(!kb(g)){h[t+1439|0]=n}h[t+1440|0]=n;break O;case 2:if(!n){break O}j[t+1384>>2]=n<<2;break O;case 8:if(!n){break O}j[t+1272>>2]=n<<8;break O;case 4:case 9:if(!n){break O}h[t+1437|0]=n;break O;case 11:Ca=yc(A,e),Da=n,h[Ca+21|0]=Da;break O;case 21:a=n<<(!(j[b+480180>>2]&59593760)&n<<24>>24>-1)&255;if(a>>>0<=128){j[da>>2]=a<<1;break O}if(j[b+480180>>2]&16777250){break O}j[da>>2]=256;break O;case 22:mb(g,O,9);ka:{if(kb(g)){a=t+1445|0;if(n){h[a|0]=n;break ka}n=k[a|0];break ka}if(n){h[f+1445|0]=n;break ka}n=k[f+1445|0]}a=da;v=n&240;y=n&15;la:{if(!(!v|(y|0)!=15)){x=j[da>>2]+(v>>>4<<!(j[b+480180>>2]&59593760)<<1&254)|0;break la}x=j[da>>2]-(y<<(j[b+480180>>2]&59593760?1:2))|0;if(!(!y|(v|0)!=240)){break la}x=j[da>>2]+p(r,(n>>>3&30)<<!(j[b+480180>>2]&59593760)&254)|0;if(v){break la}x=j[da>>2]-p(r,y<<(j[b+480180>>2]&59593760?1:2))|0}j[a>>2]=x;Md(da,0,256);break O;case 19:if(n>>>0>64){break O}j[t+1368>>2]=n;break O;case 20:a=t+1444|0;ma:{if(n){h[a|0]=n;break ma}n=k[a|0]}y=t+1368|0;v=j[y>>2];a=n;x=a&240;n=a&15;na:{if(!(!x|(n|0)!=15)){j[g>>2]=v+(a>>>4|0);break na}if(!(!n|(x|0)!=240)){j[g>>2]=v-n;break na}if(n){j[g>>2]=v-p(n,r);break na}j[g>>2]=v+p(r,a>>>4|0)}Md(g,0,64);j[y>>2]=j[g>>2];break O;case 7:$k(b,w,n,8);break O;case 25:break da;case 6:break ea;case 24:break fa;case 3:break ga;case 5:break ha;case 18:break ia;case 17:break ja;default:break O}}if(!l[b+480188>>1]|n>>>0>15){break ia}v=(n&1)<<14;a=0;while(1){y=p(a,896)+f|0;j[y+696>>2]=(v|j[y+696>>2]&-16385)^16384;a=a+1|0;if(a>>>0<l[b+480188>>1]){continue}break}}if((n&240)!=128){break O}$k(b,w,n&15,4);break O}if(n){h[t+1437|0]=n}n=0}Nj(w,n);break O}IK(b,w,n);break O}HK(w,n);break O}GK(w,n)}oa:{pa:{switch(k[X|0]-2|0){case 0:$k(b,w,k[t+1422|0],6);break oa;case 5:mb(g,O,53);n=kb(g);a=k[t+1422|0];if(n){h[t+1451|0]=a&15;break oa}Nj(w,a<<4);break oa;case 6:break pa;default:break oa}}Nj(w,k[t+1422|0])}qa:{ra:{sa:{ta:{a=k[ga|0];switch(a-5|0){case 3:break ra;case 0:case 2:break sa;case 1:break N;default:break ta}}switch(a-26|0){case 1:break qa;case 0:break sa;default:break N}}ua:{if(j[b+480180>>2]&16777248){a=Q;if(!(k[b+480208|0]&4)){break ua}}a=r}n=k[t+1451|0];mb(g,O,21);w=kb(g);t=t+1447|0;a=p(a,n);h[t|0]=k[t|0]+(w?a<<2:a);break N}va:{if(j[b+480180>>2]&16777248){a=Q;if(!(k[b+480208|0]&4)){break va}}a=r}n=k[t+1454|0];mb(g,O,21);w=kb(g);t=t+1448|0;a=p(a,n);h[t|0]=k[t|0]+(w?a<<2:a);break N}a=t+1449|0;h[a|0]=k[a|0]+p(u,k[t+1457|0]);j[114626]=0;F(1345,b|0,w|0);a=j[114626];j[114626]=0;if((a|0)==1){break M}}e=e+1|0;if(e>>>0<l[b+480188>>1]){continue}break L}break}a=D()|0;C()|0;break c}if(j[f+40>>2]==65535?j[b+480180>>2]==4:0){break g}j[f+32>>2]=j[b+480216>>2];if(FK(Ib(Y,l[f+60>>1]))){Ca=f,Da=j[Ib(Y,l[f+60>>1])+16>>2],j[Ca+32>>2]=Da}j[114626]=0;t=E(1346,b|0,f|0)|0;a=j[114626];j[114626]=0;wa:{xa:{if((a|0)!=1){a=p(t,Q);o[B+32>>3]=+(a>>>0)/+m[b+24620>>2]+o[B+32>>3];j[f>>2]=a+j[f>>2];if(!(!l[b+480188>>1]|ua)){x=0;R=(M|0)!=0&(t|0)!=(M|0);ya=Q>>>0>1?Q:1;za=$-1|0;while(1){ya:{if(j[yc(A,x)+16>>2]==-1){break ya}v=1;za:{Aa:{u=p(x,896)+f|0;X=u+1421|0;switch(k[X|0]-4|0){case 0:case 2:break za;default:break Aa}}v=k[u+1420|0]==11}if(k[u+1419|0]){j[u+1268>>2]=0}T=u+1423|0;a=k[T|0];j[114626]=0;ga=u+1418|0;e=H(553,ga|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break k}w=u+608|0;r=a&15;n=0;Ba:{if(!e){break Ba}Ca:{Da:{Ea:{if(!v){break Ea}if(!k[yc(A,x)+20|0]){break Ea}e=j[u+1308>>2];j[114626]=0;e=Hn(1347,b,w,e,0);n=ab;y=j[114626];j[114626]=0;if((y|0)==1){break Da}j[u+616>>2]=e;j[u+620>>2]=n}h[u+1432|0]=k[u+1429|0];y=u+1300|0;Aa=j[y>>2];e=k[u+1433|0];if(!e){break Ca}j[114626]=0;aa(1348,b|0,w|0,e|0,v|0,1,1);e=j[114626];j[114626]=0;if((e|0)!=1){break Ca}break j}a=D()|0;C()|0;break c}e=k[ga|0];j[114626]=0;Z(1349,b|0,w|0,e|0,v|0,1,0,65535);e=j[114626];j[114626]=0;if((e|0)==1){break j}a=a>>>4|0;Ca=yc(A,x),Da=1,h[Ca+20|0]=Da;Ba=!(j[b+480180>>2]&16777250);e=k[X|0];Fa:{if(!((e-19&255)>>>0>1|r>>>0>=Q>>>0)){n=r;if((k[T|0]&-16)==208){break Fa}}n=a>>>0<Q>>>0?(e|0)==33?a:0:0}if(!(Ba|(!n|$>>>0<2))){n=p(j[f+40>>2]+ja|0,za)+n|0}if(!v){Ca=yc(A,x),Da=0,j[Ca+16>>2]=Da}e=k[X|0];Ga:{Ha:{Ia:{if(e-19>>>0>=2){if((e|0)!=9){break Ia}break Ha}if((a|0)==8){break Ha}}if(k[u+1420|0]!=2){break Ga}}j[y>>2]=Aa}Ja:{Ka:{switch(e-39|0){default:if((e|0)!=10){break Ja}h[g|0]=0;a=j[f+48>>2];e=l[f+60>>1];j[114626]=0;a=U(1343,b|0,e|0,a|0,x&65535,g|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){if(!k[g|0]){a=a<<8;if(!a){a=j[u+1272>>2]}a=(k[u+1464|0]<<16)+a|0}j[114626]=0;I(1350,b|0,w|0,a|0);a=j[114626];j[114626]=0;if((a|0)!=1){break Ba}}a=D()|0;C()|0;break c;case 2:a=j[u+684>>2];e=k[T|0];j[114626]=0;e=OMa(a,0,e,0);a=ab;y=a>>>8|0;a=ig(789,(a&255)<<24|e>>>8,y);e=j[114626];j[114626]=0;if((e|0)==1){break j}j[114626]=0;I(1350,b|0,w|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break j}break Ba;case 1:break Ja;case 0:break Ka}}if(!j[u+712>>2]){break Ja}j[114626]=0;L(1351,B|0,x&65535,M|0,-1);a=j[114626];j[114626]=0;if((a|0)==1){break j}a=k[T|0];j[114626]=0;I(1352,f|0,w|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break j}n=j[f+40>>2]-1|0;break Ba}if(k[u+1420|0]!=15){break Ba}a=k[u+1422|0];if(a>>>0>9){break Ba}e=j[u+712>>2];if(!e){break Ba}La:{if(!a){a=j[u+1272>>2];break La}a=j[(e+(a<<2)|0)- -64>>2];j[u+1272>>2]=a}j[114626]=0;I(1350,b|0,w|0,a|0);a=j[114626];j[114626]=0;if((a|0)!=1){break Ba}a=D()|0;C()|0;break c}Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{switch(k[ga|0]-253|0){case 0:if(l[b+480192>>1]){break Ua}break;case 1:case 2:break Ua;default:break Va}}e=k[X|0];if((e-19&255)>>>0<=1){if(r>>>0>=Q>>>0){a=s;break Sa}a=s;if((k[T|0]&-16)==192){break Ua}break Sa}y=e;if((e|0)==25){break Ua}a=s;if(!((y|0)==33&(r|0)!=0&n+r>>>0<Q>>>0)){break Ta}}e=k[X|0];a=1}if((e|0)==13){break Ra}}if(k[u+1420|0]==1){j[u+1296>>2]=k[u+1422|0]<<2}if((!j[u+712>>2]|a)&1){break Qa}r=0;if(e>>>0>42){break Oa}break Pa}j[u+1296>>2]=k[T|0]<<2;e=13;if(!((!j[u+712>>2]|a)&1)){break Pa}}if(!(a&1)){break Na}break Ma}mb(g,_,e);r=1;if(kb(g)){break Oa}r=a;if(k[X|0]!=19){break Oa}e=k[T|0]&240;if((e|0)!=32){r=a;if((e|0)!=16){break Oa}}r=1}a=u+1420|0;if(k[a|0]<16){rj(g,qa,k[a|0]);if((kb(g)|r)&1){break Ma}break Na}if(r&1){break Ma}}if(R){j[114626]=0;L(1351,B|0,x&65535,M|0,-1);a=j[114626];j[114626]=0;if((a|0)==1){break k}}Wa:{Xa:{Ya:{a=k[X|0];if(a-6>>>0>=2){Za:{switch(a-19|0){case 1:break Xa;case 0:break Ya;default:break Za}}if((a|0)!=11){break Wa}}if(!Q|(j[b+480180>>2]==1?!k[T|0]:0)){break Wa}a=u+1480|0;e=0;while(1){h[a|0]=!e|k[a|0]&254;Dm(b,w,k[T|0]);e=e+1|0;if((ya|0)!=(e|0)){continue}break}break Wa}e=k[T|0];if(!(e&15)){if(!(j[b+480180>>2]&1048580)){break Wa}e=k[T|0]}a=u+1480|0;h[a|0]=k[a|0]|1;a=e&240;if((a|0)!=176){if((a|0)!=160){break Wa}Do(b,w,e&15,0);break Wa}Co(b,w,e&15,0);break Wa}_a:{switch(k[T|0]-158|0){case 0:j[114626]=0;L(1351,B|0,x&65535,M|0,-1);a=j[114626];j[114626]=0;if((a|0)==1){break k}j[u+696>>2]=j[u+696>>2]&-129;break Wa;case 1:break _a;default:break Wa}}j[114626]=0;L(1351,B|0,x&65535,M|0,-1);a=j[114626];j[114626]=0;if((a|0)==1){break k}j[u+696>>2]=j[u+696>>2]|128;if(!j[u+684>>2]|j[w+4>>2]){break Wa}j[114626]=0;a=H(553,ga|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break k}if(k[u+696|0]&2?!a:0){break Wa}e=j[u+684>>2]-1|0;a=w;j[a>>2]=-1;j[a+4>>2]=e}e=u+1480|0;h[e|0]=k[e|0]|1;$a:{ab:{bb:{cb:{r=u+1420|0;switch(k[r|0]-3|0){case 0:case 1:break ab;case 3:break bb;case 2:break cb;default:break $a}}a=k[u+1422|0];mb(g,O,41);Do(b,w,a,kb(g));break $a}a=k[u+1422|0];mb(g,O,41);Co(b,w,a,kb(g));break $a}a=k[u+1422|0];db:{if(a){break db}mb(g,O,41);a=0;if(!kb(g)){break db}a=k[u+1462|0];if(!a){break $a}}if(!Q){break $a}r=k[r|0]==3?a<<4:a;a=0;while(1){h[e|0]=!a|k[e|0]&254;Dm(b,w,r&255);a=a+1|0;if((Q|0)!=(a|0)){continue}break}}if(v){a=j[yc(A,x)+16>>2];e=yc(A,x);j[e+16>>2]=j[e+16>>2]+Q;j[114626]=0;L(1351,B|0,x&65535,t|0,(a+n|0)+1|0);a=j[114626];j[114626]=0;if((a|0)!=1){break ya}a=D()|0;C()|0;break c}a=yc(A,x);j[a+16>>2]=j[a+16>>2]+(Q-n|0);break ya}j[114626]=0;N(1342,w|0);a=j[114626];j[114626]=0;if((a|0)==1){break k}Ca=yc(A,x),Da=0,j[Ca+16>>2]=Da}x=x+1|0;if(x>>>0<l[b+480188>>1]){continue}break}}if(!ka){break wa}mb(g,O,68);if(Ca=kb(g),Da=0,Fa=la|pa,Fa?Ca:Da){break wa}mb(g+48|0,O,49);if(kb(g+48|0)&la){break wa}mb(g+40|0,O,103);M=t;if(kb(g+40|0)&fa){continue}a=0;s=gpa(g);if(!l[b+480188>>1]){break xa}while(1){eb:{r=p(a,896)+f|0;e=k[r+1423|0];r=k[r+1421|0];if(!((r|0)!=19|(e-97&255)>>>0>14?!((e+79&255)>>>0<15?(r|0)==20:0):0)){S=o[yc(A,a)>>3];j[114626]=0;o[g+48>>3]=S;r=E(1353,s|0,g+48|0)|0;M=j[114626];j[114626]=0;if((M|0)==1){break eb}if(!j[r>>2]){j[114626]=0;r=E(1353,s|0,g+48|0)|0;M=j[114626];j[114626]=0;if((M|0)==1){break eb}j[r>>2]=1}j[114626]=0;r=E(1353,s|0,g+48|0)|0;M=j[114626];j[114626]=0;if((M|0)==1){break eb}r=j[r>>2];j[114626]=0;e=E(1354,r|0,(e&15)+1|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break eb}j[114626]=0;r=E(1353,s|0,g+48|0)|0;M=j[114626];j[114626]=0;if((M|0)==1){break eb}j[r>>2]=e}a=a+1|0;if(a>>>0<l[b+480188>>1]){continue}break xa}break}break l}a=D()|0;C()|0;break c}Ca=g,Da=Wm(s),j[Ca+40>>2]=Da;Ca=g,Da=ki(s),j[Ca+32>>2]=Da;while(1){j[114626]=0;a=E(1355,g+40|0,g+32|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break l}if(!a){fb:{if(j[b+480180>>2]!=32){break fb}a=0;if(!l[b+480188>>1]){break fb}while(1){e=p(a,896)+f|0;if(!(k[e+1421|0]!=20|(k[e+1423|0]+79&255)>>>0>14)){S=o[B+32>>3];Ca=yc(A,a),Ea=S,o[Ca>>3]=Ea;e=j[f>>2];Ca=yc(A,a),Da=e,j[Ca+8>>2]=Da}a=a+1|0;if(a>>>0<l[b+480188>>1]){continue}break}}xK(s);break wa}j[114626]=0;a=H(1356,g+40|0)|0;e=j[114626];j[114626]=0;gb:{hb:{if((e|0)!=1){r=hb(a);e=a;S=o[B+32>>3];o[B+32>>3]=(S-o[a>>3])*+(j[r>>2]-1|0)+S;a=0;if(l[b+480188>>1]){break hb}break gb}break l}while(1){if(o[yc(A,a)>>3]!=o[e>>3]){a=a+1|0;if(a>>>0<l[b+480188>>1]){continue}break gb}break}e=j[f>>2];M=yc(A,a);j[f>>2]=j[f>>2]+p(j[r>>2]-1|0,e-j[M+8>>2]|0);mb(g+48|0,O,16);if(Ca=!kb(g+48|0),Da=0,Fa=j[b+480180>>2]!=2,Fa?Ca:Da){break gb}S=o[B+32>>3];Ca=yc(A,a),Ea=S,o[Ca>>3]=Ea;e=j[f>>2];Ca=yc(A,a),Da=e,j[Ca+8>>2]=Da;e=j[f+48>>2];Ca=yc(A,a),Da=e+1|0,j[Ca+12>>2]=Da}j[114626]=0;H(1357,g+40|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){continue}break}break l}M=t;continue}}a=D()|0;C()|0;break c}a=D()|0;C()|0;xK(s);break c}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}ib:{jb:{if(!(!l[b+480188>>1]|(ra|0)!=7)){a=0;while(1){if(j[yc(A,a)+16>>2]!=-1){j[114626]=0;L(1351,B|0,a&65535,M|0,-1);d=j[114626];j[114626]=0;if((d|0)==1){break jb}}a=a+1|0;if(a>>>0<l[b+480188>>1]){continue}break}}if(k[J+26|0]){i[J+20>>1]=l[f+62>>1];j[J+8>>2]=j[f+48>>2]}o[J>>3]=o[B+32>>3];j[114626]=0;F(1334,oa|0,J|0);a=j[114626];j[114626]=0;if((a|0)==1){break ib}kb:{lb:{if(!ia){break lb}mb:{if(!(ba?!k[J+26|0]:0)){a=b+1074376|0;DK(a,f);wx(a);a=b+1074396|0;j[a>>2]=0;j[a+4>>2]=0;j[b+1074428>>2]=j[b+1074424>>2];h[b+1074464|0]=1;j[b+1074392>>2]=-2;nb:{if(l[b+480188>>1]){a=0;e=(ra|0)==7;while(1){d=p(a,896)+b|0;f=k[d+1075805|0];if(f){h[d+1075808|0]=f}if(!(k[yc(A,a)+21|0]==255|e)){f=yc(A,a);j[114626]=0;h[g|0]=64;f=E(391,f+21|0,g|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break nb}j[d+1075672>>2]=k[f|0]<<2}a=a+1|0;if(a>>>0<l[b+480188>>1]){continue}break}}a=b+1304392|0;if(bd(a)){a=j[a>>2];j[114626]=0;N(1358,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break ib}}d=sy(g);Ca=g,Da=Wm(sa),j[Ca+40>>2]=Da;Ca=g,Da=ki(sa),j[Ca+32>>2]=Da;ob:{while(1){pb:{j[114626]=0;a=E(1359,g+40|0,g+32|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break pb}if(!a){if(!Soa(d)){break mb}a=0;while(1){mb(g+48|0,d,a);qb:{if(!kb(g+48|0)){break qb}e=j[(p(a,160)+b|0)+906300>>2];f=j[j[e>>2]+172>>2];j[114626]=0;N(f|0,e|0);e=j[114626];j[114626]=0;if((e|0)!=1){break qb}a=D()|0;C()|0;break c}a=a+1|0;if((a|0)!=250){continue}break}break mb}j[114626]=0;e=H(1360,g+40|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break ob}f=k[e|0]-1&255;a=j[(p(f,160)+b|0)+906300>>2];if(a){mb(g+48|0,d,f);if(!kb(g+48|0)){j[114626]=0;K(1361,d|0,f|0,1)|0;f=j[114626];j[114626]=0;if((f|0)==1){break kb}f=j[j[a>>2]+168>>2];j[114626]=0;F(f|0,a|0,-1);f=j[114626];j[114626]=0;if((f|0)==1){break kb}}f=l[e+2>>1];s=j[j[a>>2]+44>>2];e=l[e+4>>1];j[114626]=0;ma(s|0,a|0,f|0,q(q(q(e>>>0)*q(.0010010009864345193))));a=j[114626];j[114626]=0;if((a|0)==1){break kb}}j[114626]=0;H(1362,g+40|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){continue}}break}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}if((c|0)==3){break mb}j[b+1074416>>2]=j[b+480196>>2];j[b+1074420>>2]=j[b+480204>>2];j[b+1074444>>2]=j[b+480200>>2]}if(k[na+16|0]==(ha|0)){break lb}j[114626]=0;F(488,na|0,ha|0);a=j[114626];j[114626]=0;if((a|0)==1){break ib}}if(c&9){j[114626]=0;F(1363,b+1304360|0,ca|0);a=j[114626];j[114626]=0;if((a|0)==1){break ib}}Bo(ca);CK(B);Za=g+176|0;return}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}a=D()|0;C()|0}Bo(ca);break b}a=D()|0;C()|0}CK(B);break a}a=D()|0;C()|0}hl(oa);G(a|0);z()}function VAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,J=0,M=0,N=0,O=0,Q=0,R=0,S=0,T=0;e=Za-1728|0;Za=e;rc(b);f=e+1600|0;o=AAa(b,f);if(!o){dO(f)}a:{if(!o){break a}if(!iO(e+1600|0)){break a}if(!yb(b,Wc(256,0))){break a}b:{if(!c){break b}od(a,1048576);_h(a);d=Eb(e+1584|0,16384);j[114626]=0;F(219,e+1328|0,d|0);f=j[114626];j[114626]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((f|0)!=1){x=e+1608|0;j[e+160>>2]=k[x+1|0];f=k[x|0];j[114626]=0;j[e+24>>2]=f;F(661,e+88|0,e+24|0);f=j[114626];j[114626]=0;if((f|0)==1){break r}j[114626]=0;L(646,e+240|0,e+1328|0,e+160|0,e+88|0);f=j[114626];j[114626]=0;if((f|0)==1){break q}ob(a+1304436|0,e+240|0);gb(e+240|0);gb(e+88|0);qb(e+1328|0);gb(d);d=Eb(e+240|0,16401);ob(a+1304448|0,d);gb(d);ug(e+88|0,2,e+1610|0);qc(e+1328|0,e+88|0);j[114626]=0;I(13,e+240|0,7,e+1328|0);d=j[114626];j[114626]=0;if((d|0)==1){break k}ob(a+1304460|0,e+240|0);gb(e+240|0);gb(e+1328|0);j[a+1304496>>2]=7;qt(e+1328|0,2,e+1642|0);qc(e+240|0,e+1328|0);ob(a+1304400|0,e+240|0);gb(e+240|0);d=e+1712|0;i[a+480188>>1]=k[d|0]|k[d+1|0]<<8;d=kd(k[e+1716|0],1,31);j[a+480204>>2]=125e4;j[a+480208>>2]=32792;j[a+480196>>2]=d;J=e+1722|0;i[a+480192>>1]=k[J|0]|k[J+1|0]<<8;M=e+1724|0;i[a+480190>>1]=k[M|0]|k[M+1|0]<<8;d=kd(k[e+1717|0],1,32);j[a+480216>>2]=d;j[a+480228>>2]=96;j[a+480232>>2]=48;j[a+480220>>2]=d<<2;Yz(b,e+1328|0);N=a+484360|0;y=e+1706|0;At(Fb(N),e+1328|0,k[y|0]|k[y+1|0]<<8,65535,65535);d=e+1708|0;Ge(Fb(N),k[d|0]|k[d+1|0]<<8);cd(e+1312|0,b,Of(b));j[114626]=0;d=H(390,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break n}j[114626]=0;I(341,e+1296|0,b|0,d|0);d=j[114626];j[114626]=0;if((d|0)==1){break n}v=l[a+480188>>1];j[114626]=0;w=E(258,e+1312|0,274)|0;d=j[114626];j[114626]=0;if((d|0)==1){break m}if(w){i[a+480188>>1]=l[a+480188>>1]+8}A=c&1;if(!A){break l}d=e+1710|0;d=k[d|0]|k[d+1|0]<<8;j[114626]=0;F(401,a+484344|0,d|0);d=j[114626];j[114626]=0;if((d|0)!=1){break l}break f}f=D()|0;C()|0;break o}f=D()|0;C()|0;break p}f=D()|0;C()|0;gb(e+88|0)}qb(e+1328|0)}gb(d);break c}f=D()|0;C()|0;break d}f=D()|0;C()|0;break e}u=e+1710|0;if(!(k[u|0]|k[u+1|0]<<8)){break g}O=a+484344|0;Q=e+1718|0;while(1){j[114626]=0;d=H(357,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break h}j[114626]=0;j[e+160>>2]=d;d=H(390,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break i}j[114626]=0;I(341,e+240|0,b|0,d+1&-2);d=j[114626];j[114626]=0;if((d|0)==1){break i}kc(e+160|0,1024);s:{if(!A){break s}d=j[e+160>>2];if(!d){break s}j[114626]=0;d=K(402,O|0,n&65535,d|0)|0;f=j[114626];j[114626]=0;t:{if((f|0)!=1){if(!d){break s}q=0;if(h[Q|0]&1){g=0;while(1){j[114626]=0;d=E(258,e+240|0,1)|0;f=j[114626];j[114626]=0;u:{if((f|0)!=1){if(!d){break s}j[114626]=0;d=H(387,e+240|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break j}f=0;if((d|0)!=255){break u}j[114626]=0;f=H(387,e+240|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;d=H(387,e+240|0)|0;o=j[114626];j[114626]=0;if((o|0)!=1){break u}}break j}break j}v:{if(!(d&127)){break v}o=Ib(O,n);j[114626]=0;o=K(471,o|0,g|0,q&65535)|0;r=j[114626];j[114626]=0;if((r|0)==1){break j}h[e+88|0]=0;h[e+89|0]=0;h[e+90|0]=0;h[e+91|0]=0;h[e+91|0]=0;h[e+92|0]=0;h[e+93|0]=0;h[e+94|0]=0;if(d&1){j[114626]=0;r=H(387,e+240|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break j}h[e+88|0]=r}if(d&2){j[114626]=0;r=H(387,e+240|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break j}h[e+89|0]=r}if(d&4){j[114626]=0;r=H(387,e+240|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break j}h[e+90|0]=r}if(d&8){j[114626]=0;r=H(387,e+240|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break j}h[e+91|0]=r}if(d&16){j[114626]=0;r=H(387,e+240|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break j}h[e+92|0]=r}if(d&32){j[114626]=0;r=H(387,e+240|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break j}h[e+93|0]=r}if(d&64){j[114626]=0;d=H(387,e+240|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break j}h[e+94|0]=d}j[114626]=0;d=E(892,o|0,e+88|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break j}j[114626]=0;j[e+24>>2]=f;j[e+224>>2]=j[e+160>>2]+(g^-1);r=E(629,e+24|0,e+224|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break j}t=d|t;R=j[r>>2];if(!R){break v}r=0;d=o;while(1){d=p(l[a+480188>>1],6)+d|0;s=k[o|0]|k[o+1|0]<<8|(k[o+2|0]<<16|k[o+3|0]<<24);h[d|0]=s;h[d+1|0]=s>>>8;h[d+2|0]=s>>>16;h[d+3|0]=s>>>24;s=k[o+4|0]|k[o+5|0]<<8;h[d+4|0]=s;h[d+5|0]=s>>>8;r=r+1|0;if((R|0)!=(r|0)){continue}break}}g=(f+g|0)+1|0;d=j[e+160>>2];if(g>>>0>=d>>>0){while(1){q=q+1|0;g=g-d|0;if(d>>>0<=g>>>0){continue}break}}if((q&65535)>>>0<v>>>0){continue}break}break s}f=0;if(j[e+160>>2]){break t}break s}break j}while(1){d=Ib(O,n);j[114626]=0;o=E(496,d|0,f|0)|0;d=j[114626];j[114626]=0;w:{x:{if((d|0)!=1){d=0;if(v){break x}break w}break j}while(1){y:{j[114626]=0;E(893,e+240|0,e+88|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break y}j[114626]=0;g=E(892,o+p(d,6)|0,e+88|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break y}t=g|t;d=d+1|0;if((v|0)!=(d|0)){continue}break w}break}break j}f=f+1|0;if(f>>>0<m[e+160>>2]){continue}break}}jb(e+240|0);n=n+1|0;if(n>>>0<(k[u|0]|k[u+1|0]<<8)>>>0){continue}break}break g}f=D()|0;C()|0;gb(e+1328|0);break c}f=D()|0;C()|0;jb(e+240|0);break e}f=D()|0;C()|0;break e}f=D()|0;C()|0;break e}d=e+1714|0;z:{if((k[d|0]|k[d+1|0]<<8)>>>0<=1|(k[d|0]|k[d+1|0]<<8)>>>0>4999){break z}if(t&1){d=k[d|0]|k[d+1|0]<<8;j[114626]=0;d=ig(458,((d>>>1|0)+11025e5>>>0)/(d>>>0)|0,0);f=j[114626];j[114626]=0;if((f|0)==1){break f}j[a+480224>>2]=0;j[a+480204>>2]=d;break z}f=j[a+480216>>2];o=j[a+480196>>2];n=k[d|0]|k[d+1|0]<<8;j[a+480224>>2]=2;d=a;B=2646e7/+(p(n,p(f,o))>>>0);A:{if(B<4294967296&B>=0){f=~~B>>>0;break A}f=0}j[d+480204>>2]=f}d=l[a+480188>>1];j[114626]=0;h[e+240|0]=0;O=K(894,e+1280|0,d|0,e+240|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){g=a+1304412|0;o=a+484344|0;s=a+1304424|0;A=e+240|3;r=0;B:{C:{D:{E:{F:{while(1){j[114626]=0;d=E(258,e+1296|0,8)|0;f=j[114626];j[114626]=0;G:{if((f|0)!=1){if(d){break G}if(l[a+480188>>1]){d=0;while(1){f=h[fc(O,d)|0];H:{if((f|0)<=(d|0)|(f|0)>=l[a+480188>>1]){break H}n=((f<<5)+a|0)+480288|0;f=k[n|0];if(!f){break H}g=((d<<5)+a|0)+480288|0;q=k[g|0];if(!q){h[g|0]=f;break H}g=(p(q-1&255,160)+a|0)+906300|0;if((fj(g)|0)!=255){while(1){g=(p(fj(g),160)+a|0)+906300|0;if((fj(g)|0)!=255){continue}break}}f=g+28|0;n=k[n|0]-1&255;n=n>>>0<250?n+128|0:0;h[f|0]=n;h[f+1|0]=n>>>8;h[f+2|0]=n>>>16;h[f+3|0]=n>>>24}d=d+1|0;if(d>>>0<l[a+480188>>1]){continue}break}}j[e+232>>2]=0;j[e+236>>2]=0;j[e+224>>2]=0;j[e+228>>2]=0;j[e+216>>2]=0;j[e+220>>2]=0;j[e+208>>2]=0;j[e+212>>2]=0;I:{J:{K:{L:{M:{N:{if(w){j[114626]=0;E(895,e+1312|0,e+240|0)|0;d=j[114626];j[114626]=0;O:{if((d|0)!=1){g=0;while(1){d=l[a+480192>>1];j[114626]=0;d=E(896,a|0,d+1&65535)|0;f=j[114626];j[114626]=0;P:{Q:{R:{S:{T:{U:{V:{if((f|0)!=1){f=g<<1;n=f+(e+224|0)|0;i[n>>1]=d;s=f+(e+208|0)|0;f=e+f|0;q=f+242|0;i[s>>1]=k[q|0]|k[q+1|0]<<8;if((d|0)==65535){break Q}f=k[f+242|0]|k[f+243|0]<<8;j[114626]=0;d=K(454,a|0,d|0,f+1&65535)|0;f=j[114626];j[114626]=0;if((f|0)==1){break V}if(!d){break P}j[114626]=0;F(508,e+160|0,16418);f=j[114626];j[114626]=0;if((f|0)==1){break U}j[114626]=0;j[e+24>>2]=g+1;I(897,e+88|0,e+160|0,e+24|0);f=j[114626];j[114626]=0;if((f|0)==1){break T}j[114626]=0;E(369,d+492|0,e+88|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break S}gb(e+88|0);qb(e+160|0);break P}f=D()|0;C()|0;break B}f=D()|0;C()|0;break B}f=D()|0;C()|0;break B}f=D()|0;C()|0;break R}f=D()|0;C()|0;gb(e+88|0)}qb(e+160|0);break B}i[n>>1]=0}g=g+1|0;if((g|0)!=8){continue}break}break O}f=D()|0;C()|0;break B}d=k[e+240|0]|k[e+241|0]<<8;j[114626]=0;s=E(395,e+160|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break I}if(k[e+240|0]|k[e+241|0]<<8){d=0;while(1){j[114626]=0;f=H(357,b|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break K}j[114626]=0;I(341,e+88|0,b|0,f<<5);f=j[114626];j[114626]=0;if((f|0)==1){break L}Ed(_b(s,d),e+88|0);jb(e+88|0);d=d+1|0;if(d>>>0<(k[e+240|0]|k[e+241|0]<<8)>>>0){continue}break}}d=k[u|0]|k[u+1|0]<<8;j[114626]=0;t=K(898,e+88|0,d|0,16428)|0;d=j[114626];j[114626]=0;if((d|0)==1){break M}if(k[y|0]|k[y+1|0]<<8){n=0;while(1){g=e+n|0;W:{if(k[g+258|0]>=(k[e+240|0]|k[e+241|0]<<8)>>>0){break W}if(l[ac(Fb(N),n)>>1]>=(k[u|0]|k[u+1|0]<<8)>>>0){break W}f=l[ac(Fb(N),n)>>1];X:{if(l[ac(t,f)>>1]==65535){d=k[g+258|0];S=ac(t,f),T=d,i[S>>1]=T;break X}if(l[ac(t,f)>>1]==k[g+258|0]){break X}j[114626]=0;d=K(899,o|0,f|0,0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break N}if((d|0)==65535){break X}S=ac(Fb(N),n),T=d,i[S>>1]=T;f=d}j[114626]=0;d=E(442,o|0,f|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break N}if(!d){break W}A=_b(s,k[g+258|0]);rc(A);j[114626]=0;d=H(255,A|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break N}if(!j[Ib(o,f)+12>>2]){break W}Q=d>>>5|0;q=0;while(1){d=Ib(o,f);g=l[a+480188>>1];j[114626]=0;d=K(471,d|0,q|0,g-8&65535)|0;g=j[114626];j[114626]=0;if((g|0)==1){break N}g=0;while(1){Ug(e+24|0);w=l[e+28>>1];h[d+4|0]=w;h[d+5|0]=w>>>8;w=j[e+24>>2];h[d|0]=w;h[d+1|0]=w>>>8;h[d+2|0]=w>>>16;h[d+3|0]=w>>>24;Y:{if(q>>>0>=Q>>>0){break Y}j[114626]=0;E(900,A|0,e+24|0)|0;w=j[114626];j[114626]=0;if((w|0)==1){break N}if(h[e+24|0]>-1){break Y}h[d|0]=61;h[d+1|0]=k[(e+224|0)+(g<<1)|0];w=k[e+24|0]&31;h[e+72|0]=w;if(w){Ae(e+72|0,15);h[d+3|0]=20;h[d+5|0]=k[e+72|0]|208}h[d+2|0]=1;h[d+4|0]=k[e+25|0]+3>>>2}d=d+6|0;g=g+1|0;if((g|0)!=8){continue}break}q=q+1|0;if(q>>>0<m[Ib(o,f)+12>>2]){continue}break}}n=n+1|0;if(n>>>0<(k[y|0]|k[y+1|0]<<8)>>>0){continue}break}}ff(t);Sc(s)}d=e+1718|0;Z:{if(!(k[d|0]&2)){break Z}v=k[d|0]&8?l[a+480188>>1]:v;if(!(k[u|0]|k[u+1|0]<<8)){break Z}d=((v&65535)+((k[x|0]|k[x+1|0]<<8)>>>0>591?r:0)|0)+((k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24))>>>4&1)|0;v=0;while(1){g=0;_:{if(!d){break _}while(1){$:{j[114626]=0;f=E(258,b|0,4)|0;o=j[114626];j[114626]=0;if((o|0)==1){break $}if(!f){break _}f=k[x|0]|k[x+1|0]<<8;j[114626]=0;F(901,f|0,b|0);f=j[114626];j[114626]=0;if((f|0)==1){break $}g=g+1|0;if((d|0)!=(g|0)){continue}break _}break}f=D()|0;C()|0;break B}v=v+1|0;if(v>>>0<(k[u|0]|k[u+1|0]<<8)>>>0){continue}break}}j[114626]=0;u=E(395,e+192|0,255)|0;d=j[114626];j[114626]=0;aa:{ba:{ca:{da:{ea:{fa:{if((d|0)!=1){w=e+88|7;N=e+88|1;s=e+88|4;y=e+88|2;A=e+88|3;n=0;while(1){d=n;j[114626]=0;E(902,b|0,e+160|0)|0;f=j[114626];j[114626]=0;ga:{ha:{ia:{ja:{if((f|0)!=1){j[114626]=0;f=H(390,b|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break ja}o=k[x|0]|k[x+1|0]<<8;j[114626]=0;f=(f|0)==32?428:f;f=f?o>>>0>513?f+4|0:f:f;I(341,e+240|0,b|0,f|0);o=j[114626];j[114626]=0;if((o|0)==1){break ia}n=d+1|0;q=Ie(e+24|0,Ed(_b(u,d),e+240|0));jb(e+240|0);if(d>>>0>=(k[J|0]|k[J+1|0]<<8)>>>0){break ga}j[114626]=0;d=n&65535;g=K(454,a|0,d|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break ha}f=D()|0;C()|0;break ba}f=D()|0;C()|0;break aa}f=D()|0;C()|0;break aa}f=D()|0;C()|0;break aa}if(!g){break ga}j[114626]=0;I(745,e+88|0,2,e+160|0);d=j[114626];j[114626]=0;ka:{la:{ma:{if((d|0)==1){break ma}j[114626]=0;F(415,e+240|0,e+88|0);d=j[114626];j[114626]=0;if((d|0)==1){break ma}j[114626]=0;E(369,g+492|0,e+240|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break la}gb(e+240|0);if(!f){break ga}j[114626]=0;E(903,q|0,e+240|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break da}t=0;if((k[x|0]|k[x+1|0]<<8)>>>0<513){break ka}j[114626]=0;t=H(357,q|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break ka}f=D()|0;C()|0;break ba}f=D()|0;C()|0;break ba}f=D()|0;C()|0;gb(e+240|0);break ba}f=3;na:{if((k[x|0]|k[x+1|0]<<8)>>>0<514){break na}j[114626]=0;f=H(390,q|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break na}f=D()|0;C()|0;break ba}j[g>>2]=k[e+342|0]|k[e+343|0]<<8;h[g+16|0]=k[((k[e+344|0]|k[e+345|0]<<8)&3)+16430|0];h[g+17|0]=k[(k[e+345|0]&3)+16430|0];h[g+18|0]=k[((k[e+344|0]|k[e+345|0]<<8)>>>12&3)+16434|0];v=0;oa:{pa:{qa:{ra:{while(1){sa:{if(!(f&1)){break sa}j[114626]=0;E(904,q|0,e+88|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break ra}j[114626]=0;o=E(374,g|0,k[v+16438|0])|0;d=j[114626];j[114626]=0;if((d|0)==1){break qa}d=o;if(!(h[e+88|0]&1)|(v|0)!=3){r=k[o+12|0]&-17}else{r=k[o+12|0]|16}h[d+12|0]=r;h[o+12|0]=k[o+12|0]&254|h[e+88|0]&1;h[o+12|0]=k[o+12|0]&251|k[e+88|0]<<1&4;h[o+12|0]=k[o+12|0]&253|k[e+88|0]>>>1&2;d=k[N|0];j[114626]=0;h[e+72|0]=d;h[e+56|0]=16;d=E(391,e+72|0,e+56|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break pa}d=k[d|0];j[114626]=0;F(591,o|0,d|0);d=j[114626];j[114626]=0;if((d|0)==1){break pa}d=k[y|0];h[o+15|0]=d;h[o+16|0]=d;h[o+13|0]=k[A|0];h[o+14|0]=k[s|0];d=0;if(!sb(o)){break sa}while(1){r=(e+88|0)+(d<<2)|0;Q=k[r+8|0]|k[r+9|0]<<8;S=xb(o,d),T=Q,i[S>>1]=T;r=kd(k[r+10|0]|k[r+11|0]<<8,0,64);S=xb(o,d),T=r,h[S+2|0]=T;d=d+1|0;if(sb(o)>>>0>d>>>0){continue}break}}f=f>>>1|0;v=v+1|0;if((v|0)!=4){continue}break}if(!(h[g+60|0]&1|k[g+16|0]==3)){j[g>>2]=32767}j[114626]=0;I(905,g|0,127,1);d=j[114626];j[114626]=0;if((d|0)==1){break fa}j[114626]=0;I(906,g|0,0,1);d=j[114626];j[114626]=0;if((d|0)==1){break fa}if(!t){break ga}j[114626]=0;E(907,q|0,e+88|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break ca}if(!(t&2)){break oa}d=k[y|0]|k[y+1|0]<<8;j[114626]=0;d=Ya(908,a|0,+(d>>>0))|0;f=j[114626];j[114626]=0;if((f|0)==1){break ca}j[114626]=0;I(905,g|0,d|0,1);d=j[114626];j[114626]=0;if((d|0)==1){break ca}d=k[s|0];j[114626]=0;I(906,g|0,d|0,1);d=j[114626];j[114626]=0;if((d|0)!=1){break oa}break ca}f=D()|0;C()|0;break ba}f=D()|0;C()|0;break ba}f=D()|0;C()|0;break ba}h[g+25|0]=k[N|0]==1;if(!(t&4)){break ga}h[g+31|0]=k[w|0]+1;h[g+34|0]=k[e+96|0]+1;if(h[e+96|0]<=-1){h[g+30|0]=k[e+103|0]+1}if(k[e+100|0]){d=0;o=g+108|0;while(1){f=d+1|0;j[e+72>>2]=f+h[e+100|0];gO(e+72|0);v=j[e+72>>2];S=Pb(o,d),T=v,h[S|0]=T;d=f;if(d>>>0<128){continue}break}}j[114626]=0;F(776,g|0,0);d=j[114626];j[114626]=0;if((d|0)==1){break ca}}jb(q);if((n|0)!=255){continue}break}v=sy(e+88|0);o=e+24|4;x=sy(e+160|0);g=0;ta:{ua:{while(1){j[114626]=0;E(902,b|0,e+240|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break ta}j[114626]=0;d=H(390,b|0)|0;f=j[114626];j[114626]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{if((f|0)!=1){j[114626]=0;I(341,e+72|0,b|0,d|0);f=j[114626];j[114626]=0;if((f|0)==1){break Ca}if((k[M|0]|k[M+1|0]<<8)>>>0>g>>>0){j[114626]=0;I(745,e+56|0,2,e+240|0);f=j[114626];j[114626]=0;if((f|0)==1){break va}j[114626]=0;F(415,e+24|0,e+56|0);f=j[114626];j[114626]=0;if((f|0)==1){break va}j[114626]=0;E(369,((g<<5)+a|0)+946332|0,e+24|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Ba}gb(e+24|0)}if(!d|(k[M|0]|k[M+1|0]<<8)>>>0<=g>>>0){break wa}j[114626]=0;d=p(g+1|0,104)+a|0;f=d+484380|0;F(386,f|0,32);n=j[114626];j[114626]=0;if((n|0)==1){break Aa}j[114626]=0;E(909,e+72|0,e+24|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break za}j[f>>2]=k[e+24|0]|k[e+25|0]<<8|(k[e+26|0]<<16|k[e+27|0]<<24);j[d+484404>>2]=k[o|0]|k[o+1|0]<<8|(k[o+2|0]<<16|k[o+3|0]<<24);if(k[e+32|0]>=2){n=d+484414|0;i[n>>1]=l[n>>1]|1;j[f>>2]=j[f>>2]>>>1}if(k[e+33|0]>=2){n=d+484414|0;i[n>>1]=l[n>>1]|64;j[f>>2]=j[f>>2]>>>1}t=2;Da:{if(k[e+35|0]!=1){t=6;if(k[e+35|0]!=2){break Da}}f=d+484414|0;i[f>>1]=l[f>>1]|t}j[d+484384>>2]=k[e+36|0]|k[e+37|0]<<8|(k[e+38|0]<<16|k[e+39|0]<<24);j[d+484388>>2]=k[e+40|0]|k[e+41|0]<<8|(k[e+42|0]<<16|k[e+43|0]<<24);i[d+484410>>1]=(k[e+44|0]|k[e+45|0]<<8)>>>7;if(k[e+46|0]!=128){break ya}f=d+484414|0;q=l[f>>1]|256;i[f>>1]=q;break xa}f=D()|0;C()|0;break aa}f=D()|0;C()|0;break aa}f=D()|0;C()|0;gb(e+24|0);break ua}f=D()|0;C()|0;break ua}f=D()|0;C()|0;break ua}i[d+484408>>1]=h[e+46|0]+128;q=l[d+484414>>1]}f=d+484414|0;i[f>>1]=q|32;h[d+484416|0]=k[e+47|0];if(k[e+34|0]&2){mb(e+56|0,x,g);Qd(e+56|0,1)}if(k[e+34|0]&5){i[f>>1]=l[f>>1]|16384}if(!(k[e+34|0]&8)){break wa}mb(e+56|0,v,g);Qd(e+56|0,1);d=0;while(1){f=d<<1;Ea:{if(l[f+(e+208|0)>>1]!=(g|0)){break Ea}f=j[((l[f+(e+224|0)>>1]<<2)+a|0)+900380>>2];if(!f){break Ea}h[f+14|0]=0}d=d+1|0;if((d|0)!=8){continue}break}}jb(e+72|0);g=g+1|0;if((g|0)==256){break ea}continue}break}f=D()|0;C()|0}jb(e+72|0);break aa}f=D()|0;C()|0;break aa}f=D()|0;C()|0;break B}f=D()|0;C()|0;break ba}Fa:{if(!(k[J|0]|k[J+1|0]<<8)){break Fa}f=0;Ga:{Ha:{while(1){Ia:{d=_b(u,f);j[114626]=0;d=H(255,d|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break Ia}Ja:{if(!d){f=f+1|0;break Ja}d=_b(u,f);rc(d);j[114626]=0;E(903,d|0,e+240|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Ha}g=e+24|0;EAa(g);d=k[e+240|0]|k[e+241|0]<<8;j[114626]=0;K(910,b|0,g|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Ga}f=f+1|0;o=j[((f<<2)+a|0)+900380>>2];if(!(!o|k[o+34|0])){j[o+4>>2]=32;j[114626]=0;F(776,o|0,0);d=j[114626];j[114626]=0;if((d|0)==1){break Ga}M=o+108|0;y=o+236|0;d=0;while(1){n=d+e|0;Ka:{if(k[n+242|0]>=(k[e+240|0]|k[e+241|0]<<8)>>>0){break Ka}t=uk(g,k[n+242|0]);n=k[t|0];q=n+1|0;r=d+12|0;S=Oc(y,r),T=q,i[S>>1]=T;if(n>>>0>=l[a+480190>>1]){break Ka}n=p(q,104)+a|0;h[n+484418|0]=k[e+338|0]&3;h[n+484419|0]=k[e+339|0];h[n+484420|0]=k[e+340|0];h[n+484421|0]=k[e+341|0];i[n+484412>>1]=k[t+1|0]<<1;h[n+484417|0]=k[t+2|0];n=q-1|0;mb(e+72|0,v,n);if(kb(e+72|0)){h[o+14|0]=0}mb(e+72|0,x,n);if(!kb(e+72|0)){break Ka}S=Pb(M,r),T=61,h[S|0]=T}d=d+1|0;if((d|0)!=96){continue}break}}fO(g)}if((k[J|0]|k[J+1|0]<<8)>>>0>f>>>0){continue}break Fa}break}f=D()|0;C()|0;break aa}f=D()|0;C()|0;break aa}f=D()|0;C()|0;fO(g);break aa}La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{if(!(!(c&2)|!l[a+480190>>1])){g=0;while(1){g=g+1|0;d=p(g,104)+a|0;c=d+484416|0;f=h[c|0];o=d+484417|0;n=h[o|0];j[114626]=0;q=d+484380|0;fa(911,q|0,+((+(n|0)*.0078125- +(f-49|0))*.08333333333333333));f=j[114626];j[114626]=0;if((f|0)==1){break La}h[o|0]=0;h[c|0]=0;c=l[d+484414>>1];Xa:{if(!(c&16384)){c=Mc(e+240|0,c&1?16:8,c&64?3:1,0,12);j[114626]=0;K(400,c|0,q|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break Xa}f=D()|0;C()|0;break aa}j[114626]=0;f=H(390,b|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break Wa}j[114626]=0;E(338,b|0,12)|0;c=j[114626];j[114626]=0;if((c|0)==1){break Wa}c=Db(e+240|0);j[114626]=0;K(481,b|0,c|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Va}j[114626]=0;E(370,d+484423|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Va}j[114626]=0;d=E(2,e+8|0,16442)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Ua}j[114626]=0;F(219,e+72|0,d|0);f=j[114626];j[114626]=0;if((f|0)==1){break Ta}j[e+4>>2]=g;f=_y(a);j[114626]=0;I(13,e+56|0,f|0,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break Sa}j[114626]=0;L(646,e+24|0,e+72|0,e+4|0,e+56|0);f=j[114626];j[114626]=0;if((f|0)==1){break Ra}j[114626]=0;I(647,a|0,2,e+24|0);f=j[114626];j[114626]=0;if((f|0)==1){break Qa}gb(e+24|0);gb(e+56|0);qb(e+72|0);gb(d);gb(c)}if(l[a+480190>>1]>g>>>0){continue}break}}Sc(u);Np(O);jb(e+1296|0);jb(e+1312|0);break b}f=D()|0;C()|0;break aa}f=D()|0;C()|0;break Ma}f=D()|0;C()|0;break Ma}f=D()|0;C()|0;break Na}f=D()|0;C()|0;break Oa}f=D()|0;C()|0;break Pa}f=D()|0;C()|0;gb(e+24|0)}gb(e+56|0)}qb(e+72|0)}gb(d)}gb(c);break aa}f=D()|0;C()|0;break aa}f=D()|0;C()|0;break ba}f=D()|0;C()|0}jb(q)}Sc(u);break B}f=D()|0;C()|0;ff(t);break J}f=D()|0;C()|0;break J}f=D()|0;C()|0;break J}f=D()|0;C()|0}Sc(s);break B}f=D()|0;C()|0;break B}f=D()|0;C()|0;break B}j[114626]=0;f=H(390,e+1296|0)|0;n=j[114626];j[114626]=0;d=a;Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{if((n|0)!=1){j[114626]=0;n=H(390,e+1296|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break kb}j[114626]=0;I(341,e+88|0,e+1296|0,n|0);n=j[114626];j[114626]=0;if((n|0)==1){break kb}if((f|0)<=844387157){if((f|0)==4674381){break ab}if((f|0)==5068115){break $a}if(t&1|(f|0)!=726487106){break Za}j[a+480224>>2]=2;j[114626]=0;B=+$(912,e+88|0);f=j[114626];j[114626]=0;if((f|0)==1){break Ya}if(B==0){break Za}B=2646e7/(B*+(p(j[a+480216>>2],j[a+480196>>2])>>>0));if(!(B<4294967296&B>=0)){break jb}f=~~B>>>0;break ib}if((f|0)<=1314144591){if((f|0)==844387158){break _a}if((f|0)!=1280004692){break Za}q=0;if(!l[a+480188>>1]){break Za}while(1){j[114626]=0;d=E(258,e+88|0,1)|0;f=j[114626];j[114626]=0;if((f|0)==1){break E}if(!d){break Za}d=Db(e+240|0);j[114626]=0;K(597,e+88|0,d|0,-1)|0;f=j[114626];j[114626]=0;if((f|0)==1){break gb}f=zb(d);n=nb(d);j[114626]=0;L(414,e+24|0,3,f|0,n|0);f=j[114626];j[114626]=0;if((f|0)==1){break fb}j[114626]=0;F(415,e+160|0,e+24|0);f=j[114626];j[114626]=0;if((f|0)==1){break fb}j[114626]=0;E(378,((q<<5)+a|0)+480289|0,e+160|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break eb}gb(e+160|0);gb(d);q=q+1|0;if(q>>>0<l[a+480188>>1]){continue}break}break Za}if((f|0)==1397445204){break hb}if((f|0)!=1314144592){break Za}d=0;if(!(k[u|0]|k[u+1|0]<<8)){break Za}while(1){j[114626]=0;f=E(258,e+88|0,1)|0;n=j[114626];j[114626]=0;if((n|0)==1){break cb}if(!f){break Za}j[114626]=0;f=E(913,o|0,d&65535)|0;n=j[114626];j[114626]=0;if((n|0)==1){break cb}if(!f){break Za}n=Db(e+240|0);j[114626]=0;K(597,e+88|0,n|0,-1)|0;f=j[114626];j[114626]=0;if((f|0)==1){break bb}f=Ib(o,d);j[114626]=0;E(495,f|0,n|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break bb}gb(n);d=d+1|0;if(d>>>0<(k[u|0]|k[u+1|0]<<8)>>>0){continue}break}break Za}f=D()|0;C()|0;break B}f=D()|0;C()|0;break B}f=0}j[d+480204>>2]=f;break Za}j[114626]=0;d=H(357,e+88|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break D}j[a+480232>>2]=d>>>9;j[a+480228>>2]=d>>>8;d=0;if(!l[a+480188>>1]){break Za}while(1){j[114626]=0;f=E(914,e+88|0,e+240|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break F}if(f){i[((d<<5)+a|0)+480286>>1]=(k[e+240|0]|k[e+241|0]<<8)>>>10;f=k[A|0];S=fc(O,d),T=f,h[S|0]=T}d=d+1|0;if(d>>>0<l[a+480188>>1]){continue}break}break Za}f=D()|0;C()|0;break db}f=D()|0;C()|0;break db}f=D()|0;C()|0;gb(e+160|0)}gb(d);break C}f=D()|0;C()|0;break C}f=D()|0;C()|0;gb(n);break C}j[114626]=0;E(338,e+88|0,1)|0;d=j[114626];j[114626]=0;if((d|0)==1){break D}j[114626]=0;d=H(540,e+88|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break D}j[114626]=0;P(584,s|0,e+88|0,d|0,2)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break Za}break D}j[114626]=0;E(915,e+88|0,e+24|0)|0;d=j[114626];j[114626]=0;lb:{if((d|0)!=1){d=Db(e+240|0);j[114626]=0;K(597,e+88|0,d|0,-1)|0;f=j[114626];j[114626]=0;if((f|0)==1){break lb}if(_s(d,16405)){j[114626]=0;I(13,e+160|0,7,d|0);f=j[114626];j[114626]=0;if((f|0)==1){break lb}ob(g,e+160|0);gb(e+160|0)}gb(d);break Za}f=D()|0;C()|0;break C}f=D()|0;C()|0;gb(d);break C}j[114626]=0;r=H(390,e+88|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break D}}jb(e+88|0);continue}break}f=D()|0;C()|0;break C}f=D()|0;C()|0;break C}f=D()|0;C()|0;break C}f=D()|0;C()|0}jb(e+88|0)}Np(O);break e}f=D()|0;C()|0;break e}f=D()|0;C()|0}jb(e+1296|0)}jb(e+1312|0)}G(f|0);z()}d=1}Za=e+1728|0;return d|0}function $f(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,r=0,s=0,t=0,u=0,v=q(0),w=0,x=0,y=0,A=0,B=0,F=0,L=0,N=0;d=Za-2928|0;Za=d;a:{b:{c:{d:{e:{if(Sp(c)){kc(b,268435456);y=j[c+8>>2];t=d+2904|0;f=t;j[f>>2]=0;j[f+4>>2]=0;ri(f+8|0);j[d+2900>>2]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{f=d;p:{q:{r:{s:{if(k[a+3|0]-4>>>0<=4){j[114626]=0;e=H(540,c|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break m}j[d+2900>>2]=e;break s}e=k[a+3|0];if(e>>>0>18){break s}e=1<<e;t:{if(!(e&126991)){if(e&396800){break t}break s}if(!k[a|0]){break s}}e=j[b>>2];j[114626]=0;e=E(644,a|0,e|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break r}j[114626]=0;I(853,d+736|0,c|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break r}e=d+736|0;g=j[e+4>>2];j[t>>2]=j[e>>2];j[t+4>>2]=g;vpa(t+8|0,e+8|0);lc(d+736|0);j[114626]=0;g=H(412,t|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break m}j[d+2900>>2]=j[t>>2]}e=k[a+3|0];if(e>>>0>18){break o}r=1<<e;u:{if(!(r&126991)){e=0;if(r&396800){break u}break o}e=!k[a|0]}if(e|m[b>>2]<262145){break o}e=j[d+2900>>2];r=k[a+3|0];j[114626]=0;j[d+720>>2]=((r|0)==11)<<4;r=E(33,d+720|0,d+2900|0)|0;s=j[114626];j[114626]=0;if((s|0)!=1){j[d+736>>2]=e-j[r>>2];e=k[a+3|0];if(e>>>0>16){break q}v:{if(!(1<<e&126991)){if((e|0)==11){break v}break q}if(!(k[a|0]&7)){break q}}e=j[d+736>>2];if(e>>>0<=2147483647){e=e<<1;break p}e=-1;break p}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}e=0;j[114626]=0;r=H(1255,a|0)|0;s=j[114626];j[114626]=0;w:{x:{if((s|0)!=1){y:{z:{switch(k[a+3|0]){case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:e=k[a|0];break y;case 9:e=16;break y;case 11:e=4;break y;case 10:case 17:case 18:break z;default:break y}}e=8}r=p(e,r)>>>3|0;e=r-1|0;s=j[d+736>>2];if(e>>>0>-1-s>>>0){break x}e=e+s|0;break w}a=D()|0;C()|0;break a}e=-1}e=(e>>>0)/(r>>>0)|0}j[f+736>>2]=e;kc(b,e);break n}f=d;A:{B:{C:{D:{if(!(k[a+3|0]==4|k[a+3|0]==5|(k[a+3|0]==8|k[a+3|0]==7))){if(k[a+3|0]!=6){break n}e=0;if(m[d+2900>>2]<10){break f}j[114626]=0;E(338,c|0,4)|0;e=j[114626];j[114626]=0;if((e|0)==1){break m}j[114626]=0;e=H(390,c|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break D}j[d+720>>2]=e;e=j[d+2900>>2];j[114626]=0;j[d+2896>>2]=e;e=E(629,d+720|0,d+2896|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break C}j[d+736>>2]=j[e>>2];cg(c,8);e=j[d+736>>2];if(e>>>0>50529027){break B}e=p(e,85);break A}j[114626]=0;j[d+736>>2]=j[d+2900>>2];e=H(1255,a|0)|0;r=j[114626];j[114626]=0;f=d;E:{F:{if((r|0)!=1){r=j[d+736>>2];e=8/(e>>>0)|0;if(r>>>0>4294967295/(e>>>0)>>>0){break F}e=p(e,r);break E}a=D()|0;C()|0;break a}e=-1}j[f+736>>2]=e;kc(b,e);break n}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}e=-1}j[f+736>>2]=e;kc(b,(e>>>0)/(k[a|0]>>>3>>>0)|0)}if(!j[b>>2]){e=0;break f}i[b+34>>1]=l[b+34>>1]&65534|k[a|0]>15;i[b+34>>1]=l[b+34>>1]&65471|(k[a+1|0]!=1)<<6;j[114626]=0;f=H(465,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break e}if(!f){e=0;j[b>>2]=0;break f}f=Mc(d+736|0,8,1,0,11);j[114626]=0;f=E(1256,a|0,f|0)|0;e=j[114626];j[114626]=0;G:{H:{I:{J:{K:{if((e|0)!=1){if(!f){break G}e=0;j[114626]=0;a=E(1257,c|0,d+736|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break H}if(!a){break g}a=j[b>>2];j[114626]=0;j[d+720>>2]=a+1>>>1;a=H(540,c|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break K}kc(d+720|0,a);j[114626]=0;a=H(854,g|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break J}e=j[d+720>>2];if(e){break I}e=16;break g}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=a+16|0;b=j[b+20>>2];g=0;while(1){f=k[d+736|k[a|0]&15]+g|0;h[b|0]=f;g=k[d+736|k[a|0]>>>4]+(f&255)|0;h[b+1|0]=g;a=a+1|0;b=b+2|0;e=e-1|0;if(e){continue}break}e=j[d+720>>2]+16|0;break g}a=D()|0;C()|0;break a}if(!(k[a+3|0]!=5?k[a+3|0]!=4:0)){a=k[a+3|0];j[114626]=0;a=P(1258,d+1808|0,c|0,b|0,(a|0)==5|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}jb(a);e=j[c+8>>2]-y|0;break g}if(!(k[a+3|0]!=6|k[a+1|0]!=1)){j[114626]=0;E(338,c|0,4)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}j[114626]=0;a=H(390,c|0)|0;f=j[114626];j[114626]=0;L:{M:{N:{if((f|0)!=1){j[114626]=0;j[d+720>>2]=a;f=H(387,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break N}j[114626]=0;I(1259,d+736|0,c|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break L}kc(d+720|0,j[d+736>>2]);j[114626]=0;a=j[d+720>>2];e=H(412,d+736|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){g=j[d+736>>2];r=j[b+20>>2];b=ik(b);j[114626]=0;V(1260,e|0,g|0,r|0,b|0,f<<24>>24);b=j[114626];j[114626]=0;if((b|0)!=1){break M}}a=D()|0;C()|0;lc(d+736|0);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}e=a+9|0;lc(d+736|0);break g}a=D()|0;C()|0;break a}if(!(k[a+3|0]!=9|k[a+1|0]!=1|k[a|0]!=16)){a=j[d+2900>>2];f=l[bl(d+1800|0)>>1];j[114626]=0;e=P(1261,b|0,g|0,a|0,f|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(k[a+3|0]!=8|k[a+1|0]!=1|k[a|0]>16){break l}e=0;j[114626]=0;f=E(258,c|0,8)|0;g=j[114626];j[114626]=0;if((g|0)==1){break e}if(!f){break g}j[114626]=0;f=H(390,c|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break e}j[d+2900>>2]=f;if(f>>>0<4){break g}j[114626]=0;I(341,d+720|0,c|0,f|0);f=j[114626];j[114626]=0;if((f|0)==1){break b}f=Jl(d+736|0,d+720|0);jb(d+720|0);j[114626]=0;r=H(1262,f|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break d}if(!j[b>>2]){break i}s=k[a|0];A=(s|0)!=16;a=0;g=0;while(1){O:{if(A){break O}j[114626]=0;B=E(260,f|0,8)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break O}a=J(77072)|0;break j}j[114626]=0;F=E(260,f|0,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break k}j[114626]=0;e=E(260,f|0,1)|0;u=j[114626];j[114626]=0;if((u|0)==1){break k}P:{Q:{R:{if(!e){e=8;while(1){j[114626]=0;u=E(260,f|0,1)|0;x=j[114626];j[114626]=0;if((x|0)==1){break P}if(u){break R}e=e+16|0;continue}}j[114626]=0;e=E(260,f|0,3)|0;u=j[114626];j[114626]=0;if((u|0)!=1){break Q}break k}j[114626]=0;u=E(260,f|0,4)|0;x=j[114626];j[114626]=0;if((x|0)==1){break k}e=e+u|0}g=(g&255)+(((F?-1:0)^e)&255)|0;S:{if((s|0)!=16){h[j[b+20>>2]+a|0]=g;break S}i[j[b+20>>2]+(a<<1)>>1]=B&255|g<<8}a=a+1|0;if(a>>>0<m[b>>2]){continue}break i}break}a=J(77072)|0;break j}a=D()|0;C()|0;break a}T:{U:{V:{W:{X:{if(!(k[a+3|0]!=7|k[a+1|0]!=1|k[a|0]>16)){e=0;if(m[d+2900>>2]<5){break g}a=j[b+20>>2];j[114626]=0;a=H(466,a|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break X}j[114626]=0;a=H(1263,a|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}b=ik(b);j[114626]=0;e=K(1264,c|0,a|0,b|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a|0]!=8|k[a+1|0]!=1)){Y:{Z:{_:{$:{aa:{a=k[a+3|0];switch(a|0){case 2:break Z;case 1:break _;case 0:break $;default:break aa}}e=0;switch(a-10|0){case 0:break Y;case 2:break Z;default:break g}}j[114626]=0;e=K(1265,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;e=K(1266,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}a=j[d+2900>>2];f=k[Ax(d+712|0)|0];j[114626]=0;e=P(1267,b|0,g|0,a|0,f|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;e=K(1268,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a|0]!=8|k[a+1|0]!=3)){ba:{ca:{da:{ea:{f=k[a+3|0];switch(f|0){case 2:break ba;case 1:break da;case 0:break ea;default:break ca}}j[114626]=0;e=K(1269,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;e=K(1270,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}e=0;if((f|0)!=12){break g}}f=j[d+2900>>2];e=k[Ax(d+704|0)|0];j[114626]=0;e=P(1271,b|0,g|0,f|0,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}if(k[a+3|0]!=12){break g}f=j[b>>2]<<1;if((f|0)<1){break g}a=j[b+20>>2];b=f+a|0;while(1){h[a+1|0]=k[a+1|0]+k[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break g}if(!(k[a|0]!=8|k[a+1|0]!=2)){e=0;fa:{switch(k[a+3|0]){case 0:j[114626]=0;e=K(1272,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g;case 1:j[114626]=0;e=K(1273,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g;case 2:break fa;default:break g}}a=j[d+2900>>2];f=k[Ax(d+696|0)|0];j[114626]=0;e=P(1274,b|0,g|0,a|0,f|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a+2|0]|(k[a|0]!=16|k[a+1|0]!=1))){ga:{ha:{ia:{ja:{a=k[a+3|0];switch(a|0){case 2:break ga;case 1:break ia;case 0:break ja;default:break ha}}j[114626]=0;e=K(1275,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;e=K(1276,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}e=0;if((a|0)!=12){break g}}a=j[d+2900>>2];f=l[bl(d+688|0)>>1];j[114626]=0;e=P(1277,b|0,g|0,a|0,f|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a|0]!=16|k[a+1|0]!=1|k[a+2|0]!=1)){e=0;ka:{switch(k[a+3|0]){case 0:j[114626]=0;e=K(1278,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g;case 1:j[114626]=0;e=K(1279,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g;case 2:break ka;default:break g}}a=j[d+2900>>2];f=l[bl(d+680|0)>>1];j[114626]=0;e=P(1280,b|0,g|0,a|0,f|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a+2|0]|(k[a|0]!=16|k[a+1|0]!=3))){la:{ma:{na:{oa:{f=k[a+3|0];switch(f|0){case 2:break la;case 1:break na;case 0:break oa;default:break ma}}j[114626]=0;e=K(1281,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;e=K(1282,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}e=0;if((f|0)!=12){break g}}f=j[d+2900>>2];e=l[bl(d+672|0)>>1];j[114626]=0;e=P(1283,b|0,g|0,f|0,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}if(k[a+3|0]!=12){break g}f=j[b>>2];if(f<<1<1){break g}a=j[b+20>>2];b=a+(f<<2)|0;while(1){i[a+2>>1]=l[a+2>>1]+l[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break g}if(!(k[a|0]!=16|k[a+1|0]!=3|k[a+2|0]!=1)){e=0;pa:{switch(k[a+3|0]){case 0:j[114626]=0;e=K(1284,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g;case 1:j[114626]=0;e=K(1285,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g;case 2:break pa;default:break g}}a=j[d+2900>>2];f=l[bl(d+664|0)>>1];j[114626]=0;e=P(1286,b|0,g|0,a|0,f|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a+2|0]|(k[a|0]!=16|k[a+1|0]!=2))){e=0;qa:{switch(k[a+3|0]){case 0:j[114626]=0;e=K(1287,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g;case 1:j[114626]=0;e=K(1288,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g;case 2:break qa;default:break g}}a=j[d+2900>>2];f=l[bl(d+656|0)>>1];j[114626]=0;e=P(1289,b|0,g|0,a|0,f|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a|0]!=16|k[a+1|0]!=2|k[a+2|0]!=1)){e=0;ra:{switch(k[a+3|0]){case 0:j[114626]=0;e=K(1290,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g;case 1:j[114626]=0;e=K(1291,b|0,g|0,j[d+2900>>2])|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g;case 2:break ra;default:break g}}a=j[d+2900>>2];f=l[bl(d+648|0)>>1];j[114626]=0;e=P(1292,b|0,g|0,a|0,f|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a+3|0]|(k[a|0]!=24|k[a+1|0]!=1))){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;i[d>>1]=l[d+640>>1];e=P(1293,b|0,g|0,f|0,d|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;i[d+2>>1]=l[d+632>>1];e=P(1294,b|0,g|0,f|0,d+2|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a+3|0]|(k[a|0]!=24|k[a+1|0]!=2))){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;i[d+4>>1]=l[d+624>>1];e=P(1295,b|0,g|0,f|0,d+4|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;i[d+6>>1]=l[d+616>>1];e=P(1296,b|0,g|0,f|0,d+6|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a+3|0]|(k[a|0]!=32|k[a+1|0]!=1))){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;i[d+8>>1]=l[d+608>>1];e=P(1297,b|0,g|0,f|0,d+8|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;i[d+10>>1]=l[d+600>>1];e=P(1298,b|0,g|0,f|0,d+10|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a+3|0]|(k[a|0]!=32|k[a+1|0]!=2))){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;i[d+12>>1]=l[d+592>>1];e=P(1299,b|0,g|0,f|0,d+12|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;i[d+14>>1]=l[d+584>>1];e=P(1300,b|0,g|0,f|0,d+14|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a+3|0]|(k[a|0]!=64|k[a+1|0]!=1))){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;i[d+16>>1]=l[d+576>>1];e=P(1301,b|0,g|0,f|0,d+16|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;i[d+18>>1]=l[d+568>>1];e=P(1302,b|0,g|0,f|0,d+18|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a+3|0]|(k[a|0]!=64|k[a+1|0]!=2))){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;i[d+20>>1]=l[d+560>>1];e=P(1303,b|0,g|0,f|0,d+20|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;i[d+22>>1]=l[d+552>>1];e=P(1304,b|0,g|0,f|0,d+22|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a|0]!=32|k[a+1|0]!=1|k[a+3|0]!=3)){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;i[d+24>>1]=l[d+544>>1];e=P(1305,b|0,g|0,f|0,d+24|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;i[d+26>>1]=l[d+536>>1];e=P(1306,b|0,g|0,f|0,d+26|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a|0]!=32|k[a+1|0]!=2|k[a+3|0]!=3)){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;i[d+28>>1]=l[d+528>>1];e=P(1307,b|0,g|0,f|0,d+28|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;i[d+30>>1]=l[d+520>>1];e=P(1308,b|0,g|0,f|0,d+30|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a|0]!=64|k[a+1|0]!=1|k[a+3|0]!=3)){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;i[d+32>>1]=l[d+512>>1];e=P(1309,b|0,g|0,f|0,d+32|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;i[d+34>>1]=l[d+504>>1];e=P(1310,b|0,g|0,f|0,d+34|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a|0]!=64|k[a+1|0]!=2|k[a+3|0]!=3)){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;i[d+36>>1]=l[d+496>>1];e=P(1311,b|0,g|0,f|0,d+36|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;i[d+38>>1]=l[d+488>>1];e=P(1312,b|0,g|0,f|0,d+38|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a|0]!=24|(k[a+1|0]!=2?k[a+1|0]!=1:0)|k[a+3|0]!=16)){j[d+736>>2]=-2147483648;f=j[d+2900>>2];sa:{if(!k[a+2|0]){j[114626]=0;j[d+48>>2]=j[d+480>>2];j[d+476>>2]=0;a=j[d+476>>2];j[d+40>>2]=j[d+472>>2];j[d+44>>2]=a;e=U(1313,b|0,g|0,f|0,d+736|0,d+40|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break sa}break T}j[114626]=0;j[d- -64>>2]=j[d+464>>2];j[d+460>>2]=0;a=j[d+460>>2];j[d+56>>2]=j[d+456>>2];j[d+60>>2]=a;e=U(1314,b|0,g|0,f|0,d+736|0,d+56|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break T}}if(!e){break g}a=j[d+736>>2];if((a|0)==-2147483648){break g}f=l[b+32>>1];j[114626]=0;f=OMa(f,0,a,0)+1073741824|0;a=ab;a=f>>>0<1073741824?a+1|0:a;a=ig(789,(a&2147483647)<<1|f>>>31,a>>>31|0);f=j[114626];j[114626]=0;if((f|0)==1){break T}L=b,N=kd(a,1,64),i[L+32>>1]=N;i[b+34>>1]=l[b+34>>1]|8192;break g}if(!(k[a|0]!=32|(k[a+1|0]!=2?k[a+1|0]!=1:0)|k[a+3|0]!=16)){j[d+736>>2]=-2147483648;f=j[d+2900>>2];ta:{if(!k[a+2|0]){j[114626]=0;j[d+80>>2]=j[d+448>>2];j[d+444>>2]=0;a=j[d+444>>2];j[d+72>>2]=j[d+440>>2];j[d+76>>2]=a;e=U(1315,b|0,g|0,f|0,d+736|0,d+72|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break ta}break U}j[114626]=0;j[d+96>>2]=j[d+432>>2];j[d+428>>2]=0;a=j[d+428>>2];j[d+88>>2]=j[d+424>>2];j[d+92>>2]=a;e=U(1316,b|0,g|0,f|0,d+736|0,d+88|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break U}}if(!e){break g}a=j[d+736>>2];if((a|0)==-2147483648){break g}f=l[b+32>>1];j[114626]=0;a=OMa(f,0,a,0)+1073741824|0;f=ab;f=a>>>0<1073741824?f+1|0:f;a=ig(789,(f&2147483647)<<1|a>>>31,f>>>31|0);f=j[114626];j[114626]=0;if((f|0)==1){break U}L=b,N=kd(a,1,64),i[L+32>>1]=N;i[b+34>>1]=l[b+34>>1]|8192;break g}if(!(k[a|0]!=32|(k[a+1|0]!=2?k[a+1|0]!=1:0)|k[a+3|0]!=15)){j[d+736>>2]=1065353216;f=j[d+2900>>2];ua:{if(!k[a+2|0]){j[114626]=0;j[d+412>>2]=0;j[d+416>>2]=1065353216;a=j[d+420>>2];j[d+112>>2]=j[d+416>>2];j[d+116>>2]=a;a=j[d+412>>2];j[d+104>>2]=j[d+408>>2];j[d+108>>2]=a;e=U(1317,b|0,g|0,f|0,d+736|0,d+104|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break ua}break V}j[114626]=0;j[d+396>>2]=0;j[d+400>>2]=1065353216;a=j[d+404>>2];j[d+128>>2]=j[d+400>>2];j[d+132>>2]=a;a=j[d+396>>2];j[d+120>>2]=j[d+392>>2];j[d+124>>2]=a;e=U(1318,b|0,g|0,f|0,d+736|0,d+120|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break V}}if(!e){break g}v=n[d+736>>2];if(v==q(1)){break g}v=Gm(q(v*q(l[b+32>>1])),q(1),q(64));j[114626]=0;a=Wa(1319,q(v))|0;f=j[114626];j[114626]=0;if((f|0)==1){break V}i[b+32>>1]=a;i[b+34>>1]=l[b+34>>1]|8192;break g}if(!(k[a|0]!=64|(k[a+1|0]!=2?k[a+1|0]!=1:0)|k[a+3|0]!=15)){j[d+736>>2]=0;j[d+740>>2]=1072693248;f=j[d+2900>>2];va:{if(!k[a+2|0]){j[114626]=0;j[d+376>>2]=0;j[d+380>>2]=1072693248;j[d+368>>2]=0;j[d+372>>2]=0;j[d+144>>2]=0;j[d+148>>2]=0;j[d+152>>2]=0;j[d+156>>2]=1072693248;a=j[d+388>>2];j[d+160>>2]=j[d+384>>2];j[d+164>>2]=a;a=j[d+364>>2];j[d+136>>2]=j[d+360>>2];j[d+140>>2]=a;e=U(1320,b|0,g|0,f|0,d+736|0,d+136|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break va}break W}j[114626]=0;j[d+344>>2]=0;j[d+348>>2]=1072693248;j[d+336>>2]=0;j[d+340>>2]=0;j[d+176>>2]=0;j[d+180>>2]=0;j[d+184>>2]=0;j[d+188>>2]=1072693248;a=j[d+356>>2];j[d+192>>2]=j[d+352>>2];j[d+196>>2]=a;a=j[d+332>>2];j[d+168>>2]=j[d+328>>2];j[d+172>>2]=a;e=U(1321,b|0,g|0,f|0,d+736|0,d+168|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break W}}if(!e){break g}w=o[d+736>>3];if(w==1){break g}w=zx(w*+l[b+32>>1],1,64);j[114626]=0;a=na(1322,+w)|0;f=j[114626];j[114626]=0;if((f|0)==1){break W}i[b+32>>1]=a;i[b+34>>1]=l[b+34>>1]|8192;break g}if(!(k[a|0]!=32|k[a+1|0]!=1|k[a+3|0]!=13)){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;j[d+320>>2]=939524096;a=j[d+324>>2];j[d+200>>2]=j[d+320>>2];j[d+204>>2]=a;e=P(1323,b|0,g|0,f|0,d+200|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;j[d+312>>2]=939524096;a=j[d+316>>2];j[d+208>>2]=j[d+312>>2];j[d+212>>2]=a;e=P(1324,b|0,g|0,f|0,d+208|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a|0]!=32|k[a+1|0]!=2|k[a+3|0]!=13)){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;j[d+304>>2]=939524096;a=j[d+308>>2];j[d+216>>2]=j[d+304>>2];j[d+220>>2]=a;e=P(1325,b|0,g|0,f|0,d+216|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;j[d+296>>2]=939524096;a=j[d+300>>2];j[d+224>>2]=j[d+296>>2];j[d+228>>2]=a;e=P(1326,b|0,g|0,f|0,d+224|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}if(!(k[a|0]!=32|k[a+1|0]!=1|k[a+3|0]!=14)){f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;j[d+288>>2]=872415232;a=j[d+292>>2];j[d+232>>2]=j[d+288>>2];j[d+236>>2]=a;e=P(1323,b|0,g|0,f|0,d+232|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}j[114626]=0;j[d+280>>2]=872415232;a=j[d+284>>2];j[d+240>>2]=j[d+280>>2];j[d+244>>2]=a;e=P(1324,b|0,g|0,f|0,d+240|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}e=0;if(k[a|0]!=32|k[a+1|0]!=2|k[a+3|0]!=14){break g}f=j[d+2900>>2];if(!k[a+2|0]){j[114626]=0;j[d+272>>2]=872415232;a=j[d+276>>2];j[d+248>>2]=j[d+272>>2];j[d+252>>2]=a;e=P(1325,b|0,g|0,f|0,d+248|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break g}break e}j[114626]=0;j[d+264>>2]=872415232;a=j[d+268>>2];j[d+256>>2]=j[d+264>>2];j[d+260>>2]=a;e=P(1326,b|0,g|0,f|0,d+256|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}break g}a=J(0)|0;C()|0;ib(a);z()}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=J(77072)|0}if((C()|0)!=(W(77072)|0)){break c}O(a|0)|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)==1){break h}}e=r+4|0;jb(f);break g}a=D()|0;C()|0;break c}j[114626]=0;E(256,c|0,e+y|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}}lc(t)}Za=d+2928|0;return e|0}a=D()|0;C()|0;break a}a=D()|0;C()|0}jb(f);break a}a=D()|0;C()|0}lc(t);G(a|0);z()}function Qoa(a){var b=0,c=0,d=0,e=0,f=0,g=0,o=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=q(0),Q=0,R=0,S=q(0),T=0,U=0;d=Za-32|0;Za=d;a:{if(!l[a+480188>>1]){E=-1;B=65535;C=-1;break a}Q=a+1075821|0;H=a+1304392|0;r=a+1074308|0;O=a+1074376|0;L=a+480209|0;C=-1;E=-1;B=65535;while(1){f=p(u,896)+a|0;s=f+1075799|0;g=k[s|0];A=f+1075797|0;w=k[A|0];D=f+1075798|0;v=k[D|0];K=f+1075796|0;F=k[K|0];I=f+1075795|0;b=k[I|0];c=j[a+1074392>>2];o=j[a+1074400>>2];t=j[a+1074416>>2];G=f+1075794|0;x=Zr(G);y=f+1075856|0;h[y|0]=j[a+480208>>2]>>>12&1|k[y|0]&254;e=(c>>>0)%(o+t>>>0)|0;c=k[G|0];if((c|0)==252){c=k[I|0];o=yx(G);t=Wr(G);b:{if(!c|c-251>>>0<5){break b}c=j[(p(c,160)+a|0)+906140>>2];if(!c){break b}bb[j[j[c>>2]+44>>2]](c,o,q(q(t>>>0)*q(.0010010009864345193)))}c=k[G|0]}c:{if(w&255|n[f+1075868>>2]==q(0)?(c&255)!=251:0){break c}z=j[a+480208>>2]&4096;d:{if(!z){t=k[f+1075878|0];break d}t=k[I|0];h[f+1075878|0]=t}c=t&255;if(c-251>>>0<5|!c){break c}o=(p(c,160)+a|0)+906140|0;if(!j[o>>2]){break c}e:{if(!z){c=l[f+1075876>>1];break e}c=Ur(k[K|0],k[D|0]);i[f+1075876>>1]=c;P=q(q(Ur(k[A|0],k[s|0])>>>0)*q(.0010010009864345193));n[f+1075872>>2]=P;s=j[o>>2];R=f+1075868|0,S=q(q(P-q(bb[j[j[s>>2]+48>>2]](s,c)))/q(Yk(a)>>>0)),n[R>>2]=S}s=j[a+1074392>>2];t=Yk(a);o=j[o>>2];if((t|0)==(s+1|0)){bb[j[j[o>>2]+44>>2]](o,c,n[f+1075872>>2]);break c}bb[j[j[o>>2]+100>>2]](o,c,n[f+1075868>>2])}s=f+1074984|0;f:{g:{h:{i:{j:{if(!AK(k[G|0])){if(k[L|0]&16){break j}break i}Poa(s);b=0;F=0;v=0;w=0;g=0;x=0;if(!(k[L|0]&16)){break i}t=0;break g}if(!b){b=0;break h}j[f+1075768>>2]=0;break h}qK(a,s)}A=w&255;if((A|0)==33){mb(d+24|0,r,30);t=g>>>4|0;ux(a,u&65535,t+(g&15)|0,kb(d+24|0));w=33;break g}t=0;if((w-19&255)>>>0>1){break g}k:{if(!(!(j[a+480180>>2]&16777250)|g)){g=k[f+1075837|0];break k}h[f+1075837|0]=g}c=g&240;if((c|0)==208){c=g&15;if(!c){if(j[a+480180>>2]&16777248){t=1;break g}if(j[a+480180>>2]!=2){break g}break f}l:{if(c>>>0<j[a+1074400>>2]+j[a+1074416>>2]>>>0){break l}mb(d+24|0,r,14);if(!kb(d+24|0)){break l}if(!b){break f}h[f+1075809|0]=b;break f}t=c;break g}if(!(k[L|0]&16)){break g}o=19;m:{n:{o:{if(!((c|0)==96?(A|0)==19:0)){if((c|0)!=176){break n}o=20;if((A|0)!=20){break o}}mb(d+24|0,r,77);if(!(!kb(d+24|0)|!(j[((u<<5)+a|0)+480280>>2]&1024))){w=o;break g}c=Ooa(a,s,g&15);p:{if((c|0)==-1){c=E;break p}q:{if((C|0)!=-1){mb(d+24|0,r,68);C=kb(d+24|0)?c:C;break q}C=-1}mb(d+24|0,r,103);B=kb(d+24|0)?-1:B}if(!l[a+480188>>1]|j[a+480180>>2]!=2){break m}E=f+1075845|0;A=f+1075788|0;w=0;while(1){D=p(w,896)+a|0;j[D+1075788>>2]=j[A>>2];h[D+1075845|0]=k[E|0];w=w+1|0;if(w>>>0<l[a+480188>>1]){continue}break}break m}w=19;break g}if((c|0)!=224|(j[a+1074396>>2]?j[a+480180>>2]&16777250:0)){break g}c=g&15;if(j[a+480180>>2]&2?!c:0){break g}j[a+1074396>>2]=c+1;break g}w=o;E=c}M=w&255;o=(M|0)==19&j[a+480180>>2]==16&(g&240)==208;z=o?0:t;r:{if(!z|k[G|0]!=255|k[K|0]!=2){break r}mb(d+24|0,r,74);if(!kb(d+24|0)){break r}h[K|0]=0}c=j[a+1074392>>2];mb(d+24|0,r,72);s:{if(kb(d+24|0)){t=0;if(z>>>0>=m[a+1074416>>2]){break s}}mb(d+24|0,r,88);t=(e|0)==(z|0)|(c|0)==(z|0);if(!(!z|!kb(d+24|0))){break s}t=(c|0)==(z|0)}D=t;mb(d+24|0,r,44);if(kb(d+24|0)){h[y|0]=k[y|0]&254|(e|0)==(z|0)}N=g&15;e=o?N|144:g;mb(d+24|0,r,66);x=(!z|kb(d+24|0)^1)&x;t:{u:{if(!(j[a+1074392>>2]|(!b|!(j[a+480208>>2]&2097152)))){j[f+1075644>>2]=0;if(D){break u}if(!ph(s)){break t}h[f+1075809|0]=b;if(l[a+480190>>1]<b>>>0){break t}b=p(b,104)+a|0;j[f+1075672>>2]=l[b+484410>>1];j[f+1075752>>2]=h[b+484417|0];break t}if(!D){break t}}g=k[G|0];if(b){h[f+1075809|0]=b}v:{w:{if(!Ld(g)){break w}mb(d+24|0,r,67);if(!kb(d+24|0)){break w}o=j[f+1075756>>2];x:{if(!b|x){break x}y:{if(l[a+480192>>1]){c=65535;if(l[a+480192>>1]<b>>>0){break y}t=j[((b<<2)+a|0)+900380>>2];if(!t){break y}c=l[Oc(t+236|0,g-1|0)>>1];break y}c=b}c=c&65535;if(c>>>0>l[a+480190>>1]){break x}o=h[Yo(a,c)+36|0]}g=(g+o|0)-12>>>0>119?0:g;break v}if(!(j[a+480180>>2]&25165856)|!l[a+480192>>1]){break v}c=g;o=1;z:{if(!c){break z}o=Ld(c)}if(!o){break v}o=b?b:k[f+1075810|0];if(!o|(j[((o<<2)+a|0)+900380>>2]?l[a+480192>>1]>=o>>>0:0)){break v}g=0;b=0}if(!((M|0)!=25|e)){mb(d+24|0,r,55);c=kb(d+24|0);b=c?0:b;g=c?0:g}mb(d+24|0,r,65);c=(b|0)!=0;o=!g;t=kb(d+24|0);J=1;A:{if(j[a+480180>>2]&16777248){break A}mb(d+24|0,r,107);if(kb(d+24|0)){break A}mb(d+16|0,r,85);J=0;if(!kb(d+16|0)){break A}if(ph(s)){break A}J=1;y=j[f+1075088>>2];if(!y){break A}J=ke(y)^1}o=c&o;A=c&t;B:{C:{D:{E:{F:{G:{H:{I:{if(!(j[a+480180>>2]&1048580)){break I}J:{if((g|0)!=255){break J}if(!(b?0:!((M|0)==13|(F&255)==1))){mb(d+24|0,r,55);if(kb(d+24|0)){break J}}c=j[f+1075640>>2];if(h[c+60|0]&1?c:0){break J}j[f+1075672>>2]=0;b=f+1075072|0;j[b>>2]=j[b>>2]|2097152;K:{if(!(j[a+480208>>2]&4096)){break K}mb(d+24|0,r,86);if(!kb(d+24|0)){break K}j[b>>2]=j[b>>2]|4096}b=0;g=0;c=0;o=0;t=0;y=1;if(A){break C}break B}mb(d+24|0,r,59);if(!kb(d+24|0)|j[a+480208>>2]&4096){break I}c=k[f+1075803|0]-k[f+1075756|0]|0;if(!g){break G}if(g>>>0>250){J=0;A=1;c=0;break G}if(!b){mb(d+24|0,r,98);A=0;if(kb(d+24|0)){break H}}J=1;A=1;break H}c=0;t=0;if(!o){break E}break F}c=g}x=0}mb(d+24|0,r,65);if(!kb(d+24|0)){break D}g=c;t=1}o=g;c=t;y=1;if(A){break C}break B}g=c;c=1;y=A}L:{M:{if(!l[a+480192>>1]){if(l[a+480190>>1]<b>>>0){break L}o=(p(b,104)+a|0)+484380|0;break M}o=j[f+1075088>>2];if(!o){break L}}N:{if(i[o+34>>1]<0){break N}if(j[a+480180>>2]==2){if(!ke(o)){break N}}j[f+1075672>>2]=l[o+30>>1]}if(!y){break L}ns(s,l[o+28>>1],a)}o=g;t=c}mb(d+24|0,r,71);if(!(!b|!kb(d+24|0))){h[f+1075843|0]=32}O:{if(!l[a+480192>>1]){break O}mb(d+24|0,r,100);if(!b|!kb(d+24|0)){break O}if(Ld(o&255)){break O}c=j[a+480208>>2];P:{if(x){if(c&8){break P}break O}if(!(c&4)){break O}}_k(s);j[f+1075680>>2]=65536;c=f+1075072|0;j[c>>2]=j[c>>2]|2097152}if(t){mb(d+24|0,r,11);Q:{if(R=!kb(d+24|0),T=0,U=j[a+480180>>2]!=268435456,U?R:T){break Q}mb(d+24|0,r,87);g=0;if(kb(d+24|0)){g=ph(s)^1}if(l[a+480192>>1]){if((g^-1)&j[f+1075640>>2]==j[((b<<2)+a|0)+900380>>2]|l[a+480192>>1]<b>>>0){break Q}o=k[f+1075803|0];break Q}if((g^-1)&j[f+1075088>>2]==((p(b,104)+a|0)+484380|0)|b>>>0>3999){break Q}o=k[f+1075803|0]}R:{if(!l[a+480192>>1]|!(j[a+480180>>2]&1048588)){break R}_k(s);h[f+1075822|0]=0;j[f+1075764>>2]=0;j[f+1075680>>2]=65536;c=f+1075072|0;j[c>>2]=j[c>>2]&-2101249|2097152;mb(d+24|0,r,86);if(!kb(d+24|0)){break R}j[c>>2]=j[c>>2]&-2049}b=J?b:0}t=o&255;S:{if(t>>>0<251){break S}mb(d+24|0,r,50);T:{if(!b|!kb(d+24|0)){break T}if(l[a+480192>>1]){if(l[a+480192>>1]<b>>>0){break T}c=((b<<2)+a|0)+900380|0;if(!j[c>>2]){break T}g=f+1075805|0;if(!Ld(k[g|0])){break T}c=l[Oc(j[c>>2]+236|0,k[g|0]-1|0)>>1]}else{c=b}c=c&65535;if(!c|c>>>0>l[a+480190>>1]){break T}c=p(c,104)+a|0;if(i[c+484414>>1]<0){break T}j[f+1075672>>2]=l[c+484410>>1]}mb(d+24|0,r,100);if(R=kb(d+24|0),T=0,U=j[a+480208>>2]&4,U?R:T){break S}b=0}U:{if(!Ld(t)){break U}h[f+1075808|0]=o;h[f+1075805|0]=o;if(x){break U}uK(a,u&65535,b,t,0)}V:{W:{X:{Y:{if(t){g=f+1075780|0;c=i[g>>1];if(c){j[f+1075676>>2]=(c&32767)-1;if((c|0)<=-1){c=f+1075072|0;j[c>>2]=j[c>>2]|256}i[g>>1]=0}c=f+1075801|0;g=k[c|0];if(g){h[f+1075842|0]=g-1;h[c|0]=0}c=f+1075802|0;g=k[c|0];if(g){h[f+1075841|0]=g-1;h[c|0]=0}if(!b){break Y}break X}if(b){break X}b=x;break V}c=0;o=1;y=f+1075809|0;Z:{if(!k[y|0]){break Z}if(!Ld(t)){break Z}Fo(a,s,k[y|0],x,j[f+1075088>>2]?0:!j[f+1075640>>2],!(j[a+480180>>2]&1048580));h[y|0]=0;c=1}b=x;break W}c=f+1075088|0;g=j[c>>2];Fo(a,s,b,x,1,1);b=j[c>>2];_:{if(!b|!(k[b+35|0]&2)){break _}if(!bd(H)){break _}Lx(j[H>>2],u&65535,j[c>>2]+68|0)}$:{if(j[a+480180>>2]==1){if(x){mb(d+24|0,r,85);if(kb(d+24|0)){break $}}h[f+1075809|0]=0;break $}mb(d+24|0,r,50);if(kb(d+24|0)){if(!Ld(t)){break $}}h[f+1075809|0]=0}mb(d+24|0,r,42);aa:{ba:{ca:{if(kb(d+24|0)){if(!Ld(t)|(g|0)==j[c>>2]){break ba}break ca}if(!(!(j[a+480180>>2]&16777248)|(g|0)==j[c>>2])){b=0;if(Ld(t)){break aa}}mb(d+24|0,r,107);da:{if(!kb(d+24|0)|(g|0)==j[c>>2]){break da}if(!x){if(Ld(t)){break da}}b=f+1075060|0;if(m[b>>2]>=m[s+4>>2]){break da}j[b>>2]=0;break ba}mb(d+24|0,r,85);if(!kb(d+24|0)){break ba}if(ph(s)){break ba}}j[s>>2]=0;j[s+4>>2]=0}b=x}o=0;c=0;if(!t){break V}}g=f+1075088|0;x=j[g>>2];ea:{if(!x|!(k[x+35|0]&2)){break ea}if(!bd(H)){break ea}if(!c){if(vK(j[H>>2],u&65535)){break ea}}Lx(j[H>>2],u&65535,j[g>>2]+68|0)}c=u&65535;Vr(a,s,t,b,!(j[a+480180>>2]&1048580),0,c);if(!(!b|(!(j[a+480180>>2]&1048580)|o))){g=f+1075072|0;j[g>>2]=j[g>>2]|2097152;_k(s);h[f+1075822|0]=0;j[f+1075764>>2]=0}if(!(j[f+1075072>>2]&512)){break V}if(!bd(H)){break V}fa:{switch(t-253|0){case 0:mb(d+24|0,r,99);if(kb(d+24|0)){break V}break;case 1:case 2:break fa;default:break V}}Tj(j[H>>2],c)}ga:{ha:{switch((F&255)-1|0){case 0:v=v>>>0<64?v:64;j[f+1075672>>2]=v<<2;c=f+1075072|0;j[c>>2]=j[c>>2]|2097152;break ga;case 1:break ha;default:break ga}}$k(a,s,v,6)}if(l[a+480192>>1]){$I(a,u&65535)}x=b}mb(d+24|0,r,77);if(R=kb(d+24|0),T=0,U=j[((u<<5)+a|0)+480280>>2]&1024,U?R:T){break f}b=j[a+1074392>>2];mb(d+24|0,r,75);ia:{ja:{ka:{b=b>>>0>=z>>>0;la:{if(!z|!kb(d+24|0)){break la}c=j[a+1074392>>2];if(!c){break ka}b=1;if((c|0)!=(z|0)){break la}b=!k[I|0]&(F&255)!=11}c=F&255;if(!b|c>>>0<3){break ka}if((c|0)==11){xx(d+24|0,a,G,z);b=k[Rb(d+24|0)|0];Am(a,s,j[d+24>>2]);if(b){break ia}b=11;break ja}mb(d+24|0,r,62);ma:{if(!(!kb(d+24|0)|v)){v=0;b=0;na:{switch(c-8|0){case 0:break ma;case 1:break na;default:break ja}}if(k[L|0]&16){break ja}j[f+1075676>>2]=0;break ja}mb(d+24|0,r,41);if(kb(d+24|0)){break ma}if(v){h[f+1075838|0]=v;break ma}v=k[f+1075838|0]}b=F;oa:{switch(c-3|0){case 0:case 1:pa:{qa:{if(v){break qa}mb(d+24|0,r,41);if(!kb(d+24|0)){break qa}v=k[f+1075838|0];if(v){break pa}v=0;break ka}h[f+1075838|0]=v}Dm(a,s,((c|0)==3?v<<4:v)&255);break ka;case 2:if((z|0)!=j[a+1074392>>2]){mb(d+24|0,r,41);b=5;if(kb(d+24|0)){break ja}}mb(d+24|0,r,41);Do(a,s,v,kb(d+24|0));b=5;break ja;case 3:if((z|0)!=j[a+1074392>>2]){mb(d+24|0,r,41);b=6;if(kb(d+24|0)){break ja}}mb(d+24|0,r,41);Co(a,s,v,kb(d+24|0));b=6;break ja;case 4:mb(d+24|0,r,53);if(kb(d+24|0)){h[f+1075827|0]=v&15;b=7;break ja}Nj(s,v<<4);b=7;break ja;case 5:Nj(s,v);b=8;break ja;case 6:mb(d+24|0,r,62);tx(a,s,v,kb(d+24|0)^1);b=9;break ja;case 7:mb(d+24|0,r,62);tx(a,s,v<<4&240,kb(d+24|0)^1);b=10;break ja;case 9:b=12;mb(d+24|0,r,12);pK(a,u&65535,v<<2&252,kb(d+24|0));break ja;case 10:mb(d+24|0,r,12);oK(a,u&65535,v<<2&252,kb(d+24|0));b=13;break ja;case 12:break oa;default:break ja}}b=15;if(!D|v>>>0>9){break ja}c=j[f+1075088>>2];if(!c){break ja}ra:{if(!v){t=j[f+1075648>>2];break ra}t=j[(c+(v<<2)|0)- -64>>2];j[f+1075648>>2]=t}Eo(a,s,t);break ja}b=F}sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{switch(M-1|0){case 12:if(!(k[a+480209|0]&16)){break ia}b=p(u,896)+a|0;j[b+1075672>>2]=e>>>0<64?e<<2:256;b=b+1075072|0;j[b>>2]=j[b>>2]|2097152;break ia;case 1:if(j[a+480180>>2]&1?!e:0){break Qa}pK(a,u&65535,e,0);break ia;case 2:if(j[a+480180>>2]&1?!e:0){break Qa}oK(a,u&65535,e,0);break ia;case 10:if(j[a+480180>>2]==1?!e:0){break Qa}Dm(a,s,e);break ia;case 3:Am(a,s,e);break ia;case 5:if(!(j[a+480180>>2]==1?!e:0)){Dm(a,s,e)}Am(a,s,0);break ia;case 4:Nj(s,e);break ia;case 6:if(!(j[a+480180>>2]==1?!e:0)){Dm(a,s,e)}Nj(s,0);break ia;case 15:if(!(k[a+480209|0]&16)){break ia}break sa;case 16:mb(d+24|0,r,5);if(kb(d+24|0)){if(!e){break ia}if(j[a+480208>>2]&4096){break sa}break ia}e=Go(a,l[a+1074436>>1],j[a+1074424>>2],u&65535,0);Sa:{if(!(j[a+480180>>2]&16777250)){break Sa}if(e){h[(p(u,896)+a|0)+1075839|0]=e;break Sa}e=k[(p(u,896)+a|0)+1075839|0]}j[d+24>>2]=p(e,1e4);kc(d+24|0,p(j[j[a+8>>2]+24>>2],1e4));Noa(a,j[d+24>>2]);break ia;case 9:if(!D|(j[a+480180>>2]==4?x:0)){break ia}h[d+24|0]=0;b=Go(a,l[a+1074436>>1],j[a+1074424>>2],u&65535,d+24|0);c=a;g=s;if(!k[d+24|0]){o=(p(u,896)+a|0)+1075648|0;b=b<<8;Ta:{if(b){j[o>>2]=b;break Ta}b=j[o>>2]}b=(k[(p(u,896)+a|0)+1075840|0]<<16)+b|0}Eo(c,g,b);break ia;case 40:if(!D){break ia}c=OMa(j[(p(u,896)+a|0)+1075060>>2],0,e,0);b=ab;g=b>>>8|0;Eo(a,s,Wc((b&255)<<24|c>>>8,g));break ia;case 0:if(j[a+1074392>>2]){break ia}b=p(u,896)+a|0;Ua:{if(k[b+1075803|0]?j[b+1075684>>2]:0){break Ua}b=j[b+1075640>>2];if(b){if(ci(b)){break Ua}}mb(d+24|0,r,13);if(kb(d+24|0)){break Ua}if(j[a+480180>>2]&16777248){break ia}}if(!e){e=0;if(j[a+480180>>2]&5){break ia}h[(p(u,896)+a|0)+1075811|0]=1;break ia}b=p(u,896)+a|0;h[b+1075812|0]=e;h[b+1075811|0]=1;break ia;case 14:if(j[a+480180>>2]&1048580){e=e&240?e:l[(p(u,896)+a|0)+1075784>>1]&240|e;if(!(e&15)){e=l[(p(u,896)+a|0)+1075784>>1]&15|e}e=e|256}mb(d+24|0,r,23);if(kb(d+24|0)){Va:{if(!e){t=l[(p(u,896)+a|0)+1075784>>1];break Va}t=e&255;i[(p(u,896)+a|0)+1075784>>1]=t}sx(a,u&65535,t<<16>>16,(b&255)==15?v+1|0:0);break ia}Wa:{if(e){i[(p(u,896)+a|0)+1075784>>1]=e&255;break Wa}e=i[(p(u,896)+a|0)+1075784>>1]}sx(a,u&65535,e,(b&255)==15?v+1|0:0);break ia;case 39:break wa;case 38:break xa;case 34:case 35:case 36:case 37:break ya;case 13:break za;case 11:break Aa;case 29:break Ba;case 26:break Ca;case 21:break Da;case 20:break Ea;case 27:break Fa;case 24:break Ga;case 19:break Ha;case 18:break Ia;case 25:break Ja;case 7:break Ka;case 28:break La;case 8:break Ma;case 23:break Na;case 22:break Oa;case 17:break Ra;default:break ia}}if(!(k[a+480209|0]&16)){break ia}mb(d+24|0,r,22);Xa:{Ya:{if(kb(d+24|0)){if(!e){e=0;break Ya}if(k[a+480208|0]&4){break Ya}b=e&240?e-16|0:e;e=b-((b&15)!=0)|0;break Ya}mb(d+24|0,r,71);if(!kb(d+24|0)){break Xa}}b=(p(u,896)+a|0)+1075843|0;h[b|0]=k[b|0]|128}b=p(u,896)+a|0;h[b+1075811|0]=18;if(e){break Pa}}e=0;break ia}h[b+1075844|0]=e;break ia}if(!(k[a+480209|0]&16)){break ia}e=e<<!(j[a+480180>>2]&59593760);if(e>>>0<=128){j[a+1074444>>2]=e<<1;break ia}if(j[a+480180>>2]&16777250){break ia}j[a+1074444>>2]=256;break ia}mb(d+24|0,r,9);if(kb(d+24|0)){nK(a,e,(p(u,896)+a|0)+1075821|0);break ia}nK(a,e,Q);break ia}if(!(k[a+480209|0]&16)){break ia}$k(a,s,e,8);break ia}tx(a,s,e,1);break ia}HK(s,e);break ia}IK(a,s,e);break ia}Moa(a,u&65535,e);break ia}mb(d+24|0,r,78);c=a;b=u&65535;if(!(!kb(d+24|0)|e)){e=k[(p(u,896)+a|0)+1075812|0]}mK(c,b,e);break ia}mb(d+24|0,r,55);if(kb(d+24|0)){if(j[a+1074392>>2]!=(e|0)){break ia}b=j[(p(u,896)+a|0)+1075640>>2];if(h[b+60|0]&1?b:0){break ta}if(!((k[K|0]?0:!k[I|0])|e)){b=(p(u,896)+a|0)+1075072|0;j[b>>2]=j[b>>2]|4096;break ta}b=p(u,896)+a|0;j[b+1075672>>2]=0;b=b+1075072|0;j[b>>2]=j[b>>2]|2097152;break ta}if(k[a+480209|0]&16){break ta}break ia}b=(e&240)-16>>>4|0;if(b>>>0>9){break ia}if(!(1<<b&880)){if(!b){break va}if((b|0)!=1){break ia}lK(a,s,e&15);break ia}mb(d+24|0,r,58);if(kb(d+24|0)){break ia}mK(a,u&65535,e);break ia}if(!(j[a+480208>>2]&4096)|e>>>0>64){break ia}b=p(u,896)+a|0;j[b+1075744>>2]=e;b=b+1075072|0;j[b>>2]=j[b>>2]|2097152;break ia}Koa(a,s,e);break ia}GK(s,e);break ia}if(!(k[a+480209|0]&16)){break ia}b=p(u,896)+a|0;j[b+1075712>>2]=e;mb(d+24|0,r,60);if(R=0,T=kb(d+24|0),U=k[b+1075708|0]&4,U?R:T){break ia}b=p(u,896)+a|0;j[b+1075736>>2]=e;j[b+1075724>>2]=e;break ia}j[a+1074432>>2]=0;B=Go(a,l[a+1074436>>1],j[a+1074424>>2],u&65535,0);C=(C|0)!=-1?j[a+480180>>2]&5?0:C:C;break ia}b=JK(a,O,u&65535,e);if((b|0)==-1){break ia}if(!(k[a+480208|0]&32)){break ua}B=l[a+1074438>>1];break ua}b=w&255;Joa(a,s,e,(b|0)==35|(b|0)==37,(w-37&255)>>>0<2);break ia}EK(d,s,e);break ia}if(j[a+1074392>>2]|N>>>0>2|e>>>0>31){break ia}b=u;F=b;if((e&240)==16){F=l[a+480188>>1]-1|0;b=0}while(1){g=b&65535;c=((g<<5)+a|0)+480280|0;o=j[c>>2];Za:{if((N|0)==1){w=j[(p(g,896)+a|0)+1075072>>2]|67108864;o=o|67108864;break Za}w=j[(p(g,896)+a|0)+1075072>>2]&-67108865;o=o&-67108865}j[c>>2]=o;j[(p(g,896)+a|0)+1075072>>2]=w;b=b+1|0;if((b&65535)>>>0<=(F&65535)>>>0){continue}break}break ia}kK(a,s,e&15);break ia}C=b;break ia}Cm(a,s);break ia}KK(a,O,e)}mb(d+24|0,r,78);if(!(!e|!kb(d+24|0))){Ioa(s,e&255)}b=k[I|0];if(!b){break f}h[f+1075810|0]=b}u=u+1|0;if(u>>>0<l[a+480188>>1]){continue}break}}_a:{if(!(k[a+480209|0]&16)){break _a}$a:{if(!((B&65535)!=65535|(C|0)!=-1)){if((E|0)==-1){break _a}break $a}ab:{if((E|0)==-1){break ab}b=a+1074308|0;mb(d+24|0,b,68);if(kb(d+24|0)){break ab}mb(d+16|0,b,103);c=(B&65535)==65535;if(kb(d+16|0)?!c:0){break ab}mb(d+8|0,b,49);if(c|!kb(d+8|0)){break $a}}B=(B&65535)==65535?l[a+1074438>>1]+1|0:B;j[a+480208>>2]=j[a+480208>>2]|524288;b=a+484360|0;if(bc(Fb(b))>>>0<=(B&65535)>>>0){B=l[Fb(b)+28>>1]}c=(C|0)==-1?0:C;bb:{if(l[a+1074438>>1]==(B&65535)){break bb}b=a+1074308|0;mb(d+24|0,b,26);if(kb(d+24|0)){break bb}mb(d+16|0,b,68);if(kb(d+16|0)|j[a+480180>>2]==1|!l[a+480188>>1]){break bb}b=0;while(1){h[(p(b,896)+a|0)+1075845|0]=0;b=b+1|0;if(b>>>0<l[a+480188>>1]){continue}break}}j[a+1074428>>2]=c;if(k[a+480208|0]&32){break _a}i[a+1074440>>1]=B;break _a}j[a+1074428>>2]=E;i[a+1074440>>1]=l[a+1074438>>1];cb:{if(!j[a+1074396>>2]){break cb}if(j[a+480180>>2]==32){mb(d+24|0,a+1074308|0,103);if(kb(d+24|0)){break cb}}if(j[a+480180>>2]==2){break cb}j[a+1074428>>2]=j[a+1074428>>2]+1}if(m[Ib(a+484344|0,l[a+1074436>>1])+12>>2]<=E>>>0){j[a+1074428>>2]=0;i[a+1074440>>1]=l[a+1074440>>1]+1}nra(a+1304360|0,l[a+1074438>>1],E)}Za=d+32|0;return 1}function sKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,J=0,M=0,O=0,P=0,Q=0,R=0,S=0;d=Za-304|0;Za=d;rc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{if(!kf(b,d+296|0)){break S}if(!MR(d+296|0)){break S}if(!c){x=1;break S}y=pl(d+280|0,b);j[114626]=0;I(473,d+264|0,y|0,1);b=j[114626];j[114626]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{if((b|0)!=1){j[114626]=0;I(474,d+128|0,d+264|0,1229866575);b=j[114626];j[114626]=0;if((b|0)==1){break Y}j[114626]=0;x=E(475,d+128|0,d+248|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break _}jb(d+128|0);if(!x){break T}j[114626]=0;F(447,a|0,524288);b=j[114626];j[114626]=0;if((b|0)==1){break c}j[114626]=0;N(476,a|0);b=j[114626];j[114626]=0;if((b|0)!=1){break Z}break c}b=D()|0;C()|0;break a}b=D()|0;C()|0;jb(d+128|0);break b}j[a+480208>>2]=12;b=k[d+256|0]|k[d+257|0]<<8;R=a,S=kd((b<<24|b<<8&16711680)>>>16|0,1,127),i[R+480188>>1]=S;b=k[d+248|0]|k[d+249|0]<<8;j[114626]=0;i[d+128>>1]=(b<<8&16711680|b<<24)>>>16;i[d+216>>1]=255;b=E(477,d+128|0,d+216|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break d}i[a+480192>>1]=l[b>>1];b=d+248|2;b=k[b|0]|k[b+1|0]<<8;j[114626]=0;i[d+128>>1]=(b<<8&16711680|b<<24)>>>16;i[d+216>>1]=3999;b=E(477,d+128|0,d+216|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break e}i[a+480190>>1]=l[b>>1];j[114626]=0;b=a+1074308|0;K(478,b|0,6,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;E(479,b|0,21)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;E(479,b|0,13)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}j[114626]=0;b=E(2,d+128|0,12385)|0;e=j[114626];j[114626]=0;if((e|0)==1){break f}ob(a+1304436|0,b);gb(b);j[114626]=0;b=E(2,d+128|0,12401)|0;e=j[114626];j[114626]=0;if((e|0)==1){break g}ob(a+1304448|0,b);gb(b);j[114626]=0;e=E(2,d+232|0,12405)|0;b=j[114626];j[114626]=0;if((b|0)==1){break h}j[114626]=0;F(219,d+216|0,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break j}j[114626]=0;F(480,d+200|0,d+296|4);b=j[114626];j[114626]=0;if((b|0)==1){break l}j[114626]=0;F(480,d+184|0,d+296|5);b=j[114626];j[114626]=0;if((b|0)==1){break n}j[114626]=0;L(222,d+128|0,d+216|0,d+200|0,d+184|0);b=j[114626];j[114626]=0;if((b|0)==1){break o}ob(a+1304460|0,d+128|0);gb(d+128|0);gb(d+184|0);gb(d+200|0);qb(d+216|0);gb(e);j[a+1304496>>2]=2;j[114626]=0;I(474,d+216|0,d+264|0,1312902469);b=j[114626];j[114626]=0;if((b|0)==1){break p}j[114626]=0;b=H(255,d+216|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break r}j[114626]=0;f=a+1304400|0;K(481,d+216|0,f|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break r}j[114626]=0;I(474,d+200|0,d+264|0,1397706311);b=j[114626];j[114626]=0;if((b|0)==1){break s}b=a+484360|0;wp(Fb(b));$:{e=d+248|4;e=k[e|0]|k[e+1|0]<<8;aa:{if(!e){break aa}m=(e<<24|e<<8)>>>16|0;e=0;while(1){j[114626]=0;g=E(258,d+200|0,46)|0;n=j[114626];j[114626]=0;ba:{if((n|0)!=1){if(!g){break aa}j[114626]=0;K(482,d+200|0,d+128|0,44)|0;g=j[114626];j[114626]=0;if((g|0)!=1){if(!Ec(f)){break ba}j[114626]=0;E(483,f|0,d+128|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){break ba}}b=D()|0;C()|0;break t}b=D()|0;C()|0;break t}j[114626]=0;g=H(484,d+200|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break $}if(!ad(Fb(b))){j[114626]=0;n=H(485,b|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break $}if((n|0)==255){break aa}}n=Fb(b);j[114626]=0;I(6,d+184|0,2,d+128|0);o=j[114626];j[114626]=0;if((o|0)==1){break u}j[114626]=0;F(486,n|0,d+184|0);n=j[114626];j[114626]=0;if((n|0)==1){break v}gb(d+184|0);n=Fb(b);j[114626]=0;U(487,n|0,d+200|0,g|0,65535,65535)|0;g=j[114626];j[114626]=0;if((g|0)==1){break $}e=e+1|0;if(m>>>0>(e&65535)>>>0){continue}break}}j[114626]=0;F(488,b|0,0);b=j[114626];j[114626]=0;if((b|0)==1){break w}j[114626]=0;I(474,d+184|0,d+264|0,1229869908);b=j[114626];j[114626]=0;if((b|0)==1){break x}j[114626]=0;b=H(489,d+184|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break G}ca:{if(!b){break ca}if(l[a+480192>>1]){m=1;while(1){j[114626]=0;E(490,d+184|0,d+128|0)|0;b=j[114626];j[114626]=0;da:{ea:{fa:{if((b|0)!=1){b=k[d+158|0]|k[d+159|0]<<8;j[114626]=0;b=K(454,a|0,m&65535,(b<<8&16711680|b<<24)>>>16|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break fa}if(!b){break da}e=k[d+158|0]|k[d+159|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0>3999){break da}j[114626]=0;I(491,d+16|0,2,d+128|0);e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;F(415,d- -64|0,d+16|0);e=j[114626];j[114626]=0;if((e|0)!=1){break ea}}b=D()|0;C()|0;break y}b=D()|0;C()|0;break y}b=D()|0;C()|0;break y}j[114626]=0;E(369,b+492|0,d- -64|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break z}gb(d- -64|0);j[114626]=0;I(491,d+16|0,2,d+128|0);e=j[114626];j[114626]=0;if((e|0)==1){break A}j[114626]=0;F(415,d- -64|0,d+16|0);e=j[114626];j[114626]=0;if((e|0)==1){break A}e=k[d+158|0]|k[d+159|0]<<8;j[114626]=0;E(369,(((e<<8&16711680|e<<24)>>>11|0)+a|0)+946300|0,d- -64|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break B}gb(d- -64|0);j[b>>2]=0;e=k[d+174|0]|k[d+175|0]<<8;j[b+8>>2]=((e<<24|e<<8&16711680)>>>16|0)+128&65535;kc(b+8|0,256);h[b+15|0]=k[b+15|0]|1;b=k[d+158|0]|k[d+159|0]<<8;j[114626]=0;b=p((b<<8&16711680|b<<24)>>>16|0,104)+a|0;F(386,b+484380|0,0);e=j[114626];j[114626]=0;if((e|0)==1){break C}e=k[d+160|0]|k[d+161|0]<<8;j[114626]=0;i[d+64>>1]=(e<<8&16711680|e<<24)>>>16;i[d+16>>1]=64;e=E(477,d- -64|0,d+16|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break D}i[b+484410>>1]=l[e>>1]<<2;e=k[d+162|0]|k[d+163|0]<<8|(k[d+164|0]<<16|k[d+165|0]<<24);j[b+484404>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if(!(k[d+170|0]|k[d+171|0]<<8|(k[d+172|0]<<16|k[d+173|0]<<24))|!(k[d+177|0]&3)){break da}e=k[d+166|0]|k[d+167|0]<<8|(k[d+168|0]<<16|k[d+169|0]<<24);g=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);j[b+484384>>2]=g;e=k[d+170|0]|k[d+171|0]<<8|(k[d+172|0]<<16|k[d+173|0]<<24);f=b+484414|0;i[f>>1]=l[f>>1]|2;j[b+484388>>2]=g+(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));if(!(k[d+177|0]&2)){break da}i[f>>1]=l[f>>1]|4}m=m+1|0;if(l[a+480192>>1]>=(m&65535)>>>0){continue}break}}j[114626]=0;I(474,d+112|0,d+264|0,1447382614);b=j[114626];j[114626]=0;if((b|0)==1){break G}j[114626]=0;L(492,d+112|0,0,a|0,0);b=j[114626];j[114626]=0;if((b|0)==1){break E}jb(d+112|0);j[114626]=0;I(474,d+96|0,d+264|0,1346719318);b=j[114626];j[114626]=0;if((b|0)==1){break G}j[114626]=0;L(492,d+96|0,1,a|0,k[d+300|0]>2|0);b=j[114626];j[114626]=0;if((b|0)==1){break F}jb(d+96|0);if(!l[a+480192>>1]){break ca}b=1;while(1){e=j[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|h[e+60|0]&1)){j[e>>2]=32767}b=b+1|0;if(l[a+480192>>1]>=(b&65535)>>>0){continue}break}}jb(d+184|0);j[114626]=0;I(474,d+128|0,d+264|0,1346458708);b=j[114626];j[114626]=0;if((b|0)==1){break H}j[114626]=0;b=H(337,d+128|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break J}if(!(c&1)|b^1){break X}j[114626]=0;I(474,d+184|0,d+264|0,1347305805);b=j[114626];j[114626]=0;if((b|0)==1){break K}j[114626]=0;E(338,d+184|0,1)|0;b=j[114626];j[114626]=0;if((b|0)==1){break M}s=d+248|6;e=k[s|0]|k[s+1|0]<<8;b=0;j[114626]=0;t=a+484344|0;F(401,t|0,(e<<8&16711680|e<<24)>>>16|0);e=j[114626];j[114626]=0;if((e|0)==1){break M}e=d+80|0;YJa(e);if(k[s|0]|k[s+1|0]<<8){B=d+16|5;J=d+16|3;M=d+16|4;O=d+16|2;P=d+16|1;f=0;while(1){j[114626]=0;A=H(484,d+128|0)|0;m=j[114626];j[114626]=0;ga:{ha:{ia:{ja:{ka:{if((m|0)!=1){j[114626]=0;m=H(493,d+128|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break ka}j[114626]=0;I(341,d- -64|0,d+128|0,m|0);m=j[114626];j[114626]=0;if((m|0)==1){break ja}j[114626]=0;m=K(402,t|0,f&65535,A|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break ia}if(!m){break ga}v=Db(d+48|0);j[114626]=0;K(494,d+184|0,v|0,-1)|0;m=j[114626];j[114626]=0;if((m|0)!=1){m=Ib(t,f);j[114626]=0;E(495,m|0,v|0)|0;m=j[114626];j[114626]=0;if((m|0)!=1){break ha}}break P}b=D()|0;C()|0;break N}b=D()|0;C()|0;break N}b=D()|0;C()|0;break N}b=D()|0;C()|0;break O}m=Ib(t,f);j[114626]=0;m=E(496,m|0,0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break P}IR(e);u=0;la:{while(1){j[114626]=0;g=E(258,d- -64|0,1)|0;n=j[114626];j[114626]=0;ma:{na:{oa:{if((n|0)!=1){if(!g){break la}j[114626]=0;o=H(387,d- -64|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break P}if(o){break na}R=d,S=Lb(e),j[R+40>>2]=S;R=d,S=Mb(e),j[R+32>>2]=S;if(rb(d+40|0,d+32|0)){break oa}break ma}break P}while(1){pa:{m=j[d+40>>2];g=Ib(t,f);n=k[m+1|0];m=k[m|0];j[114626]=0;m=K(497,d+16|0,m|0,n|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break pa}m=Fe(m,u);j[114626]=0;E(498,g|0,m|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break pa}je(d+40|0);if(rb(d+40|0,d+32|0)){continue}break ma}break}break P}Ug(d+16|0);w=l[a+480188>>1];j[114626]=0;g=H(387,d- -64|0)|0;n=j[114626];j[114626]=0;qa:{if((n|0)==1){break qa}n=p(o-1|0,6)+m|0;ra:{if(!(g&1)){break ra}j[114626]=0;q=H(387,d- -64|0)|0;r=j[114626];j[114626]=0;sa:{if((r|0)!=1){if(!q){break ra}if((q|0)!=31){break sa}h[(o>>>0>w>>>0?d+16|0:n)|0]=255;break ra}break P}if(q>>>0>253){break ra}h[(o>>>0>w>>>0?d+16|0:n)|0]=(p(q>>>4|0,12)+(q&15)|0)+13}if(g&2){j[114626]=0;q=H(387,d- -64|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break qa}h[(o>>>0>w>>>0?P:n+1|0)|0]=q}if(!(g&60)){continue}h[d+15|0]=0;h[d+14|0]=0;h[d+13|0]=0;h[d+12|0]=0;if(g&4){j[114626]=0;q=H(387,d- -64|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break P}h[d+14|0]=q}if(g&8){j[114626]=0;q=H(387,d- -64|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break P}h[d+12|0]=q}if(g&16){j[114626]=0;q=H(387,d- -64|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break P}h[d+15|0]=q}if(g&32){j[114626]=0;g=H(387,d- -64|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break P}h[d+13|0]=g}HR(d+15|0,d+13|0);HR(d+14|0,d+12|0);g=k[d+14|0];if(!(k[d+15|0]==13|g?(g|0)!=13:0)){Tg(d+15|0,d+14|0);Tg(d+13|0,d+12|0)}j[114626]=0;V(499,d+32|0,d+15|0,d+13|0,d+14|0,d+12|0);g=j[114626];j[114626]=0;ta:{if((g|0)==1){break ta}j[114626]=0;g=E(500,k[d+32|0],k[d+33|0])|0;q=j[114626];j[114626]=0;if((q|0)==1){break ta}ua:{if(!g){break ua}R=d,S=Lb(e),j[R+40>>2]=S;Cd(d+8|0,d+40|0);j[114626]=0;K(501,e|0,j[d+8>>2],d+32|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){break ua}break P}g=o>>>0>w>>>0;h[(g?O:n+2|0)|0]=k[d+15|0];h[(g?M:n+4|0)|0]=k[d+13|0];o=k[d+14|0];h[(g?J:n+3|0)|0]=o;h[(g?B:n+5|0)|0]=k[d+12|0];if((o|0)==40){Q=1;continue}if((o|0)!=31){continue}b=1;continue}break P}break P}IR(e);u=u+1|0;if(A>>>0<=u>>>0){break la}m=Ib(t,f);j[114626]=0;m=E(496,m|0,u|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){continue}break}break P}gb(v)}jb(d- -64|0);f=f+1|0;m=k[s|0]|k[s+1|0]<<8;if(f>>>0<(m<<24|m<<8&16711680)>>>16>>>0){continue}break}}FR(e);m=b;jb(d+184|0);if(!(c&4)){break V}e=0;if(!Q){break W}f=l[a+480188>>1];if(!f){e=1;break W}b=0;while(1){e=1;g=(b<<5)+a|0;h[g+480288|0]=1;g=g+480280|0;j[g>>2]=j[g>>2]|67108864;b=b+1|0;if((f|0)!=(b|0)){continue}break}break W}b=D()|0;C()|0;break t}b=D()|0;C()|0;break b}m=0;e=0;if(!(c&4)){break U}}j[114626]=0;j[d+64>>2]=-1778364416;j[d+68>>2]=-16756736;I(474,d+184|0,d+264|0,1146310725);b=j[114626];j[114626]=0;va:{wa:{xa:{ya:{za:{Aa:{if((b|0)!=1){j[114626]=0;b=H(489,d+184|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break xa}if(!b){break za}j[114626]=0;g=H(484,d+184|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break xa}if(g){break Aa}f=e;break ya}b=D()|0;C()|0;break I}b=0;f=e;while(1){j[114626]=0;n=H(387,d+184|0)|0;o=j[114626];j[114626]=0;Ba:{Ca:{if((o|0)!=1){if(l[a+480188>>1]<=b>>>0){break Ba}if(!e){break Ca}o=((b<<5)+a|0)+480280|0;j[o>>2]=j[o>>2]&-67108865|((n|0)!=0)<<26;break Ba}break xa}if(n){break Ba}f=1;h[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((g|0)!=(b|0)){continue}break}break ya}jb(d+184|0);if(!e){break V}break va}j[114626]=0;E(502,d+184|0,d- -64|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break wa}}b=D()|0;C()|0;jb(d+184|0);break I}jb(d+184|0);if(!(f&1)){break V}}j[114626]=0;N(503,a+906300|0);b=j[114626];j[114626]=0;Da:{Ea:{Fa:{Ga:{Ha:{Ia:{if((b|0)==1){break Ia}b=a+906316|0;j[b>>2]=810369604;j[b+4>>2]=1869112133;h[a+906324|0]=16;h[a+906325|0]=0;h[a+906326|0]=10;h[a+906327|0]=0;b=a+906328|0;h[b|0]=0;h[b+1|0]=0;h[b+2|0]=0;h[b+3|0]=0;j[114626]=0;j[d+184>>2]=0;b=a+906332|0;I(504,b|0,b+16|0,d+184|0);b=j[114626];j[114626]=0;if((b|0)==1){break Ha}j[114626]=0;e=E(85,d+184|0,12427)|0;b=j[114626];j[114626]=0;if((b|0)==1){break Ga}j[114626]=0;E(505,a+906348|0,e|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break Fa}gb(e);j[114626]=0;e=E(85,d+184|0,12432)|0;b=j[114626];j[114626]=0;if((b|0)==1){break Ea}j[114626]=0;E(506,a+906380|0,e|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break Da}gb(e);j[114626]=0;b=a+906304|0;F(507,b|0,8);e=j[114626];j[114626]=0;if((e|0)==1){break Ia}DR(d+184|0,k[d+65|0],k[d+67|0],k[d+69|0],k[d+71|0]);e=j[d+188>>2];b=j[b>>2];f=j[d+184>>2];h[b|0]=f;h[b+1|0]=f>>>8;h[b+2|0]=f>>>16;h[b+3|0]=f>>>24;h[b+4|0]=e;h[b+5|0]=e>>>8;h[b+6|0]=e>>>16;h[b+7|0]=e>>>24;break V}b=D()|0;C()|0;break I}b=D()|0;C()|0;break I}b=D()|0;C()|0;break I}b=D()|0;C()|0;gb(e);break I}b=D()|0;C()|0;break I}b=D()|0;C()|0;gb(e);break I}if(!m){break U}b=0;Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{while(1){eb:{j[114626]=0;j[d+48>>2]=p(b,127)>>>5;F(508,d- -64|0,12453);e=j[114626];j[114626]=0;if((e|0)==1){break eb}j[114626]=0;F(509,d+16|0,d+48|0);e=j[114626];j[114626]=0;if((e|0)==1){break db}j[114626]=0;I(510,d+184|0,d- -64|0,d+16|0);e=j[114626];j[114626]=0;if((e|0)==1){break cb}j[114626]=0;e=(b<<5)+a|0;F(511,d+80|0,e+902204|0);f=j[114626];j[114626]=0;if((f|0)==1){break bb}j[114626]=0;E(470,d+80|0,d+184|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break bb}gb(d+184|0);gb(d+16|0);qb(d- -64|0);j[114626]=0;F(508,d- -64|0,12462);f=j[114626];j[114626]=0;if((f|0)==1){break _a}j[114626]=0;F(509,d+16|0,d+48|0);f=j[114626];j[114626]=0;if((f|0)==1){break Za}j[114626]=0;I(510,d+184|0,d- -64|0,d+16|0);f=j[114626];j[114626]=0;if((f|0)==1){break Ya}j[114626]=0;F(511,d+80|0,e+903228|0);f=j[114626];j[114626]=0;if((f|0)==1){break Xa}j[114626]=0;E(470,d+80|0,d+184|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Xa}gb(d+184|0);gb(d+16|0);qb(d- -64|0);j[114626]=0;F(508,d- -64|0,12471);f=j[114626];j[114626]=0;if((f|0)==1){break Ua}j[114626]=0;F(509,d+16|0,d+48|0);f=j[114626];j[114626]=0;if((f|0)==1){break Ta}j[114626]=0;I(510,d+184|0,d- -64|0,d+16|0);f=j[114626];j[114626]=0;if((f|0)==1){break Sa}j[114626]=0;F(511,d+80|0,e+904252|0);f=j[114626];j[114626]=0;if((f|0)==1){break Ra}j[114626]=0;E(470,d+80|0,d+184|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Ra}gb(d+184|0);gb(d+16|0);qb(d- -64|0);j[114626]=0;F(508,d- -64|0,12480);f=j[114626];j[114626]=0;if((f|0)==1){break Oa}j[114626]=0;F(509,d+16|0,d+48|0);f=j[114626];j[114626]=0;if((f|0)==1){break Na}j[114626]=0;I(510,d+184|0,d- -64|0,d+16|0);f=j[114626];j[114626]=0;if((f|0)==1){break Ma}j[114626]=0;F(511,d+80|0,e+905276|0);e=j[114626];j[114626]=0;if((e|0)==1){break La}j[114626]=0;E(470,d+80|0,d+184|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break La}gb(d+184|0);gb(d+16|0);qb(d- -64|0);b=b+1|0;if((b|0)!=32){continue}break U}break}b=D()|0;C()|0;break I}b=D()|0;C()|0;break $a}b=D()|0;C()|0;break ab}b=D()|0;C()|0;gb(d+184|0)}gb(d+16|0)}qb(d- -64|0);break I}b=D()|0;C()|0;break I}b=D()|0;C()|0;break Va}b=D()|0;C()|0;break Wa}b=D()|0;C()|0;gb(d+184|0)}gb(d+16|0)}qb(d- -64|0);break I}b=D()|0;C()|0;break I}b=D()|0;C()|0;break Pa}b=D()|0;C()|0;break Qa}b=D()|0;C()|0;gb(d+184|0)}gb(d+16|0)}qb(d- -64|0);break I}b=D()|0;C()|0;break I}b=D()|0;C()|0;break Ja}b=D()|0;C()|0;break Ka}b=D()|0;C()|0;gb(d+184|0)}gb(d+16|0)}qb(d- -64|0);break I}j[114626]=0;I(474,d+184|0,d+264|0,1397575756);b=j[114626];j[114626]=0;if((b|0)==1){break Q}j[114626]=0;b=H(337,d+184|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break R}if(!(!l[a+480190>>1]|(!(c&2)|b^1))){e=1;c=1;while(1){j[114626]=0;b=H(493,d+184|0)|0;f=j[114626];j[114626]=0;fb:{if((f|0)!=1){j[114626]=0;f=H(493,d+184|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break R}if(!(b&7)){break fb}e=(p(e,104)+a|0)+484380|0;j[e>>2]=f;b=Mc(d- -64|0,b&4?32:b&2?16:8,1,1,0);j[114626]=0;K(400,b|0,e|0,d+184|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break fb}break R}break R}c=c+1|0;e=c&65535;if(e>>>0<=l[a+480190>>1]){continue}break}}jb(d+184|0);jb(d+128|0);jb(d+200|0);jb(d+216|0)}Gz(d+264|0);jb(y)}Za=d+304|0;return x|0}b=D()|0;C()|0;jb(d+184|0);break I}b=D()|0;C()|0;break I}b=D()|0;C()|0;gb(v)}jb(d- -64|0)}FR(e);break L}b=D()|0;C()|0}jb(d+184|0);break I}b=D()|0;C()|0;break I}b=D()|0;C()|0}jb(d+128|0);break t}b=D()|0;C()|0;break t}b=D()|0;C()|0;break y}b=D()|0;C()|0;jb(d+96|0);break y}b=D()|0;C()|0;jb(d+112|0);break y}b=D()|0;C()|0;break y}b=D()|0;C()|0;break y}b=D()|0;C()|0;gb(d- -64|0);break y}b=D()|0;C()|0;break y}b=D()|0;C()|0;gb(d- -64|0)}jb(d+184|0);break t}b=D()|0;C()|0;break t}b=D()|0;C()|0;break t}b=D()|0;C()|0;gb(d+184|0);break t}b=D()|0;C()|0}jb(d+200|0);break q}b=D()|0;C()|0;break q}b=D()|0;C()|0}jb(d+216|0);break b}b=D()|0;C()|0;break b}b=D()|0;C()|0;gb(d+184|0);break m}b=D()|0;C()|0}gb(d+200|0);break k}b=D()|0;C()|0}qb(d+216|0);break i}b=D()|0;C()|0}gb(e);break b}b=D()|0;C()|0;break b}b=D()|0;C()|0;break b}b=D()|0;C()|0;break b}b=D()|0;C()|0;break b}b=D()|0;C()|0;break b}b=D()|0;C()|0}Gz(d+264|0)}jb(y);G(b|0);z()}function wza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0;d=Za-320|0;Za=d;rc(b);a:{if(!ct(b,d+304|0)){break a}if(!DN(d+304|0)){break a}w=pl(d+288|0,b);v=ny(d+272|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!c){j[114626]=0;L(948,d|0,w|0,1,1413891155);b=j[114626];j[114626]=0;if((b|0)==1){break s}break u}j[114626]=0;I(949,d|0,w|0,1);b=j[114626];j[114626]=0;if((b|0)==1){break t}}_ya(v,d);gl(d);j[114626]=0;I(950,d|0,v|0,1413891155);b=j[114626];j[114626]=0;v:{w:{if((b|0)!=1){j[114626]=0;e=E(951,d|0,16779)|0;b=j[114626];j[114626]=0;if((b|0)==1){break w}jb(d);if(!c){break b}if(!(e^1)){break v}break b}e=D()|0;C()|0;break c}e=D()|0;C()|0;jb(d);break c}j[114626]=0;F(447,a|0,4194304);b=j[114626];j[114626]=0;if((b|0)==1){break d}j[a+480208>>2]=12;j[114626]=0;I(950,d+256|0,v|0,1280592212);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=H(255,d+256|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break g}j[114626]=0;K(463,d+256|0,a+1304400|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}s=a+484360|0;wp(Fb(s));q=d+240|0;iza(q);j[114626]=0;h[d+239|0]=0;I(952,d+224|0,v|0,1196314451);b=j[114626];j[114626]=0;if((b|0)==1){break i}A=d,B=Lb(d+224|0),j[A+216>>2]=B;A=d,B=Mb(d+224|0),j[A+208>>2]=B;x:{y:{z:{A:{B:{C:{if(!rb(d+216|0,d+208|0)){break C}o=d+12|0;f=d+24|0;u=d+44|0;while(1){e=pl(d+192|0,j[d+216>>2]);j[114626]=0;g=E(953,d+192|0,d+176|0)|0;b=j[114626];j[114626]=0;D:{E:{F:{G:{H:{I:{if((b|0)!=1){b=1;if(!(g&k[d+185|0]==1)){break D}A=a,B=kd(k[d+186|0],l[a+480188>>1],127),i[A+480188>>1]=B;j[114626]=0;r=H(954,d|0)|0;b=j[114626];j[114626]=0;J:{K:{L:{M:{if((b|0)!=1){j[114626]=0;I(955,d+160|0,1,d+176|0);b=j[114626];j[114626]=0;if((b|0)==1){break M}j[114626]=0;F(415,d+120|0,d+160|0);b=j[114626];j[114626]=0;if((b|0)==1){break M}j[114626]=0;F(956,d+152|0,u|0);b=j[114626];j[114626]=0;if((b|0)==1){break L}j[114626]=0;E(470,d+152|0,d+120|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break L}gb(d+120|0);if(ad(Fb(s))){break J}j[114626]=0;b=H(485,s|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break K}if((b|0)!=255){break J}b=2;break E}e=D()|0;C()|0;break k}e=D()|0;C()|0;break l}e=D()|0;C()|0;gb(d+120|0);break l}e=D()|0;C()|0;break l}b=Fb(s);j[114626]=0;I(6,d+120|0,4,u|0);g=j[114626];j[114626]=0;N:{O:{P:{if((g|0)!=1){j[114626]=0;F(486,b|0,d+120|0);b=j[114626];j[114626]=0;if((b|0)==1){break P}gb(d+120|0);j[114626]=0;I(949,d+160|0,e|0,1);b=j[114626];j[114626]=0;if((b|0)==1){break O}A=d,B=Lb(d+160|0),j[A+144>>2]=B;A=d,B=Mb(d+160|0),j[A+136>>2]=B;if(rb(d+144|0,d+136|0)){break N}break H}e=D()|0;C()|0;break l}e=D()|0;C()|0;gb(d+120|0);break l}e=D()|0;C()|0;break l}Q:{R:{while(1){S:{e=j[d+144>>2];b=Ie(d+120|0,hb(e));g=k[e+4|0]|k[e+5|0]<<8|(k[e+6|0]<<16|k[e+7|0]<<24);j[d+152>>2]=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);j[d+156>>2]=g;t=1;T:{e=k[d+152|0]|k[d+153|0]<<8|(k[d+154|0]<<16|k[d+155|0]<<24);if((e|0)!=1212960847){if((e|0)!=1312903248){break T}e=0;if(!l[a+480188>>1]){break T}U:{while(1){j[114626]=0;g=E(258,b|0,2)|0;m=j[114626];j[114626]=0;if((m|0)==1){break U}if(!g){break T}j[114626]=0;F(472,d+96|0,b|0);g=j[114626];j[114626]=0;V:{W:{X:{Y:{if((g|0)!=1){g=Pc(d+96|0);switch(k[d+96|0]){case 4:break W;case 2:break X;case 0:break Y;default:break V}}break I}g=k[g|0];A=fc(d,e),B=g^128,h[A|0]=B;Nd(d+104|0,f,e);Qd(d+104|0,0);break V}A=fc(d,e),B=128,h[A|0]=B;Nd(d+104|0,f,e);Qd(d+104|0,1);break V}A=fc(d,e),B=128,h[A|0]=B;Nd(d+104|0,f,e);Qd(d+104|0,0)}e=e+1|0;if(e>>>0<l[a+480188>>1]){continue}break}break T}break I}if(my(d+152|0)>>>0<9){break T}m=0;j[114626]=0;E(338,b|0,2)|0;e=j[114626];j[114626]=0;g=65535;if((e|0)==1){break S}while(1){j[114626]=0;e=E(258,b|0,1)|0;n=j[114626];j[114626]=0;Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((n|0)!=1){if(!e){break T}j[114626]=0;e=H(387,b|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break I}switch(e|0){case 0:break T;case 14:break _;case 13:break $;case 12:break ba;case 8:break ca;case 7:break da;case 4:break ea;case 1:break fa;default:break aa}}break I}if(l[d+36>>1]==65535){e=Fb(s);j[114626]=0;e=H(544,e|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break I}i[d+36>>1]=e}e=Fb(s);j[114626]=0;e=H(544,e|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break I}j[114626]=0;i[d+38>>1]=e;e=E(957,b|0,d+239|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break I}ga:{ha:{switch(e-254|0){case 1:j[114626]=0;e=T(958)|0;n=j[114626];j[114626]=0;if((n|0)!=1){break ga}break I;case 0:break ha;default:break ga}}j[114626]=0;e=T(959)|0;n=j[114626];j[114626]=0;if((n|0)==1){break I}}n=Fb(s);j[114626]=0;F(793,n|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break I}g=(g&65535)==65535?m:g;break Z}j[114626]=0;e=H(357,b|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break I}if(e>>>0>=(g&65535)>>>0){i[d+40>>1]=e-g}Ge(Fb(s),l[d+40>>1]);break Z}j[114626]=0;e=H(387,b|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break I}h[d+43|0]=e;break Z}j[114626]=0;e=H(387,b|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break I}h[d+42|0]=e;break Z}j[114626]=0;e=E(915,b|0,d+104|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break I}if(!(e&!k[d+104|0])|(k[d+106|0]|k[d+107|0])|(k[d+105|0]!=255|k[d+108|0]!=1)){break aa}if(!k[d+109|0]){break Z}}t=0;break T}j[114626]=0;F(805,d+112|0,b|0);e=j[114626];j[114626]=0;ia:{ja:{ka:{la:{if((e|0)!=1){n=Pc(d+112|0);x=Bf(d+112|0);e=d+112|0;if(k[e|0]>=tc(d)>>>0){break Z}switch(k[x|0]){case 4:break ja;case 2:break ka;case 0:break la;default:break ia}}break I}n=k[n|0];A=fc(d,k[e|0]),B=n^128,h[A|0]=B;Nd(d+104|0,f,k[e|0]);Qd(d+104|0,0);break ia}A=fc(d,k[e|0]),B=128,h[A|0]=B;Nd(d+104|0,f,k[e|0]);Qd(d+104|0,1);break ia}A=fc(d,k[e|0]),B=128,h[A|0]=B;Nd(d+104|0,f,k[e|0]);Qd(d+104|0,0)}ma:{if(y){break ma}y=0;if(!Vj(q)){break Z}if(k[fc(BN(q),k[e|0])|0]!=k[fc(d,k[e|0])|0]){break ma}Nd(d+104|0,BN(q)+24|0,k[e|0]);n=kb(d+104|0);Nd(d+96|0,f,k[e|0]);if((kb(d+96|0)|0)==(n|0)){break Z}}y=1;break Z}j[114626]=0;F(472,d+104|0,b|0);e=j[114626];j[114626]=0;if((e|0)==1){break Q}e=Pc(d+104|0);n=d+104|0;x=k[n|0];if(tc(o)>>>0<=x>>>0){break Z}e=k[e|0];A=fc(o,k[n|0]),B=(e>>>2|0)+1|0,h[A|0]=B}m=m+1|0;continue}}jb(b);if(!t){break R}fk(d+144|0);if(rb(d+144|0,d+136|0)){continue}break H}break}break I}b=1;break F}break I}e=D()|0;C()|0;break k}e=D()|0;C()|0;jb(b);break G}b=0;if(l[d+36>>1]==65535|l[d+38>>1]==65535){break F}b=Fb(s);j[114626]=0;N(960,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){b=0;j[114626]=0;F(961,q|0,r|0);e=j[114626];j[114626]=0;if((e|0)!=1){break F}}e=D()|0;C()|0}gl(d+160|0);break l}gl(d+160|0)}ly(r)}jb(d+192|0);if(!b){yf(d+216|0);if(rb(d+216|0,d+208|0)){continue}break C}break}e=0;if((b|0)!=2){break B}}e=0;j[114626]=0;F(488,s|0,0);b=j[114626];j[114626]=0;if((b|0)==1){break r}if(ad(q)){break B}if(c&2){j[114626]=0;I(952,d+192|0,v|0,1347244868);b=j[114626];j[114626]=0;if((b|0)==1){break x}A=d,B=Lb(d+192|0),j[A+176>>2]=B;A=d,B=Mb(d+192|0),j[A+152>>2]=B;if(rb(d+176|0,d+152|0)){e=a+480190|0;f=d+13|0;g=d+17|0;r=k[d+239|0];while(1){b=j[d+176>>2];na:{oa:{pa:{qa:{ra:{if(!r){j[114626]=0;m=E(962,b|0,d|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break ra}if(!m){break na}m=k[d+52|0]|k[d+53|0]<<8;i[d+104>>1]=m+1;if(m>>>0>3998){break pa}j[114626]=0;m=E(452,e|0,d+104|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break ra}i[a+480190>>1]=l[m>>1];j[114626]=0;F(963,d|0,(p(l[d+104>>1],104)+a|0)+484380|0);m=j[114626];j[114626]=0;if((m|0)==1){break ra}j[114626]=0;I(964,d+160|0,1,f|0);m=j[114626];j[114626]=0;sa:{ta:{if((m|0)==1){break ta}j[114626]=0;F(415,d+120|0,d+160|0);m=j[114626];j[114626]=0;if((m|0)==1){break ta}j[114626]=0;E(369,((l[d+104>>1]<<5)+a|0)+946300|0,d+120|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break sa}gb(d+120|0);break pa}e=D()|0;C()|0;break oa}e=D()|0;C()|0;gb(d+120|0);break oa}j[114626]=0;m=E(965,b|0,d|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break qa}if(!m){break na}m=k[d+56|0]|k[d+57|0]<<8;i[d+104>>1]=m+1;if(m>>>0>3998){break pa}j[114626]=0;m=E(452,e|0,d+104|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break qa}i[a+480190>>1]=l[m>>1];j[114626]=0;F(966,d|0,(p(l[d+104>>1],104)+a|0)+484380|0);m=j[114626];j[114626]=0;if((m|0)==1){break qa}j[114626]=0;I(964,d+160|0,1,g|0);m=j[114626];j[114626]=0;ua:{va:{if((m|0)==1){break va}j[114626]=0;F(415,d+120|0,d+160|0);m=j[114626];j[114626]=0;if((m|0)==1){break va}j[114626]=0;E(369,((l[d+104>>1]<<5)+a|0)+946300|0,d+120|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break ua}gb(d+120|0);break pa}e=D()|0;C()|0;break oa}e=D()|0;C()|0;gb(d+120|0);break oa}e=D()|0;C()|0;break oa}e=D()|0;C()|0;break oa}if((l[d+104>>1]-1&65535)>>>0>3998){break na}m=Mc(d,8,1,0,2);j[114626]=0;K(400,m|0,(p(l[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break na}e=D()|0;C()|0}Sc(d+192|0);break j}yf(d+176|0);if(rb(d+176|0,d+152|0)){continue}break}}Sc(d+192|0)}A=a,B=k[fl(q,0)+43|0],j[A+480196>>2]=B;A=a,B=p(k[fl(q,0)+42|0],1e4),j[A+480204>>2]=B;Ge(Fb(s),l[fl(q,0)+40>>1]);if(l[a+480188>>1]){b=0;while(1){j[114626]=0;e=(b<<5)+a|0;f=e+480280|0;N(432,f|0);g=j[114626];j[114626]=0;if((g|0)==1){break y}A=e+480286|0,B=k[fc(fl(q,0)+12|0,b)|0],i[A>>1]=B;A=e+480284|0,B=k[fc(fl(q,0),b)|0],i[A>>1]=B;Nd(d,fl(q,0)+24|0,b);e=kb(d);j[f>>2]=j[f>>2]&-257|(e?256:0);b=b+1|0;if(b>>>0<l[a+480188>>1]){continue}break}}wa:{if(k[d+239|0]){j[114626]=0;E(2,d|0,16788)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break wa}break m}j[114626]=0;E(2,d|0,16832)|0;b=j[114626];j[114626]=0;if((b|0)==1){break m}}ob(a+1304436|0,d);gb(d);j[114626]=0;b=E(2,d|0,16866)|0;f=j[114626];j[114626]=0;e=1;if((f|0)==1){break z}ob(a+1304448|0,b);gb(b);j[a+1304496>>2]=4;if(!(c&1)|!l[a+480188>>1]){break B}j[114626]=0;I(952,d+192|0,v|0,1146045008);b=j[114626];j[114626]=0;if((b|0)==1){break n}b=Xc(d+192|0);j[114626]=0;m=a+484344|0;F(401,m|0,b&65535);b=j[114626];j[114626]=0;if((b|0)==1){break q}A=d,B=Lb(d+192|0),j[A+120>>2]=B;A=d,B=Mb(d+192|0),j[A+160>>2]=B;if(rb(d+120|0,d+160|0)){while(1){r=j[d+120>>2];j[114626]=0;b=H(255,r|0)|0;c=j[114626];j[114626]=0;xa:{ya:{za:{if((c|0)==1){break za}j[114626]=0;c=H(390,r|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break za}if((b|0)!=(c|0)){break xa}j[114626]=0;b=E(967,r|0,8)|0;c=j[114626];j[114626]=0;if((c|0)==1){break za}if(b){break ya}break xa}e=D()|0;C()|0;break o}j[114626]=0;u=E(957,r|0,d+239|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){j[114626]=0;o=H(357,r|0)|0;b=j[114626];j[114626]=0;Aa:{if((b|0)==1){break Aa}j[114626]=0;b=K(402,m|0,u|0,o|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break Aa}if(!o|b^1){break xa}g=0;while(1){Ba:{b=Ib(m,u);j[114626]=0;c=E(496,b|0,g|0)|0;b=j[114626];j[114626]=0;Ca:{Da:{Ea:{if((b|0)!=1){j[114626]=0;b=H(357,r|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Ea}if(b>>>0<3){break Ca}j[114626]=0;I(341,d|0,r|0,b-2|0);b=j[114626];j[114626]=0;if((b|0)!=1){break Da}e=D()|0;C()|0;break o}e=D()|0;C()|0;break o}e=D()|0;C()|0;break o}while(1){j[114626]=0;b=E(258,d|0,3)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Ba}if(b){j[114626]=0;F(472,d+176|0,d|0);b=j[114626];j[114626]=0;Fa:{Ga:{Ha:{Ia:{if((b|0)!=1){f=d+176|0;b=Pc(d+176|0);i[d+152>>1]=l[a+480188>>1]-1;b=k[b|0];j[114626]=0;i[d+104>>1]=b;b=E(477,d+152|0,d+104|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Ba}e=l[b>>1];b=h[f|0];if((b|0)>-1){break Fa}j[114626]=0;b=H(387,d|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break Ba}if(k[d+239|0]){break Ha}if((b|0)!=255){break Ia}b=254;break Ga}break Ba}if(b>>>0>128){break Ga}b=(p(b>>>4|0,12)+(b&15)|0)+13|0;break Ga}b=b>>>0<85?b+36|0:b}h[c+p(e,6)|0]=b;b=k[f|0]}if(b&64){j[114626]=0;b=H(387,d|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break Ba}h[(c+p(e,6)|0)+1|0]=b+1;b=k[f|0]}if(b&32){j[114626]=0;b=H(387,d|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break Ba}h[d+152|0]=b;b=c+p(e,6)|0;h[b+2|0]=1;j[114626]=0;h[d+104|0]=127;t=E(391,d+152|0,d+104|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break Ba}h[b+4|0]=k[t|0]+1>>>1;b=k[f|0]}if(!(b&16)){continue}j[114626]=0;F(472,d+152|0,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break Ba}b=c+p(e,6)|0;f=k[Pc(d+152|0)|0];h[b+5|0]=f;Ja:{switch(k[d+152|0]-1|0){case 0:h[(c+p(e,6)|0)+3|0]=11;if(!k[d+239|0]){h[b+5|0]=f<<3|15;continue}h[b+5|0]=f<<4|15;continue;case 1:h[(c+p(e,6)|0)+3|0]=11;if(k[d+239|0]){h[b+5|0]=f<<4;continue}h[b+5|0]=f<<3&240;continue;case 2:h[(c+p(e,6)|0)+3|0]=11;if(k[d+239|0]){h[b+5|0]=f|240;continue}h[b+5|0]=f>>>1|240;continue;case 3:h[(c+p(e,6)|0)+3|0]=11;if(k[d+239|0]){h[b+5|0]=f&15;continue}if(f>>>0<=1){h[b+5|0]=f|240;continue}h[b+5|0]=f>>>1&15;continue;case 10:h[(c+p(e,6)|0)+3|0]=2;A=b,B=vs(f,k[d+239|0])|240,h[A+5|0]=B;continue;case 11:h[(c+p(e,6)|0)+3|0]=2;A=b,B=vs(f,k[d+239|0]),h[A+5|0]=B;continue;case 12:h[(c+p(e,6)|0)+3|0]=3;A=b,B=vs(f,k[d+239|0])|240,h[A+5|0]=B;continue;case 13:h[(c+p(e,6)|0)+3|0]=3;A=b,B=vs(f,k[d+239|0]),h[A+5|0]=B;continue;case 14:h[(c+p(e,6)|0)+3|0]=4;if(k[d+239|0]){continue}h[b+5|0]=(f&252)>>>2;continue;case 16:h[(c+p(e,6)|0)+3|0]=20;h[b+5|0]=f&1|16;continue;case 15:h[(c+p(e,6)|0)+3|0]=6;h[b+5|0]=f&240;continue;case 17:h[(c+p(e,6)|0)+3|0]=6;h[b+5|0]=(f&240)>>>4;continue;case 18:h[(c+p(e,6)|0)+3|0]=20;continue;case 20:h[(c+p(e,6)|0)+3|0]=5;continue;case 21:h[(c+p(e,6)|0)+3|0]=20;h[b+5|0]=f&15|48;continue;case 22:h[(c+p(e,6)|0)+3|0]=7;h[b+5|0]=f|240;continue;case 23:h[(c+p(e,6)|0)+3|0]=7;continue;case 30:h[(c+p(e,6)|0)+3|0]=8;continue;case 31:h[(c+p(e,6)|0)+3|0]=20;h[b+5|0]=f&15|64;continue;case 40:h[(c+p(e,6)|0)+3|0]=10;j[114626]=0;e=H(387,d|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Ba}h[b+5|0]=e;j[114626]=0;E(338,d|0,1)|0;b=j[114626];j[114626]=0;if((b|0)!=1){continue}break Ba;case 41:h[(c+p(e,6)|0)+3|0]=15;continue;case 42:h[(c+p(e,6)|0)+3|0]=20;h[b+5|0]=f&15|192;continue;case 43:h[(c+p(e,6)|0)+3|0]=20;h[b+5|0]=f&15|208;continue;case 50:h[(c+p(e,6)|0)+3|0]=12;h[b+5|0]=(f&254)>>>1;j[114626]=0;E(338,d|0,1)|0;b=j[114626];j[114626]=0;if((b|0)!=1){continue}break Ba;case 51:h[(c+p(e,6)|0)+3|0]=14;h[b+5|0]=0;continue;case 52:h[(c+p(e,6)|0)+3|0]=20;h[b+5|0]=f&15|176;continue;case 53:h[(c+p(e,6)|0)+3|0]=20;h[b+5|0]=f&15|224;continue;case 60:h[(c+p(e,6)|0)+3|0]=16;continue;case 61:h[(c+p(e,6)|0)+3|0]=17;continue;case 70:h[(c+p(e,6)|0)+3|0]=1;continue;case 71:h[(c+p(e,6)|0)+3|0]=20;h[b+5|0]=f&15|32;continue;case 72:h[(c+p(e,6)|0)+3|0]=20;h[b+5|0]=f&15|128;continue;default:break Ja}}h[(c+p(e,6)|0)+3|0]=0;continue}break}jb(d)}g=g+1|0;if((o|0)!=(g|0)){continue}break xa}break}e=D()|0;C()|0;jb(d);break o}e=D()|0;C()|0;break o}e=D()|0;C()|0;break o}yf(d+120|0);if(rb(d+120|0,d+160|0)){continue}break}}Ka:{if(Vj(q)>>>0<2){break Ka}if(!Vj(q)){break Ka}e=0;while(1){b=gi(s,e&255);c=fl(q,e);f=l[ac(b,l[c+36>>1])>>1];j[114626]=0;f=E(442,m|0,f|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break p}La:{if(!f){break La}f=l[c+36>>1];j[114626]=0;f=E(809,b|0,f|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break p}if(!(!y|!l[a+480188>>1])){r=c+24|0;b=0;while(1){Nd(d,r,b);o=kb(d);g=Ib(m,f);Ma:{if(o){j[114626]=0;o=K(497,d|0,20,145)|0;u=j[114626];j[114626]=0;if((u|0)!=1){o=qi(cn(Fe(o,0),b&65535));j[114626]=0;E(498,g|0,o|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){break Ma}}e=D()|0;C()|0;break o}o=k[fc(c,b)|0];j[114626]=0;o=K(497,d|0,9,o|0)|0;u=j[114626];j[114626]=0;if((u|0)!=1){o=qi(cn(Fe(o,0),b&65535));j[114626]=0;E(498,g|0,o|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){break Ma}}e=D()|0;C()|0;break o}b=b+1|0;if(b>>>0<l[a+480188>>1]){continue}break}}b=Ib(m,f);g=k[c+43|0];j[114626]=0;g=K(497,d|0,16,g|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break A}g=qi(Fe(g,0));j[114626]=0;E(498,b|0,g|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break A}b=Ib(m,f);c=k[c+42|0];j[114626]=0;c=K(497,d|0,17,c|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){c=qi(Fe(c,0));j[114626]=0;E(498,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break La}}e=D()|0;C()|0;break o}e=e+1|0;if(Vj(q)>>>0>e>>>0){continue}break}}Sc(d+192|0);e=1}Sc(d+224|0);AN(q);jb(d+256|0);break b}e=D()|0;C()|0;break o}e=D()|0;C()|0;break j}e=D()|0;C()|0;break j}e=D()|0;C()|0;break j}e=D()|0;C()|0;break c}e=D()|0;C()|0;break c}e=D()|0;C()|0;break j}e=D()|0;C()|0;break o}e=D()|0;C()|0}Sc(d+192|0);break j}e=D()|0;C()|0;break j}e=D()|0;C()|0;break j}ly(r)}jb(d+192|0)}Sc(d+224|0);break h}e=D()|0;C()|0}AN(q);break f}e=D()|0;C()|0}jb(d+256|0);break c}e=D()|0;C()|0;break c}e=D()|0;C()|0}gl(v);jb(w);G(e|0);z()}gl(v);jb(w)}Za=d+320|0;return e|0}function fIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,J=0,M=0,O=0,Q=0,R=0;d=Za-288|0;Za=d;rc(b);f=d+264|0;g=QHa(b,f);if(!g){QQ(f)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!g){break u}if(!TQ(d+264|0)){break u}if(!c){e=1;break u}od(a,1024);_h(a);j[a+480208>>2]=j[a+480208>>2]|12;rg(a+1074308|0,21);if(k[d+280|0]|k[d+281|0]<<8){e=k[d+280|0]|k[d+281|0]<<8;j[a+480204>>2]=p((e<<24|e<<8&16711680)>>>16|0,1e4)}if(k[d+278|0]|k[d+279|0]<<8){e=k[d+278|0]|k[d+279|0]<<8;j[a+480196>>2]=(e<<24|e<<8&16711680)>>>16}if(!k[d+274|0]){Oi(a,1)}e=d+264|4;e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);Iz(b,a+1304400|0,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))-14|0);b=pl(d+160|0,b);j[114626]=0;I(579,d+248|0,b|0,1);e=j[114626];j[114626]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){jb(b);j[114626]=0;I(580,d+160|0,d+248|0,1395544366);b=j[114626];j[114626]=0;if((b|0)==1){break E}j[114626]=0;b=H(489,d+160|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break L}if(!b){break F}j[114626]=0;b=H(484,d+160|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break L}j[114626]=0;e=H(484,d+160|0)|0;f=j[114626];j[114626]=0;N:{if((f|0)==1){break N}j[114626]=0;E(338,d+160|0,4)|0;f=j[114626];j[114626]=0;if((f|0)==1){break N}f=a+484360|0;g=Fb(f);j[114626]=0;U(581,g|0,d+160|0,b|0,65535,65535)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break M}}break L}e=D()|0;C()|0;jb(b);break a}Ge(Fb(f),e);jb(d+160|0);j[114626]=0;I(580,d+160|0,d+248|0,1346458708);b=j[114626];j[114626]=0;if((b|0)==1){break K}j[114626]=0;b=H(489,d+160|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break J}if(!b){break H}j[114626]=0;b=H(484,d+160|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break J}i[a+480188>>1]=b;if((b-1&65535)>>>0>31){break H}j[114626]=0;b=H(484,d+160|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break J}j[114626]=0;v=a+484344|0;F(401,v|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break J}j[114626]=0;w=H(493,d+160|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break J}switch(w-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}e=D()|0;C()|0;jb(d+160|0);break b}e=D()|0;C()|0;break b}e=D()|0;C()|0;jb(d+160|0);break b}if(!w){break G}}jb(d+160|0);break A}jb(d+160|0);j[114626]=0;I(580,d+232|0,d+248|0,1398157625);b=j[114626];j[114626]=0;if((b|0)==1){break D}j[114626]=0;b=H(489,d+232|0)|0;e=j[114626];j[114626]=0;O:{if((e|0)==1){break O}if(!b){break B}j[114626]=0;E(338,d+232|0,2)|0;b=j[114626];j[114626]=0;if((b|0)==1){break O}j[114626]=0;e=H(493,d+232|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}b=a;g=b;y=(+(e>>>0)*2.3283064365386963e-10+ +(m[b+480204>>2]/1e4>>>0))*1e4;P:{if(y<4294967296&y>=0){b=~~y>>>0;break P}b=0}j[g+480204>>2]=b;j[114626]=0;E(582,d+232|0,d+160|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}b=0;while(1){if(l[a+480188>>1]<=b>>>0){break C}e=(d+160|0)+(b<<1)|0;e=k[e|0]|k[e+1|0]<<8;j[114626]=0;j[d+96>>2]=(e<<8&16711680|e<<24)>>>16;j[d+80>>2]=180;e=E(462,d+96|0,d+80|0)|0;f=j[114626];j[114626]=0;Q:{if((f|0)==1){break Q}e=j[e>>2];j[114626]=0;e=e-90|0;f=e>>31;e=ig(458,PMa(e<<7|45,f<<7|e>>>25,90,0),ab);f=j[114626];j[114626]=0;if((f|0)==1){break Q}i[((b<<5)+a|0)+480284>>1]=e+128;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}jb(d+160|0);break A}e=D()|0;C()|0;break b}e=D()|0;C()|0;break b}j[114626]=0;E(338,d+232|0,16)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}j[114626]=0;b=E(258,d+232|0,2)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}if(b){j[114626]=0;b=H(484,d+232|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;i[d+96>>1]=b;i[d+80>>1]=256;b=E(477,d+96|0,d+80|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}j[a+480200>>2]=l[b>>1]}j[114626]=0;E(338,d+232|0,128)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}j[114626]=0;b=E(582,d+232|0,d+96|0)|0;e=j[114626];j[114626]=0;R:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(l[a+480188>>1]<=b>>>0){break R}e=(d+96|0)+(b<<1)|0;e=k[e|0]|k[e+1|0]<<8;j[114626]=0;j[d+80>>2]=(e<<8&16711680|e<<24)>>>16;j[d+56>>2]=128;e=E(462,d+80|0,d+56|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){i[((b<<5)+a|0)+480286>>1]=j[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break R}break}break c}break c}j[a+480228>>2]=j[a+480228>>2]<<1}jb(d+232|0);j[114626]=0;I(580,d+160|0,d+248|0,1413830740);b=j[114626];j[114626]=0;S:{T:{if((b|0)!=1){j[114626]=0;b=H(489,d+160|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break d}if(!b){break S}j[114626]=0;E(583,d+160|0,d+96|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}if((k[d+106|0]|k[d+107|0]<<8)!=65535){break T}j[114626]=0;E(338,d+160|0,1)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break T}break d}e=D()|0;C()|0;break b}j[114626]=0;b=H(540,d+160|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break d}j[114626]=0;P(584,a+1304424|0,d+160|0,b|0,2)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}}jb(d+160|0);j[114626]=0;I(580,d+96|0,d+248|0,1229869908);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=H(489,d+96|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){if(b){j[114626]=0;b=H(484,d+96|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break g}U:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break U}j[114626]=0;e=E(258,d+96|0,p(f,(b>>>14&2)+50|0)|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break y}if(!e){break U}i[a+480190>>1]=f;g=a+480190|0;if(!f){break z}o=d+178|0;q=(b|0)>-1;b=1;V:{W:{while(1){X:{e=b;Y:{Z:{_:{if(!q){j[114626]=0;e=H(484,d+96|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break _}e=e+1|0}j[114626]=0;i[d+56>>1]=e;E(585,d+96|0,d+160|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){if((l[d+56>>1]-1&65535)>>>0>3998){break Y}j[114626]=0;e=E(452,g|0,d+56|0)|0;n=j[114626];j[114626]=0;if((n|0)!=1){break Z}}e=D()|0;C()|0;break f}e=D()|0;C()|0;break f}i[a+480190>>1]=l[e>>1];n=l[d+56>>1];e=k[d+282|0]|k[d+283|0]<<8|(k[d+284|0]<<16|k[d+285|0]<<24);j[114626]=0;L(586,d+160|0,(p(n,104)+a|0)+484380|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24),w|0);e=j[114626];j[114626]=0;if((e|0)==1){break X}j[114626]=0;I(587,d+80|0,2,o|0);e=j[114626];j[114626]=0;if((e|0)==1){break W}j[114626]=0;F(415,d+232|0,d+80|0);e=j[114626];j[114626]=0;if((e|0)==1){break W}j[114626]=0;E(369,((l[d+56>>1]<<5)+a|0)+946300|0,d+232|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break V}gb(d+232|0)}e=b&65535;b=b+1|0;if(e>>>0<f>>>0){continue}break z}break}e=D()|0;C()|0;break f}e=D()|0;C()|0;break f}e=D()|0;C()|0;gb(d+232|0);break f}jb(d+96|0);break A}break w}e=D()|0;C()|0;break f}e=0;break v}j[114626]=0;b=H(484,d+96|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break x}}e=D()|0;C()|0;break f}if((b|0)==4){b=l[g>>1];j[114626]=0;i[d+160>>1]=b;i[d+232>>1]=255;b=E(477,d+160|0,d+232|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break h}i[a+480192>>1]=l[b>>1];j[114626]=0;I(580,d+232|0,d+248|0,1229278806);b=j[114626];j[114626]=0;if((b|0)==1){break i}g=d+80|4;o=d+80|3;q=d+80|5;n=d+80|7;while(1){j[114626]=0;b=E(258,d+96|0,15)|0;e=j[114626];j[114626]=0;$:{if((e|0)!=1){aa:{if(b){j[114626]=0;E(588,d+96|0,d+80|0)|0;b=j[114626];j[114626]=0;ba:{if((b|0)!=1){b=k[d+80|0]|k[d+81|0]<<8;if(l[a+480192>>1]<=(b<<24|b<<8&16711680)>>>16>>>0){continue}b=k[d+80|0]|k[d+81|0]<<8;b=p((b<<24|b<<8&16711680)>>>16|0,104)+a|0;h[b+484524|0]=k[d+88|0];e=k[n|0];h[b+484523|0]=255;h[b+484525|0]=e;b=k[d+80|0]|k[d+81|0]<<8;e=k[d+80|0]|k[d+81|0]<<8;j[114626]=0;e=K(454,a|0,((b<<8&16711680|b<<24)>>>16|0)+1&65535,((e<<8&16711680|e<<24)>>>16|0)+1&65535)|0;b=j[114626];j[114626]=0;if((b|0)==1){break aa}if(!e){continue}b=k[q|0]|k[q+1|0]<<8;j[114626]=0;i[d+160>>1]=(b<<8&16711680|b<<24)>>>16;i[d+56>>1]=4095;b=E(477,d+160|0,d+56|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break aa}j[e>>2]=l[b>>1];if(k[o|0]==255){continue}b=k[o|0];j[114626]=0;b=E(256,d+232|0,p(b,34)+2|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break aa}if(!b){continue}j[114626]=0;E(589,d+232|0,d+160|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break aa}h[e+60|0]=k[e+60|0]|1;b=k[d+160|0]|k[d+161|0]<<8;j[d+56>>2]=(b<<24|b<<8&16711680)>>>16;j[114626]=0;j[d+76>>2]=3;j[d+64>>2]=240;j[d+60>>2]=16;j[d+72>>2]=d+56;b=j[d+76>>2];j[d+8>>2]=j[d+72>>2];j[d+12>>2]=b;b=H(590,d+8|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break aa}j[114626]=0;f=e+48|0;F(591,f|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break aa}b=0;if(sb(f)){break ba}break $}break aa}while(1){ca:{h[d+56|0]=64;u=(d+160|0)+(b<<1)|0;t=k[u+2|0];j[114626]=0;h[d+48|0]=t;t=E(391,d+56|0,d+48|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break ca}t=k[t|0];Q=xb(f,b),R=t,h[Q+2|0]=R;u=k[u+3|0];Q=xb(f,b),R=u,i[Q>>1]=R;b=b+1|0;if(sb(f)>>>0>b>>>0){continue}break $}break}break aa}jb(d+232|0);break w}}e=D()|0;C()|0;jb(d+232|0);break f}if(k[g|0]!=255){h[e+60|0]=k[e+60|0]|4;b=k[g|0];h[e+63|0]=b;h[e- -64|0]=b}if(ad(f)){continue}h[e+60|0]=k[e+60|0]|2;b=sb(f)-1|0;h[e+61|0]=b;h[e+62|0]=b;continue}}}jb(d+96|0);j[114626]=0;I(592,d+96|0,d+248|0,1145131092);b=j[114626];j[114626]=0;if((b|0)==1){break j}Q=d,R=Lb(d+96|0),j[Q+48>>2]=R;Q=d,R=Mb(d+96|0),j[Q+40>>2]=R;if(rb(d+48|0,d+40|0)){J=c&1;u=d+232|4;t=(w|0)!=841887798;M=(w|0)!=841887796;while(1){o=j[d+48>>2];j[114626]=0;E(338,o|0,4)|0;b=j[114626];j[114626]=0;da:{ea:{fa:{if((b|0)!=1){j[114626]=0;e=H(484,o|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break l}j[114626]=0;q=H(484,o|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break m}q=t?q:(q>>>0)/m[a+480196>>2]|0;if(!J|e>>>0>255){break da}j[114626]=0;b=K(402,v|0,e|0,q|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break m}if(!b){break da}if(t){break ea}j[114626]=0;E(338,o|0,4)|0;b=j[114626];j[114626]=0;if((b|0)==1){break m}n=0;if(!l[a+480188>>1]){break da}while(1){j[114626]=0;b=H(484,o|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break fa}j[114626]=0;I(341,d+160|0,o|0,b+(b&1)&65535);b=j[114626];j[114626]=0;if((b|0)==1){break n}j[d+232>>2]=0;j[d+236>>2]=0;f=0;ga:{while(1){j[114626]=0;b=E(258,d+160|0,6)|0;g=j[114626];j[114626]=0;if((g|0)==1){break o}if(b^1|m[d+232>>2]>=q>>>0){break ga}b=Ib(v,e);j[114626]=0;b=K(471,b|0,j[d+232>>2],n&65535)|0;g=j[114626];j[114626]=0;ha:{ia:{if((g|0)!=1){j[114626]=0;F(593,d+56|0,d+160|0);g=j[114626];j[114626]=0;if((g|0)==1){break o}g=Pc(d+56|0);A=Bf(d+56|0);x=pi(d+56|0);s=Rb(d+56|0);O=d+61|0;r=h[d+56|0];if((r-1&255)>>>0>95){break ia}h[b|0]=r+13;if(!j[d+236>>2]){break ha}h[b+3|0]=19;j[114626]=0;j[d+80>>2]=15;r=E(462,u|0,d+80|0)|0;B=j[114626];j[114626]=0;if((B|0)==1){break o}h[b+5|0]=k[r|0]|208;break ha}break o}if((r|0)>-1){break ha}if(j[d+236>>2]){h[b+3|0]=19;j[114626]=0;j[d+80>>2]=15;r=E(462,u|0,d+80|0)|0;B=j[114626];j[114626]=0;if((B|0)!=1){h[b+5|0]=k[r|0]|192;break ha}break o}h[b|0]=254}if(k[g|0]){h[b+2|0]=1;j[114626]=0;h[d+80|0]=64;g=E(391,g|0,d+80|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break o}h[b+4|0]=k[g|0]}g=k[A|0];if(g){h[b+1|0]=g}g=k[x|0];if(g|k[s|0]){h[b+3|0]=g;h[b+5|0]=k[s|0];j[114626]=0;N(574,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break o}}b=k[O|0];if(b&128){j[114626]=0;g=H(387,d+160|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break o}b=g|b<<8&32512}g=j[a+480196>>2];j[114626]=0;f=b+f|0;I(594,d+80|0,f|0,g|0);b=j[114626];j[114626]=0;if((b|0)!=1){b=j[d+84>>2];j[d+232>>2]=j[d+80>>2];j[d+236>>2]=b;continue}break}break o}jb(d+160|0);n=n+1|0;if(l[a+480188>>1]>(n&65535)>>>0){continue}break}break da}e=D()|0;C()|0;break k}e=D()|0;C()|0;break k}b=Ib(v,e);j[114626]=0;b=K(471,b|0,0,0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break s}n=0;if(!q){break da}while(1){e=0;ja:{if(!l[a+480188>>1]){break ja}while(1){ka:{j[114626]=0;F(595,d+160|0,o|0);f=j[114626];j[114626]=0;if((f|0)==1){break ka}la:{if(!M){j[d+232>>2]=j[d+160>>2];s=Pc(d+232|0);r=Bf(d+232|0);A=pi(d+232|0);f=h[d+232|0];if((f|0)>=1){h[b|0]=(p((f&240)>>>4|0,12)+(f&15)|0)+12}g=b;f=k[s|0];x=f>>>2|0;if(x){h[b+2|0]=1;h[b+4|0]=x-1;f=k[s|0]}h[g+1|0]=f<<4&48|k[r|0]>>>4;h[b+3|0]=k[r|0]&15;h[b+5|0]=k[A|0];break la}j[114626]=0;f=j[d+160>>2];j[d+36>>2]=f;j[d+20>>2]=f;F(596,d+20|0,b|0);f=j[114626];j[114626]=0;if((f|0)==1){break ka}f=Pb(d+160|0,0);h[b+1|0]=k[b+1|0]|k[f|0]&48}j[114626]=0;N(574,b|0);f=j[114626];j[114626]=0;if((f|0)==1){break ka}f=k[b+3|0];ma:{if(f>>>0>11){break ma}f=1<<f;na:{if(!(f&2240)){if(!(f&12)){break ma}if(!k[b+5|0]){break na}break ma}f=k[b+5|0];g=f&240;if(g){h[b+5|0]=g;break ma}if(f){break ma}}h[b+3|0]=0}b=b+6|0;e=e+1|0;if(l[a+480188>>1]>(e&65535)>>>0){continue}break ja}break}e=D()|0;C()|0;break k}n=n+1|0;if((n|0)!=(q|0)){continue}break}}yf(d+48|0);if(rb(d+48|0,d+40|0)){continue}break}}Sc(d+96|0);j[114626]=0;I(580,d+160|0,d+248|0,1346458702);b=j[114626];j[114626]=0;if((b|0)==1){e=D()|0;C()|0;break b}j[114626]=0;b=H(489,d+160|0)|0;e=j[114626];j[114626]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((e|0)!=1){if(b){f=Db(d+96|0);b=0;Ca:{while(1){Da:{j[114626]=0;e=E(258,d+160|0,1)|0;g=j[114626];j[114626]=0;if((g|0)==1){break Da}if(!e){break Ca}if(me(v)>>>0<=b>>>0){break Ca}j[114626]=0;K(597,d+160|0,f|0,32)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Da}e=Ib(v,b);j[114626]=0;E(495,e|0,f|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Da}b=b+1|0;continue}break}e=D()|0;C()|0;gb(f);break Ba}gb(f)}jb(d+160|0);j[114626]=0;I(580,d+160|0,d+248|0,1414679374);b=j[114626];j[114626]=0;if((b|0)==1){break Aa}j[114626]=0;b=H(489,d+160|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break wa}if(!b){break xa}f=Db(d+96|0);b=0;while(1){j[114626]=0;e=E(258,d+160|0,1)|0;g=j[114626];j[114626]=0;if((g|0)==1){break za}if(!e|l[a+480188>>1]<=b>>>0){break ya}j[114626]=0;K(597,d+160|0,f|0,32)|0;e=j[114626];j[114626]=0;if((e|0)==1){break za}j[114626]=0;E(378,((b<<5)+a|0)+480289|0,f|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break za}b=b+1|0;continue}}e=D()|0;C()|0}jb(d+160|0);break b}e=D()|0;C()|0;break b}e=D()|0;C()|0;gb(f);break va}gb(f)}jb(d+160|0);j[114626]=0;I(592,d+160|0,d+248|0,1145129300);b=j[114626];j[114626]=0;if((b|0)==1){break ua}Q=d,R=Lb(d+160|0),j[Q+96>>2]=R;Q=d,R=Mb(d+160|0),j[Q+232>>2]=R;if(rb(d+96|0,d+232|0)){e=c&2;while(1){b=j[d+96>>2];j[114626]=0;c=H(484,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=l[a+480190>>1])){c=p(c,104)+a|0;f=l[c+484518>>1];f=Mc(d+80|0,f&1?16:8,f&64?2:1,1,0);j[114626]=0;K(400,f|0,c+484484|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break p}}yf(d+96|0);if(rb(d+96|0,d+232|0)){continue}break}}Sc(d+160|0);b=Qc(d+96|0);if((w|0)!=841887798){break sa}j[114626]=0;c=E(2,d+160|0,12790)|0;e=j[114626];j[114626]=0;if((e|0)==1){break ta}ob(b,c);gb(c);break ra}e=D()|0;C()|0}jb(d+160|0);break b}e=D()|0;C()|0;break b}e=D()|0;C()|0;break q}j[114626]=0;I(580,d+160|0,d+248|0,1447383635);c=j[114626];j[114626]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((c|0)!=1){j[114626]=0;c=H(489,d+160|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break qa}if(!c){break Fa}j[114626]=0;e=H(493,d+160|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break Ka}j[114626]=0;c=E(2,d+24|0,12810)|0;f=j[114626];j[114626]=0;if((f|0)==1){break Ja}j[114626]=0;F(219,d+80|0,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break Ia}j[114626]=0;j[d+56>>2]=e>>>4;j[d+48>>2]=e&15;L(598,d+232|0,d+80|0,d+56|0,d+48|0);e=j[114626];j[114626]=0;if((e|0)==1){break Ha}ob(b,d+232|0);gb(d+232|0);qb(d+80|0);break Ea}e=D()|0;C()|0;break q}e=D()|0;C()|0;break r}e=D()|0;C()|0;break r}e=D()|0;C()|0;break Ga}e=D()|0;C()|0;qb(d+80|0)}gb(c);break r}j[114626]=0;c=E(2,d+232|0,12832)|0;e=j[114626];j[114626]=0;if((e|0)==1){break t}ob(b,c)}gb(c);jb(d+160|0)}j[114626]=0;c=E(2,d+160|0,12832)|0;e=j[114626];j[114626]=0;if((e|0)==1){break pa}ob(a+1304436|0,c);gb(c);j[114626]=0;c=E(2,d+160|0,12848)|0;e=j[114626];j[114626]=0;if((e|0)==1){break oa}ob(a+1304448|0,c);gb(c);ob(a+1304460|0,b);j[a+1304496>>2]=2;gb(b);e=1;break v}e=D()|0;C()|0;break r}e=D()|0;C()|0;break q}e=D()|0;C()|0;break q}pz(d+248|0)}Za=d+288|0;return e|0}e=D()|0;C()|0;break r}e=D()|0;C()|0;break k}jb(d+160|0)}gb(b);break b}e=D()|0;C()|0;Sc(d+160|0);break b}e=D()|0;C()|0;jb(d+160|0);break k}e=D()|0;C()|0;break k}e=D()|0;C()|0;break k}e=D()|0;C()|0}Sc(d+96|0);break b}e=D()|0;C()|0;break b}e=D()|0;C()|0;break f}e=D()|0;C()|0;break f}e=D()|0;C()|0}jb(d+96|0);break b}e=D()|0;C()|0;break b}e=D()|0;C()|0;jb(d+160|0);break b}e=D()|0;C()|0;jb(d+232|0)}pz(d+248|0)}G(e|0);z()}function Zwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,J=0,M=0,O=0,Q=0,R=0,S=0;d=Za-528|0;Za=d;rc(b);a:{if(!an(b,d+448|0)){break a}if(!JM(d+448|0)){break a}if(!yb(b,Wc(IM(d+448|0),ab))){break a}b:{if(!c){break b}od(a,4);_h(a);j[a+1074368>>2]=4;s=Qc(d+432|0);c:{d:{r=d+486|0;e:{if(!(Yc(r,17536,20)|(k[d+508|0]|k[d+509|0]<<8|(k[d+510|0]<<16|k[d+511|0]<<24))!=276)){e=48;if((k[d+506|0]|k[d+507|0]<<8)>>>0<260){break e}j[114626]=0;g=K(625,d+465|0,0,20)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}e=g?1154:34;break e}if(!Yc(r,17557,20)){e=1;break e}j[114626]=0;I(746,d+416|0,3,r|0);g=j[114626];j[114626]=0;f:{g:{h:{if((g|0)==1){break h}j[114626]=0;F(415,d+72|0,d+416|0);g=j[114626];j[114626]=0;if((g|0)==1){break h}j[114626]=0;I(13,d+144|0,4,d+72|0);g=j[114626];j[114626]=0;if((g|0)==1){break g}ob(s,d+144|0);gb(d+144|0);gb(d+72|0);if((k[r|0]|k[r+1|0]<<8|(k[r+2|0]<<16|k[r+3|0]<<24))!=1852141647|(k[r+4|0]|k[r+5|0]<<8|(k[r+6|0]<<16|k[r+7|0]<<24))!=542396493){break f}e=1048;break e}e=D()|0;C()|0;break c}e=D()|0;C()|0;gb(d+72|0);break c}if(!Yc(r,17587,12)){e=16;if((l[d+498>>1]|l[d+500>>1]<<16)==538976288&(l[d+502>>1]|l[d+504>>1]<<16)==538976288){break e}j[a+1074368>>2]=5;break e}if(!Yc(r,17601,20)){e=48;break e}if(!Yc(r,17622,15)){j[114626]=0;g=a+1074308|0;E(479,g|0,54)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}j[114626]=0;E(479,g|0,51)|0;g=j[114626];j[114626]=0;e=16;if((g|0)==1){break d}break e}if(!Yc(r,17638,14)){j[114626]=0;E(479,a+1074308|0,57)|0;g=j[114626];j[114626]=0;e=16;if((g|0)!=1){break e}break d}e=Yc(r,17653,11)?16:256}j[114626]=0;B=d+465|0;I(746,d+72|0,3,B|0);g=j[114626];j[114626]=0;i:{j:{k:{l:{m:{if((g|0)==1){break m}j[114626]=0;F(415,d+144|0,d+72|0);g=j[114626];j[114626]=0;if((g|0)==1){break m}ob(a+1304400|0,d+144|0);gb(d+144|0);j[a+480260>>2]=1;j[a+480264>>2]=31999;x=a+484360|0;Ge(Fb(x),k[d+514|0]|k[d+515|0]<<8);i[a+480188>>1]=k[d+516|0]|k[d+517|0]<<8;g=k[d+520|0]|k[d+521|0]<<8;j[114626]=0;i[d+144>>1]=g;i[d+72>>1]=255;g=E(477,d+144|0,d+72|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break l}i[a+480192>>1]=l[g>>1];if(k[d+524|0]|k[d+525|0]<<8){j[a+480196>>2]=k[d+524|0]|k[d+525|0]<<8}if(k[d+526|0]|k[d+527|0]<<8){g=j[19862];R=a,S=kd(p(k[d+526|0]|k[d+527|0]<<8,1e4),p(j[g+20>>2],1e4),p(j[g+24>>2],1e4)),j[R+480204>>2]=S}j[a+480208>>2]=0;j[a+480208>>2]=j[a+480208>>2]&-17|(k[d+522|0]|k[d+523|0]<<8)<<4&16;g=(k[d+522|0]|k[d+523|0]<<8)<<3&32768;j[a+480208>>2]=g|j[a+480208>>2]&-32769;f=Fb(x);o=k[d+512|0]|k[d+513|0]<<8;j[114626]=0;U(581,f|0,b|0,o|0,65535,65535)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}n=(e|0)==34?g>>>15|0?146:e:e;if(!(n&1024|(k[d+512|0]|k[d+513|0]<<8))){g=Fb(x);j[114626]=0;I(1027,g|0,1,0);g=j[114626];j[114626]=0;if((g|0)==1){break d}}g=k[d+508|0]|k[d+509|0]<<8|(k[d+510|0]<<16|k[d+511|0]<<24);j[114626]=0;E(256,b|0,g+60|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break d}if((k[d+506|0]|k[d+507|0]<<8)>>>0>=260){j[114626]=0;I(1028,b|0,d+448|0,a|0);g=j[114626];j[114626]=0;if((g|0)==1){break d}}h[d+415|0]=0;t=d+416|0;Pwa(t);if(l[a+480192>>1]){break k}g=-1;break j}e=D()|0;C()|0;break c}e=D()|0;C()|0;break c}M=c&2;O=d+90|0;Q=d+177|0;o=d+173|0;e=1;g=-1;u=1;while(1){n:{j[114626]=0;f=H(390,b|0)|0;q=j[114626];j[114626]=0;o:{p:{q:{r:{s:{t:{if((q|0)!=1){cg(b,4);j[114626]=0;K(1029,b|0,d+144|0,(f?f:263)|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break n}u:{if((n|0)==1){if((k[d+144|0]|k[d+145|0]<<8|(k[d+146|0]<<16|k[d+147|0]<<24))==245){j[a+1074304>>2]=16777381;j[114626]=0;f=E(2,d+72|0,17665)|0;n=j[114626];j[114626]=0;if((n|0)!=1){ob(s,f);gb(f);n=17;break u}e=D()|0;C()|0;break i}n=16;if((k[d+144|0]|k[d+145|0]<<8|(k[d+146|0]<<16|k[d+147|0]<<24))!=263){break u}j[a+1074304>>2]=16777395;j[114626]=0;f=E(2,d+72|0,17691)|0;n=j[114626];j[114626]=0;if((n|0)!=1){ob(s,f);gb(f);n=17;break u}e=D()|0;C()|0;break i}if(k[d+171|0]|k[d+172|0]<<8){break u}v:{if(!(n&2)|(k[d+144|0]|k[d+145|0]<<8|(k[d+146|0]<<16|k[d+147|0]<<24))!=263){break v}f=o;if(k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24)){break v}n=n|16;break u}if(!(!(n&256)|(k[d+144|0]|k[d+145|0]<<8|(k[d+146|0]<<16|k[d+147|0]<<24))==29)){n=n&-257;break u}if(!(n&160)){break u}n=(k[d+144|0]|k[d+145|0]<<8|(k[d+146|0]<<16|k[d+147|0]<<24))==33?n:0}j[114626]=0;f=K(454,a|0,u&65535,0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break n}if(!f){break o}q=((e<<2)+a|0)+900380|0;f=j[q>>2];j[114626]=0;F(1030,d+144|0,f|0);f=j[114626];j[114626]=0;if((f|0)==1){break n}f=k[d+170|0];w:{if((g|0)==-1){g=f;break w}if(!(n&32)|(f|0)==(g|0)){break w}n=n&-161|128}if(!(k[d+171|0]|k[d+172|0]<<8)){break o}f=k[d+385|0];e=k[d+386|0];w=k[d+387|0]|k[d+388|0]<<8;v=k[d+391|0];y=k[d+171|0]|k[d+172|0]<<8;j[114626]=0;I(1031,d+128|0,a|0,y|0);y=j[114626];j[114626]=0;if((y|0)==1){break t}n=v|(w|(e|f))?n&-4:n;e=12;while(1){f=l[Oc(j[q>>2]+236|0,e)>>1];if(bc(d+128|0)>>>0>f>>>0){f=l[ac(d+128|0,l[Oc(j[q>>2]+236|0,e)>>1])>>1];R=Oc(j[q>>2]+236|0,e),S=f,i[R>>1]=S}e=e+1|0;if((e|0)!=108){continue}break}if((k[d+506|0]|k[d+507|0]<<8)>>>0>259){sb(t);GM(t);xg(t)}f=k[d+171|0]|k[d+172|0]<<8;j[114626]=0;f=E(1032,d+112|0,f|0)|0;e=j[114626];j[114626]=0;x:{if((e|0)!=1){e=0;if(k[d+171|0]|k[d+172|0]<<8){break x}break s}e=D()|0;C()|0;break q}y:{z:{A:{B:{while(1){j[114626]=0;E(1033,b|0,d+72|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break y}j[114626]=0;F(1034,d+56|0,d+72|0);q=j[114626];j[114626]=0;C:{if((q|0)==1){break C}j[114626]=0;F(1035,t|0,d+56|0);q=j[114626];j[114626]=0;if((q|0)==1){break C}q=k[d+72|0]|k[d+73|0]<<8|(k[d+74|0]<<16|k[d+75|0]<<24);R=xb(f,e),S=q,j[R>>2]=S;w=k[d+89|0];if(bc(d+128|0)>>>0>e>>>0){q=l[ac(d+128|0,e)>>1];j[114626]=0;v=(p(q,104)+a|0)+484380|0;F(1036,d+72|0,v|0);y=j[114626];j[114626]=0;if((y|0)==1){break B}j[114626]=0;F(1037,Q|0,v|0);v=j[114626];j[114626]=0;if((v|0)==1){break B}j[114626]=0;I(587,d+40|0,3,O|0);v=j[114626];j[114626]=0;if((v|0)==1){break A}j[114626]=0;F(415,d+56|0,d+40|0);v=j[114626];j[114626]=0;if((v|0)==1){break A}j[114626]=0;E(369,((q<<5)+a|0)+946300|0,d+56|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break z}gb(d+56|0);n=(n&2)>>>1|0?(k[d+86|0]&3)==3?n|4:n:n}A=w|A;e=e+1|0;if(e>>>0>=(k[d+171|0]|k[d+172|0]<<8)>>>0){break s}continue}break}e=D()|0;C()|0;break r}e=D()|0;C()|0;break r}e=D()|0;C()|0;break r}e=D()|0;C()|0;gb(d+56|0);break r}e=D()|0;C()|0;break r}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}if((k[d+506|0]|k[d+507|0]<<8)>>>0<260){break p}e=0;if(!(k[d+171|0]|k[d+172|0]<<8)){break p}D:{while(1){E:{w=k[xb(t,e)+3|0];q=j[xb(f,e)>>2];j[114626]=0;I(341,d+72|0,b|0,((w|0)==11?(q+1>>>1|0)+16|0:q)|0);q=j[114626];j[114626]=0;if((q|0)==1){break E}if(!(!M|bc(d+128|0)>>>0<=e>>>0)){w=l[ac(d+128|0,e)>>1];q=xb(t,e);q=k[q|0]|k[q+1|0]<<8|(k[q+2|0]<<16|k[q+3|0]<<24);j[114626]=0;j[d+36>>2]=q;j[d+4>>2]=q;q=P(1038,(p(w,104)+a|0)+484380|0,d+4|0,d+72|0,d+415|0)|0;w=j[114626];j[114626]=0;if((w|0)==1){break D}J=q^1|J}jb(d+72|0);e=e+1|0;if(e>>>0<(k[d+171|0]|k[d+172|0]<<8)>>>0){continue}break p}break}e=D()|0;C()|0;break r}e=D()|0;C()|0;jb(d+72|0)}Ud(f)}ff(d+128|0);break i}Ud(f);ff(d+128|0)}u=u+1|0;e=u&65535;if(e>>>0<=l[a+480192>>1]){continue}break j}break}e=D()|0;C()|0;break i}F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if(!(!(n&2)|A&255)){j[114626]=0;f=K(625,B|0,0,20)|0;o=j[114626];j[114626]=0;if((o|0)==1){break W}n=f?n|16:n}X:{if((k[d+506|0]|k[d+507|0]<<8)>>>0>259){break X}if(c&3){j[114626]=0;I(1028,b|0,d+448|0,a|0);f=j[114626];j[114626]=0;if((f|0)==1){break W}}if(!(c&2)|!l[a+480190>>1]){break X}c=1;e=1;while(1){f=xb(t,c-1|0);j[114626]=0;K(400,f|0,(p(c,104)+a|0)+484380|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break V}e=e+1|0;c=e&65535;if(c>>>0<=l[a+480190>>1]){continue}break}}if(J&1){j[114626]=0;c=E(2,d+144|0,17716)|0;f=j[114626];j[114626]=0;if((f|0)==1){break U}j[114626]=0;I(647,a|0,2,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break T}gb(c)}j[114626]=0;c=E(618,b|0,17799)|0;f=j[114626];j[114626]=0;if((f|0)==1){break W}if(c){j[114626]=0;c=H(390,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break W}j[114626]=0;P(584,a+1304424|0,b|0,c|0,0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break W}n=n|16}j[114626]=0;f=E(618,b|0,17804)|0;c=j[114626];j[114626]=0;if((c|0)==1){break F}if(f){j[114626]=0;c=H(390,b|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break F}j[114626]=0;o=a+901404|0;K(1039,b|0,o|0,c|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break F}j[114626]=0;N(634,o|0);c=j[114626];j[114626]=0;if((c|0)==1){break F}n=n|16}j[114626]=0;c=E(618,b|0,17809)|0;o=j[114626];j[114626]=0;if((o|0)==1){break F}if(c){j[114626]=0;c=H(390,b|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break S}i[d+144>>1]=c>>>5;o=a+484344|0;c=me(o);j[114626]=0;i[d+72>>1]=c;c=E(477,d+144|0,d+72|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break R}e=l[c>>1];if(e){c=0;while(1){j[114626]=0;K(866,b|0,d+144|0,32)|0;u=j[114626];j[114626]=0;if((u|0)==1){break Q}u=Ib(o,c);j[114626]=0;E(867,u|0,d+144|0)|0;u=j[114626];j[114626]=0;if((u|0)==1){break Q}c=c+1|0;if((e|0)!=(c|0)){continue}break}}n=n|16}j[114626]=0;c=E(618,b|0,17814)|0;o=j[114626];j[114626]=0;if((o|0)==1){break F}if(c){j[114626]=0;c=H(390,b|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break P}i[d+144>>1]=(c>>>0)/20;c=l[a+480188>>1];j[114626]=0;i[d+72>>1]=c;c=E(477,d+144|0,d+72|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break O}c=l[c>>1];if(c){e=0;while(1){j[114626]=0;K(636,b|0,((e<<5)+a|0)+480289|0,20)|0;o=j[114626];j[114626]=0;if((o|0)==1){break K}e=e+1|0;if((c|0)!=(e|0)){continue}break}}n=n|16}j[114626]=0;c=E(258,b|0,8)|0;o=j[114626];j[114626]=0;if((o|0)==1){break F}if(c){c=j[b+8>>2];j[114626]=0;E(637,a|0,b|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break J}n=(c|0)==j[b+8>>2]?n:n|16}if(!(n&16)){break L}if(!(n&4)){break M}j[a+1074304>>2]=17367040;j[114626]=0;c=E(2,d+144|0,17819)|0;o=j[114626];j[114626]=0;if((o|0)==1){break N}ob(s,c);gb(c);break L}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;gb(c);break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}if(!(n&2)){break L}j[a+1074304>>2]=18219008;j[114626]=0;c=E(2,d+144|0,17840)|0;o=j[114626];j[114626]=0;if((o|0)==1){break I}ob(s,c);gb(c)}Y:{Z:{_:{$:{aa:{ba:{ca:{if((k[r|0]|k[r+1|0]<<8|(k[r+2|0]<<16|k[r+3|0]<<24))==1852141647&(k[r+4|0]|k[r+5|0]<<8|(k[r+6|0]<<16|k[r+7|0]<<24))==542396493){j[114626]=0;c=K(1040,d+144|0,d+494|0,12)|0;o=j[114626];j[114626]=0;if((o|0)==1){break ca}j[114626]=0;I(13,d+72|0,1,c|0);o=j[114626];j[114626]=0;if((o|0)==1){break ba}j[114626]=0;o=H(1041,d+72|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break aa}j[a+1074304>>2]=o;gb(d+72|0);j[a+1074368>>2]=m[a+1074304>>2]<19007257?4:5;gb(c);n=24}if(!(!j[a+1074304>>2]|n&8)){j[a+1074368>>2]=0;Xs(a+1074308|0)}c=n&32;da:{if(!c){break da}j[a+1074368>>2]=5;if(!f){j[114626]=0;N(635,a+901404|0);f=j[114626];j[114626]=0;if((f|0)==1){break F}}if((k[d+506|0]|k[d+507|0]<<8)>>>0<260){break da}j[114626]=0;K(478,a+1074308|0,4,1)|0;f=j[114626];j[114626]=0;if((f|0)==1){break F}}if(!Ec(s)){break Y}if(!(n&256)|(A&255|g+1>>>0>1)){break Z}j[114626]=0;c=E(2,d+144|0,17868)|0;g=j[114626];j[114626]=0;if((g|0)==1){break _}ob(s,c);gb(c);break Y}e=D()|0;C()|0;break i}e=D()|0;C()|0;break $}e=D()|0;C()|0;gb(d+72|0)}gb(c);break i}e=D()|0;C()|0;break i}if(c){j[114626]=0;c=E(2,d+144|0,17880)|0;g=j[114626];j[114626]=0;if((g|0)!=1){ob(s,c);gb(c);break Y}e=D()|0;C()|0;break i}j[114626]=0;c=E(2,d+144|0,17908)|0;g=j[114626];j[114626]=0;if((g|0)==1){break H}ob(s,c);gb(c)}h[d+40|0]=0;ea:{if(l[a+480192>>1]){j[114626]=0;c=E(653,a|0,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break ea}h[d+40|0]=c}j[114626]=0;L(654,a|0,b|0,1,d+40|0);b=j[114626];j[114626]=0;if((b|0)==1){break ea}c=a+1074304|0;if(!(!k[d+40|0]|m[c>>2]>=18284544)){j[c>>2]=18284544}fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{b=j[c>>2];if(b>>>0>=18284544){j[114626]=0;b=E(2,d+72|0,17578)|0;g=j[114626];j[114626]=0;if((g|0)==1){break sa}j[114626]=0;F(1042,d+128|0,c|0);g=j[114626];j[114626]=0;if((g|0)==1){break ra}j[114626]=0;I(3,d+144|0,b|0,d+128|0);g=j[114626];j[114626]=0;if((g|0)==1){break qa}ob(s,d+144|0);gb(d+144|0);gb(d+128|0);gb(b);b=j[c>>2]}ta:{if(!b|m[c>>2]>=19005954){break ta}j[114626]=0;b=a+484344|0;c=E(442,b|0,254)|0;g=j[114626];j[114626]=0;if((g|0)==1){break ea}if(!c){c=Fb(x);j[114626]=0;F(1043,c|0,254);c=j[114626];j[114626]=0;if((c|0)==1){break ea}}j[114626]=0;b=E(442,b|0,255)|0;c=j[114626];j[114626]=0;if((c|0)==1){break ea}if(b){break ta}b=Fb(x);j[114626]=0;c=T(958)|0;g=j[114626];j[114626]=0;if((g|0)==1){break ea}j[114626]=0;I(1044,b|0,255,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break ea}}if(!k[d+415|0]){break fa}j[114626]=0;b=E(2,d+144|0,17916)|0;c=j[114626];j[114626]=0;if((c|0)==1){break oa}ob(a+1304436|0,b);gb(b);j[114626]=0;b=E(2,d+144|0,17937)|0;c=j[114626];j[114626]=0;if((c|0)==1){break na}ob(a+1304448|0,b);gb(b);j[114626]=0;b=E(2,d+24|0,17941)|0;c=j[114626];j[114626]=0;if((c|0)==1){break ma}j[114626]=0;F(219,d+72|0,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break la}j[d+112>>2]=k[d+507|0];c=k[d+506|0];j[114626]=0;j[d+56>>2]=c;F(661,d+128|0,d+56|0);c=j[114626];j[114626]=0;if((c|0)==1){break ka}j[114626]=0;L(646,d+144|0,d+72|0,d+112|0,d+128|0);c=j[114626];j[114626]=0;if((c|0)==1){break ja}ob(a+1304472|0,d+144|0);gb(d+144|0);gb(d+128|0);qb(d+72|0);gb(b);j[114626]=0;c=E(2,d+144|0,17962)|0;b=j[114626];j[114626]=0;if((b|0)==1){break ga}ob(a+1304484|0,c);break G}e=D()|0;C()|0;break i}e=D()|0;C()|0;break pa}e=D()|0;C()|0;gb(d+128|0)}gb(b);break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break ha}e=D()|0;C()|0;break ia}e=D()|0;C()|0;gb(d+128|0)}qb(d+72|0)}gb(b);break i}e=D()|0;C()|0;break i}j[114626]=0;b=E(2,d+8|0,17941)|0;c=j[114626];j[114626]=0;ua:{va:{wa:{xa:{ya:{za:{if((c|0)!=1){j[114626]=0;F(219,d+72|0,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break za}j[d+112>>2]=k[d+507|0];c=k[d+506|0];j[114626]=0;j[d+56>>2]=c;F(661,d+128|0,d+56|0);c=j[114626];j[114626]=0;if((c|0)==1){break ya}j[114626]=0;L(646,d+144|0,d+72|0,d+112|0,d+128|0);c=j[114626];j[114626]=0;if((c|0)==1){break xa}ob(a+1304436|0,d+144|0);gb(d+144|0);gb(d+128|0);qb(d+72|0);gb(b);j[114626]=0;c=E(2,d+144|0,17962)|0;b=j[114626];j[114626]=0;if((b|0)==1){break ua}ob(a+1304448|0,c);break G}e=D()|0;C()|0;break i}e=D()|0;C()|0;break va}e=D()|0;C()|0;break wa}e=D()|0;C()|0;gb(d+128|0)}qb(d+72|0)}gb(b);break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}e=D()|0;C()|0;break i}gb(c);ob(a+1304460|0,s);j[a+1304496>>2]=j[a+1074304>>2]?7:4;HM(t);gb(s);break b}e=D()|0;C()|0}HM(t);break c}e=D()|0;C()|0}gb(s);G(e|0);z()}e=1}Za=d+528|0;return e|0}function HEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,J=0,L=0,M=0,O=0,Q=0,R=0,S=0;d=Za-288|0;Za=d;rc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!Rz(b,d+280|0)){break x}if(!EP(d+280|0)){break x}if(!c){A=1;break x}L=pl(d+264|0,b);j[114626]=0;I(742,d+248|0,L|0,0);b=j[114626];j[114626]=0;y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{if((b|0)!=1){j[114626]=0;I(743,d+232|0,d+248|0,20041);b=j[114626];j[114626]=0;if((b|0)==1){break N}j[114626]=0;b=H(337,d+232|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break E}if(!b){break y}j[114626]=0;b=E(744,d+232|0,d+136|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break E}if(!b){break y}j[114626]=0;F(447,a|0,16384);b=j[114626];j[114626]=0;if((b|0)==1){break E}j[a+480208>>2]=8;j[114626]=0;b=a+1074308|0;K(478,b|0,9,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break E}j[114626]=0;E(479,b|0,21)|0;e=j[114626];j[114626]=0;if((e|0)==1){break E}j[114626]=0;E(479,b|0,30)|0;b=j[114626];j[114626]=0;if((b|0)==1){break E}j[114626]=0;b=E(2,d+16|0,14652)|0;e=j[114626];j[114626]=0;if((e|0)==1){break K}ob(a+1304436|0,b);gb(b);j[114626]=0;b=E(2,d+16|0,14664)|0;e=j[114626];j[114626]=0;if((e|0)==1){break J}ob(a+1304448|0,b);gb(b);j[114626]=0;e=E(2,d+120|0,14668)|0;b=j[114626];j[114626]=0;if((b|0)==1){break I}b=k[d+284|0];switch(b-16|0){case 1:break H;case 0:break M;default:break L}}b=D()|0;C()|0;break a}b=D()|0;C()|0;break b}j[114626]=0;E(2,d+104|0,14683)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break F}break e}if(!b){break G}j[114626]=0;E(2,d+104|0,14698)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}break F}b=D()|0;C()|0;break c}b=D()|0;C()|0;break c}b=D()|0;C()|0;break c}j[114626]=0;E(2,d+104|0,14681)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break F}break e}j[114626]=0;E(2,d+104|0,14687)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}}j[114626]=0;I(3,d+16|0,e|0,d+104|0);b=j[114626];j[114626]=0;if((b|0)==1){break f}ob(a+1304460|0,d+16|0);gb(d+16|0);gb(d+104|0);gb(e);j[a+1304496>>2]=4;j[114626]=0;I(745,d+120|0,3,d+136|0);b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;F(415,d+16|0,d+120|0);b=j[114626];j[114626]=0;if((b|0)==1){break g}ob(a+1304400|0,d+16|0);gb(d+16|0);j[114626]=0;I(746,d+104|0,3,d+168|0);b=j[114626];j[114626]=0;if((b|0)==1){break h}j[114626]=0;F(415,d+120|0,d+104|0);b=j[114626];j[114626]=0;if((b|0)==1){break h}j[114626]=0;I(13,d+16|0,4,d+120|0);b=j[114626];j[114626]=0;if((b|0)==1){break i}ob(a+1304412|0,d+16|0);gb(d+16|0);gb(d+120|0);j[a+480200>>2]=k[d+192|0]+1;R=a,S=kd(k[d+193|0],1,255),j[R+480196>>2]=S;R=a,S=p(kd(k[d+194|0],4,255),1e4),j[R+480204>>2]=S;b=a+484360|0;e=Fb(b);f=k[d+188|0]|k[d+189|0]<<8;j[114626]=0;U(581,e|0,d+232|0,f|0,65535,65535)|0;e=j[114626];j[114626]=0;if((e|0)==1){break E}Ge(Fb(b),k[d+190|0]|k[d+191|0]<<8);i[a+480188>>1]=0;b=0;while(1){j[114626]=0;e=(b<<5)+a|0;f=e+480280|0;N(432,f|0);g=j[114626];j[114626]=0;if((g|0)==1){break j}g=b+d|0;n=k[g+195|0]<<1&254;i[e+480284>>1]=(n|0)==254?256:n;O:{if(h[g+195|0]<=-1){j[f>>2]=j[f>>2]|1024;break O}i[a+480188>>1]=b+1}j[114626]=0;K(747,d+232|0,e+480289|0,8)|0;e=j[114626];j[114626]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}j[114626]=0;I(743,d+16|0,d+248|0,17741);b=j[114626];j[114626]=0;if((b|0)==1){break k}Ed(d+232|0,d+16|0);jb(d+16|0);j[114626]=0;b=H(255,d+232|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break E}j[114626]=0;P(584,a+1304424|0,d+232|0,b|0,0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break E}j[114626]=0;I(743,d+16|0,d+248|0,21321);b=j[114626];j[114626]=0;if((b|0)==1){break l}Ed(d+232|0,d+16|0);jb(d+16|0);j[114626]=0;b=H(337,d+232|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break E}P:{if(b){j[114626]=0;I(743,d+16|0,d+248|0,16723);b=j[114626];j[114626]=0;if((b|0)==1){break m}j[114626]=0;q=H(387,d+232|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break n}Q:{if(!q){break Q}r=c&2;while(1){j[114626]=0;e=H(387,d+232|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break n}if(!e){break Q}j[114626]=0;b=E(258,d+232|0,56)|0;f=j[114626];j[114626]=0;if((f|0)==1){break n}if(!b){break Q}if(e>>>0>l[a+480190>>1]){i[a+480190>>1]=e}j[114626]=0;b=p(e,104)+a|0;f=b+484380|0;F(386,f|0,0);g=j[114626];j[114626]=0;if((g|0)==1){break n}j[114626]=0;K(548,d+232|0,((e<<5)+a|0)+946300|0,32)|0;e=j[114626];j[114626]=0;if((e|0)==1){break n}j[114626]=0;K(551,d+232|0,b+484423|0,8)|0;e=j[114626];j[114626]=0;if((e|0)==1){break n}R:{if(k[d+284|0]<=15){j[114626]=0;e=H(357,d+232|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){break R}break n}j[114626]=0;e=H(390,d+232|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break n}}j[b+484404>>2]=e<<1;j[114626]=0;e=H(390,d+232|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break n}j[f>>2]=e;j[114626]=0;g=H(390,d+232|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break n}e=b+484384|0;j[e>>2]=g;j[114626]=0;g=H(390,d+232|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break n}n=b+484388|0;j[n>>2]=g;if(g){o=b+484414|0;i[o>>1]=l[o>>1]|2;j[n>>2]=g+j[e>>2]}j[114626]=0;g=H(387,d+232|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break P}if(k[d+284|0]<=15){i[b+484410>>1]=g}j[114626]=0;g=H(387,d+232|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break n}o=8;if(g&1){o=b+484414|0;i[o>>1]=l[o>>1]|1;j[f>>2]=j[f>>2]>>>1;j[e>>2]=j[e>>2]>>>1;j[n>>2]=j[n>>2]>>>1;o=16}b=b+484414|0;i[b>>1]=l[b>>1]&65531|g<<1&4;b=Mc(d+120|0,o,1,0,((g&12)!=0)<<3);S:{if(!r){break S}j[114626]=0;K(400,b|0,f|0,d+16|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break S}break n}m=m+1|0;if(q>>>0>(m&255)>>>0){continue}break}}jb(d+16|0)}j[114626]=0;I(743,d+16|0,d+248|0,18761);b=j[114626];j[114626]=0;if((b|0)==1){break q}Ed(d+232|0,d+16|0);jb(d+16|0);j[114626]=0;b=H(337,d+232|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break E}T:{U:{V:{W:{if(b){q=Ry(d+120|0);r=Ry(d+104|0);o=Ry(d+88|0);j[114626]=0;I(743,d+72|0,d+248|0,17750);b=j[114626];j[114626]=0;if((b|0)==1){break r}j[114626]=0;F(748,d+72|0,q|0);b=j[114626];j[114626]=0;if((b|0)==1){break s}jb(d+72|0);j[114626]=0;I(743,d+56|0,d+248|0,17744);b=j[114626];j[114626]=0;if((b|0)==1){break r}j[114626]=0;F(748,d+56|0,r|0);b=j[114626];j[114626]=0;if((b|0)==1){break t}jb(d+56|0);j[114626]=0;I(743,d+40|0,d+248|0,17734);b=j[114626];j[114626]=0;if((b|0)==1){break r}j[114626]=0;F(748,d+40|0,o|0);b=j[114626];j[114626]=0;if((b|0)==1){break u}jb(d+40|0);j[114626]=0;t=H(387,d+232|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break v}if(t){y=d+16|4;A=d+16|2;v=d+16|6;w=d+16|5;x=d+16|3;e=d+16|1;m=0;while(1){j[114626]=0;F(472,d|0,d+232|0);b=j[114626];j[114626]=0;if((b|0)==1){break A}s=Pc(d);X:{Y:{Z:{if(!k[d|0]){break Z}b=k[s|0];j[114626]=0;b=E(258,d+232|0,p(b,14)+32|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break p}if(!b){break Z}b=k[d|0];j[114626]=0;n=K(454,a|0,b|0,0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break p}if(n){break Y}}b=k[s|0];j[114626]=0;E(338,d+232|0,p(b,14)+32|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break X}break p}j[114626]=0;K(548,d+232|0,n+492|0,32)|0;b=j[114626];j[114626]=0;if((b|0)==1){break p}if(!k[s|0]){break X}B=n+88|0;J=n+68|0;M=n+48|0;O=n+236|0;g=0;b=0;while(1){j[114626]=0;E(749,d+232|0,d+16|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break w}_:{if(!k[d+16|0]|l[a+480190>>1]<k[d+16|0]){break _}f=e;if(k[e|0]>128){h[f|0]=128}if(k[e|0]>=(b&255)>>>0){while(1){f=k[d+16|0];R=Oc(O,b&255),S=f,i[R>>1]=S;b=b+1|0;if(k[e|0]>=(b&255)>>>0){continue}break}}b=k[e|0];f=k[x|0];j[114626]=0;I(750,M|0,f|0,q|0);f=j[114626];j[114626]=0;if((f|0)==1){break w}f=k[w|0];j[114626]=0;I(750,J|0,f|0,r|0);f=j[114626];j[114626]=0;if((f|0)==1){break w}f=k[d+29|0];j[114626]=0;I(750,B|0,f|0,o|0);f=j[114626];j[114626]=0;if((f|0)==1){break w}j[n>>2]=(k[v|0]|k[v+1|0]<<8)+1>>>1;f=k[d+16|0];$:{if(k[x|0]&64){i[(p(f,104)+a|0)+484410>>1]=k[A|0];break $}u=(p(f,104)+a|0)+484414|0;i[u>>1]=l[u>>1]|32768}u=k[y|0];j[114626]=0;i[d+38>>1]=u<<1;i[d+36>>1]=254;u=E(477,d+38|0,d+36|0)|0;Q=j[114626];j[114626]=0;if((Q|0)==1){break W}b=b+1|0;f=p(f,104)+a|0;i[f+484408>>1]=l[u>>1];h[f+484418|0]=k[(k[d+27|0]&3)+14699|0];h[f+484419|0]=k[d+26|0];h[f+484420|0]=k[d+25|0];h[f+484421|0]=k[d+24|0];if(!(k[w|0]&64)){break _}f=f+484414|0;i[f>>1]=l[f>>1]|32}g=g+1|0;if(k[s|0]>(g&255)>>>0){continue}break}}m=m+1|0;if(t>>>0>(m&255)>>>0){continue}break}}Xm(o);Xm(r);Xm(q)}A=1;r=kp(d+120|0);if(!(c&1)){break z}j[114626]=0;I(743,d+16|0,d+248|0,21076);b=j[114626];j[114626]=0;if((b|0)!=1){b=Ed(d+232|0,d+16|0);j[114626]=0;b=H(337,b|0)|0;c=j[114626];j[114626]=0;aa:{ba:{ca:{da:{ea:{fa:{if((c|0)!=1){jb(d+16|0);ga:{if(!b){break ga}j[114626]=0;c=H(357,d+232|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break fa}j[114626]=0;F(751,r|0,c+1|0);b=j[114626];j[114626]=0;if((b|0)==1){break fa}if(!c){break ga}b=1;while(1){j[114626]=0;e=H(357,d+232|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break ea}j[114626]=0;I(341,d+16|0,d+232|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break ea}Ed(_b(r,b),d+16|0);e=(b|0)==(c|0);jb(d+16|0);b=b+1|0;if(!e){continue}break}}j[114626]=0;I(743,d+16|0,d+248|0,16720);b=j[114626];j[114626]=0;if((b|0)==1){break da}b=Ed(d+232|0,d+16|0);j[114626]=0;b=H(337,b|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break ca}jb(d+16|0);if(!b){break aa}j[114626]=0;s=H(387,d+232|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break C}if(s){q=0;while(1){g=32;ha:{if(k[d+284|0]>=16){j[114626]=0;E(752,d+232|0,d+16|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break V}if(!(k[d+16|0]>32|l[a+480188>>1]>=k[d+16|0])){i[a+480188>>1]=k[d+16|0]}g=k[d+16|0];if(!g){break ha}}e=0;while(1){j[114626]=0;b=H(357,d+232|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break U}if(!(!b|l[a+480188>>1]>(e&65535)>>>0)){i[a+480188>>1]=e+1}e=e+1|0;if((e&65535)>>>0<g>>>0){continue}break}}q=q+1|0;if(s>>>0>(q&65535)>>>0){continue}break}}j[114626]=0;E(256,d+232|0,1)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break ba}break C}b=D()|0;C()|0;jb(d+16|0);break B}b=D()|0;C()|0;break B}b=D()|0;C()|0;break B}b=D()|0;C()|0;break B}b=D()|0;C()|0;jb(d+16|0);break B}j[114626]=0;t=a+484344|0;F(401,t|0,s|0);b=j[114626];j[114626]=0;if((b|0)==1){break C}if(!s){break aa}M=d+16|2;O=d+16|1;c=0;while(1){v=Db(d+104|0);q=64;w=32;if(k[d+284|0]>=16){j[114626]=0;E(752,d+232|0,d+16|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break D}w=k[d+16|0];b=k[O|0];j[114626]=0;I(753,d|0,3,M|0);e=j[114626];j[114626]=0;if((e|0)==1){break D}j[114626]=0;F(415,d+88|0,d|0);e=j[114626];j[114626]=0;if((e|0)==1){break D}ob(v,d+88|0);gb(d+88|0);q=b+1|0}j[114626]=0;b=K(402,t|0,c&65535,q|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break D}ia:{if(!b){j[114626]=0;E(338,d+232|0,w<<1)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break ia}break D}b=Ib(t,c);j[114626]=0;E(495,b|0,v|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break D}x=0;if(!w){break ia}while(1){j[114626]=0;b=H(357,d+232|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break D}ja:{if(!b){break ja}if(Xc(r)>>>0<=b>>>0){break ja}y=x&65535;if(y>>>0>=l[a+480188>>1]){break ja}n=_b(r,b);rc(n);f=0;while(1){j[114626]=0;b=E(258,n|0,1)|0;e=j[114626];j[114626]=0;ka:{la:{ma:{na:{oa:{pa:{if((e|0)!=1){if(!b){break ja}b=Ib(t,c);j[114626]=0;b=K(471,b|0,f|0,y|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break D}j[114626]=0;g=H(387,n|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break D}e=g>>>2|0;switch((g&3)-1|0){case 2:break ma;case 1:break na;case 0:break oa;default:break pa}}break D}f=(e+f|0)+1|0;break ka}if(!f){f=0;break ka}g=Ib(t,c);j[114626]=0;g=K(471,g|0,f-1|0,y|0)|0;m=j[114626];j[114626]=0;if((m|0)!=1){while(1){m=k[g|0]|k[g+1|0]<<8|(k[g+2|0]<<16|k[g+3|0]<<24);h[b|0]=m;h[b+1|0]=m>>>8;h[b+2|0]=m>>>16;h[b+3|0]=m>>>24;m=k[g+4|0]|k[g+5|0]<<8;h[b+4|0]=m;h[b+5|0]=m>>>8;f=f+1|0;if(q>>>0<=f>>>0){break ka}b=p(l[a+480188>>1],6)+b|0;m=e&255;e=e-1|0;if(m){continue}break ka}}break D}if(e>>>0>=f>>>0){break la}g=Ib(t,c);j[114626]=0;e=K(471,g|0,e|0,y|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break T}g=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);h[b|0]=g;h[b+1|0]=g>>>8;h[b+2|0]=g>>>16;h[b+3|0]=g>>>24;e=k[e+4|0]|k[e+5|0]<<8;h[b+4|0]=e;h[b+5|0]=e>>>8;break la}if(e&1){j[114626]=0;g=H(387,n|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break T}h[b|0]=g>>>0>120?-1:g}if(e&2){j[114626]=0;g=H(387,n|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break T}h[b+1|0]=g}o=0;g=0;if(e&4){j[114626]=0;g=H(387,n|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break D}}B=0;if(e&8){j[114626]=0;m=H(387,n|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break D}B=m>>>4|0;o=m&15}J=0;m=0;if(e&16){j[114626]=0;m=H(387,n|0)|0;u=j[114626];j[114626]=0;if((u|0)==1){break D}}if(e&32){j[114626]=0;J=H(387,n|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break D}}j[114626]=0;aa(754,b|0,g|0,o|0,B|0,m|0,J|0);b=j[114626];j[114626]=0;if((b|0)==1){break D}}f=f+1|0}if(f>>>0<q>>>0){continue}break}}x=x+1|0;if((x&65535)>>>0<w>>>0){continue}break}}gb(v);c=c+1|0;if((s|0)!=(c|0)){continue}break}}j[114626]=0;I(743,d+16|0,d+248|0,20048);b=j[114626];j[114626]=0;qa:{ra:{sa:{if((b|0)!=1){b=Ed(d+232|0,d+16|0);j[114626]=0;b=H(337,b|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break sa}jb(d+16|0);if(!b){break z}a=a+484344|0;if(!me(a)){break z}while(1){j[114626]=0;b=E(258,d+232|0,16)|0;c=j[114626];j[114626]=0;if((c|0)==1){break ra}if(!b){break z}j[114626]=0;K(755,d+232|0,d+16|0,16)|0;b=j[114626];j[114626]=0;if((b|0)==1){break qa}b=Ib(a,0);j[114626]=0;E(756,b|0,d+16|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break qa}if(me(a)){continue}break}break z}b=D()|0;C()|0;break B}b=D()|0;C()|0;jb(d+16|0);break B}b=D()|0;C()|0;break B}b=D()|0;C()|0;break B}b=D()|0;C()|0;break B}b=D()|0;C()|0;break o}b=D()|0;C()|0;break B}b=D()|0;C()|0;break B}break D}break n}b=D()|0;C()|0;break c}b=D()|0;C()|0;gb(v);break B}b=D()|0;C()|0}Sc(r);break c}b=D()|0;C()|0;break o}Sc(r)}jb(d+232|0);Qy(d+248|0);jb(L)}Za=d+288|0;return A|0}b=D()|0;C()|0;break o}b=D()|0;C()|0;break o}b=D()|0;C()|0;jb(d+40|0);break o}b=D()|0;C()|0;jb(d+56|0);break o}b=D()|0;C()|0;jb(d+72|0);break o}b=D()|0;C()|0;break o}b=D()|0;C()|0;break c}b=D()|0;C()|0}Xm(o);Xm(r);Xm(q);break c}b=D()|0;C()|0;jb(d+16|0);break c}b=D()|0;C()|0;break c}b=D()|0;C()|0;break c}b=D()|0;C()|0;break c}b=D()|0;C()|0;break c}b=D()|0;C()|0;gb(d+120|0);break c}b=D()|0;C()|0;break c}b=D()|0;C()|0;break c}b=D()|0;C()|0;gb(d+104|0);break d}b=D()|0;C()|0}gb(e)}jb(d+232|0)}Qy(d+248|0)}jb(L);G(b|0);z()}function cF(a,b,c,d,e,f,g){var n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;L=Za-144|0;Za=L;a:{b:{c:{if(d>>>0<=e>>>0){q=j[f>>2];N=g&4;M=N?-1:q+((d^-1)+e|0)|0;F=M+1|0;if(!(F&M)){break c}}j[f>>2]=0;j[c>>2]=0;r=-3;break b}G=e+q|0;E=j[c>>2];B=E+b|0;H=j[a+60>>2];y=j[a+40>>2];q=j[a+36>>2];C=j[a+32>>2];t=j[a+56>>2];o=j[a+4>>2];s=b;w=e;A=-1;r=-1;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{x=j[a>>2];switch(x|0){case 35:break i;case 17:break j;case 21:break k;case 37:break l;case 34:break m;case 42:break q;case 41:break r;case 53:break s;case 52:break t;case 51:break u;case 38:break v;case 27:break w;case 26:break x;case 25:break y;case 24:break z;case 23:break A;case 18:break B;case 16:break C;case 14:break D;case 11:break E;case 9:break F;case 7:break G;case 6:break H;case 3:break I;case 32:break J;case 5:break K;case 2:break M;case 1:break N;case 0:break O;case 36:break f;case 39:break g;case 10:break h;default:break d}}j[a+28>>2]=1;t=0;j[a+8>>2]=0;j[a+12>>2]=0;j[a+16>>2]=1;y=0;q=0;C=0;o=0;if(g&1){break N}break L}if((E|0)<=0){j[a>>2]=1;break e}j[a+8>>2]=k[b|0];s=b+1|0}if(s>>>0>=B>>>0){j[a>>2]=2;r=g&2?1:-4;break d}q=k[s|0];j[a+12>>2]=q;n=j[a+8>>2];r=(((q|n<<8)>>>0)%31|q&32)!=0|(n&15)!=8;q=1;s=s+1|0;if(!N){x=36;n=256<<(n>>>4);if(!(r|(n>>>0>32768|n>>>0>F>>>0))){break L}break f}x=36;if(r){break f}}n=0;break p}if((E|0)<=0){j[a>>2]=5;break e}s=b+1|0;t=k[b|0]<<o|t;o=o+8|0;n=2;break p}if((E|0)<=0){j[a>>2]=32;break e}s=b+1|0;t=k[b|0]<<o|t;D=q;o=o+8|0;break o}n=1;break p}n=3;break p}n=4;break p}n=5;break p}n=9;break p}n=10;break p}n=11;break p}n=12;break p}n=13;break p}n=14;break p}n=15;break p}n=16;break p}n=17;break p}n=8;break p}n=6;break p}n=7;break p}n=18;break p}u=2;break n}u=1;break n}P:while(1){Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{switch(n|0){case 0:q=D;if(o>>>0>2){break Ca}n=1;continue;case 17:break la;case 16:break ma;case 15:break na;case 14:break oa;case 13:break pa;case 12:break qa;case 11:break ra;case 10:break sa;case 9:break ta;case 8:break va;case 7:break wa;case 6:break xa;case 5:break ya;case 4:break za;case 3:break Aa;case 2:break Ba;case 1:break Da;default:break ka}}while(1){if(s>>>0>=B>>>0){j[a>>2]=3;r=g&2?1:-4;break d}t=k[s|0]<<o|t;n=s+1|0;s=n;o=o+8|0;if(o>>>0<3){continue}break}s=n;D=q}q=t&7;j[a+20>>2]=q;n=q>>>1|0;j[a+24>>2]=n;o=o-3|0;t=t>>>3|0;r=0;q=D;switch(n|0){case 0:break ja;case 1:break ua;case 3:break h;default:break ga}}n=o&-8;t=t>>>(o&7)|0;q=0;o=0;break ha}while(1){if(s>>>0>=B>>>0){j[a>>2]=6;r=g&2?1:-4;break d}t=k[s|0]<<o|t;v=o>>>0>4294967287;r=s+1|0;s=r;n=o+8|0;o=n;if(v){continue}break}s=r;o=1;break ha}if(s>>>0>=B>>>0){j[a>>2]=7;r=g&2?1:-4;break d}h[(a+q|0)+10528|0]=k[s|0];s=s+1|0;n=o;o=2;break ha}if(w>>>0<G>>>0){break ia}A=2;x=9;break f}while(1){if(s>>>0>=B>>>0){j[a>>2]=51;r=g&2?1:-4;break d}t=k[s|0]<<o|t;v=o>>>0>4294967287;r=s+1|0;s=r;n=o+8|0;o=n;if(v){continue}break}s=r;break R}if(w>>>0<G>>>0){h[w|0]=C;q=q-1|0;w=w+1|0;n=o;break U}A=2;x=52;break f}if(s>>>0>=B>>>0){j[a>>2]=38;r=g&2?1:-4;break d}n=G-w|0;r=B-s|0;n=n>>>0<r>>>0?n:r;n=n>>>0<q>>>0?n:q;q=q-n|0;w=Vb(w,s,n)+n|0;s=n+s|0;break T}j[a+44>>2]=288;j[a+48>>2]=32;n=a+3552|0;j[n>>2]=84215045;j[n+4>>2]=84215045;n=a+3560|0;j[n>>2]=84215045;j[n+4>>2]=84215045;n=a+3568|0;j[n>>2]=84215045;j[n+4>>2]=84215045;n=a+3576|0;j[n>>2]=84215045;j[n+4>>2]=84215045;n=a- -64|0;Ab(n,8,144);while(1){n=n+1|0;r=r+1|0;if((r|0)!=144){continue}break}Ab(n,9,112);r=144;while(1){n=n+1|0;r=r+1|0;if((r|0)!=256){continue}break}h[n|0]=7;h[n+1|0]=7;h[n+2|0]=7;h[n+3|0]=7;h[n+4|0]=7;h[n+5|0]=7;h[n+6|0]=7;h[n+7|0]=7;h[n+16|0]=7;h[n+17|0]=7;h[n+18|0]=7;h[n+19|0]=7;h[n+20|0]=7;h[n+21|0]=7;h[n+22|0]=7;h[n+23|0]=7;h[n+8|0]=7;h[n+9|0]=7;h[n+10|0]=7;h[n+11|0]=7;h[n+12|0]=7;h[n+13|0]=7;h[n+14|0]=7;h[n+15|0]=7;r=256;while(1){n=n+1|0;r=r+1|0;if((r|0)!=280){continue}break}h[n|0]=8;h[n+1|0]=8;h[n+2|0]=8;h[n+3|0]=8;h[n+4|0]=8;h[n+5|0]=8;h[n+6|0]=8;h[n+7|0]=8;break Y}while(1){if(s>>>0>=B>>>0){j[a>>2]=11;r=g&2?1:-4;break d}t=k[s|0]<<o|t;r=s+1|0;s=r;n=o+8|0;o=n;I=h[q+42396|0];if(n>>>0<I>>>0){continue}break}s=r;r=q;o=n;q=1;break _}while(1){if(s>>>0>=B>>>0){j[a>>2]=14;r=g&2?1:-4;break d}t=k[s|0]<<o|t;n=s+1|0;s=n;o=o+8|0;if(o>>>0<3){continue}break}s=n;n=1;break Z}if(s>>>0>=B>>>0){j[a>>2]=16;r=g&2?1:-4;break d}t=k[s|0]<<o|t;s=s+1|0;o=o+8|0;if(o>>>0<15){break fa}break ea}while(1){if(s>>>0>=B>>>0){j[a>>2]=18;r=g&2?1:-4;break d}t=k[s|0]<<o|t;n=s+1|0;s=n;o=o+8|0;if(y>>>0>o>>>0){continue}break}O=C-16|0;s=n;n=3;break X}if(s>>>0>=B>>>0){j[a>>2]=23;r=g&2?1:-4;break d}t=k[s|0]<<o|t;s=s+1|0;o=o+8|0;if(o>>>0<15){break da}break ca}if(w>>>0>=G>>>0){A=2;x=24;break f}h[w|0]=q;w=w+1|0;u=t;break W}while(1){if(s>>>0>=B>>>0){j[a>>2]=25;r=g&2?1:-4;break d}t=k[s|0]<<o|t;n=s+1|0;s=n;o=o+8|0;if(y>>>0>o>>>0){continue}break}s=n;n=3;break V}if(s>>>0>=B>>>0){j[a>>2]=26;r=g&2?1:-4;break d}t=k[s|0]<<o|t;s=s+1|0;o=o+8|0;if(o>>>0<15){break ba}break aa}while(1){if(s>>>0>=B>>>0){j[a>>2]=27;r=g&2?1:-4;break d}t=k[s|0]<<o|t;n=s+1|0;s=n;o=o+8|0;if(y>>>0>o>>>0){continue}break}s=n;n=6;break V}if(w>>>0>=G>>>0){A=2;x=53;break f}h[w|0]=k[(H-C&M)+d|0];w=w+1|0;H=H+1|0;break $}n=2;continue}n=8;continue}while(1){Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{switch(o|0){case 0:if(q>>>0>3){break Ia}o=0;if(!n){break Ha}o=n;if(n>>>0>7){break Fa}n=3;continue P;case 1:h[(a+q|0)+10528|0]=t;n=n-8|0;t=t>>>8|0;break Ea;default:break Ja}}q=q+1|0;break Ga}o=n;q=l[a+10528>>1];if((q|0)==(l[a+10530>>1]^65535)){break U}break g}n=4;continue P}o=0;continue}o=1;continue}o=2;continue}}q=0;break _}n=1;break X}n=2;break X}n=0;break V}n=1;break V}n=4;break V}n=5;break V}n=7;break V}while(1){Ka:{La:{Ma:{if(!q){if(r>>>0>2){break Ma}q=r;I=h[q+42396|0];if(I>>>0<=o>>>0){break Ka}n=9;continue P}q=r<<2;j[(q+a|0)+44>>2]=j[q+42384>>2]+((-1<<I^-1)&t);r=r+1|0;o=o-I|0;t=t>>>I|0;break La}q=0;Ab(a+7040|0,0,288);n=0;break Z}q=0;continue}q=1;continue}}while(1){Na:{Oa:{Pa:{if(!n){if(m[a+52>>2]<=q>>>0){break Pa}if(o>>>0>2){break Na}n=10;continue P}h[(k[q+42448|0]+a|0)+7040|0]=t&7;q=q+1|0;o=o-3|0;t=t>>>3|0;break Oa}j[a+52>>2]=19;D=q;break Y}n=0;continue}n=1;continue}}J=j[a+24>>2];n=0}while(1){Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{switch(n|0){case 0:q=0;if((J|0)<0){u=t;q=D;break W}E=Ab(L,0,64);r=p(J,3488)+a|0;Ab(r+352|0,0,3200);x=j[a+24>>2];n=j[((x<<2)+a|0)+44>>2];if(n){while(1){v=E+(k[(q+r|0)- -64|0]<<2)|0;j[v>>2]=j[v>>2]+1;q=q+1|0;if((n|0)!=(q|0)){continue}break}}j[E+64>>2]=0;j[E+68>>2]=0;v=0;r=0;q=1;while(1){A=q<<2;q=q+1|0;A=j[A+E>>2];v=A+v<<1;j[(E- -64|0)+(q<<2)>>2]=v;r=r+A|0;if((q|0)!=16){continue}break}if(!((v|0)==65536|r>>>0<2)){q=D;break i}if(n){n=-1;F=0;K=p(J,3488)+a|0;while(1){x=k[(F+K|0)- -64|0];Za:{if(!x){break Za}r=(E- -64|0)+(x<<2)|0;q=j[r>>2];j[r>>2]=q+1;r=0;v=x;while(1){A=r;r=q&1|r<<1;q=q>>>1|0;v=v-1|0;if(v){continue}break}if(x>>>0<=10){if(r>>>0>1023){break Za}q=x<<9|F;v=1<<x;while(1){i[((r<<1)+K|0)+352>>1]=q;r=r+v|0;if(r>>>0<1024){continue}break}break Za}r=((r&1023)<<1)+K|0;q=i[r+352>>1];_a:{if(q){r=n;n=q;break _a}i[r+352>>1]=n;r=n-2|0}q=A>>>8&8388607;if(x>>>0>=12){while(1){q=q>>>1|0;v=(((q&1)+(n^-1)<<1)+K|0)+2400|0;n=i[v>>1];if(!n){i[v>>1]=r;n=r;r=n-2|0}x=x-1|0;if(x>>>0>11){continue}break}}i[(((q>>>1&1)+(n^-1)<<1)+K|0)+2400>>1]=F;n=r}F=F+1|0;x=j[a+24>>2];if(F>>>0<m[((x<<2)+a|0)+44>>2]){continue}break}}q=0;if((x|0)!=2){break Ra}break Va;case 1:n=i[(((t&1023)<<1)+a|0)+7328>>1];$a:{if((n|0)>=0){if((n>>9)-1>>>0>=o>>>0){break $a}break Ua}if(o>>>0<11){break $a}r=10;while(1){n=i[(((t>>>r&1)+(n^-1)<<1)+a|0)+9376>>1];if((n|0)<=-1){v=r+2|0;r=r+1|0;if(o>>>0>=v>>>0){continue}}break}if((n|0)>-1){break Ua}}n=11;continue P;case 2:r=i[(((t&1023)<<1)+a|0)+7328>>1];if((r|0)>=0){break Xa}n=10;while(1){v=t>>>n|0;n=n+1|0;r=i[(((v&1)+(r^-1)<<1)+a|0)+9376>>1];if((r|0)<0){continue}break}break Wa;default:break Ya}}n=h[O+42404|0]+((-1<<y^-1)&t)|0;o=o-y|0;t=t>>>y|0;r=a+q|0;Ab(r+10532|0,(C|0)==16?k[r+10531|0]:0,n);q=n+q|0;break Va}n=r>>9;r=r&511}o=o-n|0;t=t>>>n|0;C=r;if(r>>>0>15){break Ta}h[(a+q|0)+10532|0]=C;q=q+1|0}r=j[a+48>>2];n=j[a+44>>2];v=r+n|0;if(v>>>0<=q>>>0){break Sa}if(o>>>0>14){break Ua}if((B-s|0)<=1){n=1;continue}t=k[s|0]<<o|t|k[s+1|0]<<o+8;o=o+16|0;s=s+2|0}n=2;continue}if(!((C|0)!=16|q)){C=16;q=0;break j}O=C-16|0;y=h[O+42400|0];if(y>>>0<=o>>>0){break Qa}n=12;continue P}if((q|0)!=(v|0)){break k}D=a+10532|0;Vb(a- -64|0,D,n);Vb(a+3552|0,n+D|0,r);x=j[a+24>>2];D=q}J=x-1|0;j[a+24>>2]=J;n=0;continue}n=3;continue}}n=2}ab:while(1){bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{switch(n|0){case 0:n=i[(((t&1023)<<1)+a|0)+352>>1];qb:{if((n|0)>=0){if((n>>9)-1>>>0>=o>>>0){break qb}break bb}if(o>>>0<11){break qb}r=10;while(1){n=i[(((t>>>r&1)+(n^-1)<<1)+a|0)+2400>>1];if((n|0)<=-1){v=r+2|0;r=r+1|0;if(o>>>0>=v>>>0){continue}}break}if((n|0)>-1){break bb}}n=13;continue P;case 1:r=i[(((t&1023)<<1)+a|0)+352>>1];if((r|0)>=0){break ob}n=10;while(1){q=t>>>n|0;n=n+1|0;r=i[(((q&1)+(r^-1)<<1)+a|0)+2400>>1];if((r|0)<0){continue}break}q=r;break nb;case 3:break eb;case 4:break fb;case 5:break jb;case 6:break kb;case 2:break pb;default:break lb}}while(1){n=B-s|0;if(!((G-w|0)>1?(n|0)>=4:0)){if(o>>>0>14){t=u;break bb}if((n|0)<=1){t=u;n=0;continue ab}t=k[s|0]<<o|u|k[s+1|0]<<o+8;o=o+16|0;s=s+2|0;break bb}rb:{if(o>>>0>14){t=o;n=s;break rb}t=o+16|0;u=(k[s|0]|k[s+1|0]<<8)<<o|u;n=s+2|0}q=i[(((u&1023)<<1)+a|0)+352>>1];sb:{if((q|0)<0){s=10;while(1){o=u>>>s|0;s=s+1|0;q=i[(((o&1)+(q^-1)<<1)+a|0)+2400>>1];if((q|0)<0){continue}break}break sb}s=q>>9}o=t-s|0;t=u>>>s|0;if(q&256){s=n;break mb}if(o>>>0>14){r=o}else{t=(k[n|0]|k[n+1|0]<<8)<<o|t;n=n+2|0;r=o+16|0}s=n;n=i[(((t&1023)<<1)+a|0)+352>>1];tb:{if((n|0)<0){u=10;while(1){o=t>>>u|0;u=u+1|0;n=i[(((o&1)+(n^-1)<<1)+a|0)+2400>>1];if((n|0)<0){continue}break}break tb}u=n>>9}h[w|0]=q;o=r-u|0;u=t>>>u|0;if(!(n&256)){h[w+1|0]=n;w=w+2|0;continue}break}w=w+1|0;t=u;q=n;break mb}n=r>>9;q=r&511}o=o-n|0;t=t>>>n|0;if(q>>>0>255){break mb}n=14;continue P}D=256;r=q&511;if((r|0)==256){break Q}y=0;n=t;v=(r<<2)-1028|0;q=j[v+41872>>2];A=q;if(r-265>>>0>19){break db}y=j[v+42e3>>2];if(y>>>0>o>>>0){n=15;continue P}n=3;continue}if(!q){u=t;q=-1;break hb}q=q-1|0;n=18;continue P}o=o-y|0;u=t>>>y|0;C=((-1<<y^-1)&t)+C|0;break ib}y=i[(((t&1023)<<1)+a|0)+3840>>1];ub:{if((y|0)<0){n=10;while(1){r=t>>>n|0;n=n+1|0;y=i[(((r&1)+(y^-1)<<1)+a|0)+5888>>1];if((y|0)<0){continue}break}r=y;break ub}n=y>>9;r=y&511}v=r<<2;C=j[v+42128>>2];o=o-n|0;t=t>>>n|0;y=0;if(r-4>>>0>25){u=t;break ib}y=j[v+42256>>2];if(y>>>0<=o>>>0){break gb}n=17;continue P}H=w-d|0;if(!(!N|H>>>0>=C>>>0)){t=u;break l}n=(H-C&M)+d|0;if((n>>>0<w>>>0?w:n)+q>>>0>G>>>0){t=u;n=7;continue}if(q>>>0>2){while(1){h[w|0]=k[n|0];h[w+1|0]=k[n+1|0];h[w+2|0]=k[n+2|0];n=n+3|0;w=w+3|0;q=q-3|0;if(q>>>0>2){continue}break}}if(!q){break hb}h[w|0]=k[n|0];if((q|0)!=1){h[w+1|0]=k[n+1|0]}w=q+w|0}n=2;continue}n=6;continue}n=i[(((t&1023)<<1)+a|0)+3840>>1];vb:{if((n|0)>=0){if((n>>9)-1>>>0>=o>>>0){break vb}break cb}if(o>>>0<11){break vb}r=10;while(1){n=i[(((t>>>r&1)+(n^-1)<<1)+a|0)+5888>>1];if((n|0)<=-1){v=r+2|0;r=r+1|0;if(o>>>0>=v>>>0){continue}}break}if((n|0)>-1){break cb}}n=16;continue P}o=o-y|0;n=t>>>y|0;A=((-1<<y^-1)&t)+q|0}q=A;t=n;if(o>>>0>14){break cb}if((B-s|0)<=1){n=4;continue}t=t|k[s|0]<<o|k[s+1|0]<<o+8;o=o+16|0;s=s+2|0}n=5;continue}n=1;continue}}if(n?q:0){break S}o=n}D=0;if(!q){break Q}n=5;continue}o=n;if(n>>>0>7){break R}n=6;continue}o=n-8|0;C=t&255;t=t>>>8|0;n=7;continue}if(h[a+20|0]&1){break o}n=0;continue}}u=o&-8;if(!(!u|b>>>0>=s>>>0)){q=u-8|0;d=q>>>3|0;n=(b^-1)+s|0;d=d>>>0<n>>>0?d:n;u=q-(d<<3)|0;s=(d^-1)+s|0}if(!u){t=(((u&63)>>>0>=32?0:-1<<u)^-1)&t>>>(o&7);v=0;n=0;q=D;o=0;if(!(g&1)){break m}u=0;break n}X(42408,41840,2787,42418);z()}while(1){wb:{xb:{yb:{zb:{Ab:{Bb:{switch(u|0){case 0:if(v>>>0>3){q=v;o=n;break m}o=0;if(n){break Ab}q=v;u=1;continue;case 1:break Bb;default:break zb}}if(s>>>0<B>>>0){break xb}j[a>>2]=42;r=g&2?1:-4;break d}q=v;o=n;if(n>>>0>7){break yb}u=2;continue}while(1){if(s>>>0>=B>>>0){j[a>>2]=41;r=g&2?1:-4;break d}t=k[s|0]<<o|t;u=o>>>0>4294967287;d=s+1|0;s=d;n=o+8|0;o=n;if(u){continue}break}s=d;v=q}u=t&255;t=t>>>8|0;n=n-8|0;break wb}u=k[s|0];s=s+1|0;v=q;n=o}j[a+16>>2]=j[a+16>>2]<<8|u;v=v+1|0;u=0;continue}}A=0;x=34;break f}x=37;A=-1;break f}x=21;A=-1;break f}x=17;A=-1;break f}x=35;A=-1;break f}x=10;A=-1;break f}x=39;A=-1}j[a>>2]=x;if(!(o>>>0<8|b>>>0>=s>>>0)){n=o-8|0;d=n>>>3|0;o=(b^-1)+s|0;d=d>>>0<o>>>0?d:o;s=(d^-1)+s|0;o=n-(d<<3)|0}r=A;break d}r=g&2?1:-4}j[a+4>>2]=o;j[a+60>>2]=H;j[a+40>>2]=y;j[a+36>>2]=q;j[a+32>>2]=C;j[a+56>>2]=(((o&63)>>>0>=32?0:-1<<o)^-1)&t;j[c>>2]=s-b;n=w-e|0;j[f>>2]=n;if(!(g&9)|(r|0)<0){break b}b=j[a+28>>2];o=b>>>16|0;t=b&65535;if(n){q=(n>>>0)%5552|0;while(1){s=0;if(q>>>0>7){while(1){b=k[e|0]+t|0;c=b+k[e+1|0]|0;d=c+k[e+2|0]|0;f=d+k[e+3|0]|0;u=f+k[e+4|0]|0;D=u+k[e+5|0]|0;v=D+k[e+6|0]|0;t=v+k[e+7|0]|0;o=t+(v+(D+(u+(f+(d+(c+(b+o|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;s=s+8|0;if((s|7)>>>0<q>>>0){continue}break}s=q&8184}if(q>>>0>s>>>0){b=q-s|0;u=e;while(1){t=k[u|0]+t|0;o=t+o|0;u=u+1|0;s=s+1|0;if((s|0)!=(q|0)){continue}break}e=b+e|0}n=n-q|0;o=(o>>>0)%65521|0;t=(t>>>0)%65521|0;q=5552;if(n){continue}break}}b=o<<16|t;j[a+28>>2]=b;if(r){break b}r=0;if(g&1){break a}}Za=L+144|0;return r}Za=L+144|0;return j[a+16>>2]==(b|0)?0:-2}function _xa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,W=0,X=0,Y=0,Z=0;f=Za-416|0;Za=f;rc(b);t=f+208|0;e=Bxa(b,t);if(!e){TM(t)}a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!e){break i}if(!YM(f+208|0)){break i}if(!c){d=1;break i}od(a,134217728);d=Eb(f+192|0,17360);j[114626]=0;F(219,f+144|0,d|0);t=j[114626];j[114626]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((t|0)!=1){j[114626]=0;v=f+208|4;I(999,f+16|0,f+144|0,v|0);t=j[114626];j[114626]=0;if((t|0)==1){break q}ob(a+1304436|0,f+16|0);gb(f+16|0);qb(f+144|0);gb(d);d=Eb(f+16|0,17384);ob(a+1304448|0,d);gb(d);j[a+480188>>2]=4;j[a+1304496>>2]=2;d=k[f+344|0]|k[f+345|0]<<8;j[a+480196>>2]=(d<<24|d<<8&16711680)>>>16;d=k[f+348|0]|k[f+349|0]<<8;j[a+480260>>2]=56;j[a+480264>>2]=13696;Y=a,Z=XM((d<<8&16711680|d<<24)>>>16|0),j[Y+480204>>2]=Z;fn(Fb(a+484360|0),f+216|0,k[f+208|6],65535,65535);y=a+480190|0;w=f+176|0;Mxa(w);x=mn(f+160|0);if(k[f+408|0]|k[f+409|0]<<8){break o}break n}a=D()|0;C()|0;break p}a=D()|0;C()|0;qb(f+144|0)}gb(d);break a}t=0;while(1){j[114626]=0;d=H(484,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break e}i[f+120>>1]=d;if((d-1&65535)>>>0>3998){break k}d=k[f+410|0]|k[f+411|0]<<8;d=(d<<8&16711680|d<<24)>>>16|0;r:{if((k[v|0]|k[v+1|0]<<8)!=512){break r}j[114626]=0;d=H(493,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break f}d=d-2|0}j[114626]=0;I(341,f+144|0,b|0,d|0);d=j[114626];j[114626]=0;s:{t:{u:{if((d|0)!=1){j[114626]=0;d=E(452,y|0,f+120|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break u}J=l[d>>1];i[a+480190>>1]=J;j[114626]=0;d=p(l[f+120>>1],104)+a|0;u=d+484380|0;F(386,u|0,1);e=j[114626];j[114626]=0;v:{if((e|0)==1){break v}e=k[v|0]|k[v+1|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0>1){break t}j[114626]=0;K(1e3,f+144|0,d+484423|0,31)|0;e=j[114626];j[114626]=0;if((e|0)==1){break v}j[114626]=0;E(338,f+144|0,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break v}j[114626]=0;K(388,f+144|0,((l[f+120>>1]<<5)+a|0)+946300|0,30)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break s}}a=D()|0;C()|0;break c}a=D()|0;C()|0;break b}a=D()|0;C()|0;break c}e=Db(f+16|0);j[114626]=0;K(597,f+144|0,e|0,257)|0;q=j[114626];j[114626]=0;w:{x:{if((q|0)==1){break x}j[114626]=0;E(370,d+484423|0,e|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break x}j[114626]=0;E(338,f+144|0,1)|0;q=j[114626];j[114626]=0;if((q|0)==1){break x}j[114626]=0;K(597,f+144|0,e|0,31)|0;q=j[114626];j[114626]=0;if((q|0)==1){break x}j[114626]=0;E(369,((l[f+120>>1]<<5)+a|0)+946300|0,e|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break x}if(!(j[f+152>>2]&1)){break w}j[114626]=0;E(338,f+144|0,1)|0;q=j[114626];j[114626]=0;if((q|0)!=1){break w}}a=D()|0;C()|0;gb(e);break c}gb(e)}j[114626]=0;E(1001,f+144|0,f+16|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break m}j[114626]=0;F(1002,f+16|0,u|0);e=j[114626];j[114626]=0;if((e|0)==1){break m}if((k[v|0]|k[v+1|0]<<8)==512){h[d+484417|0]=k[f+34|0]<<3}y:{if(!(k[v|0]|k[v+1|0]<<8)){break y}j[114626]=0;F(384,x|0,J|0);e=j[114626];j[114626]=0;if((e|0)==1){break m}j[114626]=0;F(1003,w|0,J|0);e=j[114626];j[114626]=0;if((e|0)==1){break m}e=Zc(w,l[f+120>>1]-1|0);cc(e);VM(e);ts(e);j[114626]=0;u=H(484,b|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break g}j[114626]=0;F(1004,e|0,u|0);q=j[114626];j[114626]=0;if((q|0)==1){break g}g=0;j[f+136>>2]=0;if(!u){if(!(k[d+484414|0]&2)){break y}u=j[d+484384>>2];j[f+128>>2]=u;d=j[d+484388>>2];j[114626]=0;j[f+132>>2]=d-u;F(1005,e|0,f+128|0);d=j[114626];j[114626]=0;if((d|0)!=1){break y}a=D()|0;C()|0;break c}while(1){j[114626]=0;d=H(493,b|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break h}j[114626]=0;j[f+128>>2]=d;d=H(493,b|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break h}j[114626]=0;j[f+132>>2]=d;F(1005,e|0,f+128|0);d=j[114626];j[114626]=0;if((d|0)==1){break h}g=g+1|0;if(u>>>0>(g&65535)>>>0){continue}break}}jb(f+144|0);t=t+1|0;d=k[f+408|0]|k[f+409|0]<<8;if((t&65535)>>>0<(d<<24|d<<8&16711680)>>>16>>>0){continue}break}}L=128;if(k[v|0]|k[v+1|0]<<8){break l}j[114626]=0;L=H(484,b|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break l}a=D()|0;C()|0;break b}a=D()|0;C()|0;break c}t=a+480188|0;M=k[f+208|7];i[f+126>>1]=4;z:{A:{B:{if(!(k[v|0]|k[v+1|0]<<8)){g=l[t>>1];break B}e=j[b+8>>2];C:{if(!L){break C}d=0;while(1){j[114626]=0;u=H(484,b|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break A}if((u|0)==65535){break C}j[114626]=0;M=H(484,b|0)|0;u=j[114626];j[114626]=0;if((u|0)==1){break A}j[114626]=0;u=H(484,b|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break A}j[114626]=0;i[f+126>>1]=u;u=E(452,t|0,f+126|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break A}i[t>>1]=l[u>>1];j[114626]=0;E(338,b|0,p(l[f+126>>1],M)<<2)|0;u=j[114626];j[114626]=0;if((u|0)==1){break A}d=d+1|0;if((d&65535)>>>0<L>>>0){continue}break}}d=0;j[114626]=0;E(256,b|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break z}g=l[t>>1];if(g>>>0>127){break j}}j[114626]=0;P=E(1006,f+144|0,g&65535)|0;d=j[114626];j[114626]=0;if((d|0)!=1){D:{if(!L){break D}T=a+484344|0;X=c&1;Q=k[f+347|0];t=0;u=0;while(1){d=u;if(k[v|0]|k[v+1|0]<<8){j[114626]=0;d=H(484,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break d}if((d|0)==65535){break D}j[114626]=0;M=H(484,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break d}j[114626]=0;e=H(484,b|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break d}i[f+126>>1]=e}N=M&65535;E:{F:{if(!X){break F}j[114626]=0;U=d&65535;d=K(402,T|0,U|0,N|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break d}if(!d){break F}if(!N){break E}A=0;while(1){d=Ib(T,U);j[114626]=0;r=E(496,d|0,A|0)|0;d=j[114626];j[114626]=0;G:{if((d|0)!=1){g=0;B=0;H:{I:{switch((Q&3)-1|0){case 0:B=!(A&3);break H;case 1:B=!(A&1);break H;case 2:break I;default:break H}}B=(A&3)!=3}R=0;if(!l[f+126>>1]){break G}while(1){d=j[P>>2];j[114626]=0;F(595,f+128|0,b|0);e=j[114626];j[114626]=0;if((e|0)==1){break d}o=p(g,9)+d|0;d=Pc(f+128|0);q=Bf(f+128|0);n=pi(f+128|0);s=p(g,6)+r|0;h[s+1|0]=k[f+128|0];e=k[d|0];h[s|0]=e;d=k[n|0];h[s+5|0]=d;n=s+5|0;if(e){h[s|0]=e+25;h[o+8|0]=0;h[o|0]=0;h[o+1|0]=0;h[o+2|0]=0;h[o+3|0]=0;h[o+4|0]=0;h[o+5|0]=0;h[o+6|0]=0;h[o+7|0]=0;d=k[n|0]}e=d;S=k[q|0];J:{if(S>>>0>=240){d=e|(S&15)<<8;if(d){d=XM(d);j[114626]=0;d=na(1007,+(+(d>>>0)*1e-4))|0;e=j[114626];j[114626]=0;if((e|0)!=1){h[n|0]=d;h[s+3|0]=17;break J}break d}h[s+3|0]=0;break J}O=e>>>4|0;W=e<<4;q=O|W;K:{switch(S|0){case 0:e=p(g,6)+r|0;if(d){h[e+3|0]=1;break J}h[e+3|0]=0;break J;case 1:h[(p(g,6)+r|0)+3|0]=2;break J;case 2:h[(p(g,6)+r|0)+3|0]=3;break J;case 3:j[114626]=0;h[f+16|0]=15;d=E(391,n|0,f+16|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){h[o|0]=k[d|0]|16;h[o+7|0]=0;h[o+1|0]=0;h[o+2|0]=0;h[(p(g,6)+r|0)+3|0]=0;break J}break d;case 4:j[114626]=0;h[f+16|0]=15;d=E(391,n|0,f+16|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){h[o|0]=k[d|0]|32;h[o+7|0]=0;h[o+1|0]=0;h[o+2|0]=0;h[(p(g,6)+r|0)+3|0]=0;break J}break d;case 5:h[o+7|0]=0;h[o+2|0]=0;h[o+1|0]=d;h[o|0]=0;h[(p(g,6)+r|0)+3|0]=0;break J;case 6:h[o+7|0]=0;h[o+2|0]=d;h[o|0]=0;h[o+1|0]=0;h[(p(g,6)+r|0)+3|0]=0;break J;case 7:h[(p(g,6)+r|0)+3|0]=23;t=0;break J;case 8:h[(p(g,6)+r|0)+3|0]=0;t=q;break J;case 9:h[(p(g,6)+r|0)+3|0]=19;j[114626]=0;h[f+16|0]=15;d=E(391,n|0,f+16|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){h[n|0]=k[d|0]|16;break J}break d;case 10:h[(p(g,6)+r|0)+3|0]=19;j[114626]=0;h[f+16|0]=15;d=E(391,n|0,f+16|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){h[n|0]=k[d|0]|32;break J}break d;case 11:h[o+3|0]=q;h[(p(g,6)+r|0)+3|0]=0;break J;case 12:e=p(g,6)+r|0;h[e+4|0]=d;h[e+2|0]=1;h[o+3|0]=0;h[e+3|0]=0;break J;case 13:q=p(g,6)+r|0;L:{M:{if(e&240){h[(p(g,6)+r|0)+2|0]=4;d=(d&240)>>>4|0;break M}if(!(e&15)){break L}h[(p(g,6)+r|0)+2|0]=3;d=d&15}h[q+4|0]=d}h[o+3|0]=0;h[(p(g,6)+r|0)+3|0]=0;break J;case 14:h[(p(g,6)+r|0)+3|0]=19;h[n|0]=!d;break J;case 15:h[(p(g,6)+r|0)+3|0]=16;h[n|0]=(d&240)>>>4;Q=d&15;break J;case 16:h[o+5|0]=0;h[o+4|0]=d;h[(p(g,6)+r|0)+3|0]=0;break J;case 17:h[o+6|0]=e&15?d:0;h[(p(g,6)+r|0)+3|0]=0;break J;case 18:h[(p(g,6)+r|0)+3|0]=14;break J;case 19:h[o+8|0]=0;h[o+7|0]=d;h[o+2|0]=0;h[o|0]=0;h[o+1|0]=0;h[(p(g,6)+r|0)+3|0]=0;break J;case 20:h[(p(g,6)+r|0)+3|0]=12;break J;case 22:N:{d=k[s+1|0];O:{if(!d){break O}if(cc(w)>>>0<d>>>0){break O}d=Zc(w,k[s+1|0]-1|0);e=k[n|0]-1|0;h[n|0]=e;j[114626]=0;E(1008,f+16|0,0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break d}j[f+120>>2]=9;d=cc(d);j[114626]=0;j[f+12>>2]=d;d=E(33,f+120|0,f+12|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break N}if(m[d>>2]<=(e&255)>>>0){break O}d=p(g,6)+r|0;h[d+2|0]=15;h[d+4|0]=k[n|0]}h[(p(g,6)+r|0)+3|0]=0;break J}break d;case 23:d=k[s+1|0];P:{if(!d){break P}if(cc(w)>>>0<d>>>0){break P}d=Zc(w,k[s+1|0]-1|0);e=k[n|0]-1|0;h[n|0]=e;if(cc(d)>>>0<=(e&255)>>>0){break P}Q:{if(l[Zc(d,k[n|0])+8>>1]){break Q}if(!bn(a)){break Q}e=l[y>>1]+1|0;i[y>>1]=e;Y=Zc(d,k[n|0]),Z=e,i[Y+8>>1]=Z}Y=s,Z=k[Zc(d,k[n|0])+8|0],h[Y+1|0]=Z}h[(p(g,6)+r|0)+3|0]=0;break J;case 24:R:{d=k[s+1|0];S:{if(!d){break S}if(cc(w)>>>0<d>>>0){break S}d=Zc(w,k[s+1|0]-1|0);e=k[n|0]-1|0;h[n|0]=e;j[114626]=0;E(1008,f+16|0,0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break d}j[f+120>>2]=9;d=cc(d);j[114626]=0;j[f+12>>2]=d;d=E(33,f+120|0,f+12|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break R}if(m[d>>2]>(e&255)>>>0){d=p(g,6)+r|0;h[d+2|0]=15;h[d+4|0]=k[n|0]}T:{if(l[ac(x,k[s+1|0]-1|0)>>1]){break T}if(!bn(a)){break T}d=l[y>>1]+1|0;i[y>>1]=d;Y=ac(x,k[s+1|0]-1|0),Z=d,i[Y>>1]=Z}Y=s,Z=k[ac(x,k[s+1|0]-1|0)|0],h[Y+1|0]=Z}h[(p(g,6)+r|0)+3|0]=0;break J}break d;case 25:d=k[s+1|0];U:{if(!d){break U}if(cc(w)>>>0<d>>>0){break U}d=Zc(w,k[s+1|0]-1|0);e=k[n|0]-1|0;h[n|0]=e;if(cc(d)>>>0<=(e&255)>>>0){break U}V:{if(l[Zc(d,k[n|0])+10>>1]){break V}if(!bn(a)){break V}e=l[y>>1]+1|0;i[y>>1]=e;Y=Zc(d,k[n|0]),Z=e,i[Y+10>>1]=Z}Y=s,Z=k[Zc(d,k[n|0])+10|0],h[Y+1|0]=Z}h[(p(g,6)+r|0)+3|0]=0;break J;case 29:h[(p(g,6)+r|0)+3|0]=11;h[n|0]=q;if(e&15){h[n|0]=W|15;break J}if(!O){break J}h[n|0]=O|240;break J;case 32:if(e&240){h[o+3|0]=O;h[(p(g,6)+r|0)+3|0]=0;break J}h[(p(g,6)+r|0)+3|0]=19;h[n|0]=d&15|192;break J;case 33:h[(p(g,6)+r|0)+3|0]=19;j[114626]=0;h[f+16|0]=15;d=E(391,n|0,f+16|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){h[n|0]=k[d|0]|208;break J}break d;case 34:h[(p(g,6)+r|0)+3|0]=19;j[114626]=0;h[f+16|0]=15;d=E(391,n|0,f+16|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){h[n|0]=k[d|0]|144;break J}break d;case 73:h[(p(g,6)+r|0)+3|0]=10;break J;case 78:if((d&112|128)==224){h[(p(g,6)+r|0)+3|0]=19;break J}h[(p(g,6)+r|0)+3|0]=0;break J;case 79:e=p(g,6)+r|0;if(d>>>0<=31){h[e+3|0]=16;Q=0;break J}h[e+3|0]=17;break J;default:break K}}h[(p(g,6)+r|0)+3|0]=0}d=0;e=k[o+3|0];if(!(k[s+2|0]|!e)){W:{if(e>>>0>=16){h[s+2|0]=5;h[s+4|0]=e>>>4;break W}h[s+2|0]=6;h[s+4|0]=e}d=1}X:{if(k[s+3|0]){break X}e=k[o+1|0];if(e){h[s+3|0]=2;h[n|0]=e;break X}e=k[o+2|0];if(e){h[s+3|0]=3;h[n|0]=e;break X}e=k[o|0];if(e){h[s+3|0]=19;h[n|0]=e;break X}e=k[o+7|0];if(e){h[s+3|0]=4;h[o+8|0]=e;h[n|0]=e;break X}e=k[o+4|0];if(e){h[s+3|0]=5;h[o+5|0]=e;h[n|0]=e;break X}e=d;d=k[o+3|0];if(!(e|!d)){h[s+3|0]=11;h[n|0]=d;if(d&15){h[n|0]=d|240;break X}if(!(d&240)){break X}h[n|0]=d|15;break X}d=k[o+6|0];if(d){h[s+3|0]=8;h[n|0]=d;break X}if(B){h[s+3|0]=20;h[n|0]=97;B=0;break X}B=0;d=t&255;if(!d|!(R^1)){break X}h[s+3|0]=24;h[n|0]=t;if(t&15){h[n|0]=t|240;R=1;break X}R=1;if(!(d&240)){break X}h[n|0]=t|15}g=g+1|0;if(g>>>0<l[f+126>>1]){continue}break}break G}break d}A=A+1|0;if((N|0)!=(A|0)){continue}break}break E}j[114626]=0;E(338,b|0,p(l[f+126>>1],N)<<2)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break E}break d}u=u+1|0;if((u&65535)>>>0<L>>>0){continue}break}}j[a+480228>>2]=256/l[a+480188>>1];j[114626]=0;F(449,a|0,1);d=j[114626];j[114626]=0;if((d|0)==1){break d}if(k[v|0]|k[v+1|0]<<8){Y:{while(1){j[114626]=0;d=E(258,b|0,2)|0;t=j[114626];j[114626]=0;if((t|0)==1){break d}if(!d){break Y}j[114626]=0;d=H(484,b|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break d}if((d|0)==65535){break Y}j[114626]=0;E(338,b|0,2)|0;d=j[114626];j[114626]=0;if((d|0)==1){break d}j[114626]=0;d=H(493,b|0)|0;t=j[114626];j[114626]=0;if((t|0)!=1){j[114626]=0;E(338,b|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){continue}}break}break d}j[114626]=0;E(338,b|0,34)|0;d=j[114626];j[114626]=0;if((d|0)==1){break d}}Z:{if(!(!(c&2)|!J)){d=1;t=1;while(1){c=(p(d,104)+a|0)+484380|0;_:{if(!j[c>>2]){break _}e=Mc(f+16|0,8,1,0,0);j[114626]=0;K(400,e|0,c|0,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Z}if(cc(w)>>>0<d>>>0){break _}d=d-1|0;e=Zc(w,d);j[114626]=0;F(1009,c|0,e|0);e=j[114626];j[114626]=0;$:{if((e|0)!=1){if(!l[ac(x,d)>>1]){break $}e=l[ac(x,d)>>1];u=j[c>>2];j[114626]=0;V(1010,c|0,(p(e,104)+a|0)+484380|0,0,u|0,0);e=j[114626];j[114626]=0;if((e|0)!=1){break $}}break d}d=Zc(w,d);Y=f,Z=Lb(d),j[Y+16>>2]=Z;Y=f,Z=Mb(d),j[Y+128>>2]=Z;if(!rb(f+16|0,f+128|0)){break _}while(1){d=j[f+16>>2];e=l[d+8>>1];if(e){u=j[d+4>>2];q=j[d>>2];j[114626]=0;V(1010,c|0,(p(e,104)+a|0)+484380|0,q|0,u|0,1);e=j[114626];j[114626]=0;if((e|0)==1){break d}}e=l[d+10>>1];if(e){u=j[d+4>>2];d=j[d>>2];j[114626]=0;V(1010,c|0,(p(e,104)+a|0)+484380|0,d|0,u|0,0);d=j[114626];j[114626]=0;if((d|0)==1){break d}}_m(f+16|0);if(rb(f+16|0,f+128|0)){continue}break}}t=t+1|0;d=t&65535;if(J>>>0>=d>>>0){continue}break}}cy(P);d=1;break j}break d}a=D()|0;C()|0;break b}a=D()|0;C()|0;break b}a=D()|0;C()|0;break b}d=0}ff(x);WM(w)}Za=f+416|0;return d|0}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}a=D()|0;C()|0;break b}a=D()|0;C()|0;break b}a=D()|0;C()|0;cy(P);break b}jb(f+144|0)}ff(x);WM(w)}G(a|0);z()}function q5(a){var b=0,c=0,d=0,e=0,f=0,g=0,o=0,r=0,s=0,t=0,u=0,v=0,w=q(0),x=q(0),y=0,A=0,B=0,C=0,D=q(0);t=Za-1024|0;Za=t;h[a+1377|0]=1;a:{if(!Wq(a)){break a}e=k[a+1375|0];if(!(e&2)){Nb(a,34);break a}if(e&4){Nb(a,34);break a}if(e&1){Nb(a,34);break a}if(j[a+1116>>2]!=1){Nb(a,34);break a}e=k[a+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!Fv(a,t+1018|0,6)|k[t+1018|0]!=102|(k[t+1019|0]!=105|k[t+1020|0]!=115)){break b}if(k[t+1021|0]!=104|k[t+1022|0]!=101|k[t+1023|0]!=97){break b}if((he(a)|0)!=100){break b}if(he(a)){break b}Nb(a,38);break a}Nb(a,34);break a}if((he(a)|0)!=1){Nb(a,34);break a}if(!Fv(a,t+1018|0,6)){Nb(a,10);break a}if(!Ev(t+1018|0)){Nb(a,34);break a}if(Oh(a)){Nb(a,34);break a}e=he(a);j[a+4>>2]=e;if(!e){Nb(a,34);break a}if(e>>>0>=17){Nb(a,5);break a}e=Oh(a);j[a>>2]=e;if(!e){Nb(a,34);break a}Oh(a);Oh(a);Oh(a);e=he(a);d=e>>>4|0;j[a+116>>2]=1<<d;c=e&15;j[a+112>>2]=1<<c;if(c-6>>>0>=8){Nb(a,20);break a}if((e<<24)-1610612736>>24<=-1){Nb(a,20);break a}if(c>>>0>d>>>0){Nb(a,20);break a}if(!(he(a)&1)){Nb(a,34);break a}if(!Wq(a)){break a}if(!Dv(a)){break a}if(!Cv(a)){break a}c:{d:{if((pg(a)|0)==3){while(1){B=(t+1018|0)+b|0,C=pg(a),h[B|0]=C;b=b+1|0;if((b|0)!=6){continue}break}if(!Ev(t+1018|0)){Nb(a,20);break c}d=Bv(a);c=Ad(a,d+1|0);j[a+20>>2]=c;if(c){b=0;e=0;if((d|0)>0){while(1){c=pg(a);h[j[a+20>>2]+b|0]=c;b=b+1|0;if((d|0)!=(b|0)){continue}break}c=j[a+20>>2]}h[c+d|0]=0;b=Bv(a);j[a+24>>2]=b;b=Ad(a,b<<2);j[a+28>>2]=b;if(b){e:{if(j[a+24>>2]>0){while(1){d=Bv(a);b=Ad(a,d+1|0);f=e<<2;j[f+j[a+28>>2]>>2]=b;c=j[f+j[a+28>>2]>>2];if(!c){break e}b=0;if((d|0)>0){while(1){c=pg(a);h[j[f+j[a+28>>2]>>2]+b|0]=c;b=b+1|0;if((d|0)!=(b|0)){continue}break}c=j[f+j[a+28>>2]>>2]}h[c+d|0]=0;e=e+1|0;if((e|0)<j[a+24>>2]){continue}break}}if(!(pg(a)&1)){Nb(a,20);break c}RE(a,k[a+1376|0]);h[a+1376|0]=0;while(1){b=Cv(a);RE(a,b);h[a+1376|0]=0;if(b){continue}break}b=0;if(!Dv(a)){break a}if(!SE(a)){if(j[a+100>>2]!=21){break a}j[a+100>>2]=20;break a}o5();if((pg(a)|0)==5){while(1){B=(t+1018|0)+b|0,C=pg(a),h[B|0]=C;b=b+1|0;if((b|0)!=6){continue}break}if(!Ev(t+1018|0)){Nb(a,20);break c}b=Tb(a,8)+1|0;j[a+120>>2]=b;b=Ad(a,p(b,2096));j[a+124>>2]=b;if(!b){Nb(a,3);break c}Ab(b,0,p(j[a+120>>2],2096));f:{g:{if(j[a+120>>2]>=1){while(1){b=j[a+124>>2];if((Tb(a,8)&255)!=66){Nb(a,20);break c}if((Tb(a,8)&255)!=67){Nb(a,20);break c}if((Tb(a,8)&255)!=86){Nb(a,20);break c}d=b+p(v,2096)|0;B=d,C=Tb(a,8)&255|Tb(a,8)<<8,j[B>>2]=C;b=Tb(a,8);B=d,C=Tb(a,8)<<8&65280|b&255|Tb(a,8)<<16,j[B+4>>2]=C;b=0;r=d+4|0;f=Tb(a,1);if(!f){b=Tb(a,1)}h[d+23|0]=b;if(!(j[d>>2]|!j[r>>2])){Nb(a,20);break c}e=j[r>>2];h:{if(b&255){c=im(a,e);break h}c=Ad(a,e);j[d+8>>2]=c}if(!c){Nb(a,3);break c}i:{if(!f){b=0;s=0;e=j[r>>2];if((e|0)<=0){break i}while(1){j:{k:{if(k[d+23|0]){if(!Tb(a,1)){break k}}e=Tb(a,5)+1|0;h[b+c|0]=e;if((e&255)!=32){s=s+1|0;break j}Nb(a,20);break c}h[b+c|0]=255}b=b+1|0;e=j[r>>2];if((b|0)<(e|0)){continue}break}break i}g=Tb(a,5);s=0;b=0;e=j[r>>2];if((e|0)<1){break i}while(1){f=Tb(a,Nk(e-b|0));g=g+1|0;if((g|0)>=32){Nb(a,20);break c}e=b+f|0;if((e|0)>j[r>>2]){Nb(a,20);break c}Ab(b+c|0,g,f);b=e;e=j[r>>2];if((b|0)<(e|0)){continue}break}}l:{m:{if(k[d+23|0]){if(e>>2>(s|0)){break m}b=d;f=a;if(j[a+16>>2]<(e|0)){j[a+16>>2]=e;e=j[r>>2]}g=b;b=Ad(f,e);j[g+8>>2]=b;if(!b){Nb(a,3);break c}Vb(b,c,j[r>>2]);Nh(a,c,j[r>>2]);c=j[d+8>>2];h[d+23|0]=0}g=0;b=0;e=0;f=j[r>>2];if((f|0)>=1){while(1){e=((k[b+c|0]-11&255)>>>0<244)+e|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}}j[d+2092>>2]=e;b=Ad(a,f<<2);j[d+32>>2]=b;if(b){e=d+2092|0;break l}Nb(a,3);break c}j[d+2092>>2]=s;e=d+2092|0;n:{if(!s){g=0;break n}b=Ad(a,s);j[d+8>>2]=b;if(!b){Nb(a,3);break c}b=im(a,j[e>>2]<<2);j[d+32>>2]=b;if(!b){Nb(a,3);break c}g=im(a,j[e>>2]<<2);if(g){break n}Nb(a,3);break c}b=j[r>>2]+(j[e>>2]<<3)|0;if(b>>>0<=m[a+16>>2]){break l}j[a+16>>2]=b}if(!n5(d,c,j[r>>2],g)){if(k[d+23|0]){Nh(a,g,0)}Nb(a,20);break c}b=j[e>>2];if(b){b=Ad(a,(b<<2)+4|0);j[d+2084>>2]=b;if(!b){Nb(a,3);break c}b=Ad(a,(j[e>>2]<<2)+4|0);j[d+2088>>2]=b;if(!b){Nb(a,3);break c}j[d+2088>>2]=b+4;j[b>>2]=-1;m5(d,c,g)}if(k[d+23|0]){Nh(a,g,j[e>>2]<<2);Nh(a,j[d+32>>2],j[e>>2]<<2);Nh(a,c,j[r>>2]);j[d+32>>2]=0}l5(d);b=Tb(a,4);h[d+21|0]=b;b=b&255;if(b>>>0>=3){Nb(a,20);break c}if(b){B=d,D=QE(Tb(a,32)),n[B+12>>2]=D;B=d,D=QE(Tb(a,32)),n[B+16>>2]=D;B=d,C=Tb(a,4)+1|0,h[B+20|0]=C;B=d,C=Tb(a,1),h[B+22|0]=C;b=j[d>>2];c=j[r>>2];o:{if(k[d+21|0]==1){b=k5(c,b);if((b|0)>-1){break o}Nb(a,20);break c}b=p(b,c)}j[d+24>>2]=b;if(!b){Nb(a,20);break c}c=im(a,b<<1);if(!c){break g}b=0;g=j[d+24>>2];if((g|0)>0){while(1){f=Tb(a,k[d+20|0]);if((f|0)==-1){Nh(a,c,j[d+24>>2]<<1);Nb(a,20);break c}i[c+(b<<1)>>1]=f;b=b+1|0;g=j[d+24>>2];if((b|0)<(g|0)){continue}break}}p:{if(k[d+21|0]==1){s=k[d+23|0];q:{if(s){b=j[e>>2];if(b){break q}break p}b=j[r>>2]}b=Ad(a,p(j[d>>2],b)<<2);j[d+28>>2]=b;if(!b){Nh(a,c,j[d+24>>2]<<1);Nb(a,3);break c}y=j[(s?e:r)>>2];if((y|0)>=1){A=d+2088|0;w=q(0);f=0;while(1){e=f;e=s?j[j[A>>2]+(e<<2)>>2]:e;b=1;r=0;r:{g=j[d>>2];if((g|0)<1){break r}while(1){x=q(q(n[d+12>>2]+w)+q(n[d+16>>2]*q(l[c+(((e>>>0)/(b>>>0)>>>0)%m[d+24>>2]<<1)>>1])));n[j[d+28>>2]+(p(f,g)+r<<2)>>2]=x;w=k[d+22|0]?x:w;g=j[d>>2];r=r+1|0;if((g|0)<=(r|0)){break r}u=j[d+24>>2];OMa(u,0,b,0);if(!ab){b=p(b,u);continue}else{Nh(a,c,u<<1);Nb(a,20);break c}}}f=f+1|0;if((y|0)!=(f|0)){continue}break}}h[d+21|0]=2;g=j[d+24>>2];break p}b=Ad(a,g<<2);j[d+28>>2]=b;g=j[d+24>>2];if(!b){break f}if((g|0)<1){break p}w=q(n[d+12>>2]+q(n[d+16>>2]*q(l[c>>1])));n[b>>2]=w;b=1;g=j[d+24>>2];if((g|0)<=1){break p}x=q(0);while(1){x=k[d+22|0]?w:x;w=q(q(n[d+12>>2]+x)+q(n[d+16>>2]*q(l[c+(b<<1)>>1])));n[j[d+28>>2]+(b<<2)>>2]=w;b=b+1|0;g=j[d+24>>2];if((b|0)<(g|0)){continue}break}}Nh(a,c,g<<1)}v=v+1|0;if((v|0)<j[a+120>>2]){continue}break}}s:{b=Tb(a,6)+1&255;if(!b){break s}while(1){if(!Tb(a,16)){o=o+1|0;if((b|0)!=(o|0)){continue}break s}break}Nb(a,20);break c}b=Tb(a,6)+1|0;j[a+128>>2]=b;b=Ad(a,p(b,1596));j[a+260>>2]=b;t:{if(b){if(j[a+128>>2]>=1){break t}e=0;break d}Nb(a,3);break c}s=0;f=0;u:while(1){b=Tb(a,16);i[((s<<1)+a|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){Nb(a,20);break c}if(!b){e=j[a+260>>2]+p(s,1596)|0;B=e,C=Tb(a,8),h[B|0]=C;B=e,C=Tb(a,16),i[B+2>>1]=C;B=e,C=Tb(a,16),i[B+4>>1]=C;B=e,C=Tb(a,6),h[B+6|0]=C;B=e,C=Tb(a,8),h[B+7|0]=C;b=(Tb(a,4)&255)+1|0;h[e+8|0]=b;if((b|0)==(b&255)){c=e+9|0;b=0;while(1){B=b+c|0,C=Tb(a,8),h[B|0]=C;b=b+1|0;if(b>>>0<k[e+8|0]){continue}break}}Nb(a,4);break c}d=j[a+260>>2]+p(s,1596)|0;o=Tb(a,5);h[d|0]=o;b=-1;e=0;c=0;if(o&255){while(1){o=Tb(a,4);h[(c+d|0)+1|0]=o;o=o&255;b=(b|0)<(o|0)?o:b;c=c+1|0;if(c>>>0<k[d|0]){continue}break}while(1){o=d+e|0;B=o,C=Tb(a,3)+1|0,h[B+33|0]=C;c=Tb(a,2);h[o+49|0]=c;v:{if(c&255){c=Tb(a,8);h[o+65|0]=c;if(j[a+120>>2]<=(c&255)){Nb(a,20);break c}if(k[o+49|0]==31){break v}}c=0;while(1){w:{g=Tb(a,8)-1|0;i[((d+(e<<4)|0)+(c<<1)|0)+82>>1]=g;if(j[a+120>>2]<=g<<16>>16){break w}c=c+1|0;if((c|0)<1<<k[o+49|0]){continue}break v}break}Nb(a,20);break c}c=(b|0)!=(e|0);e=e+1|0;if(c){continue}break}}r=2;B=d,C=Tb(a,2)+1|0,h[B+1588|0]=C;b=Tb(a,4);j[d+1592>>2]=2;g=0;i[d+338>>1]=0;h[d+1589|0]=b;i[d+340>>1]=1<<b;b=d+1592|0;o=k[d|0];x:{if(o){e=d+1589|0;while(1){c=0;v=d+k[(d+g|0)+1|0]|0;if(k[v+33|0]){while(1){o=Tb(a,k[e|0]);i[(d+(j[b>>2]<<1)|0)+338>>1]=o;r=j[b>>2]+1|0;j[b>>2]=r;c=c+1|0;if(c>>>0<k[v+33|0]){continue}break}o=k[d|0]}g=g+1|0;if(g>>>0<(o&255)>>>0){continue}break}if((r|0)<1){break x}}c=0;while(1){e=l[(d+(c<<1)|0)+338>>1];o=(t+16|0)+(c<<2)|0;i[o+2>>1]=c;i[o>>1]=e;c=c+1|0;r=j[b>>2];if((c|0)<(r|0)){continue}break}}e=d+338|0;sE(t+16|0,r,2293);c=0;r=j[b>>2];o=r-1|0;o=(o|0)>0?o:0;while(1){if((c|0)==(o|0)){c=0;y:{if((r|0)<=0){break y}while(1){h[(c+d|0)+838|0]=k[((t+16|0)+(c<<2)|0)+2|0];c=c+1|0;r=j[b>>2];if((c|0)<(r|0)){continue}break}c=2;if((r|0)<=2){break y}while(1){j[t+12>>2]=0;j[t+8>>2]=0;i5(e,c,t+12|0,t+8|0);o=d+(c<<1)|0;h[o+1088|0]=j[t+12>>2];h[o+1089|0]=j[t+8>>2];c=c+1|0;r=j[b>>2];if((c|0)<(r|0)){continue}break}}f=(f|0)<(r|0)?r:f;s=s+1|0;if((s|0)<j[a+128>>2]){continue u}e=f<<1;break d}g=l[(t+16|0)+(c<<2)>>1];c=c+1|0;if((g|0)!=l[(t+16|0)+(c<<2)>>1]){continue}break}break}Nb(a,20);break c}Nb(a,3);break c}Nh(a,c,g<<1);Nb(a,3);break c}Nb(a,20);break c}Nb(a,3);break c}Nb(a,3);break c}Nb(a,3);break c}Nb(a,20);break c}b=Tb(a,6)+1|0;j[a+264>>2]=b;b=Ad(a,p(b,24));j[a+396>>2]=b;if(!b){Nb(a,3);break c}r=0;Ab(b,0,p(j[a+264>>2],24));z:{if(j[a+264>>2]>=1){while(1){b=j[a+396>>2];c=Tb(a,16);i[((r<<1)+a|0)+268>>1]=c;if((c&65535)>>>0>=3){Nb(a,20);break c}f=b+p(r,24)|0;B=f,C=Tb(a,24),j[B>>2]=C;b=Tb(a,24);j[f+4>>2]=b;if(b>>>0<m[f>>2]){Nb(a,20);break c}B=f,C=Tb(a,24)+1|0,j[B+8>>2]=C;B=f,C=Tb(a,6)+1|0,h[B+12|0]=C;b=Tb(a,8);h[f+13|0]=b;A:{B:{if(j[a+120>>2]>(b&255)){b=0;if(k[f+12|0]){break B}c=0;break A}Nb(a,20);break c}while(1){d=(t+16|0)+b|0;o=Tb(a,3);if(Tb(a,1)){c=Tb(a,5)}else{c=0}h[d|0]=o+(c<<3);b=b+1|0;c=k[f+12|0];if(b>>>0<c>>>0){continue}break}}b=Ad(a,c<<4);j[f+20>>2]=b;if(!b){break z}if(k[f+12|0]){g=0;while(1){c=k[(t+16|0)+g|0];b=0;while(1){C:{if(c>>>b&1){d=Tb(a,8);s=b<<1;o=g<<4;i[s+(o+j[f+20>>2]|0)>>1]=d;if(j[a+120>>2]>i[s+(o+j[f+20>>2]|0)>>1]){break C}Nb(a,20);break c}i[(j[f+20>>2]+(g<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}g=g+1|0;if(g>>>0<k[f+12|0]){continue}break}}b=Ad(a,j[(j[a+124>>2]+p(k[f+13|0],2096)|0)+4>>2]<<2);j[f+16>>2]=b;if(!b){Nb(a,3);break c}o=0;Ab(b,0,j[(j[a+124>>2]+p(k[f+13|0],2096)|0)+4>>2]<<2);b=j[a+124>>2];c=k[f+13|0];if(j[(b+p(c,2096)|0)+4>>2]>0){while(1){d=j[p(c,2096)+b>>2];b=Ad(a,d);g=o<<2;j[g+j[f+16>>2]>>2]=b;D:{c=j[g+j[f+16>>2]>>2];if(c){if((d|0)<1){break D}b=d-1|0;h[c+b|0]=(o>>>0)%k[f+12|0];c=o;if((d|0)==1){break D}while(1){d=b-1|0;s=k[f+12|0];c=(c|0)/(s|0)|0;h[d+j[g+j[f+16>>2]>>2]|0]=(c|0)%(s|0);s=(b|0)>1;b=d;if(s){continue}break}break D}Nb(a,3);break c}o=o+1|0;b=j[a+124>>2];c=k[f+13|0];if((o|0)<j[(b+p(c,2096)|0)+4>>2]){continue}break}}r=r+1|0;if((r|0)<j[a+264>>2]){continue}break}}b=Tb(a,6)+1|0;j[a+400>>2]=b;b=Ad(a,p(b,40));j[a+404>>2]=b;if(!b){Nb(a,3);break c}g=0;Ab(b,0,p(j[a+400>>2],40));if(j[a+400>>2]>=1){while(1){b=j[a+404>>2];if(Tb(a,16)){Nb(a,20);break c}d=b+p(g,40)|0;b=Ad(a,p(j[a+4>>2],3));j[d+4>>2]=b;if(!b){Nb(a,3);break c}b=d;if(Tb(a,1)){c=Tb(a,4)+1|0}else{c=1}h[b+8|0]=c;E:{if(Tb(a,1)){b=Tb(a,8)+1|0;i[d>>1]=b;F:{c=j[a+4>>2];b=b&65535;if((c|0)>=(b|0)){f=0;if(b){break F}break E}Nb(a,20);break c}while(1){c=Tb(a,Nk(c-1|0));b=p(f,3);h[b+j[d+4>>2]|0]=c;c=Tb(a,Nk(j[a+4>>2]-1|0));h[(b+j[d+4>>2]|0)+1|0]=c;c=j[a+4>>2];b=b+j[d+4>>2]|0;o=k[b|0];if((c|0)<=(o|0)){Nb(a,20);break c}b=k[b+1|0];if((b|0)>=(c|0)){Nb(a,20);break c}if((b|0)!=(o|0)){f=f+1|0;if(f>>>0>=l[d>>1]){break E}continue}break}Nb(a,20);break c}i[d>>1]=0}if(Tb(a,2)){Nb(a,20);break c}f=j[a+4>>2];G:{H:{b=k[d+8|0];if(b>>>0<=1){c=0;if((f|0)>0){while(1){h[(j[d+4>>2]+p(c,3)|0)+2|0]=0;c=c+1|0;if((c|0)<j[a+4>>2]){continue}break}b=k[d+8|0]}if(!(b&255)){break G}break H}c=0;if((f|0)<=0){break H}while(1){I:{b=Tb(a,4);f=p(c,3);h[(f+j[d+4>>2]|0)+2|0]=b;if(k[(f+j[d+4>>2]|0)+2|0]>=k[d+8|0]){break I}c=c+1|0;if((c|0)<j[a+4>>2]){continue}break H}break}Nb(a,20);break c}b=0;while(1){Tb(a,8);f=b+d|0;c=f;B=c,C=Tb(a,8),h[B+9|0]=C;f=Tb(a,8);h[c+24|0]=f;if(j[a+128>>2]<=k[c+9|0]){Nb(a,20);break c}if(j[a+264>>2]>(f&255)){b=b+1|0;if(b>>>0>=k[d+8|0]){break G}continue}break}Nb(a,20);break c}g=g+1|0;if((g|0)<j[a+400>>2]){continue}break}}b=Tb(a,6)+1|0;j[a+408>>2]=b;c=0;J:{if((b|0)<=0){break J}while(1){b=p(c,6)+a|0;B=b,C=Tb(a,1),h[B+412|0]=C;B=b,C=Tb(a,16),i[B+414>>1]=C;B=b,C=Tb(a,16),i[B+416>>1]=C;d=Tb(a,8);h[b+413|0]=d;if(l[b+414>>1]){Nb(a,20);break c}if(l[b+416>>1]){Nb(a,20);break c}if(j[a+400>>2]>(d&255)){c=c+1|0;if((c|0)>=j[a+408>>2]){break J}continue}break}Nb(a,20);break c}OE(a);b=0;j[a+992>>2]=0;if(j[a+4>>2]>=1){while(1){c=(b<<2)+a|0;B=c,C=Ad(a,j[a+116>>2]<<2),j[B+800>>2]=C;B=c,C=Ad(a,j[a+116>>2]<<1&2147483646),j[B+928>>2]=C;d=Ad(a,e);j[c+996>>2]=d;f=j[c+800>>2];if(!(j[c+928>>2]?!(!f|!d):0)){Nb(a,3);break c}Ab(f,0,j[a+116>>2]<<2);b=b+1|0;if((b|0)<j[a+4>>2]){continue}break}}b=0;if(!NE(a,0,j[a+112>>2])){break a}if(!NE(a,1,j[a+116>>2])){break a}j[a+104>>2]=j[a+112>>2];c=j[a+116>>2];j[a+108>>2]=c;g=a;o=c<<1&2147483646;y=o;s=j[a+264>>2];d=4;K:{if((s|0)<1){break K}c=(c|0)/2|0;v=j[a+396>>2];r=0;f=0;while(1){d=v+p(f,24)|0;u=j[d+4>>2];e=c>>>0>u>>>0?u:c;u=j[d>>2];d=(e-(c>>>0>u>>>0?u:c)>>>0)/m[d+8>>2]|0;r=(d|0)>(r|0)?d:r;f=f+1|0;if((s|0)!=(f|0)){continue}break}d=(r<<2)+4|0}e=p(d,j[a+4>>2]);e=e>>>0<o>>>0?y:e;j[g+12>>2]=e;L:{M:{if(!j[a+80>>2]){break M}c=j[a+92>>2];if((c|0)!=j[a+84>>2]){break L}if(c>>>0>=(e+j[a+88>>2]|0)+1512>>>0){break M}Nb(a,3);break a}if(j[a+1380>>2]==-1){j[a+52>>2]=k[a+48|0]?0:j[a+32>>2]-j[a+36>>2]|0;b=1;break a}j[a+52>>2]=0;b=1;break a}X(51940,50496,4177,51996);z()}Nb(a,3)}b=0}Za=t+1024|0;return b}function qya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,J=0,L=0,M=0,O=0,P=0,Q=0;d=Za-304|0;Za=d;rc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!xs(b,d+208|0)){break h}if(!fN(d+208|0)){break h}if(!yb(b,Wc(eN(d+208|0),ab))){break h}if(!c){A=1;break h}od(a,2);j[a+480260>>2]=64;j[a+480264>>2]=32767;r=Qc(d+192|0);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{n=d+248|0;switch(((k[n|0]|k[n+1|0]<<8)&61440)-4096>>>12|0){case 6:break q;case 5:break r;case 4:break s;case 3:break t;case 2:break u;case 1:break v;case 0:break w;default:break p}}x:{if(k[d+270|0]|k[d+271|0]<<8|(k[n|0]|k[n+1|0]<<8)!=4896|(k[d+260|0]|k[d+240|0]&15)){break x}if((k[d+246|0]|k[d+247|0]<<8)&65455){break x}j[a+1074304>>2]=18219008;j[114626]=0;e=E(2,d+32|0,17034)|0;g=j[114626];j[114626]=0;m=1;if((g|0)==1){break o}ob(r,e);gb(e);j[114626]=0;K(478,a+1074308|0,81,1)|0;g=j[114626];j[114626]=0;e=1;if((g|0)!=1){break i}break b}y:{if(k[d+270|0]|k[d+271|0]<<8|(k[n|0]|k[n+1|0]<<8)!=4896|(k[d+260|0]|(k[d+246|0]|k[d+247|0]<<8))){break y}if(k[d+261|0]){break y}j[114626]=0;g=E(2,d+32|0,17060)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break j}f=D()|0;C()|0;break a}j[114626]=0;g=E(2,d+32|0,17074)|0;o=j[114626];j[114626]=0;f=1;if((o|0)!=1){ob(r,g);gb(g);break k}f=D()|0;C()|0;break a}j[114626]=0;g=E(2,d+32|0,17089)|0;o=j[114626];j[114626]=0;e=1;if((o|0)!=1){ob(r,g);gb(g);break k}f=D()|0;C()|0;break a}z:{A:{B:{C:{D:{s=k[n|0]|k[n+1|0]<<8;E:{if(s>>>0<=12820){j[114626]=0;g=E(2,d+32|0,17103)|0;e=j[114626];j[114626]=0;if((e|0)!=1){ob(r,g);break E}f=D()|0;C()|0;break a}j[114626]=0;g=E(2,d+160|0,17119)|0;e=j[114626];j[114626]=0;if((e|0)==1){break D}j[114626]=0;F(219,d+176|0,g|0);e=j[114626];j[114626]=0;if((e|0)==1){break C}e=k[n|0]|k[n+1|0]<<8;j[114626]=0;j[d+128>>2]=e-12820;I(245,d+32|0,d+176|0,d+128|0);e=j[114626];j[114626]=0;if((e|0)==1){break B}ob(r,d+32|0);gb(d+32|0);qb(d+176|0)}gb(g);if((k[n|0]|k[n+1|0]<<8)>>>0<12807){break l}if(k[d+264|0]|k[d+265|0]<<8|(k[d+266|0]<<16|k[d+267|0]<<24)){break z}break l}f=D()|0;C()|0;break a}f=D()|0;C()|0;break A}f=D()|0;C()|0;qb(d+176|0)}gb(g);break a}e=k[n|0]|k[n+1|0]<<8;g=k[d+264|0]|k[d+265|0]<<8|(k[d+266|0]<<16|k[d+267|0]<<24);j[114626]=0;e=E(662,e|0,g|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break n}g=pp(d+32|0);j[g+44>>2]=e;j[114626]=0;F(663,a+1304500|0,g|0);e=j[114626];j[114626]=0;if((e|0)!=1){break l}f=D()|0;C()|0;break a}f=k[n|0]|k[n+1|0]<<8;F:{if((f|0)==16640){j[114626]=0;e=E(2,d+32|0,17143)|0;g=j[114626];j[114626]=0;if((g|0)!=1){ob(r,e);gb(e);j[114626]=0;K(478,a+1074308|0,81,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break b}break F}f=D()|0;C()|0;break a}e=k[n|0]|k[n+1|0]<<8;g=k[d+262|0]|k[d+263|0]<<8;j[114626]=0;I(664,d+32|0,e|0,g|0);e=j[114626];j[114626]=0;if((e|0)==1){break m}ob(r,d+32|0);gb(d+32|0);j[a+480260>>2]=1}o=(f|0)!=16640;e=1;f=0;break i}j[114626]=0;f=E(2,d+32|0,17155)|0;g=j[114626];j[114626]=0;if((g|0)!=1){ob(r,f);gb(f);j[a+1074304>>2]=((k[n|0]|k[n+1|0]<<8)&4095)<<16;f=0;break k}f=D()|0;C()|0;break a}j[114626]=0;e=E(2,d+32|0,17143)|0;g=j[114626];j[114626]=0;if((g|0)!=1){ob(r,e);gb(e);j[114626]=0;K(478,a+1074308|0,81,1)|0;g=j[114626];j[114626]=0;e=0;if((g|0)==1){break b}break i}f=D()|0;C()|0;break a}j[114626]=0;g=E(2,d+32|0,17163)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break j}f=D()|0;C()|0;break a}if((k[n|0]|k[n+1|0]<<8)!=51712){break i}j[114626]=0;g=E(2,d+32|0,17176)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break j}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}j[114626]=0;e=1;K(478,a+1074308|0,107,1)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}j[a+480260>>2]=1;if(s>>>0>12820){break i}}j[114626]=0;g=E(2,d+144|0,17183)|0;o=j[114626];j[114626]=0;G:{H:{I:{J:{K:{if((o|0)!=1){j[114626]=0;F(219,d+176|0,g|0);o=j[114626];j[114626]=0;if((o|0)==1){break K}j[d+16>>2]=k[n+1|0]&15;o=k[n|0];j[114626]=0;j[d>>2]=o;F(661,d+128|0,d|0);o=j[114626];j[114626]=0;if((o|0)==1){break J}j[114626]=0;V(992,d+32|0,d+176|0,r|0,d+16|0,d+128|0);o=j[114626];j[114626]=0;if((o|0)==1){break I}ob(r,d+32|0);gb(d+32|0);gb(d+128|0);qb(d+176|0);gb(g);o=0;break i}f=D()|0;C()|0;break a}f=D()|0;C()|0;break G}f=D()|0;C()|0;break H}f=D()|0;C()|0;gb(d+128|0)}qb(d+176|0)}gb(g);break a}ob(r,g);gb(g);e=0}j[114626]=0;g=E(2,d+32|0,17192)|0;s=j[114626];j[114626]=0;L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((s|0)!=1){ob(a+1304436|0,g);gb(g);j[114626]=0;g=E(2,d+32|0,17208)|0;s=j[114626];j[114626]=0;if((s|0)==1){break Z}ob(a+1304448|0,g);gb(g);ob(a+1304460|0,r);j[a+1304496>>2]=j[a+1074304>>2]?7:4;if(e){j[114626]=0;e=a+1074308|0;E(479,e|0,77)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}j[114626]=0;E(479,e|0,78)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}j[114626]=0;E(479,e|0,79)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}j[114626]=0;E(479,e|0,80)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}j[114626]=0;E(479,e|0,82)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}j[114626]=0;E(479,e|0,96)|0;e=j[114626];j[114626]=0;if((e|0)==1){break b}}m=((k[n|0]|k[n+1|0]<<8)&61440)>>>0<4097|((k[n|0]|k[n+1|0]<<8)>>>0<12820?((k[n|0]|k[n+1|0]<<8)&61440)==12288:0)?m:1;j[114626]=0;e=a+901404|0;N(993,e|0);g=j[114626];j[114626]=0;if((g|0)==1){break b}if(!m){j[114626]=0;N(635,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break b}}j[114626]=0;I(577,d+176|0,1,d+208|0);e=j[114626];j[114626]=0;if((e|0)==1){break Y}j[114626]=0;F(415,d+32|0,d+176|0);e=j[114626];j[114626]=0;if((e|0)==1){break Y}ob(a+1304400|0,d+32|0);gb(d+32|0);if(k[d+246|0]&16){j[a+480208>>2]=j[a+480208>>2]|65536}if(h[d+246|0]&1){j[a+480208>>2]=j[a+480208>>2]|131072}if(!(k[d+246|0]&64?0:(k[n|0]|k[n+1|0]<<8)!=4864)){j[a+480208>>2]=j[a+480208>>2]|2}e=k[d+257|0];j[a+480196>>2]=e;_:{$:{if(e){if((e|0)!=255){break $}e=0;if(!f){break _}}j[a+480196>>2]=6}e=f}j[a+480204>>2]=p(k[d+258|0],1e4);if(k[d+258|0]<=32){j[a+480204>>2]=e?125e4:32e4}f=k[d+256|0];j[114626]=0;h[d+32|0]=f;h[d+176|0]=64;f=E(391,d+32|0,d+176|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break U}f=k[f|0];j[a+480200>>2]=f<<2;if(!((k[n|0]|k[n+1|0]<<8)>>>0>4895|f)){j[a+480200>>2]=256}if((k[d+250|0]|k[d+251|0]<<8)!=1|k[d+259|0]>7){break W}f=k[d+259|0];j[114626]=0;j[d+32>>2]=(f<<4)+16;j[d+176>>2]=127;f=E(462,d+32|0,d+176|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break X}j[a+480228>>2]=j[f>>2];break V}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}if(!(k[d+259|0]!=18?k[d+259|0]!=2:0)){j[a+480228>>2]=32;break V}f=k[d+259|0];j[114626]=0;j[d+32>>2]=f&127;j[d+176>>2]=16;f=E(552,d+32|0,d+176|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break T}j[a+480228>>2]=j[f>>2]}j[a+480232>>2]=36;if(!(!o|(k[n|0]|k[n+1|0]<<8)>>>0>=19763)){j[a+480232>>2]=64}i[a+480188>>1]=4;o=Ys(d+120|0);f=0;while(1){j[114626]=0;g=(f<<5)+a|0;q=g+480280|0;N(432,q|0);m=j[114626];j[114626]=0;if((m|0)==1){break S}m=d+f|0;s=k[m+272|0];if(k[m+272|0]!=255){i[a+480188>>1]=f+1;i[g+480284>>1]=s&8?204:51}if(h[m+272|0]<=-1){j[q>>2]=1024}if(((s&127)-16&255)>>>0<=13){i[g+480284>>1]=128;rj(d+32|0,o,f);Qd(d+32|0,1)}f=f+1|0;if((f|0)!=32){continue}break}if(!l[a+480188>>1]){i[a+480188>>1]=1}f=Fb(a+484360|0);g=k[d+240|0]|k[d+241|0]<<8;j[114626]=0;U(581,f|0,b|0,g|0,255,254)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}x=yt(d+176|0);f=k[d+242|0]|k[d+243|0]<<8;j[114626]=0;K(393,b|0,x|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}s=yt(d+128|0);f=k[d+244|0]|k[d+245|0]<<8;j[114626]=0;K(393,b|0,s|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){if(k[d+261|0]==252){f=0;j[114626]=0;E(994,b|0,d+32|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break g}while(1){m=(d+32|0)+f|0;g=k[m|0];aa:{if(!(g&32)){break aa}q=((f<<5)+a|0)+480284|0;if(e){rj(d+16|0,o,f);if(kb(d+16|0)){break aa}g=k[m|0]}i[q>>1]=(((g&15)<<8|8)>>>0)/15}f=f+1|0;if((f|0)!=32){continue}break}}e=k[d+242|0]|k[d+243|0]<<8;j[114626]=0;i[d+32>>1]=e;i[d+16>>1]=3999;e=E(477,d+32|0,d+16|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break R}e=l[e>>1];i[a+480190>>1]=e;if(e){e=c&2;g=d+45|0;o=d+80|0;f=0;while(1){m=ac(x,f);m=k[m|0]|k[m+1|0]<<8;j[114626]=0;m=E(256,b|0,m<<4)|0;q=j[114626];j[114626]=0;if((q|0)==1){break Q}ba:{if(!m){break ba}j[114626]=0;m=E(995,b|0,d+32|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break Q}if(!m){break ba}j[114626]=0;m=f+1|0;q=(p(m,104)+a|0)+484380|0;F(996,d+32|0,q|0);t=j[114626];j[114626]=0;if((t|0)==1){break Q}j[114626]=0;I(577,d|0,1,o|0);t=j[114626];j[114626]=0;ca:{da:{ea:{if((t|0)==1){break ea}j[114626]=0;F(415,d+16|0,d|0);t=j[114626];j[114626]=0;if((t|0)==1){break ea}j[114626]=0;E(369,((m<<5)+a|0)+946300|0,d+16|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break da}gb(d+16|0);if(!(k[d+48|0]|k[d+49|0]<<8|(k[d+50|0]<<16|k[d+51|0]<<24))|(!e|k[d+32|0]>1)){break ba}m=k[d+46|0];t=k[d+47|0];w=k[g|0];j[114626]=0;m=E(256,b|0,t<<12|m<<4|w<<20)|0;t=j[114626];j[114626]=0;if((t|0)==1){break ca}if(!m){break ba}m=k[d+250|0]|k[d+251|0]<<8;j[114626]=0;I(997,d+16|0,d+32|0,(m|0)==1|0);m=j[114626];j[114626]=0;if((m|0)!=1){j[114626]=0;K(400,d+16|0,q|0,b|0)|0;m=j[114626];j[114626]=0;if((m|0)!=1){break ba}}f=D()|0;C()|0;break f}f=D()|0;C()|0;break f}f=D()|0;C()|0;gb(d+16|0);break f}f=D()|0;C()|0;break f}f=f+1|0;if(f>>>0<l[a+480190>>1]){continue}break}}A=1;if(!(c&1)){break L}c=k[n|0]|k[n+1|0]<<8;e=k[d+244|0]|k[d+245|0]<<8;j[114626]=0;i[d+32>>1]=e;i[d+16>>1]=255;e=E(477,d+32|0,d+16|0)|0;f=j[114626];j[114626]=0;fa:{ga:{if((f|0)!=1){y=l[e>>1];j[114626]=0;q=a+484344|0;F(401,q|0,y|0);e=j[114626];j[114626]=0;if((e|0)==1){break ga}B=c>>>0<4896;if(y){break fa}t=0;w=0;break M}f=D()|0;C()|0;break f}f=D()|0;C()|0;break f}M=d+32|5;O=d+32|3;J=d+32|4;P=d+32|2;Q=d+32|1;o=0;w=0;t=0;while(1){j[114626]=0;c=K(402,q|0,o&65535,64)|0;e=j[114626];j[114626]=0;if((e|0)==1){break P}ha:{if(!c){break ha}c=ac(s,o);if(!(k[c|0]|k[c+1|0]<<8)){break ha}c=ac(s,o);c=k[c|0]|k[c+1|0]<<8;j[114626]=0;c=E(256,b|0,c<<4)|0;e=j[114626];j[114626]=0;if((e|0)==1){break P}if(!c){break ha}j[114626]=0;E(338,b|0,2)|0;c=j[114626];j[114626]=0;if((c|0)==1){break P}f=0;c=Ib(q,o);j[114626]=0;g=E(496,c|0,0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break O}while(1){j[114626]=0;v=H(387,b|0)|0;c=j[114626];j[114626]=0;ia:{ja:{if((c|0)!=1){if(v){break ja}if(f>>>0>62){break ha}c=Ib(q,o);j[114626]=0;f=f+1|0;g=E(496,c|0,f|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break ia}}f=D()|0;C()|0;break f}Ug(d+32|0);e=v&31;c=p(e,6)+g|0;m=e>>>0<l[a+480188>>1];L=m?c:d+32|0;if(v&32){j[114626]=0;F(472,d+16|0,b|0);e=j[114626];j[114626]=0;ka:{la:{ma:{if((e|0)!=1){u=Pc(d+16|0);e=k[d+16|0];if(e>>>0>239){break ma}e=(p(e>>>4|0,12)+(e&15)|0)+13|0;break la}f=D()|0;C()|0;break f}na:{switch(e-254|0){case 0:break la;case 1:break na;default:break ka}}e=0}h[L|0]=e}h[(m?c+1|0:Q)|0]=k[u|0]}oa:{if(!(v&64)){break oa}j[114626]=0;e=H(387,b|0)|0;u=j[114626];j[114626]=0;pa:{if((u|0)!=1){u=m?c+2|0:P;h[d+16|0]=e;if(e<<24>>24>-1|e>>>0>192){break pa}h[u|0]=2;h[(m?c+4|0:J)|0]=k[d+16|0]^128;break oa}f=D()|0;C()|0;break f}h[u|0]=1;j[114626]=0;h[d|0]=64;e=E(391,d+16|0,d|0)|0;u=j[114626];j[114626]=0;if((u|0)==1){break N}h[(m?c+4|0:J)|0]=k[e|0]}if(!(v&128)){break ia}j[114626]=0;F(472,d+16|0,b|0);e=j[114626];j[114626]=0;qa:{if((e|0)!=1){u=Pc(d+16|0);v=m?c+3|0:O;h[v|0]=k[d+16|0];e=m?c+5|0:M;h[e|0]=k[u|0];gy(L,0);ra:{c=k[v|0];if((c|0)==20){if((k[e|0]&240)!=160){break ia}if((k[n|0]|k[n+1|0]<<8)>>>0<4896){break ra}c=k[v|0]}if((c|0)!=31){break ia}c=k[e|0];if(c>>>0<=15){break qa}B=0;break ia}h[e|0]=k[e|0]&15^136;break ia}f=D()|0;C()|0;break f}if(c>>>0<=7){w=w+1|0;break ia}t=((c|0)!=8)+t|0}if(f>>>0<64){continue}break}}o=o+1|0;if((y|0)!=(o|0)){continue}break}break M}f=D()|0;C()|0;break f}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}f=D()|0;C()|0;break a}f=D()|0;C()|0;break f}f=D()|0;C()|0;break f}f=D()|0;C()|0;break f}f=D()|0;C()|0;break f}f=D()|0;C()|0;break f}if(!B){break L}a=l[a+480188>>1];if((a|0)>(t+w|0)|(a|0)<=(t-w|0)){break L}oya(q,me(q)-1&65535)}jk(s);jk(x);gb(r)}Za=d+304|0;return A|0}f=D()|0;C()|0}jk(s);break d}f=D()|0;C()|0}jk(x);break a}f=D()|0;C()|0;break a}f=D()|0;C()|0}gb(r);G(f|0);z()}function YKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=Za-288|0;Za=e;rc(b);a:{if(hS(b,12222)){u=Db(e+272|0);j[114626]=0;f=K(430,b|0,u|0,-1)|0;n=j[114626];j[114626]=0;b:{c:{d:{e:{f:{g:{h:{if((n|0)!=1){if(!f){break b}j[114626]=0;f=E(445,b|0,e+264|0)|0;n=j[114626];j[114626]=0;i:{if((n|0)==1){break i}if(!f){break b}if(!gS(e+264|0)){break b}d=fS(e+264|0);j[114626]=0;d=ig(446,d,ab);f=j[114626];j[114626]=0;if((f|0)==1){break i}j[114626]=0;f=E(258,b|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break i}d=0;if(!f){break b}if(!c){break c}j[114626]=0;F(447,a|0,4096);d=j[114626];j[114626]=0;if((d|0)==1){break i}j[114626]=0;E(448,a+1304400|0,u|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break i}d=k[e+264|2];i[a+480188>>1]=32;i[a+480192>>1]=d;j[114626]=0;F(449,a|0,1);d=j[114626];j[114626]=0;if((d|0)==1){break i}j[114626]=0;d=E(2,e+96|0,12230)|0;f=j[114626];j[114626]=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((f|0)!=1){ob(a+1304436|0,d);gb(d);j[114626]=0;d=E(2,e+96|0,12194)|0;f=j[114626];j[114626]=0;if((f|0)==1){break t}ob(a+1304448|0,d);gb(d);j[114626]=0;d=E(2,e+248|0,12244)|0;f=j[114626];j[114626]=0;if((f|0)==1){break s}j[114626]=0;F(219,e+48|0,d|0);f=j[114626];j[114626]=0;if((f|0)==1){break r}h[e+216|0]=k[e+264|1];f=k[e+264|0];j[114626]=0;h[e+8|0]=f;F(450,e+232|0,e+8|0);f=j[114626];j[114626]=0;if((f|0)==1){break q}j[114626]=0;L(451,e+96|0,e+48|0,e+216|0,e+232|0);f=j[114626];j[114626]=0;if((f|0)==1){break p}ob(a+1304460|0,e+96|0);gb(e+96|0);gb(e+232|0);qb(e+48|0);gb(d);j[a+1304496>>2]=4;if(k[e+264|0]<2){break k}j[114626]=0;i[e+96>>1]=8192;d=H(357,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break m}j[114626]=0;i[e+48>>1]=d;d=E(452,e+96|0,e+48|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break m}j[a+480204>>2]=p(l[d>>1],1e4)>>>8;j[114626]=0;h[e+96|0]=1;d=H(387,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break l}j[114626]=0;h[e+48|0]=d;d=E(453,e+96|0,e+48|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break l}j[a+480196>>2]=k[d|0];j[114626]=0;E(338,b|0,3)|0;d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;d=H(357,b|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){break j}}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;break n}b=D()|0;C()|0;break o}b=D()|0;C()|0;gb(e+232|0)}qb(e+48|0)}gb(d);break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}j[114626]=0;h[e+96|0]=32;d=H(387,b|0)|0;f=j[114626];j[114626]=0;u:{v:{if((f|0)==1){break v}j[114626]=0;h[e+48|0]=d;d=E(453,e+96|0,e+48|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break v}j[a+480204>>2]=p(k[d|0],1e4);j[114626]=0;h[e+96|0]=1;d=H(387,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break u}j[114626]=0;h[e+48|0]=d;d=E(453,e+96|0,e+48|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break u}j[a+480196>>2]=k[d|0];j[114626]=0;d=H(387,b|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){break j}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}j[a+480208>>2]=d>>>2&16|12;t=mn(e+232|0);s=mn(e+216|0);w:{x:{if(!l[a+480192>>1]){break x}n=e+80|1;v=e+96|12;o=1;while(1){j[114626]=0;f=K(454,a|0,o&65535,0)|0;d=j[114626];j[114626]=0;y:{z:{A:{if((d|0)==1){break A}if(!f){break x}j[114626]=0;d=K(431,b|0,f+492|0,-1)|0;m=j[114626];j[114626]=0;if((m|0)==1){break A}if(!d){break x}j[114626]=0;m=H(387,b|0)|0;d=j[114626];j[114626]=0;B:{C:{D:{E:{if((d|0)!=1){Ab(e+96|0,0,120);if(!m){break y}if(k[e+264|0]){j[114626]=0;d=E(455,b|0,e+96|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break E}if(!d){break y}}if(!k[e+264|0]){j[114626]=0;d=K(261,b|0,v|0,96)|0;g=j[114626];j[114626]=0;if((g|0)==1){break E}if(!d){break y}}g=f+236|0;d=0;while(1){r=k[(e+96|0)+d|0];q=l[a+480190>>1];x=Oc(g,d),y=(q+r|0)+1|0,i[x>>1]=y;d=d+1|0;if((d|0)!=120){continue}break}j[114626]=0;d=f+48|0;I(456,e+8|0,d|0,b|0);g=j[114626];j[114626]=0;if((g|0)==1){break D}j[114626]=0;g=f+68|0;I(456,e+32|0,g|0,b|0);r=j[114626];j[114626]=0;if((r|0)==1){break D}j[114626]=0;r=f+88|0;I(456,e+88|0,r|0,b|0);q=j[114626];j[114626]=0;if((q|0)==1){break D}j[114626]=0;E(457,b|0,e+80|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break C}j[f>>2]=(k[n|0]|k[n+1|0]<<8)&4095;f=k[n|0]|k[n+1|0]<<8;Qz(e+80|0,d,0);Qz(e+80|0,g,1);Qz(e+80|0,r,2);x=e,y=Lb(d),j[x+48>>2]=y;x=e,y=Mb(d),j[x+72>>2]=y;if(rb(e+48|0,e+72|0)){break B}break z}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}while(1){F:{d=j[e+48>>2];h[e+68|0]=64;q=k[d+2|0];j[114626]=0;h[e+71|0]=((q<<6)- -64>>>0)/127;q=E(391,e+68|0,e+71|0)|0;w=j[114626];j[114626]=0;if((w|0)==1){break F}h[d+2|0]=k[q|0];Id(e+48|0);if(rb(e+48|0,e+72|0)){continue}break z}break}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}x=e,y=Lb(g),j[x+48>>2]=y;x=e,y=Mb(g),j[x+72>>2]=y;G:{if(!rb(e+48|0,e+72|0)){break G}while(1){H:{d=j[e+48>>2];h[e+68|0]=64;g=k[d+2|0];j[114626]=0;h[e+71|0]=((g<<6)+128>>>0)/255;g=E(391,e+68|0,e+71|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break H}h[d+2|0]=k[g|0];Id(e+48|0);if(rb(e+48|0,e+72|0)){continue}break G}break}b=D()|0;C()|0;break e}x=e,y=Lb(r),j[x+48>>2]=y;x=e,y=Mb(r),j[x+72>>2]=y;if(rb(e+48|0,e+72|0)){r=1<<(f>>>12&3)&65535;while(1){q=j[e+48>>2];d=h[q+2|0];f=OMa(d^-128,d>>31^-1,r,0);g=ab;d=g;I:{if((d|0)>-1?1:(d|0)>=-1?f>>>0>=4294967292:0){j[114626]=0;f=f+4|0;d=f>>>0<4?d+1|0:d;f=ig(458,((d&7)<<29|f>>>3)&536870911,0);d=j[114626];j[114626]=0;if((d|0)!=1){break I}break f}j[114626]=0;d=(f-3|0)/8|0;f=ig(458,d,d>>31);d=j[114626];j[114626]=0;if((d|0)==1){break f}}h[q+2|0]=f^128;Id(e+48|0);if(rb(e+48|0,e+72|0)){continue}break}}d=l[a+480190>>1]+1|0;i[e+68>>1]=d;J:{K:{L:{M:{g=d&65535;if(g>>>0<=3999){f=0;d=0;while(1){j[114626]=0;K(431,b|0,((g<<5)+a|0)+946300|0,-1)|0;g=j[114626];j[114626]=0;if((g|0)==1){break M}j[114626]=0;E(459,b|0,e+48|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break L}j[114626]=0;F(460,e+48|0,(p(l[e+68>>1]+d|0,104)+a|0)+484380|0);d=j[114626];j[114626]=0;if((d|0)==1){break L}d=k[e+80|0];g=k[e+67|0];j[114626]=0;i[e+72>>1]=d|f<<8&32512|((g&3)!=0)<<15;F(461,s|0,e+72|0);d=j[114626];j[114626]=0;if((d|0)==1){break K}f=f+1|0;d=f&65535;if(m>>>0<=d>>>0){break J}g=l[e+68>>1]+d|0;if(g>>>0<=3999){continue}break}}j[114626]=0;E(338,b|0,20)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break J}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}j[114626]=0;F(461,t|0,e+68|0);d=j[114626];j[114626]=0;if((d|0)==1){break g}j[e+48>>2]=3999;d=l[a+480190>>1];j[114626]=0;j[e+72>>2]=d+m;d=E(462,e+48|0,e+72|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break w}i[a+480190>>1]=j[d>>2]}o=o+1|0;if(l[a+480192>>1]>=(o&65535)>>>0){continue}break}}j[114626]=0;f=H(387,b|0)|0;d=j[114626];j[114626]=0;N:{if((d|0)!=1){if(!f){break h}d=Db(e+96|0);j[114626]=0;K(463,b|0,d|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break N}j[114626]=0;I(13,e+48|0,6,d|0);f=j[114626];j[114626]=0;if((f|0)==1){break N}ob(a+1304412|0,e+48|0);gb(e+48|0);gb(d);break h}b=D()|0;C()|0;break e}b=D()|0;C()|0;gb(d);break e}b=D()|0;C()|0;break e}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}f=0;O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{while(1){j[114626]=0;d=(f<<5)+a|0;N(432,d+480280|0);n=j[114626];j[114626]=0;if((n|0)==1){break Y}j[114626]=0;K(433,b|0,d+480289|0,-1)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Y}f=f+1|0;if((f|0)!=32){continue}break}j[114626]=0;d=E(464,b|0,e+32|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break V}if(!d){break S}if((k[e+32|0]|k[e+33|0]<<8|(k[e+34|0]<<16|k[e+35|0]<<24))>>>0<12){break W}d=k[e+32|0]|k[e+33|0]<<8|(k[e+34|0]<<16|k[e+35|0]<<24);j[114626]=0;d=E(258,b|0,d-11|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break V}if(d){break X}break W}b=D()|0;C()|0;break e}d=k[e+32|0]|k[e+33|0]<<8|(k[e+34|0]<<16|k[e+35|0]<<24);o=Wt(e+96|0);j[114626]=0;m=d-11|0;K(436,b|0,o|0,m|0)|0;d=j[114626];j[114626]=0;Z:{if((d|0)!=1){n=Db(e+48|0);d=e+32|4;d=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);j[114626]=0;F(111,n|0,d|0);d=j[114626];j[114626]=0;if((d|0)!=1){_:{if(m){d=0;while(1){$:{g=k[fc(o,d)|0];f=d+1|0;if(!((g|0)!=255|m-f>>>0<2)){f=h[fc(o,f)|0];g=k[fc(o,d+2|0)|0];x=e,y=_e(n),j[x+8>>2]=y;Cd(e+24|0,e+8|0);j[114626]=0;P(437,n|0,j[e+24>>2],g|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){f=d+3|0;break $}break _}j[114626]=0;F(110,n|0,g<<24>>24);d=j[114626];j[114626]=0;if((d|0)!=1){break $}break _}d=f;if(m>>>0>d>>>0){continue}break}}j[114626]=0;L(438,e+8|0,4,6,n|0);d=j[114626];j[114626]=0;if((d|0)!=1){aa:{ob(n,e+8|0);gb(e+8|0);d=zb(n);j[114626]=0;d=H(439,d|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break aa}f=nb(n);j[114626]=0;U(440,a+1304424|0,d|0,f|0,74,0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break aa}gb(n);Od(o);break W}}}}b=D()|0;C()|0;gb(n);break Z}b=D()|0;C()|0}Od(o);break e}d=Fb(a+484360|0);f=e+264|5;f=k[f|0]|k[f+1|0]<<8;j[114626]=0;U(441,d|0,b|0,f|0,65535,65535)|0;d=j[114626];j[114626]=0;if((d|0)==1){break V}o=c&1;if(o){d=e+264|3;d=k[d|0]|k[d+1|0]<<8;j[114626]=0;F(401,a+484344|0,d|0);d=j[114626];j[114626]=0;if((d|0)==1){break V}}d=e+264|3;ba:{if(!(k[d|0]|k[d+1|0]<<8)){break ba}n=a+484344|0;f=0;while(1){j[114626]=0;m=E(258,b|0,4)|0;g=j[114626];j[114626]=0;ca:{if((g|0)!=1){if(m){break ca}break ba}b=D()|0;C()|0;break e}j[114626]=0;m=H(390,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break P}j[114626]=0;I(341,e+96|0,b|0,m|0);m=j[114626];j[114626]=0;if((m|0)==1){break Q}da:{if(!o){break da}j[114626]=0;m=H(387,e+96|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break O}j[114626]=0;E(338,e+96|0,1)|0;g=j[114626];j[114626]=0;if((g|0)==1){break O}j[114626]=0;m=K(402,n|0,f&65535,m+1|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break O}if(!m){break da}j[114626]=0;K(434,e+96|0,e+48|0,-1)|0;m=j[114626];j[114626]=0;if((m|0)==1){break O}m=Ib(n,f);j[114626]=0;E(435,m|0,e+48|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break O}m=Ib(n,f);j[114626]=0;I(443,m|0,1,e+96|0);m=j[114626];j[114626]=0;if((m|0)==1){break O}}jb(e+96|0);f=f+1|0;if(f>>>0<(k[d|0]|k[d+1|0]<<8)>>>0){continue}break}}if(!(c&2)){break S}if(!l[a+480190>>1]){break T}d=0;while(1){c=d+1|0;if(!k[ac(s,d)|0]){c=d+1|0;f=p(c,104)+a|0;d=Mc(e+96|0,i[f+484414>>1]&1?16:8,1,0,i[ac(s,d)>>1]>-1?0:6);j[114626]=0;K(400,d|0,f+484380|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break U}}d=c;if(d>>>0<l[a+480190>>1]){continue}break}break T}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}if(!l[a+480190>>1]){break S}b=0;while(1){c=k[ac(s,b)|0];ea:{if(!c){break ea}c=c-1&65535;if(bc(t)>>>0<=c>>>0){break ea}c=(k[ac(s,b)+1|0]&127)+l[ac(t,c)>>1]&65535;if(c>>>0>l[a+480190>>1]){break ea}f=p(c,104);n=f+a|0;d=n+484380|0;if(!ke(d)){break ea}o=a+484380|0;m=p(b+1|0,104);c=o+m|0;i[c+34>>1]=l[c+34>>1]&65534|i[(f+o|0)+34>>1]&1;j[c>>2]=j[d>>2];j[114626]=0;c=H(465,c|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break R}if(!c){break ea}c=j[(a+m|0)+484400>>2];j[114626]=0;c=H(466,c|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}f=j[n+484400>>2];j[114626]=0;f=H(466,f|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break a}Vb(c,f,ik(d))}b=b+1|0;if(b>>>0<l[a+480190>>1]){continue}break}}ff(s);ff(t);break c}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}b=D()|0;C()|0;jb(e+96|0);break e}b=D()|0;C()|0;break e}b=D()|0;C()|0}ff(s);ff(t)}gb(u);G(b|0);z()}d=1}gb(u)}Za=e+288|0;return d|0}a=J(0)|0;C()|0;ib(a);z()}function _c(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,l=0,n=0,o=0,p=0,q=0,r=0;p=Za-16|0;Za=p;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(a>>>0<=244){g=j[115936];f=a>>>0<11?16:a+11&-8;a=f>>>3|0;b=g>>>a|0;if(b&3){c=a+((b^-1)&1)|0;f=c<<3;b=j[f+463792>>2];a=b+8|0;d=j[b+8>>2];f=f+463784|0;m:{if((d|0)==(f|0)){q=463744,r=TMa(-2,c)&g,j[q>>2]=r;break m}j[d+12>>2]=f;j[f+8>>2]=d}c=c<<3;j[b+4>>2]=c|3;b=b+c|0;j[b+4>>2]=j[b+4>>2]|1;break a}i=j[115938];if(i>>>0>=f>>>0){break l}if(b){c=2<<a;a=(0-c|c)&b<<a;a=(0-a&a)-1|0;b=a>>>12&16;c=b;a=a>>>b|0;b=a>>>5&8;c=c|b;a=a>>>b|0;b=a>>>2&4;c=c|b;a=a>>>b|0;b=a>>>1&2;c=c|b;a=a>>>b|0;b=a>>>1&1;c=(c|b)+(a>>>b|0)|0;d=c<<3;b=j[d+463792>>2];a=j[b+8>>2];d=d+463784|0;n:{if((a|0)==(d|0)){g=TMa(-2,c)&g;j[115936]=g;break n}j[a+12>>2]=d;j[d+8>>2]=a}a=b+8|0;j[b+4>>2]=f|3;e=b+f|0;c=c<<3;f=c-f|0;j[e+4>>2]=f|1;j[b+c>>2]=f;if(i){c=i>>>3|0;b=(c<<3)+463784|0;d=j[115941];c=1<<c;o:{if(!(c&g)){j[115936]=c|g;c=b;break o}c=j[b+8>>2]}j[b+8>>2]=d;j[c+12>>2]=d;j[d+12>>2]=b;j[d+8>>2]=c}j[115941]=e;j[115938]=f;break a}n=j[115937];if(!n){break l}a=(n&0-n)-1|0;b=a>>>12&16;c=b;a=a>>>b|0;b=a>>>5&8;c=c|b;a=a>>>b|0;b=a>>>2&4;c=c|b;a=a>>>b|0;b=a>>>1&2;c=c|b;a=a>>>b|0;b=a>>>1&1;b=j[((c|b)+(a>>>b|0)<<2)+464048>>2];e=(j[b+4>>2]&-8)-f|0;c=b;while(1){p:{a=j[c+16>>2];if(!a){a=j[c+20>>2];if(!a){break p}}d=(j[a+4>>2]&-8)-f|0;c=d>>>0<e>>>0;e=c?d:e;b=c?a:b;c=a;continue}break}o=b+f|0;if(o>>>0<=b>>>0){break k}l=j[b+24>>2];d=j[b+12>>2];if((d|0)!=(b|0)){a=j[b+8>>2];j[a+12>>2]=d;j[d+8>>2]=a;break b}c=b+20|0;a=j[c>>2];if(!a){a=j[b+16>>2];if(!a){break j}c=b+16|0}while(1){h=c;d=a;c=a+20|0;a=j[c>>2];if(a){continue}c=d+16|0;a=j[d+16>>2];if(a){continue}break}j[h>>2]=0;break b}f=-1;if(a>>>0>4294967231){break l}a=a+11|0;f=a&-8;i=j[115937];if(!i){break l}h=31;e=0-f|0;if(f>>>0<=16777215){b=a>>>8|0;a=b+1048320>>>16&8;c=b<<a;b=c+520192>>>16&4;g=c<<b;c=g+245760>>>16&2;a=(g<<c>>>15|0)-(c|(a|b))|0;h=(a<<1|f>>>a+21&1)+28|0}c=j[(h<<2)+464048>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=f<<((h|0)==31?0:25-(h>>>1|0)|0);while(1){t:{g=(j[c+4>>2]&-8)-f|0;if(g>>>0>=e>>>0){break t}d=c;e=g;if(e){break t}e=0;a=c;break r}g=j[c+20>>2];c=j[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|d)){a=2<<h;a=(0-a|a)&i;if(!a){break l}a=(a&0-a)-1|0;b=a>>>12&16;c=b;a=a>>>b|0;b=a>>>5&8;c=c|b;a=a>>>b|0;b=a>>>2&4;c=c|b;a=a>>>b|0;b=a>>>1&2;c=c|b;a=a>>>b|0;b=a>>>1&1;a=j[((c|b)+(a>>>b|0)<<2)+464048>>2]}if(!a){break q}}while(1){c=(j[a+4>>2]&-8)-f|0;b=c>>>0<e>>>0;e=b?c:e;d=b?a:d;b=j[a+16>>2];if(b){a=b}else{a=j[a+20>>2]}if(a){continue}break}}if(!d|j[115938]-f>>>0<=e>>>0){break l}h=d+f|0;if(h>>>0<=d>>>0){break k}l=j[d+24>>2];b=j[d+12>>2];if((d|0)!=(b|0)){a=j[d+8>>2];j[a+12>>2]=b;j[b+8>>2]=a;break c}c=d+20|0;a=j[c>>2];if(!a){a=j[d+16>>2];if(!a){break i}c=d+16|0}while(1){g=c;b=a;c=a+20|0;a=j[c>>2];if(a){continue}c=b+16|0;a=j[b+16>>2];if(a){continue}break}j[g>>2]=0;break c}b=j[115938];if(b>>>0>=f>>>0){a=j[115941];c=b-f|0;u:{if(c>>>0>=16){j[115938]=c;d=a+f|0;j[115941]=d;j[d+4>>2]=c|1;j[a+b>>2]=c;j[a+4>>2]=f|3;break u}j[115941]=0;j[115938]=0;j[a+4>>2]=b|3;b=a+b|0;j[b+4>>2]=j[b+4>>2]|1}a=a+8|0;break a}d=j[115939];if(d>>>0>f>>>0){b=d-f|0;j[115939]=b;a=j[115942];c=a+f|0;j[115942]=c;j[c+4>>2]=b|1;j[a+4>>2]=f|3;a=a+8|0;break a}a=0;e=f+47|0;c=e;if(j[116054]){b=j[116056]}else{j[116057]=-1;j[116058]=-1;j[116055]=4096;j[116056]=4096;j[116054]=p+12&-16^1431655768;j[116059]=0;j[116047]=0;b=4096}g=c+b|0;h=0-b|0;c=g&h;if(c>>>0<=f>>>0){break a}i=j[116046];if(i){l=j[116044];b=l+c|0;if(b>>>0<=l>>>0|b>>>0>i>>>0){break a}}if(k[464188]&4){break f}v:{w:{b=j[115942];if(b){a=464192;while(1){i=j[a>>2];if(b>>>0<i+j[a+4>>2]>>>0?i>>>0<=b>>>0:0){break w}a=j[a+8>>2];if(a){continue}break}}b=yk(0);if((b|0)==-1){break g}g=c;a=j[116055];d=a-1|0;if(d&b){g=(c-b|0)+(b+d&0-a)|0}if(g>>>0>2147483646|f>>>0>=g>>>0){break g}d=j[116046];if(d){h=j[116044];a=h+g|0;if(a>>>0<=h>>>0|a>>>0>d>>>0){break g}}a=yk(g);if((b|0)!=(a|0)){break v}break e}g=h&g-d;if(g>>>0>2147483646){break g}b=yk(g);if((b|0)==(j[a>>2]+j[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|f+48>>>0<=g>>>0)){b=j[116056];b=b+(e-g|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((yk(b)|0)!=-1){g=b+g|0;b=a;break e}yk(0-g|0);break g}b=a;if((a|0)!=-1){break e}break g}z()}d=0;break b}b=0;break c}if((b|0)!=-1){break e}}j[116047]=j[116047]|4}if(c>>>0>2147483646){break d}b=yk(c);a=yk(0);if(b>>>0>=a>>>0|(b|0)==-1|(a|0)==-1){break d}g=a-b|0;if(g>>>0<=f+40>>>0){break d}}a=j[116044]+g|0;j[116044]=a;if(a>>>0>m[116045]){j[116045]=a}x:{y:{z:{e=j[115942];if(e){a=464192;while(1){c=j[a>>2];d=j[a+4>>2];if((c+d|0)==(b|0)){break z}a=j[a+8>>2];if(a){continue}break}break y}a=j[115940];if(!(a>>>0<=b>>>0?a:0)){j[115940]=b}a=0;j[116049]=g;j[116048]=b;j[115944]=-1;j[115945]=j[116054];j[116051]=0;while(1){c=a<<3;d=c+463784|0;j[c+463792>>2]=d;j[c+463796>>2]=d;a=a+1|0;if((a|0)!=32){continue}break}a=g-40|0;c=b+8&7?-8-b&7:0;d=a-c|0;j[115939]=d;c=b+c|0;j[115942]=c;j[c+4>>2]=d|1;j[(a+b|0)+4>>2]=40;j[115943]=j[116058];break x}if(k[a+12|0]&8|b>>>0<=e>>>0|c>>>0>e>>>0){break y}j[a+4>>2]=d+g;a=e+8&7?-8-e&7:0;b=a+e|0;j[115942]=b;c=j[115939]+g|0;a=c-a|0;j[115939]=a;j[b+4>>2]=a|1;j[(c+e|0)+4>>2]=40;j[115943]=j[116058];break x}d=j[115940];if(d>>>0>b>>>0){j[115940]=b;d=0}c=b+g|0;a=464192;A:{B:{C:{D:{E:{F:{while(1){if((c|0)!=j[a>>2]){a=j[a+8>>2];if(a){continue}break F}break}if(!(k[a+12|0]&8)){break E}}a=464192;while(1){c=j[a>>2];if(c>>>0<=e>>>0){d=c+j[a+4>>2]|0;if(d>>>0>e>>>0){break D}}a=j[a+8>>2];continue}}j[a>>2]=b;j[a+4>>2]=j[a+4>>2]+g;l=(b+8&7?-8-b&7:0)+b|0;j[l+4>>2]=f|3;b=c+(c+8&7?-8-c&7:0)|0;a=(b-l|0)-f|0;h=f+l|0;if((b|0)==(e|0)){j[115942]=h;a=j[115939]+a|0;j[115939]=a;j[h+4>>2]=a|1;break B}if(j[115941]==(b|0)){j[115941]=h;a=j[115938]+a|0;j[115938]=a;j[h+4>>2]=a|1;j[a+h>>2]=a;break B}c=j[b+4>>2];if((c&3)==1){n=c&-8;G:{if(c>>>0<=255){f=c>>>3|0;c=j[b+8>>2];d=j[b+12>>2];if((d|0)==(c|0)){q=463744,r=j[115936]&TMa(-2,f),j[q>>2]=r;break G}j[c+12>>2]=d;j[d+8>>2]=c;break G}i=j[b+24>>2];g=j[b+12>>2];H:{if((g|0)!=(b|0)){c=j[b+8>>2];j[c+12>>2]=g;j[g+8>>2]=c;break H}I:{e=b+20|0;f=j[e>>2];if(f){break I}e=b+16|0;f=j[e>>2];if(f){break I}g=0;break H}while(1){c=e;g=f;e=f+20|0;f=j[e>>2];if(f){continue}e=g+16|0;f=j[g+16>>2];if(f){continue}break}j[c>>2]=0}if(!i){break G}c=j[b+28>>2];d=(c<<2)+464048|0;J:{if(j[d>>2]==(b|0)){j[d>>2]=g;if(g){break J}q=463748,r=j[115937]&TMa(-2,c),j[q>>2]=r;break G}j[i+(j[i+16>>2]==(b|0)?16:20)>>2]=g;if(!g){break G}}j[g+24>>2]=i;c=j[b+16>>2];if(c){j[g+16>>2]=c;j[c+24>>2]=g}c=j[b+20>>2];if(!c){break G}j[g+20>>2]=c;j[c+24>>2]=g}b=b+n|0;a=a+n|0}j[b+4>>2]=j[b+4>>2]&-2;j[h+4>>2]=a|1;j[a+h>>2]=a;if(a>>>0<=255){b=a>>>3|0;a=(b<<3)+463784|0;c=j[115936];b=1<<b;K:{if(!(c&b)){j[115936]=b|c;b=a;break K}b=j[a+8>>2]}j[a+8>>2]=h;j[b+12>>2]=h;j[h+12>>2]=a;j[h+8>>2]=b;break B}e=31;if(a>>>0<=16777215){c=a>>>8|0;b=c+1048320>>>16&8;d=c<<b;c=d+520192>>>16&4;f=d<<c;d=f+245760>>>16&2;b=(f<<d>>>15|0)-(d|(b|c))|0;e=(b<<1|a>>>b+21&1)+28|0}j[h+28>>2]=e;j[h+16>>2]=0;j[h+20>>2]=0;b=(e<<2)+464048|0;c=j[115937];d=1<<e;L:{if(!(c&d)){j[115937]=c|d;j[b>>2]=h;j[h+24>>2]=b;break L}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=j[b>>2];while(1){c=b;if((j[b+4>>2]&-8)==(a|0)){break C}b=e>>>29|0;e=e<<1;d=c+(b&4)|0;b=j[d+16>>2];if(b){continue}break}j[d+16>>2]=h;j[h+24>>2]=c}j[h+12>>2]=h;j[h+8>>2]=h;break B}a=g-40|0;c=b+8&7?-8-b&7:0;h=a-c|0;j[115939]=h;c=b+c|0;j[115942]=c;j[c+4>>2]=h|1;j[(a+b|0)+4>>2]=40;j[115943]=j[116058];a=(d+(d-39&7?39-d&7:0)|0)-47|0;c=a>>>0<e+16>>>0?e:a;j[c+4>>2]=27;a=j[116051];j[c+16>>2]=j[116050];j[c+20>>2]=a;a=j[116049];j[c+8>>2]=j[116048];j[c+12>>2]=a;j[116050]=c+8;j[116049]=g;j[116048]=b;j[116051]=0;a=c+24|0;while(1){j[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<d>>>0){continue}break}if((c|0)==(e|0)){break x}j[c+4>>2]=j[c+4>>2]&-2;d=c-e|0;j[e+4>>2]=d|1;j[c>>2]=d;if(d>>>0<=255){b=d>>>3|0;a=(b<<3)+463784|0;c=j[115936];b=1<<b;M:{if(!(c&b)){j[115936]=b|c;b=a;break M}b=j[a+8>>2]}j[a+8>>2]=e;j[b+12>>2]=e;j[e+12>>2]=a;j[e+8>>2]=b;break x}a=31;j[e+16>>2]=0;j[e+20>>2]=0;if(d>>>0<=16777215){b=d>>>8|0;a=b+1048320>>>16&8;c=b<<a;b=c+520192>>>16&4;g=c<<b;c=g+245760>>>16&2;a=(g<<c>>>15|0)-(c|(a|b))|0;a=(a<<1|d>>>a+21&1)+28|0}j[e+28>>2]=a;b=(a<<2)+464048|0;c=j[115937];g=1<<a;N:{if(!(c&g)){j[115937]=c|g;j[b>>2]=e;j[e+24>>2]=b;break N}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);b=j[b>>2];while(1){c=b;if((d|0)==(j[b+4>>2]&-8)){break A}b=a>>>29|0;a=a<<1;g=c+(b&4)|0;b=j[g+16>>2];if(b){continue}break}j[g+16>>2]=e;j[e+24>>2]=c}j[e+12>>2]=e;j[e+8>>2]=e;break x}a=j[c+8>>2];j[a+12>>2]=h;j[c+8>>2]=h;j[h+24>>2]=0;j[h+12>>2]=c;j[h+8>>2]=a}a=l+8|0;break a}a=j[c+8>>2];j[a+12>>2]=e;j[c+8>>2]=e;j[e+24>>2]=0;j[e+12>>2]=c;j[e+8>>2]=a}a=j[115939];if(a>>>0<=f>>>0){break d}b=a-f|0;j[115939]=b;a=j[115942];c=a+f|0;j[115942]=c;j[c+4>>2]=b|1;j[a+4>>2]=f|3;a=a+8|0;break a}j[114600]=48;a=0;break a}O:{if(!l){break O}a=j[d+28>>2];c=(a<<2)+464048|0;P:{if(j[c>>2]==(d|0)){j[c>>2]=b;if(b){break P}i=TMa(-2,a)&i;j[115937]=i;break O}j[l+(j[l+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break O}}j[b+24>>2]=l;a=j[d+16>>2];if(a){j[b+16>>2]=a;j[a+24>>2]=b}a=j[d+20>>2];if(!a){break O}j[b+20>>2]=a;j[a+24>>2]=b}Q:{if(e>>>0<=15){a=e+f|0;j[d+4>>2]=a|3;a=a+d|0;j[a+4>>2]=j[a+4>>2]|1;break Q}j[d+4>>2]=f|3;j[h+4>>2]=e|1;j[e+h>>2]=e;if(e>>>0<=255){b=e>>>3|0;a=(b<<3)+463784|0;c=j[115936];b=1<<b;R:{if(!(c&b)){j[115936]=b|c;b=a;break R}b=j[a+8>>2]}j[a+8>>2]=h;j[b+12>>2]=h;j[h+12>>2]=a;j[h+8>>2]=b;break Q}a=31;if(e>>>0<=16777215){b=e>>>8|0;a=b+1048320>>>16&8;c=b<<a;b=c+520192>>>16&4;f=c<<b;c=f+245760>>>16&2;a=(f<<c>>>15|0)-(c|(a|b))|0;a=(a<<1|e>>>a+21&1)+28|0}j[h+28>>2]=a;j[h+16>>2]=0;j[h+20>>2]=0;b=(a<<2)+464048|0;S:{c=1<<a;T:{if(!(c&i)){j[115937]=c|i;j[b>>2]=h;break T}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);f=j[b>>2];while(1){b=f;if((j[b+4>>2]&-8)==(e|0)){break S}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;f=j[c+16>>2];if(f){continue}break}j[c+16>>2]=h}j[h+24>>2]=b;j[h+12>>2]=h;j[h+8>>2]=h;break Q}a=j[b+8>>2];j[a+12>>2]=h;j[b+8>>2]=h;j[h+24>>2]=0;j[h+12>>2]=b;j[h+8>>2]=a}a=d+8|0;break a}U:{if(!l){break U}a=j[b+28>>2];c=(a<<2)+464048|0;V:{if(j[c>>2]==(b|0)){j[c>>2]=d;if(d){break V}q=463748,r=TMa(-2,a)&n,j[q>>2]=r;break U}j[l+(j[l+16>>2]==(b|0)?16:20)>>2]=d;if(!d){break U}}j[d+24>>2]=l;a=j[b+16>>2];if(a){j[d+16>>2]=a;j[a+24>>2]=d}a=j[b+20>>2];if(!a){break U}j[d+20>>2]=a;j[a+24>>2]=d}W:{if(e>>>0<=15){a=e+f|0;j[b+4>>2]=a|3;a=a+b|0;j[a+4>>2]=j[a+4>>2]|1;break W}j[b+4>>2]=f|3;j[o+4>>2]=e|1;j[e+o>>2]=e;if(i){c=i>>>3|0;a=(c<<3)+463784|0;d=j[115941];c=1<<c;X:{if(!(c&g)){j[115936]=c|g;c=a;break X}c=j[a+8>>2]}j[a+8>>2]=d;j[c+12>>2]=d;j[d+12>>2]=a;j[d+8>>2]=c}j[115941]=o;j[115938]=e}a=b+8|0}Za=p+16|0;return a|0}function ala(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=Za-720|0;Za=d;rc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(!kf(b,d+712|0)){break D}if(!KI(d+712|0)){break D}if(!Ws(b,d+704|0)){break D}if(!JI(d+704|0)){break D}n=1313423693;f=k[d+704|0]|k[d+705|0]<<8|(k[d+706|0]<<16|k[d+707|0]<<24);if((f|0)!=1179012417){n=1414090313;if((f|0)!=538987841){break D}}r=pl(d+688|0,b);o=Ow(d+672|0);E:{F:{G:{H:{I:{J:{K:{L:{M:{if(!c){j[114626]=0;L(1528,d+112|0,r|0,((f|0)==1179012417?1:2)|0,n|0);b=j[114626];j[114626]=0;if((b|0)!=1){break M}a=D()|0;C()|0;break a}j[114626]=0;I(1529,d+112|0,r|0,((f|0)==1179012417?1:2)|0);b=j[114626];j[114626]=0;if((b|0)==1){break L}}Gka(o,d+112|0);Vk(d+112|0);j[114626]=0;I(1530,d+656|0,o|0,n|0);b=j[114626];j[114626]=0;if((b|0)!=1){j[114626]=0;b=H(337,d+656|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break G}g=0;if(!b){break E}j[114626]=0;b=E(1531,d+656|0,d+576|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break G}if(!b|!k[d+641|0]){break E}b=k[d+641|0];j[114626]=0;g=E(258,d+656|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break G}if(!c|g^1){break E}j[114626]=0;F(447,a|0,8388608);b=j[114626];j[114626]=0;if((b|0)==1){break G}j[a+480208>>2]=12;j[a+480208>>2]=j[a+480208>>2]&-17|(k[d+640|0]<<4^-1)&16;b=k[d+641|0];j[114626]=0;i[d+112>>1]=b;i[d+480>>1]=127;b=E(477,d+112|0,d+480|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break K}i[a+480188>>1]=l[b>>1];j[a+480196>>2]=k[d+642|0];j[a+480204>>2]=p(k[d+643|0],1e4);j[a+480200>>2]=k[d+648|0]<<1;j[114626]=0;E(238,a+1304436|0,((f|0)==1179012417?31715:31681)|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break G}j[114626]=0;b=E(2,d+112|0,31749)|0;g=j[114626];j[114626]=0;if((g|0)==1){break I}ob(a+1304448|0,b);gb(b);j[a+1304496>>2]=4;j[114626]=0;I(1532,d+480|0,2,d+576|0);b=j[114626];j[114626]=0;if((b|0)==1){break J}j[114626]=0;F(415,d+112|0,d+480|0);b=j[114626];j[114626]=0;if((b|0)==1){break J}ob(a+1304400|0,d+112|0);gb(d+112|0);if(!l[a+480188>>1]){break H}m=(f|0)==1179012417;b=0;while(1){j[114626]=0;n=(b<<5)+a|0;e=n+480280|0;N(432,e|0);g=j[114626];j[114626]=0;N:{O:{P:{Q:{R:{if((g|0)!=1){j[114626]=0;g=H(387,d+656|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break R}if(m){break Q}if(g>>>0<129){break P}break O}a=D()|0;C()|0;break b}a=D()|0;C()|0;break b}if(g<<24>>24<=-1){break O}j[114626]=0;j[d+112>>2]=g<<2;j[d+480>>2]=256;g=E(462,d+112|0,d+480|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){i[n+480284>>1]=j[g>>2];break N}a=D()|0;C()|0;break b}i[n+480284>>1]=g<<1;break N}j[e>>2]=1024}b=b+1|0;if(b>>>0<l[a+480188>>1]){continue}break}break H}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;break b}a=D()|0;C()|0;break b}j[114626]=0;b=E(1533,o|0,1380209231)|0;g=j[114626];j[114626]=0;if((g|0)!=1){break F}}a=D()|0;C()|0;break b}if(b){j[114626]=0;I(1530,d+112|0,o|0,1380209231);b=j[114626];j[114626]=0;if((b|0)==1){break c}j[114626]=0;b=H(387,d+112|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break d}g=Fb(a+484360|0);j[114626]=0;U(581,g|0,d+112|0,b+1&255,255,254)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}jb(d+112|0)}if(c&1){j[114626]=0;i[d+40>>1]=0;I(1534,d+480|0,o|0,1414807888);b=j[114626];j[114626]=0;if((b|0)==1){break e}b=Xc(d+480|0);j[114626]=0;g=a+484344|0;F(401,g|0,b&65535);b=j[114626];j[114626]=0;if((b|0)==1){break k}s=d,t=Lb(d+480|0),j[s+544>>2]=t;s=d,t=Mb(d+480|0),j[s+64>>2]=t;if(rb(d+544|0,d- -64|0)){n=(f|0)!=1179012417;while(1){b=Ie(d+112|0,j[d+544>>2]);j[114626]=0;m=H(387,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break h}j[114626]=0;i[d+464>>1]=m;m=H(390,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break i}j[114626]=0;I(341,d+560|0,b|0,m|0);m=j[114626];j[114626]=0;if((m|0)==1){break i}j[114626]=0;L(1535,d+560|0,l[d+464>>1],n|0,a|0);m=j[114626];j[114626]=0;if((m|0)==1){break j}jb(d+560|0);j[114626]=0;m=E(452,d+40|0,d+464|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break i}i[d+40>>1]=l[m>>1];jb(b);yf(d+544|0);if(rb(d+544|0,d- -64|0)){continue}break}}if(l[d+40>>1]){b=0;while(1){j[114626]=0;n=b&65535;m=E(442,g|0,n|0)|0;e=j[114626];j[114626]=0;S:{if((e|0)!=1){if(m){break S}j[114626]=0;K(402,g|0,n|0,64)|0;n=j[114626];j[114626]=0;if((n|0)!=1){break S}}a=D()|0;C()|0;break f}b=b+1|0;if(l[d+40>>1]>(b&65535)>>>0){continue}break}}Sc(d+480|0)}T:{if((f|0)==1179012417){j[114626]=0;I(1534,d- -64|0,o|0,1414745673);b=j[114626];j[114626]=0;if((b|0)==1){break B}s=d,t=Lb(d- -64|0),j[s+96>>2]=t;s=d,t=Mb(d- -64|0),j[s+24>>2]=t;U:{if(rb(d+96|0,d+24|0)){g=c&2;n=d+488|0;m=d+112|1;while(1){c=Ie(d+544|0,j[d+96>>2]);j[114626]=0;b=E(1536,c|0,d+112|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break U}V:{if(!b){break V}b=k[m|0];if((b|0)==255){break V}j[114626]=0;b=K(454,a|0,b+1|0,0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break A}if(!b){break V}f=l[a+480190>>1];j[114626]=0;I(1537,d+112|0,b|0,f|0);b=j[114626];j[114626]=0;if((b|0)==1){break A}b=0;if(!k[d+142|0]){break V}while(1){W:{if(!bn(a)){break W}j[114626]=0;f=E(1538,c|0,d+480|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break z}if(!f){break W}f=l[a+480190>>1]+1|0;i[a+480190>>1]=f;if((k[d+480|0]|k[d+481|0]<<8|(k[d+482|0]<<16|k[d+483|0]<<24))!=1347240275){break W}j[114626]=0;I(577,d+464|0,2,n|0);e=j[114626];j[114626]=0;X:{Y:{Z:{if((e|0)==1){break Z}j[114626]=0;F(415,d+40|0,d+464|0);e=j[114626];j[114626]=0;if((e|0)==1){break Z}j[114626]=0;f=f&65535;E(369,((f<<5)+a|0)+946300|0,d+40|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break Y}gb(d+40|0);j[114626]=0;f=(p(f,104)+a|0)+484380|0;I(1539,d+480|0,d+112|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break m}if(!g){break X}j[114626]=0;F(1540,d+40|0,d+480|0);e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;K(400,d+40|0,f|0,c|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){break W}}a=D()|0;C()|0;break l}a=D()|0;C()|0;break l}a=D()|0;C()|0;gb(d+40|0);break l}f=ik(f);j[114626]=0;E(338,c|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break m}}b=b+1|0;if(b>>>0<k[d+142|0]){continue}break}}jb(c);yf(d+96|0);if(rb(d+96|0,d+24|0)){continue}break}}Sc(d- -64|0);break T}a=D()|0;C()|0;break l}j[114626]=0;I(1534,d+464|0,o|0,1179011410);b=j[114626];j[114626]=0;if((b|0)==1){break y}s=d,t=Lb(d+464|0),j[s+456>>2]=t;s=d,t=Mb(d+464|0),j[s+448>>2]=t;if(rb(d+456|0,d+448|0)){f=c&2;g=d+480|4;c=d+56|4;n=d+112|5;while(1){m=pl(d+544|0,j[d+456>>2]);j[114626]=0;b=H(390,d+544|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break x}_:{if((b|0)!=538986817){break _}j[114626]=0;b=E(1541,d+544|0,d+440|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break w}if(!b|(k[d+440|0]|k[d+441|0]<<8|(k[d+442|0]<<16|k[d+443|0]<<24))!=1414745673){break _}j[114626]=0;b=E(1542,d+544|0,d+112|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break v}if(!b){break _}b=k[n|0];if((b|0)==255){break _}j[114626]=0;b=K(454,a|0,b+1|0,0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break u}if(!b){break _}e=l[a+480190>>1];j[114626]=0;I(1543,d+112|0,b|0,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break u}j[114626]=0;I(1529,d+480|0,m|0,2);b=j[114626];j[114626]=0;if((b|0)==1){break C}j[114626]=0;I(1534,d+96|0,d+480|0,1179011410);b=j[114626];j[114626]=0;if((b|0)==1){break t}Vk(d+480|0);s=d,t=Lb(d+96|0),j[s+88>>2]=t;s=d,t=Mb(d+96|0),j[s+80>>2]=t;$:{if(!rb(d+88|0,d+80|0)){break $}aa:{while(1){b=Ie(d- -64|0,j[d+88>>2]);j[114626]=0;m=H(390,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break s}ba:{ca:{if((m|0)!=538989377){break ca}if(!bn(a)){break ca}m=k[d+436|0]|k[d+437|0]<<8;e=m-1|0;h[d+436|0]=e;h[d+437|0]=e>>>8;if(!m){jb(b);break $}m=l[a+480190>>1]+1|0;i[a+480190>>1]=m;j[114626]=0;e=E(1541,b|0,d+56|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break r}da:{if(!(!e|(k[d+56|0]|k[d+57|0]<<8|(k[d+58|0]<<16|k[d+59|0]<<24))!=1347240275)){e=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[114626]=0;I(341,d+40|0,b|0,e|0);e=j[114626];j[114626]=0;ea:{if((e|0)!=1){j[114626]=0;e=E(1544,d+40|0,d+480|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break ba}if(!e){break aa}j[114626]=0;I(745,d+8|0,2,g|0);e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)!=1){break ea}}a=D()|0;C()|0;break p}a=D()|0;C()|0;break o}j[114626]=0;m=m&65535;E(369,((m<<5)+a|0)+946300|0,d+24|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break q}gb(d+24|0);j[114626]=0;m=(p(m,104)+a|0)+484380|0;I(1545,d+480|0,d+112|0,m|0);e=j[114626];j[114626]=0;if((e|0)==1){break ba}if(!f){break da}e=k[d+480|0]|k[d+481|0]<<8|(k[d+482|0]<<16|k[d+483|0]<<24);j[114626]=0;E(256,d+40|0,e+4|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break ba}j[114626]=0;F(1546,d+24|0,d+480|0);e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;K(400,d+24|0,m|0,d+40|0)|0;m=j[114626];j[114626]=0;if((m|0)!=1){break da}}a=D()|0;C()|0;break p}jb(b);break $}jb(d+40|0)}jb(b);yf(d+88|0);if(rb(d+88|0,d+80|0)){continue}break $}break}a=D()|0;C()|0;break p}jb(d+40|0);jb(b)}Sc(d+96|0)}jb(d+544|0);yf(d+456|0);if(rb(d+456|0,d+448|0)){continue}break}}Sc(d+464|0)}g=1}jb(d+656|0);Vk(o);jb(r)}Za=d+720|0;return g|0}a=D()|0;C()|0;break n}a=D()|0;C()|0;break b}a=D()|0;C()|0;break l}a=D()|0;C()|0;break l}a=D()|0;C()|0;break b}a=D()|0;C()|0;break n}a=D()|0;C()|0;break n}a=D()|0;C()|0;break n}a=D()|0;C()|0;break n}a=D()|0;C()|0;Vk(d+480|0);break n}a=D()|0;C()|0;break o}a=D()|0;C()|0;break o}a=D()|0;C()|0;gb(d+24|0)}jb(d+40|0)}jb(b);Sc(d+96|0)}jb(d+544|0);Sc(d+464|0);break b}a=D()|0;C()|0}jb(c);Sc(d- -64|0);break b}a=D()|0;C()|0;break f}a=D()|0;C()|0;jb(d+560|0);break g}a=D()|0;C()|0;break g}a=D()|0;C()|0}jb(b)}Sc(d+480|0);break b}a=D()|0;C()|0;break b}a=D()|0;C()|0;jb(d+112|0);break b}a=D()|0;C()|0}jb(d+656|0)}Vk(o);jb(r);G(a|0);z()}function dJa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,F=0,I=0,J=0,L=0,M=0,N=0;f=Za+ -64|0;Za=f;rc(a);a:{b:{if(b>>>0<=2){M=f,N=dd(a),h[M+56|0]=N;Jb(a,2);e=f+56|2;b=Of(a);h[e|0]=b;h[e+1|0]=b>>>8;e=f+56|4;b=hf(a);h[e|0]=b;h[e+1|0]=b>>>8;h[e+2|0]=b>>>16;h[e+3|0]=b>>>24;break b}kf(a,f+56|0);if(b>>>0>5){break a}}h[f+56|1]=0}c:{u=d+484344|0;b=f+56|2;B=kd(k[b|0]|k[b+1|0]<<8,1,1024);t=Cw(u,B,0);if((t|0)!=65535){e=Dp(Ib(u,t),0);i[f+8>>1]=l[d+480188>>1]-1;i[f+40>>1]=k[f+56|0];F=l[gf(f+8|0,f+40|0)>>1];g=F+1|0;if(l[d+480188>>1]>(g&65535)>>>0){b=g&65535;while(1){h[e+p(b,6)|0]=254;b=b+1|0;if(b>>>0<l[d+480188>>1]){continue}break}}h[c+13|0]=k[f+56|1]>>>4;b=k[c+12|0];h[f+8|0]=0;v=lt(f+40|0,g,f+8|0);if(B){b=(b|0)!=0;while(1){d:{e:{if(!k[fc(v,0)|0]){j[114626]=0;g=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}r=g<<24>>24;if((r|0)<=-1){j[114626]=0;g=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}M=fc(v,0),N=g,h[M|0]=N}I=0;h[f+8|0]=0;m=r&63;f:{g:{if(!m){break g}j[114626]=0;e=H(387,a|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}h[f+8|0]=e;r=0;h:{switch(m-1|0){case 0:h[c+12|0]=0;j[114626]=0;h[f+36|0]=1;e=E(453,f+36|0,f+8|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){h[c+14|0]=k[e|0];h[c+15|0]=0;b=1;break f}break c;case 1:if(!e){break f}h[c+15|0]=e;b=1;h[c+12|0]=1;g=k[c+13|0];if(!g){break g}h[c+14|0]=p(p(e,g),15);break g;case 2:e=e>>>4|0;h[c+13|0]=e;if(e){b=k[c+12|0]!=0;break f}h[c+12|0]=0;break f;case 3:r=e;break f;case 5:if(!e){break f}b=(k[c+12|0]?15:14)+c|0;g=k[b|0];h[b|0]=g>>>0<256-e>>>0?e+g|0:-1;b=1;break g;case 6:break h;default:break f}}if(!e){break f}b=1;g=(k[c+12|0]?15:14)+c|0;r=k[g|0];h[g|0]=r>>>0>e+1>>>0?r-e|0:1}r=0}j[f+36>>2]=0;j[f+32>>2]=0;if(b&1){break e}break d}r=0;e=fc(v,0);h[e|0]=k[e|0]-1;j[f+36>>2]=0;j[f+32>>2]=0;I=0;if(!(b&1)){break d}}b=k[c+12|0];e=k[c+13|0];if(e?0:b){break d}i:{if(b){j[f+8>>2]=1;b=k[c+15|0];j[114626]=0;j[f+28>>2]=p(b,e)<<1;e=E(552,f+8|0,f+28|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}g=j[e>>2];break i}g=p(k[c+14|0],30)+30|0}b=255;j[f+36>>2]=255;while(1){s=p(b,g);if(s-1536>>>0>=10752){e=b-1|0;j[f+36>>2]=e;m=b>>>0<2;b=e;if(!m){continue}}break}j[f+32>>2]=(s|0)/48;Md(f+32|0,32,255);j[114626]=0;j[f+8>>2]=1;e=E(552,f+8|0,f+36|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}h[c+16|0]=j[e>>2];I=1}b=Ib(u,t);j[114626]=0;b=K(471,b|0,q|0,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}if(F){J=q-1|0;n=1;y=1;while(1){j:{if(!k[fc(v,n)|0]){j[114626]=0;x=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}if(x&128){j[114626]=0;g=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}M=fc(v,n),N=g,h[M|0]=N}L=1;if(x&64){j[114626]=0;g=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}h[b+1|0]=g;L=!g}k:{if(!(x&32)){break k}j[114626]=0;g=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}h[b|0]=g;if((g-1&255)>>>0<=107){e=op(g+24|0);h[b|0]=e;M=wc(c,n),N=e,h[M+1|0]=N;break k}if((g+127&255)>>>0<=107){e=op((g&127)+24|0);h[b|0]=e;M=wc(c,n),N=e,h[M|0]=N;h[b|0]=0;break k}if((g|0)!=255){break k}h[b|0]=254}if(!(k[b|0]|!k[b+1|0])){e=k[wc(c,n)+1|0];h[b+1|0]=0;h[b|0]=e}j[114626]=0;g=H(553,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}if(g){M=wc(c,n),N=0,h[M+5|0]=N}h[f+28|0]=0;h[f+27|0]=0;h[f+26|0]=0;h[f+25|0]=0;if(x&16){h[b+2|0]=1;j[114626]=0;g=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}h[b+4|0]=g+2>>>2}g=0;A=0;w=0;l:{if(!(x&8)){break l}j[114626]=0;o=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;w=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}m:{switch(o-1|0){case 0:h[b|0]=254;break l;case 1:h[b|0]=255;break l;case 2:M=b,N=k[wc(c,n)+1|0],h[M|0]=N;M=wc(c,n),N=0,h[M+5|0]=N;break l;case 3:e=kt(w,k[c+16|0]);w=e?e|-48:0;A=e?20:0;if(k[b|0]){break l}M=b,N=k[wc(c,n)+1|0],h[M|0]=N;M=wc(c,n),N=0,h[M+5|0]=N;break l;case 4:h[f+8|0]=1;e=kt(w,k[c+16|0]);j[114626]=0;h[f+24|0]=e;m=E(453,f+8|0,f+24|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){w=k[m|0];M=wc(c,n),N=0,h[M+5|0]=N;A=15;break l}break c;case 5:case 6:case 7:case 8:n:{if(!q){break n}if((o|0)==k[wc(c,n)+4|0]){break n}s=Ib(u,t);j[114626]=0;m=K(497,f+8|0,20,(o+122|160)&255)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}e=dn(cn(Fe(m,J),y&65535));j[114626]=0;m=E(498,s|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}if(!m){break n}M=wc(c,n),N=o,h[M+4|0]=N}if(!k[b|0]){M=b,N=k[wc(c,n)+1|0],h[M|0]=N}M=wc(c,n),N=0,h[M+5|0]=N;A=10;break l;case 9:break m;default:break l}}m=k[wc(c,n)+5|0];e=k[wc(c,n)+5|0];M=wc(c,n),N=e^1,h[M+5|0]=N;w=m?-98:-97;A=20}o:{if(!(x&4)){break o}j[114626]=0;m=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;h[f+28|0]=m;o=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}h[f+26|0]=o;e=f;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{m=k[f+28|0];switch(m-1|0){case 11:break r;case 10:break s;case 7:case 8:case 9:break t;case 6:break u;case 5:break v;case 3:case 4:break w;case 2:break x;case 1:break y;case 0:break z;default:break q}}h[f+28|0]=o<<24>>24>-1?2:3;if(o>>>0>=129){h[f+26|0]=0-o}j[114626]=0;h[f+8|0]=15;m=E(391,f+8|0,f+26|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){h[f+26|0]=k[m|0]|240;break o}break c}e=kt(o,k[c+16|0]);h[f+26|0]=e;if(e){h[f+28|0]=20;h[f+26|0]=e|208;g=1;break o}h[f+28|0]=0;g=1;break o}g=1;break p}e=k[c+16|0];j[114626]=0;g=K(554,o|0,e|0,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}h[f+26|0]=g;h[f+28|0]=k[f+28|0]==4?2:3;g=1;break o}if(!k[b|0]){M=b,N=k[wc(c,n)|0],h[M|0]=N;o=k[f+26|0]}e=k[c+16|0];j[114626]=0;g=K(554,o&255,e|0,0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}h[f+28|0]=4;h[f+26|0]=g;g=1;break o}M=b,N=op(o+25|0),h[M|0]=N;h[f+26|0]=255;h[f+28|0]=4;g=1;break o}A:{if(!q){break A}if((m|0)==k[wc(c,n)+2|0]){break A}m=Ib(u,t);j[114626]=0;g=K(497,f+8|0,20,(k[f+28|0]-8|48)&255)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}e=dn(cn(Fe(g,J),y&65535));j[114626]=0;g=E(498,m|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}if(!g){break A}e=k[f+28|0];M=wc(c,n),N=e,h[M+2|0]=N}h[f+28|0]=5;e=k[c+16|0];j[114626]=0;g=E(555,k[f+26|0],e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}h[f+26|0]=g;g=1;break o}e=iR(o,k[c+16|0]);h[f+28|0]=18;h[f+26|0]=e;g=1;break o}e=kt(o,k[c+16|0]);h[f+26|0]=e;if(e){h[f+28|0]=20;h[f+26|0]=e|192;g=1;break o}h[f+28|0]=0;h[b|0]=254;g=1;break o}g=0}h[e+28|0]=g}o=0;B:{if(!(x&2)){break B}j[114626]=0;m=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;h[f+27|0]=m;s=H(387,a|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}h[f+25|0]=s;C:{D:{E:{F:{G:{H:{I:{m=k[f+27|0];switch(m-1|0){case 9:break D;case 7:case 8:break E;case 6:break F;case 3:case 4:case 5:break G;case 2:break H;case 0:case 1:break I;default:break C}}e=k[c+16|0];j[114626]=0;m=K(556,s|0,e|0,(m|0)==1|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}h[f+27|0]=11;h[f+25|0]=m;o=1;break B}e=iR(s,k[c+16|0]);h[f+27|0]=18;h[f+25|0]=e;o=1;break B}J:{if(!q){break J}if((m|0)==k[wc(c,n)+3|0]){break J}s=Ib(u,t);j[114626]=0;m=K(497,f+8|0,20,(k[f+27|0]-4|64)&255)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}e=dn(cn(Fe(m,J),y&65535));j[114626]=0;m=E(498,s|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}if(!m){break J}e=k[f+27|0];M=wc(c,n),N=e,h[M+3|0]=N}h[f+27|0]=8;e=k[c+16|0];j[114626]=0;m=E(555,k[f+25|0],e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}h[f+25|0]=m;o=1;break B}h[f+27|0]=9;break B}e=k[c+16|0];j[114626]=0;m=K(556,s|0,e|0,(m|0)==8|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}h[f+27|0]=29;h[f+25|0]=m;o=1;break B}h[f+27|0]=27;e=k[c+16|0];j[114626]=0;m=E(555,s|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}h[f+25|0]=m;o=1;break B}h[f+27|0]=0}if(g){hR(b,q,l[d+480188>>1],k[f+28|0],f+26|0)}if(o){hR(b,q,l[d+480188>>1],k[f+27|0],f+25|0)}K:{if(!L){break K}j[114626]=0;g=H(553,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}if(!g){break K}e=k[f+28|0];if(!e){h[f+26|0]=255;h[f+28|0]=4;break K}if(k[f+27|0]|(e|0)==4){break K}h[f+25|0]=255;h[f+27|0]=4}L:{if(k[b+2|0]!=1){break L}M:{if(!k[f+28|0]){h[f+28|0]=13;h[f+26|0]=k[b+4|0];break M}if(k[f+27|0]){break L}h[f+27|0]=13;h[f+25|0]=k[b+4|0]}h[b+2|0]=0}j[114626]=0;V(499,f+8|0,f+28|0,f+26|0,f+27|0,f+25|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}N:{if(k[b+2|0]){break N}e=k[f+28|0];if(!e){break N}h[b+2|0]=e;h[b+4|0]=k[f+26|0]}O:{if(A){h[b+3|0]=A;break O}e=k[f+27|0];if(!e){break j}h[b+3|0]=e;w=k[f+25|0]}h[b+5|0]=w;break j}e=fc(v,n);h[e|0]=k[e|0]-1}b=b+6|0;y=y+1|0;n=y&65535;if(F>>>0>=n>>>0){continue}break}}P:{if(!I){break P}g=Ib(u,t);j[114626]=0;e=K(497,f+8|0,17,k[f+32|0])|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}b=qi(cn(Fe(e,q),0));j[114626]=0;E(498,g|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}g=Ib(u,t);j[114626]=0;e=K(497,f+8|0,16,k[f+36|0])|0;b=j[114626];j[114626]=0;if((b|0)!=1){b=qi(Fe(e,q));j[114626]=0;E(498,g|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break P}}break c}Q:{if(!(r&240)){break Q}g=Ib(u,t);j[114626]=0;e=K(497,f+8|0,20,r>>>4|224)|0;b=j[114626];j[114626]=0;if((b|0)!=1){b=fR(Fe(e,q));j[114626]=0;E(498,g|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break Q}}break c}R:{e=r&15;if(!e){break R}b=k[c+16|0];g=Ib(u,t);b=kd((p(b,e)>>>0)/15&255,1,15);j[114626]=0;e=K(497,f+8|0,20,b|96)|0;b=j[114626];j[114626]=0;if((b|0)!=1){b=fR(Fe(e,q));j[114626]=0;E(498,g|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break R}}break c}b=0;q=q+1|0;if((B|0)!=(q|0)){continue}break}}Od(v)}Za=f- -64|0;return t|0}a=D()|0;C()|0;Od(v);G(a|0);z()}function nT(a,b,c,d){var e=0,f=0,g=0,k=0,l=0;f=Za-32|0;Za=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!a){break i}j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{if((b|0)<=1347628589){if((b|0)<=1297100333){if((b|0)<=1179931727){if((b|0)<=1145263149){if((b|0)==1095062094){break t}if((b|0)==1095126087){break q}if((b|0)!=1129524782|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+23|0]=l;e=1;break i}if((b|0)<=1179463213){if((b|0)==1145263150){break I}if((b|0)!=1145979182|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+18|0]=l;e=1;break i}if((b|0)==1179463214){break w}if((b|0)!=1179594286|c>>>0>4){break i}if(!yb(d,c)){break i}k=a,l=ok(d,c),j[k>>2]=l;e=1;break i}if((b|0)<=1229345325){if((b|0)==1179931728){break j}if((b|0)==1196830254){break S}if((b|0)!=1229341486|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+21|0]=l;e=1;break i}if((b|0)<=1296182829){if((b|0)==1229345326){break F}if((b|0)!=1264266798|c>>>0>256){break i}a=a+236|0;cd(f+16|0,d,c);b=0;while(1){j[114626]=0;c=H(373,f+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break A}k=Oc(a,b),l=c,i[k>>1]=l;b=b+1|0;if(b>>>0<128){continue}break}jb(f+16|0);e=1;break i}if((b|0)==1296182830){break E}if((b|0)!=1296248366|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+31|0]=l;e=1;break i}if((b|0)<=1346720333){if((b|0)<=1313692461){if((b|0)==1297100334){break D}if((b|0)==1297110852){break o}if((b|0)!=1298747438|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+34|0]=l;e=1;break i}if((b|0)<=1345203757){if((b|0)==1313692462){break B}if((b|0)!=1313751342|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+16|0]=l;e=1;break i}if((b|0)==1345203758){break R}if((b|0)!=1346711086){break i}j[f+16>>2]=240;k=f,l=ok(d,c),j[k>>2]=l;Nf(a+68|0,j[tb(f+16|0,f)>>2]);e=1;break i}if((b|0)<=1347179309){if((b|0)<=1346784326){if((b|0)==1346720334){break u}if((b|0)!=1346722606){break i}cd(f+16|0,d,c);j[114626]=0;a=E(374,a|0,1)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}if(sb(a)){b=0;while(1){j[114626]=0;c=H(375,f+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}k=xb(a,b),l=c,h[k+2|0]=l;b=b+1|0;if(sb(a)>>>0>b>>>0){continue}break}}jb(f+16|0);e=1;break i}if((b|0)==1346784327){break r}if((b|0)!=1347175726|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+82|0]=l;e=1;break i}if((b|0)<=1347441453){if((b|0)==1347179310){break O}if((b|0)!=1347437358|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+27|0]=l;e=1;break i}if((b|0)==1347441454){break C}if((b|0)!=1347443502){break i}cd(f+16|0,d,c);j[114626]=0;a=E(374,a|0,1)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}if(sb(a)){b=0;while(1){j[114626]=0;c=H(373,f+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}k=xb(a,b),l=c,i[k>>1]=l;b=b+1|0;if(sb(a)>>>0>b>>>0){continue}break}}jb(f+16|0);e=1;break i}if((b|0)<=1447374381){if((b|0)<=1349078084){if((b|0)<=1347831111){if((b|0)<=1347634477){if((b|0)==1347628590){break H}if((b|0)!=1347633710|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+83|0]=l;e=1;break i}if((b|0)==1347634478){break N}if((b|0)!=1347703884){break i}k=a,l=p(Ep(d,c),1e4)+(m[a+40>>2]%1e4|0)|0,j[k+40>>2]=l;e=1;break i}if((b|0)<=1349076269){if((b|0)==1347831112){break v}if((b|0)!=1347833672|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+36|0]=l;e=1;break i}if((b|0)==1349076270){break l}if((b|0)!=1349076315){break i}cd(f+16|0,d,c);j[114626]=0;a=E(374,a|0,2)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}if(sb(a)){b=0;while(1){j[114626]=0;c=H(375,f+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}k=xb(a,b),l=c,h[k+2|0]=l;b=b+1|0;if(sb(a)>>>0>b>>>0){continue}break}}jb(f+16|0);e=1;break i}if((b|0)<=1349079873){if((b|0)==1349078085){break L}if((b|0)==1349078099){break M}if((b|0)!=1349079131){break i}cd(f+16|0,d,c);j[114626]=0;a=E(374,a|0,2)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}if(sb(a)){b=0;while(1){j[114626]=0;c=H(373,f+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break d}k=xb(a,b),l=c,i[k>>1]=l;b=b+1|0;if(sb(a)>>>0>b>>>0){continue}break}}jb(f+16|0);e=1;break i}T:{switch(b-1349079874|0){case 3:break J;case 0:break K;case 1:case 2:break i;default:break T}}if((b|0)==1378758190){break n}if((b|0)!=1381183022|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+24|0]=l;e=1;break i}if((b|0)<=1448226349){if((b|0)<=1447447622){if((b|0)==1447374382){break m}if((b|0)==1447383630){break s}if((b|0)!=1447385902){break i}cd(f+16|0,d,c);j[114626]=0;a=E(374,a|0,0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}if(sb(a)){b=0;while(1){j[114626]=0;c=H(375,f+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}k=xb(a,b),l=c,h[k+2|0]=l;b=b+1|0;if(sb(a)>>>0>b>>>0){continue}break}}jb(f+16|0);e=1;break i}if((b|0)<=1447842605){if((b|0)==1447447623){break p}if((b|0)!=1447839022|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+62|0]=l;e=1;break i}if((b|0)==1447842606){break Q}if((b|0)!=1448106798){break i}cd(f+16|0,d,c);j[114626]=0;a=E(374,a|0,0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}if(sb(a)){b=0;while(1){j[114626]=0;c=H(373,f+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}k=xb(a,b),l=c,i[k>>1]=l;b=b+1|0;if(sb(a)>>>0>b>>>0){continue}break}}jb(f+16|0);e=1;break i}if((b|0)<=1448297773){if((b|0)==1448226350){break x}if((b|0)==1448291886){break G}if((b|0)!=1448297006|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+63|0]=l;e=1;break i}if((b|0)<=1718508333){if((b|0)==1448297774){break P}if((b|0)!=1682320942|c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+15|0]=l;e=1;break i}if((b|0)==1718508334){break y}if((b|0)!=1851469358|c>>>0>32){break i}b=a+492|0;cd(f+16|0,d,c);d=Db(f);if(c){a=0;while(1){j[114626]=0;e=H(376,f+16|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break z}j[114626]=0;E(377,d|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break z}a=a+1|0;if((c|0)!=(a|0)){continue}break}}j[114626]=0;E(369,b|0,d|0)|0;a=j[114626];j[114626]=0;e=1;if((a|0)==1){break z}gb(d);jb(f+16|0);break i}if(c>>>0>4){break i}if(!yb(d,c)){break i}k=a,l=ok(d,c),j[k+4>>2]=l;e=1;break i}if(c>>>0>4){break i}if(!yb(d,c)){break i}k=a,l=ok(d,c),j[k+8>>2]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+61|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a- -64|0,l=Tc(d,c),h[k|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+81|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+84|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+101|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+102|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+103|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+104|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+17|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+19|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+20|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+22|0]=l;e=1;break i}if(c>>>0>2){break i}if(!yb(d,c)){break i}k=a,l=Ep(d,c),i[k+28>>1]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+30|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=eA(d,c),h[k+26|0]=l;e=1;break i}if(c>>>0>128){break i}a=a+108|0;cd(f+16|0,d,c);b=0;while(1){j[114626]=0;c=H(375,f+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break k}k=Pb(a,b),l=c,h[k|0]=l;b=b+1|0;if(b>>>0<128){continue}break}jb(f+16|0);e=1;break i}b=D()|0;C()|0;break a}b=D()|0;C()|0;gb(d);break a}if(c>>>0>32){break i}b=a+524|0;cd(f+16|0,d,c);d=Db(f);if(c){a=0;while(1){j[114626]=0;e=H(376,f+16|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break h}j[114626]=0;E(377,d|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break h}a=a+1|0;if((c|0)!=(a|0)){continue}break}}j[114626]=0;E(369,b|0,d|0)|0;a=j[114626];j[114626]=0;e=1;if((a|0)!=1){gb(d);jb(f+16|0);break i}break h}if(c>>>0>2){break i}if(!yb(d,c)){break i}k=a,l=Ep(d,c),i[k+12>>1]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+25|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+35|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+105|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+85|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+65|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+100|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+80|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=Tc(d,c),h[k+60|0]=l;e=1;break i}if(c>>>0>1){break i}if(!yb(d,c)){break i}k=a,l=eA(d,c),h[k+33|0]=l;e=1;break i}e=1;b=ok(d,c);if(!qn(b)){break i}h[a+14|0]=b;break i}j[f+16>>2]=240;k=f,l=ok(d,c),j[k>>2]=l;Nf(a+48|0,j[tb(f+16|0,f)>>2]);e=1;break i}j[f+16>>2]=240;k=f,l=ok(d,c),j[k>>2]=l;Nf(a+88|0,j[tb(f+16|0,f)>>2]);e=1;break i}b=D()|0;C()|0;break a}b=Ep(d,c);c=a;a=j[a+40>>2];j[c+40>>2]=a-((a>>>0)%1e4|0)+(b>>>0)%1e4;e=1}Za=f+32|0;return e}b=D()|0;C()|0;gb(d);break a}b=D()|0;C()|0;break a}b=D()|0;C()|0;break a}b=D()|0;C()|0;break a}b=D()|0;C()|0;break a}b=D()|0;C()|0;break a}b=D()|0;C()|0}jb(f+16|0);G(b|0);z()}function ED(a,b,c,d,e,f,g,h,i){var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;n=Za-192|0;Za=n;z=h;F=i&65535;o=d;p=e&65535;G=(e^i)&-2147483648;m=i>>>16&32767;a:{u=e>>>16&32767;b:{c:{if(m-1>>>0<32766?u-1>>>0<=32765:0){break c}H=e&2147483647;l=H;k=d;if(!(!k&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){J=d;G=e|32768;break b}H=i&2147483647;e=H;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){J=h;G=i|32768;b=f;c=g;break b}if(!(b|k|(l^2147418112|c))){if(!(d|f|(e^2147418112|g))){b=0;c=0;G=2147450880;break b}G=G|2147418112;b=0;c=0;break b}if(!(d|f|(e^2147418112|g))){b=0;c=0;break b}if(!(b|k|(c|l))){break a}if(!(d|f|(e|g))){G=G|2147418112;b=0;c=0;break b}if((l|0)==65535|l>>>0<65535){i=b;d=!(p|o);h=d<<6;k=s(d?b:o)+32|0;b=s(d?c:p);b=h+((b|0)==32?k:b)|0;We(n+176|0,i,c,o,p,b-15|0);I=16-b|0;o=j[n+184>>2];p=j[n+188>>2];c=j[n+180>>2];b=j[n+176>>2]}if(e>>>0>65535){break c}d=!(z|F);e=d<<6;h=s(d?f:z)+32|0;d=s(d?g:F);d=e+((d|0)==32?h:d)|0;We(n+160|0,f,g,z,F,d-15|0);I=(d+I|0)-16|0;z=j[n+168>>2];F=j[n+172>>2];f=j[n+160>>2];g=j[n+164>>2]}e=F|65536;H=e;N=z;d=z;l=e<<15|d>>>17;d=d<<15|g>>>17;h=-102865788-d|0;e=l;k=l;i=1963258675-(k+(d>>>0>4192101508)|0)|0;eh(n+144|0,d,k,h,i);k=j[n+152>>2];eh(n+128|0,0-k|0,0-(j[n+156>>2]+((k|0)!=0)|0)|0,h,i);h=j[n+136>>2];i=h<<1|j[n+132>>2]>>>31;h=j[n+140>>2]<<1|h>>>31;eh(n+112|0,i,h,d,l);k=h;h=j[n+120>>2];eh(n+96|0,i,k,0-h|0,0-(j[n+124>>2]+((h|0)!=0)|0)|0);h=j[n+104>>2];i=h<<1|j[n+100>>2]>>>31;h=j[n+108>>2]<<1|h>>>31;eh(n+80|0,i,h,d,l);k=h;h=j[n+88>>2];eh(n- -64|0,i,k,0-h|0,0-(j[n+92>>2]+((h|0)!=0)|0)|0);h=j[n+72>>2];i=h<<1|j[n+68>>2]>>>31;h=j[n+76>>2]<<1|h>>>31;eh(n+48|0,i,h,d,l);k=h;h=j[n+56>>2];eh(n+32|0,i,k,0-h|0,0-(j[n+60>>2]+((h|0)!=0)|0)|0);h=j[n+40>>2];i=h<<1|j[n+36>>2]>>>31;h=j[n+44>>2]<<1|h>>>31;eh(n+16|0,i,h,d,l);k=h;h=j[n+24>>2];eh(n,i,k,0-h|0,0-(j[n+28>>2]+((h|0)!=0)|0)|0);I=(u-m|0)+I|0;h=j[n+8>>2];k=j[n+12>>2]<<1|h>>>31;l=h<<1|j[n+4>>2]>>>31;h=l-1|0;l=k-(l>>>0<1)|0;k=0;C=k;i=h;q=e;e=0;r=OMa(h,k,q,e);k=ab;v=k;y=l;m=0;u=d;h=OMa(l,m,d,0);d=h+r|0;k=ab+k|0;k=d>>>0<h>>>0?k+1|0:k;h=d;d=k;k=0;l=(d|0)==(v|0)&h>>>0<r>>>0|d>>>0<v>>>0;r=OMa(y,m,q,e);e=r+d|0;l=ab+(k|l)|0;k=e;e=k>>>0<r>>>0?l+1|0:l;q=k;l=h;r=0;h=OMa(i,C,u,t);d=r+h|0;k=ab+l|0;k=d>>>0<h>>>0?k+1|0:k;h=k;u=(l|0)==(k|0)&r>>>0>d>>>0|k>>>0<l>>>0;l=q+u|0;k=e;A=l;e=l>>>0<u>>>0?k+1|0:k;q=d;r=d;u=h;d=g;B=(d&131071)<<15|f>>>17;v=OMa(i,C,B,0);d=ab;t=d;k=f;l=k<<15&-32768;x=0;D=OMa(y,m,l,x);h=D+v|0;k=ab+d|0;k=h>>>0<D>>>0?k+1|0:k;d=k;D=0;E=OMa(i,C,l,x);x=D+E|0;l=h;k=l+ab|0;k=x>>>0<E>>>0?k+1|0:k;w=(k|0)==(l|0)&x>>>0<D>>>0|k>>>0<l>>>0;k=(d|0)==(t|0)&l>>>0<v>>>0|d>>>0<t>>>0;h=d;d=OMa(y,m,B,K)+d|0;l=k+ab|0;l=d>>>0<h>>>0?l+1|0:l;h=d;d=w+d|0;k=l;k=d>>>0<h>>>0?k+1|0:k;h=d;d=d+r|0;k=k+u|0;k=d>>>0<h>>>0?k+1|0:k;r=d;v=k;h=(k|0)==(u|0)&d>>>0<q>>>0|k>>>0<u>>>0;d=h+A|0;k=e;k=d>>>0<h>>>0?k+1|0:k;e=(r|0)!=0|(v|0)!=0;d=e+d|0;l=d>>>0<e>>>0?k+1|0:k;h=d;t=0-d|0;A=0;u=OMa(t,A,i,C);d=ab;x=d;e=u;q=d;A=OMa(y,m,t,A);d=ab;w=d;B=0-(((h|0)!=0)+l|0)|0;t=0;l=OMa(i,C,B,t);h=l+A|0;k=ab+d|0;k=h>>>0<l>>>0?k+1|0:k;d=k;l=h+q|0;e=0+e|0;q=e;k=e;l=k>>>0<K>>>0?l+1|0:l;e=l;l=(x|0)==(l|0)&k>>>0<u>>>0|l>>>0<x>>>0;k=(d|0)==(w|0)&h>>>0<A>>>0|d>>>0<w>>>0;h=d;d=OMa(y,m,B,t)+d|0;k=k+ab|0;k=d>>>0<h>>>0?k+1|0:k;h=d;d=l+d|0;w=d;h=d>>>0<h>>>0?k+1|0:k;d=0-r|0;B=0-(((r|0)!=0)+v|0)|0;r=0;A=OMa(B,r,i,C);x=ab;v=d;l=OMa(d,0,y,m);d=l+A|0;k=ab+x|0;k=d>>>0<l>>>0?k+1|0:k;l=d;d=k;C=OMa(i,C,v,K);v=0+C|0;k=l+ab|0;k=v>>>0<C>>>0?k+1|0:k;v=(l|0)==(k|0)&v>>>0<D>>>0|l>>>0>k>>>0;i=(d|0)==(x|0)&l>>>0<A>>>0|d>>>0<x>>>0;l=d;d=OMa(y,m,B,r)+l|0;k=i+ab|0;k=d>>>0<l>>>0?k+1|0:k;i=d;d=d+v|0;l=d>>>0<i>>>0?k+1|0:k;i=d;d=d+q|0;k=l+e|0;k=d>>>0<i>>>0?k+1|0:k;i=d;l=d;d=k;l=(e|0)==(k|0)&l>>>0<q>>>0|e>>>0>k>>>0;e=l+w|0;k=h;k=e>>>0<l>>>0?k+1|0:k;l=e;e=i;v=e-2|0;h=v;r=d-(e>>>0<2)|0;e=r;e=(d|0)==(e|0)&h>>>0<i>>>0|d>>>0>e>>>0;d=l+e|0;k=d>>>0<e>>>0?k+1|0:k;e=d;d=d-1|0;h=k-(e>>>0<1)|0;e=0;x=e;m=d;i=o;w=i<<2|c>>>30;B=0;q=OMa(d,e,w,B);e=ab;t=e;l=e;e=c;K=(e&1073741823)<<2|b>>>30;u=0;D=h;i=0;e=OMa(K,u,h,i);d=e+q|0;l=ab+l|0;l=d>>>0<e>>>0?l+1|0:l;k=(l|0)==(t|0)&d>>>0<q>>>0|l>>>0<t>>>0;q=d;h=l;A=r;l=0;r=l;c=k;E=((p&1073741823)<<2|o>>>30)&-262145|262144;l=OMa(A,l,E,0);d=l+d|0;k=ab+h|0;k=d>>>0<l>>>0?k+1|0:k;p=d;e=k;h=(k|0)==(h|0)&d>>>0<q>>>0|h>>>0>k>>>0;d=c+h|0;k=0;k=d>>>0<h>>>0?1:k;h=OMa(D,i,E,M);d=h+d|0;l=ab+k|0;l=d>>>0<h>>>0?l+1|0:l;o=OMa(m,x,E,M);h=ab;c=d;t=OMa(w,B,D,i);d=t+o|0;k=ab+h|0;k=d>>>0<t>>>0?k+1|0:k;t=d;d=k;k=(h|0)==(k|0)&o>>>0>t>>>0|h>>>0>k>>>0;o=c+d|0;k=k+l|0;l=o;h=l>>>0<d>>>0?k+1|0:k;q=p;c=l;p=0;d=q+p|0;o=e;l=t+e|0;l=d>>>0<p>>>0?l+1|0:l;k=d;e=l;p=(l|0)==(o|0)&k>>>0<q>>>0|l>>>0<o>>>0;l=c+p|0;k=h;C=l;h=l>>>0<p>>>0?k+1|0:k;o=d;p=e;q=OMa(K,u,A,r);e=ab;t=OMa(v,0,w,B);d=t+q|0;l=ab+e|0;l=d>>>0<t>>>0?l+1|0:l;t=d;q=(e|0)==(l|0)&q>>>0>d>>>0|e>>>0>l>>>0;e=l;y=q;k=b;L=k<<2&-4;c=0;k=OMa(m,x,L,c);d=k+d|0;l=ab+l|0;l=d>>>0<k>>>0?l+1|0:l;q=d;k=d;d=l;l=(l|0)==(e|0)&k>>>0<t>>>0|e>>>0>l>>>0;e=y+l|0;k=0;k=e>>>0<l>>>0?1:k;l=e;e=o+l|0;k=k+p|0;k=e>>>0<l>>>0?k+1|0:k;t=e;l=e;e=k;p=(k|0)==(p|0)&l>>>0<o>>>0|k>>>0<p>>>0;k=p+C|0;l=h;C=k;p=k>>>0<p>>>0?l+1|0:l;y=OMa(D,i,L,c);D=ab;i=OMa(E,M,v,O);h=i+y|0;k=ab+D|0;k=h>>>0<i>>>0?k+1|0:k;E=h;l=OMa(w,B,A,r);h=h+l|0;i=k;k=k+ab|0;k=h>>>0<l>>>0?k+1|0:k;w=h;o=OMa(m,x,K,u);h=h+o|0;l=k+ab|0;l=h>>>0<o>>>0?l+1|0:l;o=h;h=l;x=0;m=(l|0)==(k|0)&o>>>0<w>>>0|l>>>0<k>>>0;l=(i|0)==(k|0)&w>>>0<E>>>0|i>>>0>k>>>0;i=l+((i|0)==(D|0)&E>>>0<y>>>0|i>>>0<D>>>0)|0;k=0;i=m+i|0;k=i;l=h|0;i=l+t|0;k=(k|x)+e|0;k=i>>>0<l>>>0?k+1|0:k;l=k;m=(e|0)==(k|0)&i>>>0<t>>>0|e>>>0>k>>>0;e=m+C|0;k=p;w=e;e=e>>>0<m>>>0?k+1|0:k;t=i;p=l;A=OMa(A,r,L,c);r=ab;k=OMa(K,u,v,O);i=k+A|0;l=ab+r|0;l=i>>>0<k>>>0?l+1|0:l;m=l;l=0;k=(m|0)==(r|0)&i>>>0<A>>>0|m>>>0<r>>>0;i=m+q|0;k=(k|l)+d|0;k=i>>>0<m>>>0?k+1|0:k;m=i;l=i;i=k;l=(d|0)==(k|0)&l>>>0<q>>>0|d>>>0>k>>>0;d=k;q=l;k=o;o=0;h=o+m|0;l=d+k|0;d=h;l=d>>>0<o>>>0?l+1|0:l;h=(i|0)==(l|0)&d>>>0<m>>>0|i>>>0>l>>>0;d=q+h|0;l=0;l=d>>>0<h>>>0?1:l;h=d;d=d+t|0;k=l+p|0;k=d>>>0<h>>>0?k+1|0:k;h=d;i=k;k=(k|0)==(p|0)&d>>>0<t>>>0|k>>>0<p>>>0;d=k+w|0;l=e;l=d>>>0<k>>>0?l+1|0:l;e=l;d:{if((l|0)==131071|l>>>0<131071){y=0;m=f;x=0;k=OMa(h,y,m,x);o=ab;l=b<<17;b=0;c=(k|0)!=0|(o|0)!=0;u=b-c|0;D=l-(b>>>0<c>>>0)|0;b=0-(((k|0)!=0)+o|0)|0;r=0-k|0;v=b;c=0;w=OMa(i,c,m,x);b=ab;B=b;o=0;q=OMa(h,y,g,o);k=q+w|0;l=ab+b|0;l=k>>>0<q>>>0?l+1|0:l;b=k;q=0;t=k;k=(k|0)==(v|0)&r>>>0<q>>>0|k>>>0>v>>>0;C=u-k|0;u=D-(k>>>0>u>>>0)|0;k=OMa(d,0,m,x);m=ab;y=OMa(h,y,z,0);p=y+k|0;k=ab+m|0;k=p>>>0<y>>>0?k+1|0:k;m=OMa(g,o,i,c);p=m+p|0;k=ab+k|0;k=((l|0)==(B|0)&b>>>0<w>>>0|l>>>0<B>>>0)+(m>>>0>p>>>0?k+1|0:k)|0;b=l+p|0;p=b;b=b>>>0<l>>>0?k+1|0:k;k=OMa(h,i,H,0);m=ab;w=p;p=OMa(f,g,e,0);k=p+k|0;l=ab+m|0;l=k>>>0<p>>>0?l+1|0:l;m=OMa(d,e,g,o);p=m+k|0;l=OMa(i,c,z,F);c=l+p|0;l=c;z=0;c=w+z|0;k=b+l|0;k=c>>>0<z>>>0?k+1|0:k;b=c;z=C-b|0;F=u-((b>>>0>C>>>0)+k|0)|0;I=I-1|0;p=r-q|0;b=v-((r>>>0<q>>>0)+t|0)|0;break d}r=i>>>1|0;l=0;o=b<<16;h=(i&1)<<31|h>>>1;i=d<<31|i>>>1;w=0;m=f;B=0;b=OMa(h,w,m,B);k=ab;u=k;k=(b|0)!=0|(k|0)!=0;v=0-k|0;E=o-(c>>>0<k>>>0)|0;q=0-b|0;t=0-(((b|0)!=0)+u|0)|0;o=0;u=OMa(h,w,g,o);b=ab;D=b;k=e<<31|d>>>1;r=r|d<<31;O=k|l;C=r;L=0;l=OMa(r,L,m,B);c=l+u|0;k=ab+b|0;k=c>>>0<l>>>0?k+1|0:k;b=k;l=c;x=l;y=0;k=(l|0)==(t|0)&y>>>0>q>>>0|l>>>0>t>>>0;A=v-k|0;v=E-(k>>>0>v>>>0)|0;k=OMa(h,i,H,0);E=ab;M=OMa(m,g,e>>>1|0,0);l=M+k|0;k=ab+E|0;E=l;l=l>>>0<M>>>0?k+1|0:k;k=E;d=(e&1)<<31|d>>>1;e=e>>>1|0;E=OMa(d,e,g,o);k=k+E|0;l=ab+l|0;F=OMa(r,O,z,F);k=F+k|0;r=0;F=k;k=OMa(g,o,C,L);o=ab;m=OMa(d,0,m,B);l=m+k|0;k=ab+o|0;k=l>>>0<m>>>0?k+1|0:k;z=OMa(h,w,z,0);l=z+l|0;k=ab+k|0;p=l;l=l>>>0<z>>>0?k+1|0:k;z=(b|0)==(D|0)&c>>>0<u>>>0|b>>>0<D>>>0;c=b;b=b+p|0;l=l+z|0;l=b>>>0<c>>>0?l+1|0:l;c=b;b=b+r|0;l=l+F|0;l=b>>>0<c>>>0?l+1|0:l;z=A-b|0;F=v-((b>>>0>A>>>0)+l|0)|0;p=q-y|0;b=t-((q>>>0<y>>>0)+x|0)|0}if((I|0)>=16384){G=G|2147418112;b=0;c=0;break b}m=I+16383|0;if((I|0)<=-16383){e:{if(m){break e}m=p;k=b<<1|m>>>31;m=m<<1;c=(g|0)==(k|0)&f>>>0<m>>>0|g>>>0<k>>>0;f=z;k=F<<1|f>>>31;g=f<<1|b>>>31;l=g;f=(l|0)==(N|0)&(k|0)==(H|0)?c:(H|0)==(k|0)&l>>>0>N>>>0|k>>>0>H>>>0;b=f+h|0;k=i;k=b>>>0<f>>>0?k+1|0:k;c=k;f=d+((i|0)==(k|0)&b>>>0<h>>>0|i>>>0>k>>>0)|0;l=e&65535;e=f;l=d>>>0>e>>>0?l+1|0:l;d=l;if(!(l&65536)){break e}J=e|J;G=d|G;break b}b=0;c=0;break b}o=p;l=b<<1|o>>>31;o=o<<1;c=(g|0)==(l|0)&f>>>0<=o>>>0|g>>>0<l>>>0;f=z;l=F<<1|f>>>31;f=f<<1|b>>>31;f=(f|0)==(N|0)&(l|0)==(H|0)?c:(H|0)==(l|0)&f>>>0>=N>>>0|l>>>0>H>>>0;b=f+h|0;k=i;k=b>>>0<f>>>0?k+1|0:k;c=k;f=d+((i|0)==(k|0)&b>>>0<h>>>0|i>>>0>k>>>0)|0;l=e&65535;l=d>>>0>f>>>0?l+1|0:l;e=0;d=e+f|0;k=(m<<16)+l|0;J=d|J;G=G|(d>>>0<e>>>0?k+1|0:k)}j[a>>2]=b;j[a+4>>2]=c;j[a+8>>2]=J;j[a+12>>2]=G;Za=n+192|0;return}j[a>>2]=0;j[a+4>>2]=0;b=!(d|f|(e|g));j[a+8>>2]=b?0:J;j[a+12>>2]=b?2147450880:G;Za=n+192|0}function TF(a,b,c,d,e,f,g){var h=0,i=0,m=0,n=0;h=Za-128|0;Za=h;a:{b:{if(g){gj(h+112|0,f,32);j[114626]=0;K(798,h+96|0,f|0,32)|0;i=j[114626];j[114626]=0;if((i|0)!=1){break b}c=D()|0;C()|0;break a}Db(h+112|0);Db(h+96|0)}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(er(c)){i=b+24|0;b=j[i>>2];j[114626]=0;b=E(442,b+484344|0,c&65535)|0;m=j[114626];j[114626]=0;if((m|0)==1){break r}if(b){break q}}j[114626]=0;I(2187,a|0,h+112|0,h+96|0);a=j[114626];j[114626]=0;if((a|0)!=1){break p}}c=D()|0;C()|0;break c}b=Ib(j[i>>2]+484344|0,c);if(!(j[b+12>>2]>(d|0)?(d|0)>=0:0)){j[114626]=0;I(2187,a|0,h+112|0,h+96|0);a=j[114626];j[114626]=0;if((a|0)!=1){break p}break d}if(!(l[j[i>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){j[114626]=0;I(2187,a|0,h+112|0,h+96|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}break p}j[114626]=0;c=K(2188,b|0,d|0,e&65535)|0;b=j[114626];j[114626]=0;if((b|0)==1){break o}De(h+112|0);De(h+96|0);j[114626]=0;b=H(553,c|0)|0;d=j[114626];j[114626]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if((d|0)!=1){H:{I:{if(!b){if(!Er(c)){break I}}b=j[i>>2];d=k[c+1|0];e=k[c|0];j[114626]=0;L(2189,h- -64|0,b|0,e|0,d|0);d=j[114626];j[114626]=0;b=1;if((d|0)==1){break G}j[114626]=0;I(9,h+80|0,0,h- -64|0);d=j[114626];j[114626]=0;if((d|0)!=1){break H}c=D()|0;C()|0;break E}b=0;j[114626]=0;E(85,h+80|0,38869)|0;d=j[114626];j[114626]=0;if((d|0)==1){break v}}j[114626]=0;E(1245,h+112|0,h+80|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break F}gb(h+80|0);if(b){gb(h- -64|0)}j[114626]=0;b=H(553,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}J:{if(b){j[114626]=0;E(85,h+80|0,38873)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}break J}if(Er(c)){j[114626]=0;E(85,h+80|0,38877)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break J}break e}j[114626]=0;E(85,h+80|0,38869)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}}j[114626]=0;E(1245,h+96|0,h+80|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break D}gb(h+80|0);m=f-1|0;if(m>>>0<5){break w}j[114626]=0;b=E(85,h+80|0,38887)|0;d=j[114626];j[114626]=0;if((d|0)==1){break C}j[114626]=0;E(1245,h+112|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break B}gb(b);j[114626]=0;b=E(85,h+80|0,38887)|0;d=j[114626];j[114626]=0;if((d|0)==1){break A}j[114626]=0;E(1245,h+96|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break z}gb(b);b=c+1|0;K:{if(k[c+1|0]){j[114626]=0;F(835,h+80|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){break K}break f}j[114626]=0;E(85,h+80|0,38881)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}}j[114626]=0;E(1245,h+112|0,h+80|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break y}gb(h+80|0);L:{if(k[b|0]){j[114626]=0;E(85,h+80|0,38884)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break L}break g}j[114626]=0;E(85,h+80|0,38881)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}}j[114626]=0;E(1245,h+96|0,h+80|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break x}c=D()|0;C()|0;gb(h+80|0);break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;gb(h+80|0);if(!b){break c}}gb(h- -64|0);break c}c=D()|0;C()|0;gb(h+80|0);break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;gb(b);break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;gb(b);break c}c=D()|0;C()|0;gb(h+80|0);break c}gb(h+80|0);if(m>>>0<8){break w}j[114626]=0;b=H(1336,c|0)|0;d=j[114626];j[114626]=0;M:{N:{O:{P:{Q:{R:{S:{if((d|0)!=1){T:{if(b){j[114626]=0;b=E(85,h+48|0,38887)|0;d=j[114626];j[114626]=0;if((d|0)==1){break S}j[114626]=0;e=H(1338,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break R}d=0;j[114626]=0;j[h+16>>2]=e&255;F(834,h+32|0,h+16|0);n=j[114626];j[114626]=0;e=1;if((n|0)==1){break R}j[114626]=0;I(138,h+80|0,b|0,h+32|0);b=j[114626];j[114626]=0;if((b|0)!=1){break T}c=D()|0;C()|0;break i}if(k[c+2|0]){b=j[j[i>>2]+8>>2];d=k[c+2|0];j[114626]=0;b=E(2190,b|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break N}j[114626]=0;b=K(798,h+48|0,1,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break N}e=0;j[114626]=0;F(835,h+32|0,c+4|0);n=j[114626];j[114626]=0;d=1;if((n|0)==1){break Q}j[114626]=0;I(138,h+80|0,b|0,h+32|0);b=j[114626];j[114626]=0;if((b|0)!=1){break T}c=D()|0;C()|0;gb(h+32|0);break k}e=0;j[114626]=0;E(85,h+80|0,38901)|0;b=j[114626];j[114626]=0;d=0;if((b|0)==1){break O}}j[114626]=0;E(1245,h+112|0,h+80|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break P}gb(h+80|0);if(d){gb(h+32|0);gb(h+48|0)}if(e){gb(h+32|0);gb(h+48|0)}j[114626]=0;b=H(1336,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break l}U:{if(b){j[114626]=0;E(85,h+80|0,38905)|0;b=j[114626];j[114626]=0;if((b|0)==1){break l}break U}if(k[c+2|0]){j[114626]=0;E(85,h+80|0,38909)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break U}break l}j[114626]=0;E(85,h+80|0,38901)|0;b=j[114626];j[114626]=0;if((b|0)==1){break l}}j[114626]=0;E(1245,h+96|0,h+80|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break M}c=D()|0;C()|0;gb(h+80|0);break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;break h}c=D()|0;C()|0;break k}c=D()|0;C()|0;gb(h+80|0);if(!d){break j}gb(h+32|0);break k}c=D()|0;C()|0;break c}c=D()|0;C()|0;break c}gb(h+80|0);if(m>>>0<12){break w}j[114626]=0;b=E(85,h+80|0,38887)|0;d=j[114626];j[114626]=0;V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if((d|0)!=1){j[114626]=0;E(1245,h+112|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break ba}gb(b);j[114626]=0;b=E(85,h+80|0,38887)|0;d=j[114626];j[114626]=0;if((d|0)==1){break aa}j[114626]=0;E(1245,h+96|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break $}gb(b);j[114626]=0;b=H(1336,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break _}ca:{if(b){b=0;j[114626]=0;d=H(1337,c|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;j[h+28>>2]=d&4095;F(1056,h+80|0,h+28|0);d=j[114626];j[114626]=0;if((d|0)!=1){break ca}}c=D()|0;C()|0;break c}if(k[c+3|0]){b=j[j[i>>2]+8>>2];d=k[c+3|0];j[114626]=0;b=E(2191,b|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break Z}j[114626]=0;d=K(798,h+16|0,1,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break Z}j[114626]=0;F(835,h|0,c+5|0);e=j[114626];j[114626]=0;b=1;if((e|0)==1){break Y}j[114626]=0;I(138,h+80|0,d|0,h|0);d=j[114626];j[114626]=0;if((d|0)!=1){break ca}c=D()|0;C()|0;gb(h);break m}b=0;j[114626]=0;E(85,h+80|0,38869)|0;d=j[114626];j[114626]=0;if((d|0)==1){break W}}j[114626]=0;E(1245,h+112|0,h+80|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break X}gb(h+80|0);if(b){gb(h);gb(h+16|0)}j[114626]=0;b=H(1336,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break n}da:{if(b){j[114626]=0;E(85,h+80|0,38913)|0;b=j[114626];j[114626]=0;if((b|0)==1){break n}break da}if(k[c+3|0]){j[114626]=0;E(85,h+80|0,38913)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break da}break n}j[114626]=0;E(85,h+80|0,38869)|0;b=j[114626];j[114626]=0;if((b|0)==1){break n}}j[114626]=0;E(1245,h+96|0,h+80|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break V}c=D()|0;C()|0;gb(h+80|0);break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;gb(b);break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;gb(b);break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;break m}c=D()|0;C()|0;gb(h+80|0);if(!b){break c}gb(h);break m}c=D()|0;C()|0;break c}gb(h+80|0);if(!f){break s}}ea:{fa:{if(nb(h+112|0)>>>0>f>>>0){j[114626]=0;L(232,h+80|0,h+112|0,0,f|0);b=j[114626];j[114626]=0;if((b|0)!=1){break fa}c=D()|0;C()|0;break c}if(g){b=nb(h+112|0);j[114626]=0;b=K(798,h+80|0,f-b|0,32)|0;c=j[114626];j[114626]=0;if((c|0)==1){break u}j[114626]=0;E(1245,h+112|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){c=D()|0;C()|0;gb(b);break c}gb(b);if(nb(h+96|0)>>>0>f>>>0){break t}break ea}if(nb(h+96|0)>>>0<=f>>>0){break s}break t}ob(h+112|0,h+80|0);gb(h+80|0);if(nb(h+96|0)>>>0>f>>>0){break t}if(!g){break s}}b=nb(h+96|0);j[114626]=0;b=K(798,h+80|0,f-b|0,32)|0;c=j[114626];j[114626]=0;ga:{if((c|0)!=1){j[114626]=0;E(1245,h+96|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break ga}gb(b);break s}c=D()|0;C()|0;break c}c=D()|0;C()|0;gb(b);break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;break c}j[114626]=0;L(232,h+80|0,h+96|0,0,f|0);b=j[114626];j[114626]=0;if((b|0)!=1){ob(h+96|0,h+80|0);gb(h+80|0);break s}c=D()|0;C()|0;break c}j[114626]=0;I(2187,a|0,h+112|0,h+96|0);a=j[114626];j[114626]=0;if((a|0)==1){break o}}gb(h+96|0);gb(h+112|0);Za=h+128|0;return}c=D()|0;C()|0;break c}c=D()|0;C()|0;break c}gb(h+16|0);break c}c=D()|0;C()|0;break c}gb(h+48|0)}if(!e){break c}}gb(h+32|0)}gb(h+48|0);break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;break c}c=D()|0;C()|0;break c}c=D()|0;C()|0}gb(h+96|0)}gb(h+112|0);G(c|0);z()}function H2(a,b,c,d,e,f,g){var h=0,i=0,l=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=Za-8976|0;Za=h;z=d+e|0;F=0-z|0;a:{b:{while(1){if((c|0)!=48){c:{if((c|0)!=46){break a}c=j[b+4>>2];if(c>>>0>=m[b+104>>2]){break c}j[b+4>>2]=c+1;c=k[c|0];break b}}else{c=j[b+4>>2];if(c>>>0<m[b+104>>2]){l=1;j[b+4>>2]=c+1;c=k[c|0]}else{l=1;c=Lc(b)}continue}break}c=Lc(b)}n=1;if((c|0)!=48){break a}while(1){c=q;q=c-1|0;o=o-(c>>>0<1)|0;c=j[b+4>>2];d:{if(c>>>0<m[b+104>>2]){j[b+4>>2]=c+1;c=k[c|0];break d}c=Lc(b)}if((c|0)==48){continue}break}l=1}j[h+784>>2]=0;e:{f:{t=(c|0)==46;s=c-48|0;g:{h:{i:{j:{if(t|s>>>0<=9){while(1){k:{if(t&1){if(!n){q=r;o=i;n=1;break k}l=!l;break j}r=r+1|0;i=r>>>0<1?i+1|0:i;if((v|0)<=2044){y=(c|0)==48?y:r;l=(h+784|0)+(v<<2)|0;t=l;if(u){s=(p(j[l>>2],10)+c|0)-48|0}j[t>>2]=s;l=1;s=u+1|0;c=(s|0)==9;u=c?0:s;v=c+v|0;break k}if((c|0)==48){break k}j[h+8960>>2]=j[h+8960>>2]|1;y=18396}c=j[b+4>>2];l:{if(c>>>0<m[b+104>>2]){j[b+4>>2]=c+1;c=k[c|0];break l}c=Lc(b)}t=(c|0)==46;s=c-48|0;if(t|s>>>0<10){continue}break}}q=n?q:r;o=n?o:i;if(!(!l|(c&-33)!=69)){n=CD(b,g);c=ab;t=c;m:{if(n|(c|0)!=-2147483648){break m}if(!g){break g}n=0;t=0;if(!j[b+104>>2]){break m}j[b+4>>2]=j[b+4>>2]-1}if(!l){break h}o=o+t|0;b=n+q|0;o=b>>>0<n>>>0?o+1|0:o;q=b;break f}l=!l;if((c|0)<0){break i}}if(!j[b+104>>2]){break i}j[b+4>>2]=j[b+4>>2]-1}if(!l){break f}}j[114600]=28}r=0;i=0;Hg(b,0,0);c=0;b=0;break e}b=j[h+784>>2];if(!b){Ih(h,+(f|0)*0);r=j[h>>2];i=j[h+4>>2];c=j[h+12>>2];b=j[h+8>>2];break e}if(!((q|0)!=(r|0)|(i|0)!=(o|0)|((i|0)>0?1:(i|0)>=0?r>>>0>9:0)|(b>>>d|0?(d|0)<=30:0))){Vf(h+48|0,f);_l(h+32|0,b);$c(h+16|0,j[h+48>>2],j[h+52>>2],j[h+56>>2],j[h+60>>2],j[h+32>>2],j[h+36>>2],j[h+40>>2],j[h+44>>2]);r=j[h+16>>2];i=j[h+20>>2];c=j[h+28>>2];b=j[h+24>>2];break e}if((o|0)>0?1:(o|0)>=0?q>>>0>(e|0)/-2>>>0:0){j[114600]=68;Vf(h+96|0,f);$c(h+80|0,j[h+96>>2],j[h+100>>2],j[h+104>>2],j[h+108>>2],-1,-1,-1,2147418111);$c(h- -64|0,j[h+80>>2],j[h+84>>2],j[h+88>>2],j[h+92>>2],-1,-1,-1,2147418111);r=j[h+64>>2];i=j[h+68>>2];c=j[h+76>>2];b=j[h+72>>2];break e}b=e-226|0;c=q>>>0<b>>>0;b=b>>31;if((b|0)>(o|0)?1:(o|0)<=(b|0)?c:0){j[114600]=68;Vf(h+144|0,f);$c(h+128|0,j[h+144>>2],j[h+148>>2],j[h+152>>2],j[h+156>>2],0,0,0,65536);$c(h+112|0,j[h+128>>2],j[h+132>>2],j[h+136>>2],j[h+140>>2],0,0,0,65536);r=j[h+112>>2];i=j[h+116>>2];c=j[h+124>>2];b=j[h+120>>2];break e}if(u){if((u|0)<=8){c=(h+784|0)+(v<<2)|0;b=j[c>>2];while(1){b=p(b,10);u=u+1|0;if((u|0)!=9){continue}break}j[c>>2]=b}v=v+1|0}n:{n=q;if((y|0)>(n|0)|(y|0)>=9|(n|0)>17){break n}if((n|0)==9){Vf(h+192|0,f);_l(h+176|0,j[h+784>>2]);$c(h+160|0,j[h+192>>2],j[h+196>>2],j[h+200>>2],j[h+204>>2],j[h+176>>2],j[h+180>>2],j[h+184>>2],j[h+188>>2]);r=j[h+160>>2];i=j[h+164>>2];c=j[h+172>>2];b=j[h+168>>2];break e}if((n|0)<=8){Vf(h+272|0,f);_l(h+256|0,j[h+784>>2]);$c(h+240|0,j[h+272>>2],j[h+276>>2],j[h+280>>2],j[h+284>>2],j[h+256>>2],j[h+260>>2],j[h+264>>2],j[h+268>>2]);Vf(h+224|0,j[(0-n<<2)+57408>>2]);ED(h+208|0,j[h+240>>2],j[h+244>>2],j[h+248>>2],j[h+252>>2],j[h+224>>2],j[h+228>>2],j[h+232>>2],j[h+236>>2]);r=j[h+208>>2];i=j[h+212>>2];c=j[h+220>>2];b=j[h+216>>2];break e}b=(p(n,-3)+d|0)+27|0;c=j[h+784>>2];if(c>>>b|0?(b|0)<=30:0){break n}Vf(h+352|0,f);_l(h+336|0,c);$c(h+320|0,j[h+352>>2],j[h+356>>2],j[h+360>>2],j[h+364>>2],j[h+336>>2],j[h+340>>2],j[h+344>>2],j[h+348>>2]);Vf(h+304|0,j[(n<<2)+57336>>2]);$c(h+288|0,j[h+320>>2],j[h+324>>2],j[h+328>>2],j[h+332>>2],j[h+304>>2],j[h+308>>2],j[h+312>>2],j[h+316>>2]);r=j[h+288>>2];i=j[h+292>>2];c=j[h+300>>2];b=j[h+296>>2];break e}while(1){c=v;v=c-1|0;if(!j[(h+784|0)+(v<<2)>>2]){continue}break}u=0;b=(n|0)%9|0;o:{if(!b){l=0;break o}g=(n|0)>-1?b:b+9|0;p:{if(!c){l=0;c=0;break p}q=j[(0-g<<2)+57408>>2];o=1e9/(q|0)|0;t=0;b=0;l=0;while(1){s=t;i=(h+784|0)+(b<<2)|0;r=j[i>>2];t=(r>>>0)/(q>>>0)|0;s=s+t|0;j[i>>2]=s;s=!s&(b|0)==(l|0);l=s?l+1&2047:l;n=s?n-9|0:n;t=p(o,r-p(q,t)|0);b=b+1|0;if((c|0)!=(b|0)){continue}break}if(!t){break p}j[(h+784|0)+(c<<2)>>2]=t;c=c+1|0}n=(n-g|0)+9|0}while(1){r=(h+784|0)+(l<<2)|0;q:{while(1){if((n|0)!=36|m[r>>2]>=10384593?(n|0)>=36:0){break q}v=c+2047|0;t=0;s=c;while(1){c=s;i=v&2047;s=(h+784|0)+(i<<2)|0;b=j[s>>2];o=b>>>3|0;g=b<<29;b=g+t|0;o=b>>>0<g>>>0?o+1|0:o;q=b;g=0;r:{if(!o&b>>>0<1000000001){break r}g=RMa(b,o,1e9,0);q=q-OMa(g,ab,1e9,0)|0}t=g;j[s>>2]=q;s=(i|0)!=(c-1&2047)?c:(i|0)==(l|0)?c:q?c:i;v=i-1|0;if((i|0)!=(l|0)){continue}break}u=u-29|0;if(!t){continue}break}l=l-1&2047;if((s|0)==(l|0)){b=(h+784|0)+((s+2046&2047)<<2)|0;c=s-1&2047;j[b>>2]=j[b>>2]|j[(h+784|0)+(c<<2)>>2]}n=n+9|0;j[(h+784|0)+(l<<2)>>2]=t;continue}break}s:{t:while(1){g=c+1&2047;o=(h+784|0)+((c-1&2047)<<2)|0;while(1){q=(n|0)>45?9:1;u:{while(1){s=l;b=0;v:{while(1){w:{l=b+s&2047;if((l|0)==(c|0)){break w}l=j[(h+784|0)+(l<<2)>>2];i=j[(b<<2)+57360>>2];if(l>>>0<i>>>0){break w}if(i>>>0<l>>>0){break v}b=b+1|0;if((b|0)!=4){continue}}break}if((n|0)!=36){break v}q=0;o=0;b=0;r=0;i=0;while(1){g=b+s&2047;if((g|0)==(c|0)){c=c+1&2047;j[((c<<2)+h|0)+780>>2]=0}$c(h+768|0,q,o,r,i,0,0,1342177280,1075633366);_l(h+752|0,j[(h+784|0)+(g<<2)>>2]);Gf(h+736|0,j[h+768>>2],j[h+772>>2],j[h+776>>2],j[h+780>>2],j[h+752>>2],j[h+756>>2],j[h+760>>2],j[h+764>>2]);r=j[h+744>>2];i=j[h+748>>2];q=j[h+736>>2];o=j[h+740>>2];b=b+1|0;if((b|0)!=4){continue}break}Vf(h+720|0,f);$c(h+704|0,q,o,r,i,j[h+720>>2],j[h+724>>2],j[h+728>>2],j[h+732>>2]);r=j[h+712>>2];i=j[h+716>>2];q=0;o=0;n=j[h+704>>2];t=j[h+708>>2];l=u+113|0;e=l-e|0;g=(e|0)<(d|0);d=g?(e|0)>0?e:0:d;if((d|0)<=112){break u}break s}u=q+u|0;l=c;if((c|0)==(s|0)){continue}break}i=1e9>>>q|0;r=-1<<q^-1;b=0;l=s;while(1){t=(h+784|0)+(s<<2)|0;v=j[t>>2];b=(v>>>q|0)+b|0;j[t>>2]=b;b=!b&(l|0)==(s|0);l=b?l+1&2047:l;n=b?n-9|0:n;b=p(i,r&v);s=s+1&2047;if((s|0)!=(c|0)){continue}break}if(!b){continue}if((g|0)!=(l|0)){j[(h+784|0)+(c<<2)>>2]=b;c=g;continue t}j[o>>2]=j[o>>2]|1;l=g;continue}break}break}Ih(h+656|0,Bh(1,225-d|0));HD(h+688|0,j[h+656>>2],j[h+660>>2],j[h+664>>2],j[h+668>>2],n,t,r,i);A=j[h+696>>2];B=j[h+700>>2];C=j[h+688>>2];D=j[h+692>>2];Ih(h+640|0,Bh(1,113-d|0));KB(h+672|0,n,t,r,i,j[h+640>>2],j[h+644>>2],j[h+648>>2],j[h+652>>2]);q=j[h+672>>2];o=j[h+676>>2];w=j[h+680>>2];x=j[h+684>>2];fv(h+624|0,n,t,r,i,q,o,w,x);Gf(h+608|0,C,D,A,B,j[h+624>>2],j[h+628>>2],j[h+632>>2],j[h+636>>2]);r=j[h+616>>2];i=j[h+620>>2];n=j[h+608>>2];t=j[h+612>>2]}b=s+4&2047;x:{if((b|0)==(c|0)){break x}b=j[(h+784|0)+(b<<2)>>2];y:{if(b>>>0<=499999999){if((s+5&2047)==(c|0)?!b:0){break y}Ih(h+496|0,+(f|0)*.25);Gf(h+480|0,q,o,w,x,j[h+496>>2],j[h+500>>2],j[h+504>>2],j[h+508>>2]);w=j[h+488>>2];x=j[h+492>>2];q=j[h+480>>2];o=j[h+484>>2];break y}if((b|0)!=5e8){Ih(h+592|0,+(f|0)*.75);Gf(h+576|0,q,o,w,x,j[h+592>>2],j[h+596>>2],j[h+600>>2],j[h+604>>2]);w=j[h+584>>2];x=j[h+588>>2];q=j[h+576>>2];o=j[h+580>>2];break y}E=+(f|0);if((s+5&2047)==(c|0)){Ih(h+528|0,E*.5);Gf(h+512|0,q,o,w,x,j[h+528>>2],j[h+532>>2],j[h+536>>2],j[h+540>>2]);w=j[h+520>>2];x=j[h+524>>2];q=j[h+512>>2];o=j[h+516>>2];break y}Ih(h+560|0,E*.75);Gf(h+544|0,q,o,w,x,j[h+560>>2],j[h+564>>2],j[h+568>>2],j[h+572>>2]);w=j[h+552>>2];x=j[h+556>>2];q=j[h+544>>2];o=j[h+548>>2]}if((d|0)>111){break x}KB(h+464|0,q,o,w,x,0,0,0,1073676288);if(Kk(j[h+464>>2],j[h+468>>2],j[h+472>>2],j[h+476>>2],0,0,0,0)){break x}Gf(h+448|0,q,o,w,x,0,0,0,1073676288);w=j[h+456>>2];x=j[h+460>>2];q=j[h+448>>2];o=j[h+452>>2]}Gf(h+432|0,n,t,r,i,q,o,w,x);fv(h+416|0,j[h+432>>2],j[h+436>>2],j[h+440>>2],j[h+444>>2],C,D,A,B);r=j[h+424>>2];i=j[h+428>>2];n=j[h+416>>2];t=j[h+420>>2];z:{if((-2-z|0)>=(l&2147483647)){break z}j[h+408>>2]=r;j[h+412>>2]=i&2147483647;j[h+400>>2]=n;j[h+404>>2]=t;$c(h+384|0,n,t,r,i,0,0,0,1073610752);c=nE(j[h+400>>2],j[h+404>>2],j[h+408>>2],j[h+412>>2],1081081856);b=(c|0)<0;r=b?r:j[h+392>>2];i=b?i:j[h+396>>2];n=b?n:j[h+384>>2];t=b?t:j[h+388>>2];u=((c|0)>-1)+u|0;if(G=!(g&(b|(d|0)!=(e|0))&(Kk(q,o,w,x,0,0,0,0)|0)!=0),H=0,I=(u+110|0)<=(F|0),I?G:H){break z}j[114600]=68}FD(h+368|0,n,t,r,i,u);r=j[h+368>>2];i=j[h+372>>2];c=j[h+380>>2];b=j[h+376>>2]}j[a>>2]=r;j[a+4>>2]=i;j[a+8>>2]=b;j[a+12>>2]=c;Za=h+8976|0}function Pza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,H=0,J=0,L=0,M=0,O=0,Q=0,R=0;d=Za-304|0;Za=d;rc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!xs(b,d+208|0)){break j}if(!PN(d+208|0)){break j}if(!yb(b,Wc(ON(d+208|0),ab))){break j}if(!c){J=1;break j}if(!xc(b,k[d+208|4])){break j}od(a,268435456);_h(a);j[a+480208>>2]=4;f=Eb(d+88|0,16651);ob(a+1304436|0,f);gb(f);f=Eb(d+88|0,16670);ob(a+1304448|0,f);gb(f);j[a+1304496>>2]=4;He(d+16|0,d+208|6,48,3);qc(d+88|0,d+16|0);ob(a+1304400|0,d+88|0);gb(d+88|0);i[a+480188>>1]=k[d+262|0]+1;j[a+480228>>2]=k[d+265|0];j[a+480204>>2]=p(k[d+266|0],1e4);j[a+480196>>2]=k[d+267|0];if(k[d+262|0]){f=0;while(1){i[((f<<5)+a|0)+480284>>1]=p(k[(d+f|0)+268|0],17);f=f+1|0;if(f>>>0<k[d+262|0]){continue}break}}i[a+480190>>1]=k[d+300|0];r=Oza(d+192|0,k[d+302|0]|k[d+303|0]<<8);f=k[d+302|0]|k[d+303|0]<<8;j[114626]=0;K(934,b|0,r|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break i}x=jp(d+176|0);s=jp(d+160|0);f=k[d+301|0];j[114626]=0;K(628,b|0,x|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break f}f=k[d+300|0];j[114626]=0;K(628,b|0,s|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break f}if(k[d+300|0]){t=c&2;u=d+88|4;v=d+126|0;w=d+88|6;f=0;while(1){j[114626]=0;m=f;f=f+1|0;n=p(f,104)+a|0;g=n+484380|0;F(386,g|0,0);e=j[114626];j[114626]=0;k:{l:{if((e|0)!=1){e=xb(s,m);if(!(k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))){break k}e=xb(s,m);e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);j[114626]=0;e=E(256,b|0,e|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break c}if(!e){break k}j[114626]=0;e=E(935,b|0,d+88|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break c}if(!e){break k}j[114626]=0;I(745,d+72|0,2,w|0);e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;F(415,d+16|0,d+72|0);e=j[114626];j[114626]=0;if((e|0)!=1){break l}}f=D()|0;C()|0;break b}f=D()|0;C()|0;break b}j[114626]=0;E(369,((f<<5)+a|0)+946300|0,d+16|0)|0;e=j[114626];j[114626]=0;m:{n:{o:{p:{q:{if((e|0)!=1){gb(d+16|0);j[114626]=0;I(936,d+72|0,2,v|0);e=j[114626];j[114626]=0;if((e|0)==1){break q}j[114626]=0;F(415,d+16|0,d+72|0);e=j[114626];j[114626]=0;if((e|0)==1){break q}j[114626]=0;E(370,n+484423|0,d+16|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break p}gb(d+16|0);if(k[d+138|0]<=15){e=n+484414|0;i[e>>1]=l[e>>1]|32;i[n+484408>>1]=p(k[d+138|0],17)}e=k[d+139|0];j[114626]=0;h[d+16|0]=e;h[d+72|0]=64;e=E(391,d+16|0,d+72|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break o}i[n+484412>>1]=k[e|0];j[n+484404>>2]=k[d+141|0]|k[d+142|0]<<8;e=n+484384|0;j[e>>2]=k[d+147|0]|k[d+148|0]<<8|(k[d+149|0]<<16|k[d+150|0]<<24);q=n+484388|0;j[q>>2]=k[d+151|0]|k[d+152|0]<<8|(k[d+153|0]<<16|k[d+154|0]<<24);j[g>>2]=k[d+155|0]|k[d+156|0]<<8|(k[d+157|0]<<16|k[d+158|0]<<24);if(h[d+140|0]&1){break n}o=j[e>>2];e=j[q>>2];break m}f=D()|0;C()|0;gb(d+16|0);break b}f=D()|0;C()|0;break b}f=D()|0;C()|0;gb(d+16|0);break b}f=D()|0;C()|0;break b}o=j[e>>2]>>>1|0;j[e>>2]=o;e=j[q>>2]>>>1|0;j[q>>2]=e;j[g>>2]=j[g>>2]>>>1}r:{if(e>>>0<=o>>>0){break r}e=n+484414|0;i[e>>1]=l[e>>1]|2;if(!(k[d+140|0]&2)){break r}i[e>>1]=l[e>>1]|4}j[114626]=0;N(937,g|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}if(!t){break k}m=xb(s,m);m=k[m|0]|k[m+1|0]<<8|(k[m+2|0]<<16|k[m+3|0]<<24);e=k[u|0];j[114626]=0;E(256,b|0,e+m|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break c}m=Mc(d+16|0,h[d+140|0]&1?16:8,1,0,1);j[114626]=0;K(400,m|0,g|0,b|0)|0;m=j[114626];j[114626]=0;if((m|0)!=1){break k}f=D()|0;C()|0;break b}if(k[d+300|0]>f>>>0){continue}break}}J=1;s:{if(!(c&1)){break s}j[d+68>>2]=0;n=a+484360|0;wp(Fb(n));Q=d,R=Lb(r),j[Q+64>>2]=R;Q=d,R=Mb(r),j[Q+56>>2]=R;if(rb(d- -64|0,d+56|0)){q=a+484344|0;w=d+88|5;t=d+88|4;while(1){m=j[d- -64>>2];c=m;t:{if(k[c+3|0]>=k[d+301|0]|k[c+2|0]>k[d+262|0]){break t}c=xb(x,k[c+3|0]);c=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[114626]=0;c=E(256,b|0,c|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break g}if(!c){break t}j[114626]=0;E(938,b|0,d+88|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break h}if(!k[t|0]){break t}c=k[m|0]|k[m+1|0]<<8;f=k[m|0]|k[m+1|0]<<8;h[d+16|0]=k[w|0];e=k[d+262|0];g=k[m+2|0];j[114626]=0;h[d+72|0]=e-g;e=E(391,d+16|0,d+72|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break d}u=k[e|0];e=k[m|0]|k[m+1|0]<<8;g=k[t|0];j[114626]=0;j[d+52>>2]=e+g;e=E(392,d+68|0,d+52|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break e}j[d+68>>2]=j[e>>2];j[d+40>>2]=0;j[d+44>>2]=0;j[d+32>>2]=0;j[d+36>>2]=0;j[d+24>>2]=0;j[d+28>>2]=0;j[d+16>>2]=0;j[d+20>>2]=0;if(!k[t|0]){break t}y=c>>>6|0;e=f&63;B=0;while(1){u:{v:{w:{x:{y:{z:{A:{f=e>>>0>63;y=f+y|0;c=y&65535;if(bc(Fb(n))>>>0<=c>>>0){g=Fb(n);j[114626]=0;F(925,g|0,y+1&65535);g=j[114626];j[114626]=0;if((g|0)==1){break A}j[114626]=0;g=K(810,q|0,64,0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break A}Q=ac(Fb(n),c),R=g,i[Q>>1]=R}v=l[ac(Fb(n),c)>>1];j[114626]=0;c=E(442,q|0,v|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break y}if(!c){break t}c=Ib(q,v);g=k[m+2|0];j[114626]=0;A=f?0:e;f=K(471,c|0,A|0,g|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break v}o=0;H=0;if(u){break z}break w}f=D()|0;C()|0;break b}while(1){j[114626]=0;F(939,d+72|0,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break x}g=Pc(d+72|0);M=Bf(d+72|0);L=pi(d+72|0);O=Rb(d+72|0);e=0;c=k[d+72|0];if((c-1&255)>>>0<=142){e=(p((c&240)>>>4|0,12)+(c&15)|0)+13|0;h[(d+16|0)+o|0]=e}h[f|0]=e;c=k[g|0];h[f+2|0]=1;h[f+1|0]=c;c=k[M|0];B:{if((c|0)!=255){h[f+4|0]=c;break B}h[f+2|0]=0}c=k[L|0];C:{if(c>>>0>22){break C}h[f+3|0]=k[c+16688|0];g=k[O|0];h[f+5|0]=g;c=f+5|0;D:{switch(k[L|0]-4|0){case 3:h[c|0]=g&3|64;break C;case 4:h[c|0]=g&3|48;break C;case 7:if(sb(r)>>>0<=g>>>0){break C}g=c;c=xb(r,k[c|0]);e=k[c|0]|k[c+1|0]<<8;h[g|0]=e>>>6;c=Ib(q,v);g=l[a+480188>>1];j[114626]=0;c=K(471,c|0,A|0,g-1&65535)|0;g=j[114626];j[114626]=0;if((g|0)!=1){h[c+3|0]=14;h[c+5|0]=e&63;break C}f=D()|0;C()|0;break b;case 8:h[c|0]=j[d+52>>2]>>>6;c=Ib(q,v);e=l[a+480188>>1];j[114626]=0;c=K(471,c|0,A|0,e-1&65535)|0;e=j[114626];j[114626]=0;if((e|0)!=1){h[c+3|0]=14;h[c+5|0]=k[d+52|0]&63;break C}f=D()|0;C()|0;break b;case 10:h[c|0]=g&15|128;break C;case 12:j[114626]=0;h[d+15|0]=15;e=E(391,c|0,d+15|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){h[c|0]=k[e|0]|208;break C}f=D()|0;C()|0;break b;case 13:j[114626]=0;h[d+15|0]=15;e=E(391,c|0,d+15|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){h[c|0]=k[e|0]|192;break C}f=D()|0;C()|0;break b;case 14:j[114626]=0;h[d+15|0]=15;e=E(391,c|0,d+15|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){h[c|0]=k[e|0]|224;break C}f=D()|0;C()|0;break b;case 0:case 16:case 17:if(!(g&15)){break C}e=g&240;if(!e|(e|0)==240){break C}h[c|0]=g|15;break C;case 9:case 18:break D;default:break C}}if(e&255){break C}h[f|0]=k[(d+16|0)+o|0]}f=f+6|0;H=H+1|0;o=H&65535;if(u>>>0>o>>>0){continue}break}break w}f=D()|0;C()|0;break b}f=D()|0;C()|0;break b}if(u>>>0>=k[w|0]){break u}c=k[w|0];j[114626]=0;E(338,b|0,p(c-u|0,5)|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break u}}f=D()|0;C()|0;break b}e=A+1|0;B=B+1|0;if(B>>>0<k[t|0]){continue}break}}Id(d- -64|0);if(rb(d- -64|0,d+56|0)){continue}break}}E:{b=j[d+68>>2];c=b&63;if(!c){break E}f=Fb(n);j[114626]=0;b=b>>>6|0;f=E(546,f|0,b&65535)|0;m=j[114626];j[114626]=0;if((m|0)!=1){if(!f){break E}b=Ib(a+484344|0,l[ac(Fb(n),b&65535)>>1]);j[114626]=0;P(940,b|0,c|0,0,1)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break E}}f=D()|0;C()|0;break b}b=Fb(n);Q=d,R=Lb(b),j[Q+88>>2]=R;Q=d,R=Mb(b),j[Q+16>>2]=R;if(!rb(d+88|0,d+16|0)){break s}a=a+484344|0;e=65535;while(1){b=j[d+88>>2];if(l[b>>1]==65535){F:{if((e&65535)!=65535){break F}j[114626]=0;e=K(810,a|0,64,0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break F}f=D()|0;C()|0;break b}i[b>>1]=e}je(d+88|0);if(rb(d+88|0,d+16|0)){continue}break}}li(s);li(x);MN(r)}Za=d+304|0;return J|0}f=D()|0;C()|0;break a}f=D()|0;C()|0;break b}f=D()|0;C()|0;break b}f=D()|0;C()|0;break b}f=D()|0;C()|0;break b}f=D()|0;C()|0;break b}f=D()|0;C()|0}li(s);li(x)}MN(r);G(f|0);z()}function jJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,m=0,n=0,o=0,q=0,r=0,s=0;d=Za-240|0;Za=d;rc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!zz(b,d+168|0)){break j}if(!pR(d+168|0)){break j}if(!c){e=1;break j}od(a,131072);n=Eb(d+152|0,12688);j[114626]=0;F(219,d+32|0,n|0);e=j[114626];j[114626]=0;k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){j[114626]=0;I(536,d+104|0,d+32|0,d+168|4);e=j[114626];j[114626]=0;if((e|0)==1){break q}ob(a+1304436|0,d+104|0);gb(d+104|0);qb(d+32|0);gb(n);e=Eb(d+104|0,12702);ob(a+1304448|0,e);gb(e);j[a+1304496>>2]=4;JR(d+32|0,3,d+181|0);qc(d+104|0,d+32|0);ob(a+1304400|0,d+104|0);gb(d+104|0);en(d+72|0,3,d+211|0);qc(d+32|0,d+72|0);j[114626]=0;I(13,d+104|0,4,d+32|0);e=j[114626];j[114626]=0;if((e|0)==1){break i}ob(a+1304412|0,d+104|0);gb(d+104|0);gb(d+32|0);e=pp(d+104|0);r=e,s=kd(k[d+231|0],1,31),j[r+12>>2]=s;r=e,s=kd(k[d+232|0],1,12)-1|0,j[r+16>>2]=s;j[e+20>>2]=k[d+233|0];n=a+1304500|0;yz(n);oR(n,e);m=d+72|4;n=d+88|0;OIa(n);while(1){j[114626]=0;e=E(258,b|0,8)|0;f=j[114626];j[114626]=0;if((f|0)==1){break o}if(!e){break k}j[114626]=0;E(537,b|0,d+72|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break n}e=k[m|0]|k[m+1|0]<<8|(k[m+2|0]<<16|k[m+3|0]<<24);f=k[d+172|0];r:{if((f|0)==3){f=k[d+72|0]|k[d+73|0]<<8|(k[d+74|0]<<16|k[d+75|0]<<24);if(e>>>0<=4294967292){g=2;if((f|0)==1431389523){break r}}f=k[d+172|0]}if((f|0)==4){f=k[d+72|0]|k[d+73|0]<<8|(k[d+74|0]<<16|k[d+75|0]<<24);if(e>>>0<=4294967290){g=4;if((f|0)==1431389523){break r}}f=k[d+172|0]}g=0;if(f>>>0>7){break r}e=(k[d+72|0]|k[d+73|0]<<8|(k[d+74|0]<<16|k[d+75|0]<<24))==1146113363?-1:e}j[114626]=0;I(341,d+32|0,b|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break m}j[114626]=0;K(538,n|0,d+72|0,d+32|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break l}jb(d+32|0);j[114626]=0;E(338,b|0,g|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){continue}break}e=D()|0;C()|0;break b}e=D()|0;C()|0;break p}e=D()|0;C()|0;qb(d+32|0)}gb(n);break a}e=D()|0;C()|0;break b}e=D()|0;C()|0;break b}e=D()|0;C()|0;break b}e=D()|0;C()|0;jb(d+32|0);break b}j[114626]=0;b=H(277,d+72|0)|0;e=j[114626];j[114626]=0;s:{t:{u:{if((e|0)!=1){j[114626]=0;I(539,d+32|0,n|0,1431389523);e=j[114626];j[114626]=0;if((e|0)==1){break u}Ed(b,d+32|0);jb(d+32|0);i[d+70>>1]=0;i[d+68>>1]=65534;if(k[d+172|0]<3){break s}j[114626]=0;e=H(357,b|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){break t}break d}e=D()|0;C()|0;break b}e=D()|0;C()|0;break c}i[d+70>>1]=e;if(k[d+172|0]<4){break s}j[114626]=0;e=H(357,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}i[d+68>>1]=k[d+172|0]==4?e?e:-2:e}e=a+484360|0;f=Fb(e);j[114626]=0;g=H(540,b|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break d}j[114626]=0;U(441,f|0,b|0,g>>>1|0,65535,65535)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}f=Fb(e);j[114626]=0;f=H(541,f|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break d}Sf(d+70|0,f);f=Fb(e);j[114626]=0;f=H(541,f|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break d}Sf(d+68|0,f);j[114626]=0;I(539,d+32|0,n|0,1414807888);f=j[114626];j[114626]=0;v:{w:{x:{y:{z:{A:{B:{C:{if((f|0)!=1){Ed(b,d+32|0);jb(d+32|0);j[114626]=0;f=H(337,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break d}if(!(c&1)|f^1){break v}j[114626]=0;E(542,b|0,d- -64|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break C}r=a,s=kd(k[d- -64|2],1,32)+1|0,i[r+480188>>1]=s;f=d- -64|0;f=k[f|0]|k[f+1|0]<<8;j[114626]=0;f=E(395,d|0,f|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break B}r=d,s=Lb(f),j[r+16>>2]=s;r=d,s=Mb(f),j[r+56>>2]=s;if(rb(d+16|0,d+56|0)){while(1){m=j[d+16>>2];j[114626]=0;g=k[d+172|0]<3?9:8;E(338,b|0,g-4|0)|0;h=j[114626];j[114626]=0;if((h|0)==1){break A}j[114626]=0;h=H(390,b|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break z}cg(b,g);j[114626]=0;I(341,d+32|0,b|0,g+h|0);g=j[114626];j[114626]=0;if((g|0)==1){break y}Ed(m,d+32|0);jb(d+32|0);yf(d+16|0);if(rb(d+16|0,d+56|0)){continue}break}}g=l[a+480188>>1];j[114626]=0;g=E(543,d+32|0,g|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break x}m=Fb(e);j[114626]=0;h=H(544,m|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break f}j[114626]=0;m=a+484344|0;F(401,m|0,h|0);h=j[114626];j[114626]=0;if((h|0)==1){break f}h=Fb(e);r=d,s=Lb(h),j[r+16>>2]=s;r=d,s=Mb(h),j[r+56>>2]=s;if(rb(d+16|0,d+56|0)){while(1){h=j[d+16>>2];o=l[h>>1];if(Xc(f)>>>0>o>>>0){o=_b(f,l[h>>1]);j[114626]=0;o=P(545,o|0,k[d+172|0],g|0,a|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break f}i[h>>1]=o}je(d+16|0);if(rb(d+16|0,d+56|0)){continue}break}}h=Fb(e);j[114626]=0;h=E(546,h|0,l[d+68>>1])|0;o=j[114626];j[114626]=0;if((o|0)==1){break f}if(!h){break w}if(!l[d+70>>1]){h=l[d+68>>1];o=Fb(e);j[114626]=0;o=H(541,o|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break f}if(h>>>0>=o>>>0){break w}}e=l[ac(Fb(e),l[d+68>>1])>>1];h=Ib(m,e);j[114626]=0;o=K(497,d+16|0,12,k[d+70|0])|0;q=j[114626];j[114626]=0;if((q|0)!=1){e=dn(Fe(o,j[Ib(m,e)+12>>2]-1|0));j[114626]=0;E(498,h|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break w}}break f}e=D()|0;C()|0;break c}e=D()|0;C()|0;break c}e=D()|0;C()|0;break c}e=D()|0;C()|0;break e}e=D()|0;C()|0;break e}e=D()|0;C()|0;break e}e=D()|0;C()|0;break e}eR(g);Sc(f)}j[114626]=0;I(539,d+32|0,n|0,1196641603);e=j[114626];j[114626]=0;if((e|0)==1){break h}Ed(b,d+32|0);jb(d+32|0);j[114626]=0;e=H(337,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}if(e){j[114626]=0;E(338,b|0,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break d}j[114626]=0;e=H(540,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}j[114626]=0;U(547,a+1304424|0,b|0,e|0,40,0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break d}}j[114626]=0;I(539,d+32|0,n|0,1146113363);e=j[114626];j[114626]=0;if((e|0)==1){break g}j[114626]=0;I(539,d+16|0,n|0,1229999443);e=j[114626];j[114626]=0;D:{E:{if((e|0)!=1){Ed(b,d+16|0);jb(d+16|0);j[114626]=0;e=H(387,b|0)|0;f=j[114626];j[114626]=0;F:{if((f|0)!=1){i[a+480190>>1]=e;if(l[a+480190>>1]){m=c&2;e=1;c=1;while(1){g=30;G:{H:{I:{if(k[d+172|0]>=2){j[114626]=0;g=H(387,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break I}}j[114626]=0;K(548,b|0,((e<<5)+a|0)+946300|0,g|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break I}j[114626]=0;E(549,b|0,d+16|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break H}j[114626]=0;e=p(e,104)+a|0;g=e+484380|0;F(550,d+16|0,g|0);f=j[114626];j[114626]=0;if((f|0)==1){break H}f=k[d+172|0];if(f>>>0>=8){j[114626]=0;K(551,b|0,e+484423|0,8)|0;f=j[114626];j[114626]=0;if((f|0)==1){break H}f=k[d+172|0]}j[114626]=0;E(338,b|0,(f>>>0>1?6:2)|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break H}j[114626]=0;f=H(390,d+32|0)|0;h=j[114626];j[114626]=0;if((h|0)!=1){j[114626]=0;I(341,d|0,d+32|0,f|0);f=j[114626];j[114626]=0;if((f|0)!=1){break G}}e=D()|0;C()|0;break E}e=D()|0;C()|0;break E}e=D()|0;C()|0;break E}j[114626]=0;f=H(337,d|0)|0;h=j[114626];j[114626]=0;if((h|0)==1){break F}J:{if(!m|f^1){break J}e=Mc(d+56|0,i[e+484414>>1]&1?16:8,1,0,(k[d+31|0]&12)==4?7:0);j[114626]=0;K(400,e|0,g|0,d|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break J}break F}jb(d);c=c+1|0;e=c&65535;if(e>>>0<=l[a+480190>>1]){continue}break}}j[114626]=0;N(476,a|0);c=j[114626];j[114626]=0;e=1;if((c|0)!=1){break D}}e=D()|0;C()|0;break E}e=D()|0;C()|0;jb(d);break E}e=D()|0;C()|0}jb(d+32|0);break c}j[a+480204>>2]=12e5;j[a+480208>>2]=24;j[a+480196>>2]=6;j[a+480200>>2]=256;j[a+480228>>2]=48;j[a+480232>>2]=48;jb(d+32|0);jb(b);nR(n)}Za=d+240|0;return e|0}e=D()|0;C()|0;gb(d+32|0);break a}e=D()|0;C()|0;break c}e=D()|0;C()|0;break c}e=D()|0;C()|0;eR(g)}Sc(f);break c}e=D()|0;C()|0}jb(b)}nR(n)}G(e|0);z()}function wma(a){var b=0,c=0,d=0,e=0,f=0,g=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;c=Za-32|0;Za=c;a:{if(!uma(a)|!j[a+1074420>>2]){break a}b=tJ(a,a+1074376|0);j[a+1074380>>2]=b;j[a+1074404>>2]=b;w=kd(l[a+480188>>1],1,31);z=a+1074328|0;b:{if(k[z+37|0]){b=j[a+24628>>2];if((b|0)>=129){b=((p(b-128|0,w+4|0)|0)/16|0)+128|0}A=p(j[a+480228>>2],b)>>>6|0;break b}A=j[a+480228>>2]}A=k[z+37|0]?(A<<7>>>0)/k[(w>>>1|0)+20752|0]|0:A;i[a+480212>>1]=0;y=a+1304392|0;x=a+1074308|0;C=a+480210|0;D=a+480209|0;while(1){d=p(v,896)+a|0;q=d+1075072|0;c:{if(!(j[q>>2]&4096)|(j[d+1075008>>2]|(j[d+1075004>>2]|j[d+1075680>>2]))){break c}mb(c+24|0,x,64);if(kb(c+24|0)){break c}j[d+1075060>>2]=0;b=d+1075076|0;j[b>>2]=0;j[b+4>>2]=0}b=l[a+480188>>1];g=j[q>>2];d:{if(!(j[d+1075060>>2]|b>>>0>v>>>0?!(g&1024):0)){if(b>>>0>v>>>0){iJ(a,v&65535)}i[d+1075846>>1]=0;break d}o=0;B=d+1075704|0;j[B>>2]=0;t=d+1075664|0;j[t>>2]=0;w=d+1074992|0;e=w;j[e>>2]=0;j[e+4>>2]=0;j[d+1075084>>2]=0;j[c+20>>2]=1065353216;i[c+18>>1]=0;f=0;e=d+1075684|0;f=j[e>>2]?j[d+1075060>>2]!=0:f;s=d+1074984|0;E=d+1075640|0;r=j[E>>2];e:{f:{g:{if(b>>>0<=v>>>0){break g}if(k[((v<<5)+a|0)+480288|0]){break f}if(!r){break g}o=k[r+34|0]!=0}if((f|o)!=1){break e}}j[c+8>>2]=j[d+1075672>>2];j[c+4>>2]=j[d+1075748>>2];mb(c+24|0,x,28);tma(a,s,kb(c+24|0)?c+4|0:c+8|0);sma(a,s);rma(a,s,c+8|0);g=v&65535;pma(a,g,c+8|0);Md(c+8|0,0,256);b=j[c+8>>2]<<6;j[c+8>>2]=b;h:{i:{if(r){mb(c+24|0,x,31);if(kb(c+24|0)){Hr(a,s)}oma(a,s,c+8|0);hJ(s,c+8|0);nma(a,s);mma(s);b=j[c+8>>2];break i}if(!(k[q+1|0]&16)){break i}j[d+1075680>>2]=0;j[c+8>>2]=0;break h}if(!b){break h}if(k[q+3|0]&8){j[t>>2]=0;break h}b=j[c+8>>2];if(k[z+36|0]){o=p(j[c+4>>2],j[d+1075744>>2]);b=b<<8;I=t,J=ic(PMa(OMa(o,o>>31,b,b>>31),ab,1048576,0),ab),j[I>>2]=J;break h}o=p(j[c+4>>2],j[d+1075744>>2]);b=p(b,j[a+1074444>>2]);I=t,J=ic(PMa(OMa(o,o>>31,b,b>>31),ab,1048576,0),ab),j[I>>2]=J}j[B>>2]=j[c+8>>2];j:{if(j[a+480180>>2]==2|j[e>>2]>=j[a+480260>>2]){break j}if(zo(a)){break j}j[e>>2]=j[a+480260>>2]}mb(c+24|0,x,73);if(kb(c+24|0)){Gb(j[e>>2],1,31999)}b=j[e>>2];j[c+12>>2]=b;k:{if((j[q>>2]&1572864)!=1572864){break k}if(k[C|0]&32){if(!Zr(d+1075794|0)|k[D|0]&16){break k}b=j[c+12>>2]}o=d+1075696|0;l:{if(j[o>>2]==(b|0)){b=j[d+1075700>>2];break l}j[o>>2]=b;u=b;b=d+1075752|0;o=d+1075688|0;b=Zf(a,Qr(a,u,j[b>>2],j[o>>2]),j[b>>2],j[o>>2]);j[d+1075700>>2]=b}j[c+12>>2]=b}lma(a,g,c+12|0,c+18|0);if(!(!(k[C|0]&33)|j[c+12>>2]==2147483647)){m:{if(j[a+480180>>2]==2){b=452;g=3424;break m}g=p(j[d+1075752>>2]>>>4&15,24)+21024|0;b=l[g+22>>1];b=b>>>0<904?452:b>>>1|0;g=l[g>>1]<<1}Md(c+12|0,b,g);Md(e,b,g)}gJ(a,s);g=j[q>>2]}n:{if(!(g&256)|k[D|0]&64){break n}mb(c+24|0,x,37);if(!kb(c+24|0)){break n}j[d+1075668>>2]=128}b=v&65535;iJ(a,b);o:{if(!f){break o}g=fJ(a,s,c+12|0);if((g|0)<0|!(k[q+1|0]&2)){break o}if(!bd(y)){break o}No(j[y>>2],b,g>>>2&255,1)}p:{if(k[d+1075796|0]!=8){break p}q:{r:{g=k[d+1075797|0];switch(g-5|0){case 1:break p;case 0:case 2:break q;default:break r}}if((g|0)!=26){break p}}if(j[a+480180>>2]==4){if(k[D|0]&16){break p}g=d+1075823|0;h[g|0]=k[g|0]+k[d+1075827|0];break p}if(!(j[a+480180>>2]&16777248)){break p}Nj(s,k[d+1075798|0]);eJ(a,b,c+12|0,c+20|0)}eJ(a,b,c+12|0,c+20|0);if(f){j[c+8>>2]=0;kma(a,s,c+12|0,c+20|0,c+8|0);if(j[c+12>>2]<=j[a+480260>>2]){mb(c+24|0,x,81);if(kb(c+24|0)){j[d+1075060>>2]=0}j[c+12>>2]=j[a+480260>>2]}o=Wi(s);s:{if(!o){break s}f=d+1075856|0;g=k[f|0];if(j[a+1074392>>2]|!(g&4)?!(g&8):0){break s}oM(s,n[c+20>>2],i[c+18>>1],a);g=k[f|0];if(!(g&8)){h[f|0]=g&251;break s}h[f|0]=g&247}t:{if((j[q>>2]&134219264)!=512){break t}if(!bd(y)){break t}mb(c+24|0,x,99);if(!(I=!(kb(c+24|0)|!(k[q+1|0]&16)),J=0,K=j[a+480180>>2]!=2,K?I:J)){if(!(k[q+1|0]&8?j[a+480180>>2]==2:0)){if(o){e=j[e>>2]}else{e=_J(a,j[c+12>>2],j[d+1075688>>2],j[c+8>>2])}f=OMa(e,0,261625,0)+66904|0;e=ab;f=Wc(RMa(f,f>>>0<66904?e+1|0:e,133808,0),ab);g=j[q>>2];e=1;u:{if(g&2048){break u}e=0;if(!(g&4096)){break u}e=!j[d+1075680>>2]}g=j[y>>2];mb(c+24|0,x,95);osa(g,b,f,e,kb(c+24|0))}u=j[y>>2];f=OMa(p(j[d+1075748>>2],p(j[d+1075744>>2],j[B>>2])),0,63,0)+33554432|0;e=ab;e=f>>>0<33554432?e+1|0:e;No(u,b,Wc((e&67108863)<<6|f>>>26,e>>>26|0)&255,0);e=d+1075668|0;I=e,J=(nsa(j[y>>2],b,j[e>>2])<<7)+128|0,j[I>>2]=J}v:{e=j[E>>2];if(!e|(k[e+60|0]&7)!=1){break v}e=e+48|0;if(ad(e)){break v}if(m[dJ(s,0)+4>>2]<l[Ri(e)>>1]){break v}if(k[Ri(e)+2|0]){break v}bi(j[y>>2],b,1);mb(c+24|0,x,109);e=kb(c+24|0);b=j[q>>2];if(!e){b=b&-513;j[q>>2]=b}j[q>>2]=b|4096;j[d+1075680>>2]=0;break t}mb(c+24|0,x,99);if(!kb(c+24|0)|!(k[q+1|0]&16)|j[d+1075680>>2]){break t}bi(j[y>>2],b,1);j[q>>2]=j[q>>2]&-513}f=OMa(_w(a,s,j[c+12>>2],j[c+8>>2]),ab,j[a+480240>>2],0);b=ab;g=PMa(f,b,65536,0);o=ab;e=w;f=f+65535|0;b=f>>>0<65535?b+1|0:b;b=!b&f>>>0<131071;j[e>>2]=b?1:g;j[e+4>>2]=b?0:o}w:{if(!r){break w}mb(c+24|0,x,31);if(kb(c+24|0)){break w}Hr(a,s)}B=d+1075004|0;F=d+1075008|0;j[q>>2]=j[q>>2]&-65537|((j[B>>2]|(j[F>>2]|j[t>>2]))!=0)<<16;e=d+1075656|0;b=e;j[b>>2]=0;j[b+4>>2]=0;r=d+1075846|0;b=k[r|0];h[r|0]=(b>>>0>4?b:4)-4;g=d+1075847|0;b=k[g|0];h[g|0]=(b>>>0>4?b:4)-4;x:{y:{z:{A:{B:{b=d+1075088|0;f=j[b>>2];C:{if(!f){break C}if(!ke(f)|!j[d+1075060>>2]){break C}if(ph(s)){break B}}o=d+1075e3|0;j[o>>2]=0;break A}o=d+1075e3|0;b=j[j[b>>2]+20>>2];j[o>>2]=b;if(b){break z}}if(!Qi(s)|k[q+1|0]&24){break y}}G=j[t>>2];H=j[d+1075668>>2];b=(p(G,256-H|0)|0)/16384|0;f=b>>>0<127?b:127;b=h[r|0];if((b|0)<=-1){h[r|0]=f;u=f}else{u=b}b=f>>>1|0;if((u&255)>>>0<b>>>0){h[r|0]=b}b=(p(G,H)|0)/16384|0;f=b>>>0<127?b:127;b=h[g|0];if((b|0)<=-1){h[g|0]=f;u=f}else{u=b}b=f>>>1|0;if((u&255)>>>0>=b>>>0){break x}h[g|0]=b;break x}if(k[r|0]>=129){h[r|0]=0}if(k[g|0]<129){break x}h[g|0]=0}D:{if(j[o>>2]){b=d+1075660|0;E:{if(m[a+24624>>2]>=2){j[c+24>>2]=j[d+1075668>>2];Md(c+24|0,0,256);r=p(j[t>>2],A)>>>(k[z+37|0]?7:8)|0;f=b;F:{G:{H:{switch(j[z+32>>2]){case 0:if(!(k[a+24616|0]&16)){break G};case 1:t=j[c+24>>2];if((t|0)<=127){j[e>>2]=r>>>1;u=(p(r,t)|0)/256|0;break F}j[e>>2]=(p(r,256-t|0)|0)/256;u=r>>>1|0;break F;case 3:break H;default:break G}}Zj(c+24|0,255);u=e;o=j[c+24>>2];g=65536;I:{if((o|0)<1){break I}g=l[(0-o<<1)+27872>>1]}j[u>>2]=p(g,r)>>>16;u=p(r,l[(o<<1)+27360>>1])>>>16|0;break F}t=j[c+24>>2];j[e>>2]=(p(r,256-t|0)|0)/256;u=(p(r,t)|0)/256|0}j[f>>2]=u;break E}f=p(j[t>>2],A)>>>8|0;j[e>>2]=f;j[b>>2]=f}f=j[E>>2];J:{if(f){f=k[f+14|0];if(qn(f)){break J}}f=k[a+480268|0];if(qn(f)){break J}if(k[C|0]&128){f=255;if(j[a+24668>>2]){break J}}f=k[a+24648|0]}t=d+1075800|0;h[t|0]=f;if(!(k[q+2|0]&2|(j[w>>2]!=0|j[w+4>>2]!=1)|(j[d+1075764>>2]|(f|0)==255))){h[t|0]=0}f=e;u=j[e>>2];e=1<<j[z+28>>2];j[f>>2]=(u|0)/(e|0);e=j[b>>2]/(e|0)|0;j[b>>2]=e;f=j[q>>2];if(!(!(f&256)|j[a+24624>>2]!=2)){j[b>>2]=0-e}if(f&128){b=j[w>>2];e=0-(j[w+4>>2]+((b|0)!=0)|0)|0;j[w>>2]=0-b;j[w+4>>2]=e}jma(a,s);if(k[q+1|0]&2){break D}b=l[a+480212>>1];i[a+480212>>1]=b+1;i[((b<<1)+a|0)+1074466>>1]=v;break D}j[B>>2]=0;j[F>>2]=0;j[d+1075060>>2]=0;if(j[d+1075076>>2]?0:!j[d+1075080>>2]){break D}b=l[a+480212>>1];i[a+480212>>1]=b+1;i[((b<<1)+a|0)+1074466>>1]=v}j[d+1075652>>2]=j[q>>2]}v=v+1|0;if((v|0)!=256){continue}break}f=1;if(m[a+24608>>2]>l[a+480212>>1]){break a}b=a+1074466|0;ima(b,b+(j[a+24608>>2]<<1)|0,b+(l[a+480212>>1]<<1)|0,a)}Za=c+32|0;return f}function $T(a,b){var c=0,d=0,e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;c=Za-112|0;Za=c;if(b){N=a+12|0;O=a+24592|0;P=a+24588|0;Rm(N,b,O,P);if(m[a+24624>>2]>=3){Rm(a+8204|0,b,a+24600|0,a+24596|0)}i[c+30>>1]=0;L=a+1074308|0;mb(c+8|0,L,33);d=kb(c+8|0);f=l[a+480212>>1];if(f){X=d?2:1;Y=a+24648|0;Z=a+24596|0;_=a+24600|0;$=a+8204|0;aa=a+397460|0;ba=a+397456|0;ca=a+393352|0;Q=a+1074376|0;while(1){w=(M<<1)+Q|0;d=p(l[w+90>>1],896);o=d+Q|0;y=o;a:{b:{if(j[o+624>>2]){break b}n=a+d|0;if(j[n+1075080>>2]){break b}if(!j[n+1075076>>2]){break a}}e=a+d|0;g=rua(k[e+1075800|0]);s=e+1075072|0;n=j[s>>2];q=n&1;t=n>>>5|0;c:{if(!(n&8388608)){z=N;B=P;f=n;d=O;if(!(!(f&16777216)&(k[a+24612|0]&32)>>>5)){break c}}z=kea(ca,b);f=j[s>>2];B=aa;d=ba}G=d;d=g|q;g=t&2;n=n>>>12|0;if(!(!(f&256)|m[a+24624>>2]<3)){G=_;B=Z;z=$}g=d|g;q=n&8;n=o+608|0;C=Zk(a,l[w+90>>1],2,1);d:{if((!C|0)==(C>>>0<251|0)){break d}f=j[(p(C,160)+a|0)+906140>>2];if(!f){break d}d=j[f+24>>2];if(!d){break d}B=f+36|0;G=f+40|0;if(!(h[f+28|0]&1)){Rm(d,b,G,B);j[f+28>>2]=j[f+28>>2]|1}z=d}da=g|q;R=e+1075809|0;ea=e+1075792|0;fa=e+1075680|0;ga=e+1075016|0;ha=e+1075012|0;ia=e+1075660|0;ja=e+1075656|0;v=e+1074992|0;D=e+1075080|0;E=e+1075076|0;S=e+1075008|0;T=e+1075004|0;I=e+1075088|0;H=e+1075068|0;t=e+1075060|0;J=e+1075064|0;F=e+1075084|0;A=0;ka=_T(c+8|0,n);w=b;while(1){e:{d=j[F>>2];d=d?d>>>0<w>>>0?d:w:w;j[c+68>>2]=d;x=j[J>>2];r=j[s>>2];g=j[v+4>>2];f=j[v>>2];j[c+56>>2]=f;j[c+60>>2]=g;f:{g:{if(!d|!(f|g)){break g}q=j[t>>2];if(!q){break g}j[y+624>>2]=j[c+8>>2];u=j[n+4>>2];d=u;e=j[n>>2];o=x&r<<30>>31;h:{if((o|0)>(d|0)){if((g|0)<-1?1:(g|0)<=-1){j[c+104>>2]=0;f=o;j[c+108>>2]=f<<1;e=Qf(c+104|0,n);g=ab;d=g;j[n>>2]=e;j[n+4>>2]=d;if(!(d>>>0<j[t>>2]+f>>>1>>>0?(f|0)<=(d|0):0)){e=0;j[n>>2]=e;d=f;j[n+4>>2]=d}q=j[c+60>>2];r=j[c+56>>2];g=r;f=0-(q+((g|0)!=0)|0)|0;g=0-g|0;j[c+56>>2]=g;j[c+60>>2]=f;j[v>>2]=g;j[v+4>>2]=f;f=j[s>>2];i:{if(f&4){f=f&-129;j[s>>2]=f;break i}f=f|128;j[s>>2]=f;u=j[t>>2]-1|0;d=u;j[n>>2]=e;j[n+4>>2]=d;j[v>>2]=r;j[v+4>>2]=q}j:{if(!(f&2)){f=j[t>>2];break j}f=j[t>>2];if(d>>>0<f>>>0){break h}}e=n;j[e>>2]=0;j[e+4>>2]=f;break g}if((u|0)>-1){break h}f=0;d=f;j[n>>2]=e;j[n+4>>2]=d;break h}if(q>>>0>u>>>0){break h}if(!(r&2)){break g}if(r&4){if((g|0)>0?1:(g|0)>=0?f>>>0>=1:0){d=0-(((f|0)!=0)+g|0)|0;f=0-f|0;j[c+56>>2]=f;j[c+60>>2]=d;j[v>>2]=f;j[v+4>>2]=d}j[s>>2]=r|128;d=1-((e|0)!=0)|0;e=0-e|0;g=((q<<1)-u|0)-d|0;d=g;f=n;j[f>>2]=e;j[f+4>>2]=d;if(d>>>0<q>>>0?d>>>0>x>>>0:0){break h}j[c+104>>2]=X;d=q-j[tb(t,c+104|0)>>2]|0;e=j[f>>2];j[n>>2]=e;j[f+4>>2]=d;break h}if((g|0)<-1?1:(g|0)<=-1){e=0-f|0;j[c+56>>2]=e;d=0-(((f|0)!=0)+g|0)|0;j[c+60>>2]=d;j[v>>2]=e;j[v+4>>2]=d}j[c+104>>2]=0;j[c+108>>2]=o-q;Bb(n,c+104|0);j[s>>2]=j[s>>2]|8192;e=j[n>>2];d=j[n+4>>2]}j[c+48>>2]=e;j[c+52>>2]=d;k:{l:{e=d;m:{if((d|0)<(o|0)){if((d|j[c+60>>2])>-1){break m}break l}if((d|0)<0){break l}}d=0;if(e>>>0>=m[t>>2]){break k}U=j[c+68>>2];j[c+44>>2]=U;d=j[c+56>>2];e=j[c+60>>2];kc(c+68|0,j[c+20>>2]);ma=c,na=Zt(c+56|0,j[c+68>>2]-1|0),j[ma+32>>2]=na;j[c+36>>2]=ab;f=e;r=d;d=e>>31;V=e>>31;g=V;e=r+g|0;r=f;f=d;d=r+d|0;la=e;g=e>>>0<g>>>0?d+1|0:d;q=j[c+48>>2];e=q+j[c+32>>2]|0;d=j[c+36>>2]+j[c+52>>2]|0;d=e>>>0<q>>>0?d+1|0:d;e=j[J>>2];K=e+16|0;x=j[c+52>>2];r=x;u=j[c+48>>2];W=e>>>0>r>>>0;if(!(r>>>0<K>>>0?!W:0)){j[s>>2]=j[s>>2]&-8193}q=V^la;g=f^g;f=d;n:{o:{p:{if(!j[c+12>>2]){x=j[c+60>>2];break p}d=j[c+16>>2];if(d>>>0<=x>>>0){e=c;f=j[c+60>>2];q:{if((f|0)<-1?1:(f|0)<=-1){j[c+96>>2]=u;j[c+100>>2]=r;j[c+104>>2]=0;j[c+108>>2]=d;ma=c,na=Qf(c+96|0,c+104|0),j[ma+80>>2]=na;j[c+84>>2]=ab;j[c+72>>2]=1;j[c+76>>2]=0;ma=c,na=Qf(c+80|0,c+72|0),j[ma+88>>2]=na;j[c+92>>2]=ab;d=yl(c+88|0,q,g);break q}d=j[H>>2];j[c+104>>2]=u;j[c+108>>2]=r;j[c+96>>2]=0;j[c+100>>2]=d;ma=c,na=Qf(c+96|0,c+104|0),j[ma+80>>2]=na;j[c+84>>2]=ab;j[c+72>>2]=1;j[c+76>>2]=0;ma=c,na=Qf(c+80|0,c+72|0),j[ma+88>>2]=na;j[c+92>>2]=ab;d=yl(c+88|0,q,g)}j[e+44>>2]=d+1;j[y+624>>2]=j[c+12>>2];break n}if(!(W|!(k[s+1|0]&32)|x>>>0>=K>>>0)){j[c+104>>2]=u;j[c+108>>2]=r;j[c+96>>2]=0;j[c+100>>2]=o+16;ma=c,na=Qf(c+96|0,c+104|0),j[ma+80>>2]=na;j[c+84>>2]=ab;j[c+72>>2]=1;j[c+76>>2]=0;ma=c,na=Qf(c+80|0,c+72|0),j[ma+88>>2]=na;j[c+92>>2]=ab;ma=c,na=yl(c+88|0,q,g)+1|0,j[ma+44>>2]=na;ma=y,na=j[c+12>>2]+p(j[H>>2]-o|0,xn(j[I>>2]))|0,j[ma+624>>2]=na;break n}K=j[c+60>>2];x=K;if((x|0)<0?1:(x|0)<=0?m[c+56>>2]<1:0){break p}if(U>>>0<2|d>>>0>f>>>0){break o}j[c+104>>2]=u;j[c+108>>2]=r;j[c+96>>2]=0;j[c+100>>2]=d;ma=c,na=Qf(c+96|0,c+104|0),j[ma+80>>2]=na;j[c+84>>2]=ab;j[c+72>>2]=1;j[c+76>>2]=0;ma=c,na=Qf(c+80|0,c+72|0),j[ma+88>>2]=na;j[c+92>>2]=ab;ma=c,na=yl(c+88|0,q,g)+1|0,j[ma+44>>2]=na;break n}if((x|0)>-1){break o}if((f|0)>=(o|0)){break n}j[c+96>>2]=u;j[c+100>>2]=r;j[c+104>>2]=0;j[c+108>>2]=e;ma=c,na=Qf(c+96|0,c+104|0),j[ma+80>>2]=na;j[c+84>>2]=ab;j[c+72>>2]=1;j[c+76>>2]=0;ma=c,na=Qf(c+80|0,c+72|0),j[ma+88>>2]=na;j[c+92>>2]=ab;ma=c,na=yl(c+88|0,q,g)+1|0,j[ma+44>>2]=na;break n}d=j[t>>2];if((d|0)>(f|0)){break n}j[c+104>>2]=u;j[c+108>>2]=r;j[c+96>>2]=0;j[c+100>>2]=d;ma=c,na=Qf(c+96|0,c+104|0),j[ma+80>>2]=na;j[c+84>>2]=ab;j[c+72>>2]=1;j[c+76>>2]=0;ma=c,na=Qf(c+80|0,c+72|0),j[ma+88>>2]=na;j[c+92>>2]=ab;ma=c,na=yl(c+88|0,q,g)+1|0,j[ma+44>>2]=na}wn(c+44|0,1,j[c+68>>2]);d=j[c+44>>2];break k}d=0}if((d|0)>0){break f}}j[y+624>>2]=0;j[t>>2]=0;j[n>>2]=0;j[n+4>>2]=0;j[F>>2]=0;kua(n,z,w);j[G>>2]=j[G>>2]+j[E>>2];j[B>>2]=j[B>>2]+j[D>>2];j[D>>2]=0;j[E>>2]=0;j[s>>2]=j[s>>2]&-129;break e}r:{s:{if(m[a+24608>>2]>l[c+30>>1]){A=4;if(j[F>>2]){break s}A=0;if(j[S>>2]|j[T>>2]){break s}}ma=c,na=OMa(j[v>>2],j[v+4>>2],d,d>>31),j[ma+104>>2]=na;j[c+108>>2]=ab;Bb(n,c+104|0);A=0;j[D>>2]=0;j[E>>2]=0;e=(d<<3)+z|0;break r}e=(d<<3)+z|0;f=e-8|0;j[E>>2]=0-j[f>>2];o=e-4|0;j[D>>2]=0-j[o>>2];bb[j[((A|da)<<2)+77552>>2]](n,Y,z,d);j[E>>2]=j[E>>2]+j[f>>2];j[D>>2]=j[D>>2]+j[o>>2];A=1}z=e;e=j[F>>2];t:{if(!e){break t}if(d>>>0>=e>>>0){j[F>>2]=0;j[T>>2]=j[ja>>2];j[S>>2]=j[ia>>2];j[ha>>2]=0;j[ga>>2]=0;if(j[fa>>2]|!(k[s+1|0]&16)){break t}j[t>>2]=0;j[y+624>>2]=0;break t}j[F>>2]=e-d}e=0;f=0;o=j[n+4>>2];f=o>>>0>=m[H>>2]?(k[s|0]&2)>>>1|0:f;g=o;o=j[t>>2];e=j[s>>2]&2|(g>>>0<o>>>0|!o)?e:!l[ea>>1];w=w-d|0;mb(c+104|0,L,85);u:{v:{w:{x:{if(!kb(c+104|0)){break x}d=k[R|0];if(!d|d>>>0>l[a+480190>>1]){break x}g=!(e|f);o=j[I>>2];d=p(k[R|0],104)+a|0;e=d+484380|0;if(g|(o|0)==(e|0)){break w}j[I>>2]=e;j[y+624>>2]=j[d+484400>>2];e=l[d+484414>>1];j[s>>2]=e|j[s>>2]&-768;f=e<<30>>31;e=j[d+484388>>2];j[t>>2]=f&e;d=j[d+484384>>2];j[J>>2]=d;j[H>>2]=e;j[n+4>>2]=d;EA(ka,n);if(!j[y+624>>2]){break e}if((w|0)>0){continue}break e}if(f){break v}break u}if(!f|(e|0)!=(o|0)){break u}}mb(c+104|0,L,83);if(!kb(c+104|0)|j[J>>2]){break u}j[n>>2]=j[n>>2];j[n+4>>2]=0;d=j[j[I>>2]+8>>2];j[t>>2]=d;j[H>>2]=d}if((w|0)>0){continue}}break}j[y+624>>2]=j[c+8>>2];i[c+30>>1]=l[c+30>>1]+A;y:{if(!A|(!C|C>>>0>250)){break y}d=j[(p(C,160)+a|0)+906140>>2];if(!d){break y}bb[j[j[d>>2]+144>>2]](d)}f=l[a+480212>>1]}M=M+1|0;if(M>>>0<(f&65535)>>>0){continue}break}}ma=a,na=l[ui(a+480214|0,c+30|0)>>1],i[ma+480214>>1]=na}Za=c+112|0}function oHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=Za-272|0;Za=d;rc(b);e=d+112|0;g=lHa(b,e);if(!g){DQ(e)}a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!g){break i}if(!FQ(d+112|0)){break i}if(!c){f=1;break i}od(a,j[((k[d+228|0]|k[d+229|0]<<8)<<2)+12976>>2]);e=Eb(d+16|0,13016);ob(a+1304436|0,e);gb(e);e=Eb(d+16|0,13038);ob(a+1304448|0,e);gb(e);e=Eb(d+80|0,13042);j[114626]=0;F(219,d+96|0,e|0);f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;L(427,d+16|0,d+96|0,d+191|0,d+188|0);f=j[114626];j[114626]=0;if((f|0)==1){break d}ob(a+1304460|0,d+16|0);gb(d+16|0);qb(d+96|0);gb(e);vc(a+1304484|0,((k[d+228|0]|k[d+229|0]<<8)<<2)+13072|0);vc(a+1304472|0,j[((k[d+228|0]|k[d+229|0]<<8)<<2)+77456>>2]);j[a+1304496>>2]=4;ug(d+96|0,2,d+112|4);qc(d+16|0,d+96|0);ob(a+1304400|0,d+16|0);gb(d+16|0);ug(d+96|0,2,d+148|0);qc(d+16|0,d+96|0);if(_s(d+16|0,13112)){j[114626]=0;I(13,d+96|0,4,d+16|0);e=j[114626];j[114626]=0;if((e|0)==1){break h}ob(a+1304412|0,d+96|0);gb(d+96|0)}gb(d+16|0);i[a+480188>>1]=32;e=0;j:{while(1){g=(e<<5)+a|0;n=g+480280|0;vg(n);k:{f=d+e|0;if(k[f+193|0]<=15){j[d+16>>2]=k[f+193|0]<<4|8;j[d+96>>2]=256;x=g+480284|0,y=j[Pd(d+16|0,d+96|0)>>2],i[x>>1]=y;break k}if(k[f+193|0]==16){i[g+480284>>1]=128;j[n>>2]=256;break k}if(k[f+193|0]!=255){break k}i[a+480188>>1]=e;break j}e=e+1|0;if((e|0)!=32){continue}break}e=l[a+480188>>1]}f=0;if(!(e&65535)){break i}j[d+16>>2]=k[d+225|0]<<2;j[d+96>>2]=256;x=a,y=j[tb(d+16|0,d+96|0)>>2],j[x+480200>>2]=y;j[a+480196>>2]=k[d+226|0];j[a+480204>>2]=p(k[d+227|0],1e4);if(xc(b,k[d+230|0]|k[d+231|0]<<8|(k[d+232|0]<<16|k[d+233|0]<<24))){lp(Fb(a+484360|0),b,k[d+234|0]+1|0,255,254)}if(!xc(b,k[d+240|0]|k[d+241|0]<<8|(k[d+242|0]<<16|k[d+243|0]<<24))){break i}i[a+480190>>1]=k[d+248|0]+1;m=d+48|0;e=1;n=1;while(1){if(nHa(b,d+16|0)){f=p(e,104)+a|0;g=f+484380|0;md(g,0);ug(d,2,d+16|0);qc(d+96|0,d);j[114626]=0;E(369,((e<<5)+a|0)+946300|0,d+96|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break e}gb(d+96|0);dk(d,2,m);qc(d+96|0,d);j[114626]=0;E(370,f+484423|0,d+96|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break f}gb(d+96|0);e=f+484404|0;j[e>>2]=k[d+74|0]|k[d+75|0]<<8;l:{if(!Zs(a)){break l}o=j[e>>2];e=0;while(1){if((o|0)==l[(e<<1)+13120>>1]){h[f+484417|0]=e<<4;break l}e=e+1|0;if((e|0)!=16){continue}break}}i[f+484412>>1]=64;j[g>>2]=k[d+61|0]|k[d+62|0]<<8|(k[d+63|0]<<16|k[d+64|0]<<24);if(k[d+73|0]&2){e=f+484414|0;i[e>>1]=l[e>>1]|1;j[g>>2]=j[g>>2]>>>1}j[f+484384>>2]=k[d+65|0]|k[d+66|0]<<8|(k[d+67|0]<<16|k[d+68|0]<<24);j[f+484388>>2]=(k[d+69|0]|k[d+70|0]<<8|(k[d+71|0]<<16|k[d+72|0]<<24))-1;if(h[d+73|0]&1){e=f+484414|0;i[e>>1]=l[e>>1]|2}m:{if(k[d+73|0]&4){h[d+96|0]=k[d+76|0];h[d|0]=64;x=f+484410|0,y=k[Yb(d+96|0,d)|0]<<2,i[x>>1]=y;break m}e=f+484414|0;i[e>>1]=l[e>>1]|32768}n:{if(!(k[d+73|0]&8)){i[f+484408>>1]=128;break n}e=f+484414|0;i[e>>1]=l[e>>1]|32;g=f+484408|0;if(k[d+77|0]<=15){f=k[d+77|0];j[d>>2]=256;j[d+96>>2]=f<<4|8;q=j[Pd(d+96|0,d)>>2]}else{q=128}i[g>>1]=q;i[e>>1]=l[e>>1]&65279|(k[d+77|0]==16)<<8}n=n+1|0;e=n&65535;if(e>>>0<=l[a+480190>>1]){continue}}break}o:{if(!(c&2)){break o}if(!xc(b,k[d+244|0]|k[d+245|0]<<8|(k[d+246|0]<<16|k[d+247|0]<<24))|!l[a+480190>>1]){break o}e=1;while(1){f=p(e&65535,104)+a|0;$f(Mc(d+16|0,i[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);e=e+1|0;if(l[a+480190>>1]>=(e&65535)>>>0){continue}break}}s=a+484344|0;If(s,k[d+239|0]+1|0);o=Yma(to(a));xc(b,k[d+235|0]|k[d+236|0]<<8|(k[d+237|0]<<16|k[d+238|0]<<24));v=c&1;n=0;t=1;while(1){c=Of(b);if(c>>>0>=3){cd(d+16|0,b,c-2|0);p:{if(!v){break p}j[114626]=0;c=H(337,d+16|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break g}if(!c){break p}j[114626]=0;c=K(402,s|0,n&65535,64)|0;e=j[114626];j[114626]=0;if((e|0)==1){break g}r=0;if(!c){break p}while(1){c=Ib(s,n);j[114626]=0;w=E(496,c|0,r|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break g}q:while(1){j[114626]=0;c=H(387,d+16|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break g}r:{if(!c){break r}e=c&31;if(e>>>0>=l[a+480188>>1]){break r}f=p(e,6)+w|0;if(c&32){j[114626]=0;F(472,d+96|0,d+16|0);e=j[114626];j[114626]=0;if((e|0)==1){break g}g=Pc(d+96|0);e=d+96|0;m=k[e|0];if(m){q=e;e=(m&127)-1|0;h[q|0]=e;h[f|0]=(p((e&240)>>>4|0,12)+(e&15)|0)+13;j[114626]=0;e=H(611,f|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break g}t=e&t}h[f+1|0]=k[g|0]}if(!(c&64)){continue}h[f+2|0]=0;h[f+3|0]=0;g=f+5|0;while(1){j[114626]=0;c=E(258,d+16|0,2)|0;e=j[114626];j[114626]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((e|0)!=1){if(!c){continue q}q=k[g|0];c=k[f+3|0];j[114626]=0;F(472,d+96|0,d+16|0);e=j[114626];j[114626]=0;if((e|0)==1){break g}m=k[Pc(d+96|0)|0];h[g|0]=m;u=d+96|0;e=k[(k[u|0]&31)+13152|0];h[f+3|0]=e;switch(e-2|0){case 2:case 3:case 6:case 7:case 8:case 9:case 10:case 12:case 14:case 15:case 16:break u;case 18:break y;case 13:break z;case 17:break A;case 11:break B;case 5:break C;case 4:break D;case 1:break E;case 0:break F;default:break x}}break g}if(m>>>0<224){break s}break t}if(m>>>0>=224){break t}break s}e=m&240;if(!e){break s}h[g|0]=e;break v}e=m&240;if(!e){break s}h[g|0]=e;break v}j[114626]=0;h[d|0]=64;e=E(391,g|0,d|0)|0;m=j[114626];j[114626]=0;if((m|0)!=1){h[g|0]=k[e|0];j[114626]=0;e=E(612,o|0,1)|0;m=j[114626];j[114626]=0;if((m|0)==1){break g}if(!e){break v}h[f+2|0]=1;h[f+4|0]=k[g|0];h[f+3|0]=c;h[g|0]=q;e=c;break u}break g}j[114626]=0;e=E(613,o|0,19)|0;m=j[114626];j[114626]=0;if((m|0)==1){break g}if(e){break v}j[114626]=0;N(614,f|0);e=j[114626];j[114626]=0;if((e|0)!=1){break v}break g}j[114626]=0;e=E(613,o|0,15)|0;m=j[114626];j[114626]=0;if((m|0)==1){break g}if(e){break v}j[114626]=0;e=E(613,o|0,19)|0;m=j[114626];j[114626]=0;if((m|0)==1){break g}if(!e){break v}h[f+3|0]=19;h[g|0]=k[g|0]&15|144;break s}G:{e=m>>>4|0;if((e|0)!=8){if(e){break G}H:{switch(m&15){case 4:h[f+3|0]=20;h[g|0]=158;break s;case 0:case 1:break w;case 5:break H;default:break G}}h[f+3|0]=20;h[g|0]=159;break s}j[114626]=0;e=E(613,o|0,20)|0;m=j[114626];j[114626]=0;if((m|0)==1){break g}if(e){break v}h[f+3|0]=19;break s}h[f+3|0]=0;break s}if((e|0)!=31){break u}h[f+3|0]=17;break s}h[g|0]=m-112}e=k[f+3|0]}if((e&255)!=20){break s}e=k[g|0];if(k[f+2|0]|(e&240)!=128){break s}h[f+2|0]=2;h[f+4|0]=(((e&15)<<6|8)>>>0)/15;h[f+3|0]=c;h[g|0]=q;break s}h[g|0]=223}if(k[u|0]&32){continue}break}continue}break}r=r+1|0;if((r|0)!=64){continue}break}}jb(d+16|0)}c=k[d+239|0]>n>>>0;n=n+1|0;if(c){continue}break}c=a;if((t^-1|l[a+480188>>1]!=4)&1|j[a+480180>>2]!=1){e=j[a+480208>>2]&-8454145}else{e=j[a+480208>>2]|8454144}j[c+480208>>2]=e;f=1;if(!(k[d+253|0]|k[d+254|0]<<8|(k[d+255|0]<<16|k[d+256|0]<<24))){break i}if(!xc(b,k[d+249|0]|k[d+250|0]<<8|(k[d+251|0]<<16|k[d+252|0]<<24))){break i}Yx(a+1304424|0,b,k[d+253|0]|k[d+254|0]<<8|(k[d+255|0]<<16|k[d+256|0]<<24),4)}Za=d+272|0;return f|0}f=D()|0;C()|0;gb(d+16|0);break a}f=D()|0;C()|0;jb(d+16|0);break a}f=D()|0;C()|0;gb(d+96|0);break a}f=D()|0;C()|0;gb(d+96|0);break a}f=D()|0;C()|0;qb(d+96|0);break b}f=D()|0;C()|0}gb(e)}G(f|0);z()}function DBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,E=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;d=Za-336|0;Za=d;a:{if(!xc(b,1080)){break a}if(!$m(b,d+332|0)){break a}od(a,1);v=EO(d+312|0);if(!DO(d+332|0,v)){break a}f=l[v+8>>1];if((f-1&65535)>>>0>126){break a}if(!c){e=1;break a}i[a+480188>>1]=f;r=k[v+12|0];S=k[v+11|0];e=k[v+10|0];O=1;if(!Jd(d+332|0,15619)){O=Jd(d+332|0,15624)}if(k[v+13|0]){vb(a+1074308|0,5,1)}L=a+480188|0;B=S?l[L>>1]==8:0;E=Jd(d+332|0,15629);u=1;if(!Jd(d+332|0,15634)){u=Jd(d+332|0,15639)}xc(b,0);Pz(b,a+1304400|0,20);i[a+480190>>1]=31;t=(e|0)!=0;y=d+201|0;g=d+204|0;n=d+198|0;x=d+200|0;e=1;f=E;while(1){A=p(e,104)+a|0;w=A+484380|0;J=Cy(b,d+176|0,w,((e<<5)+a|0)+946300|0,l[a+480188>>1]==4);w=j[w>>2];b:{if(u){h[A+484417|0]=0-(k[x|0]<<3);break b}t=w>>>0<65536&t}P=k[n|0]|k[n+1|0]<<8?!(k[g|0]|k[g+1|0]<<8)|P:P;A=f&1;f=0;c:{if(!A){break c}s=q;q=k[n|0]|k[n+1|0]<<8;q=s+((q<<24|q<<8&16711680)>>>15|0)|0;if(k[x|0]){break c}if(!(k[n|0]|k[n+1|0]<<8)){f=1;break c}f=k[y|0]==64}Q=J+Q|0;m=m+w|0;e=e+1|0;if((e|0)!=32){continue}break}d:{e:{f:{g:{h:{i:{j:{k:{T=j[v+4>>2];if(T>>>0>=Q>>>0){By(b,d+176|0);Jb(b,4);x=d+176|1;n=k[x|0];e=128;g=a+484360|0;fn(Fb(g),d+176|2,128,65535,65535);s=q;q=!n&f;u=q?s:0;f=k[d+176|0];l:{if(f>>>0>128){break l}e=f;if(e){break l}f=128;while(1){n=f-1|0;if(!l[ac(Fb(g),n)>>1]){e=1;f=n;if(f>>>0>1){continue}break l}break}e=f}U=(r|0)!=0;f=BO(b,Fb(g),e&65535,m,L,u);if(!(!q|l[a+480188>>1]!=8)){j[v>>2]=15644;U=1}m:{if(!B){break m}m=Fb(g);da=d,ea=Lb(m),j[da+160>>2]=ea;da=d,ea=Mb(m),j[da+144>>2]=ea;if(!rb(d+160|0,d+144|0)){break m}while(1){m=j[d+160>>2];i[m>>1]=l[m>>1]>>>1;je(d+160|0);if(rb(d+160|0,d+144|0)){continue}break}}Ge(Fb(g),k[x|0]);V=e-1&65535;if(!(k[x|0]!=120|l[L>>1]!=4?V>>>0>=k[x|0]:0)){Ge(Fb(g),0)}j[a+480260>>2]=56;j[a+480264>>2]=13696;j[a+480204>>2]=125e4;j[a+480196>>2]=6;e=0;m=Gb(256/l[a+480188>>1]|0,32,128);j[a+480208>>2]=0;j[a+480228>>2]=m;Oi(a,0);h[d+175|0]=0;w=1;W=1;if(!(t&1)){n:{if(!f){m=E;e=0;break n}y=d+160|5;m=E;t=0;n=0;u=0;while(1){q=0;e=0;while(1){g=bj(d+160|0);Gs(b,g);g=EQ(g);r=k[d+163|0];o:{if((r-7&255)>>>0>=3){m=g?m:0;p:{q:{switch(r-13|0){case 1:r=k[d+165|0];m=r>>>0>1?0:m;if((r&240)!=128){break o}h[d+144|0]=r<<4;da=d,ea=k[Wg(d+175|0,d+144|0)|0],h[da+175|0]=ea;break o;case 2:if(k[d+165|0]>31){break p}break o;case 0:break q;default:break o}}e=e+1|0;if((e&65535)>>>0<2){break o}}m=0;break o}m=0;if((r|0)!=8){break o}da=d,ea=k[Wg(d+175|0,y)|0],h[da+175|0]=ea;r=h[d+165|0];if((r|0)>-1){u=1;break o}n=(r|0)!=-92&(r&255)>>>0>143|n}w=g&w;q=q+1|0;if((q|0)!=256){continue}break}t=t+1|0;if(f>>>0>(t&65535)>>>0){continue}break}e=0;if((u^-1|n)&1){break n}e=k[d+175|0]>47}W=m&1}xc(b,1084);u=4;u=B?u:l[L>>1];y=a+484344|0;M=f+B&65535;If(y,M);r:{s:{t:{u:{v:{if(!M){A=0;J=0;break v}$=a+1074308|0;aa=e^1;ba=c&1;t=0;J=0;A=0;while(1){f=!ba;w:{if(B){e=(t&65534)>>>1|0;m=t&1;if(!m){if(!Wf(y,e,64)){break v}}n=Se(Ib(y,e),0,m<<2);break w}if(!Wf(y,t&65535,64)){break v}n=Se(Ib(y,t),0,0)}if(f|!n){break v}e=l[a+480188>>1];h[d+144|0]=0;r=lt(d+160|0,e,d+144|0);e=l[a+480188>>1];j[114626]=0;h[d+64|0]=0;N=K(881,d+144|0,e|0,d- -64|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break u}R=0;while(1){e=0;X=0;q=0;m=0;if(u){while(1){j[114626]=0;g=p(q,6)+n|0;F(882,b|0,g|0);f=j[114626];j[114626]=0;x:{y:{z:{if((f|0)==1){break z}f=k[g+3|0];A:{B:{C:{if(!f){if(k[g+5|0]){break C}break B}if(!S){break C}D:{switch(f-14|0){case 0:h[g+3|0]=0;h[g+5|0]=0;break C;case 1:break D;default:break C}}if(k[g+5|0]<32){break C}h[g+5|0]=31}Yi(g);f=1;E:{F:{G:{s=k[g+3|0];switch(s-14|0){case 2:break A;case 0:break F;case 3:break G;default:break E}}A=k[g+5|0]<100|A;X=1;break B}if(!W){break B}h[g+5|0]=0;break B}if(!((s|0)!=9|aa)){f=k[g+5|0];if((f|0)==164){h[g+3|0]=20;h[g+5|0]=145;break B}j[114626]=0;f=H(883,f<<1)|0;s=j[114626];j[114626]=0;if((s|0)==1){break z}h[g+5|0]=f;break B}if((s|0)!=19){break B}f=k[g+5|0];if(f>>>0>15){break B}s=f&1;f=s^1;ca=!s;s=Y&1;Y=(s|0)==(f|0)?Y:ca;Z=((f|0)!=(s|0))+Z|0}f=e}if(k[g|0]){break y}if(!k[g+1|0]|B){break x}if(!k[fc(r,q)|0]){break x}if(k[fc(r,q)|0]==k[g+1|0]){break x}s=fc(N,q);e=k[s|0]+1|0;h[s|0]=e;if((e&255)>>>0<4){break x}j[114626]=0;K(478,$|0,85,1)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break x}}e=D()|0;C()|0;Od(N);break t}da=fc(N,q),ea=0,h[da|0]=ea}e=k[g+1|0];if(e){da=fc(r,q),ea=e,h[da|0]=ea}e=f;m=m+1|0;q=m&65535;if(q>>>0<u>>>0){continue}break}}J=e&X|J;n=p(l[L>>1],6)+n|0;R=R+1|0;if((R|0)!=64){continue}break}Od(N);Od(r);t=t+1|0;if((M|0)!=(t|0)){continue}break}}H:{f=w^1;if((f|P)&1){break H}I:{if(Jd(d+332|0,15629)){break I}if(Jd(d+332|0,15656)){break I}if(!Jd(d+332|0,15661)){break H}}j[a+480208>>2]=j[a+480208>>2]|2162688;e=a+1074308|0;vb(e,85,1);vb(e,91,1);vb(e,92,1);J:{if(k[d+175|0]>47){break J}vb(e,84,1);if(k[x|0]==127){break J}vb(e,83,1)}if(!w){break r}break s}if(w){break s}if(E^1|k[x|0]!=127|k[x|0]+1>>>0<V>>>0){break r}j[v>>2]=15666;break r}e=D()|0;C()|0}Od(r);break d}if(!(U^1)|(Z|0)>6){break r}j[a+480208>>2]=j[a+480208>>2]|8388608}if(O){vb(a+1074308|0,84,1)}if(c&2){xc(b,(p(u,M)<<8)+1084|0);m=f|E^1;e=1;while(1){n=p(e,104)+a|0;c=n+484380|0;if(j[c>>2]){q=d+160|0;if(O){f=2}else{f=AO(b,15680)?11:0}f=Mc(q,8,1,0,f);B=j[b+8>>2]+sQ(f,j[c>>2])|0;if(!m){da=c,ea=j[Gc(c,n+484388|0)>>2],j[da>>2]=ea}$f(f,c,b);xc(b,B)}e=e+1|0;if((e|0)!=32){continue}break}}K:{if((A&E^-1|J)&1){break K}b=zO(d+120|0,0);c=j[b+20>>2];j[d+40>>2]=j[b+16>>2];j[d+44>>2]=c;c=j[b+12>>2];j[d+32>>2]=j[b+8>>2];j[d+36>>2]=c;c=j[b+4>>2];j[d+24>>2]=j[b>>2];j[d+28>>2]=c;Yr(d+160|0,a,0,d+24|0);_=o[j[d+160>>2]>>3];hl(d+160|0);if(_<600){break K}c=a+1074308|0;vb(c,5,1);b=yO(d+96|0,_);e=j[b+20>>2];j[d+16>>2]=j[b+16>>2];j[d+20>>2]=e;e=j[b+12>>2];j[d+8>>2]=j[b+8>>2];j[d+12>>2]=e;e=j[b+4>>2];j[d>>2]=j[b>>2];j[d+4>>2]=e;Yr(d+160|0,a,0,d);b=k[j[d+160>>2]+26|0];hl(d+160|0);if(b){rg(c,5);break K}j[v>>2]=15686}BBa(d+332|0,Rb(d+332|0),d+332|0);b=Eb(d+80|0,15706);j[114626]=0;F(219,d+144|0,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break k}c=Rb(d+332|0);j[114626]=0;c=K(884,d+48|0,d+332|0,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break j}j[114626]=0;I(13,d- -64|0,1,c|0);e=j[114626];j[114626]=0;if((e|0)==1){break i}j[114626]=0;I(247,d+160|0,d+144|0,d- -64|0);e=j[114626];j[114626]=0;if((e|0)==1){break h}ob(a+1304436|0,d+160|0);gb(d+160|0);gb(d- -64|0);gb(c);qb(d+144|0);gb(b);b=Eb(d+160|0,15726);ob(a+1304448|0,b);gb(b);b=j[v>>2];if(b){vc(a+1304460|0,b)}j[a+1304496>>2]=2}e=Q>>>0<=T>>>0;break a}e=D()|0;C()|0;break e}e=D()|0;C()|0;break f}e=D()|0;C()|0;break g}e=D()|0;C()|0;gb(d- -64|0)}gb(c)}qb(d+144|0)}gb(b)}G(e|0);z()}Za=d+336|0;return e|0}function jMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0;e=Za-176|0;Za=e;rc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!RS(b,e+128|0)){break h}if(!SS(e+128|0)){break h}if(!c){t=1;break h}od(a,2048);_h(a);d=Eb(e+96|0,12026);j[114626]=0;F(219,e+112|0,d|0);o=j[114626];j[114626]=0;if((o|0)==1){break c}j[114626]=0;r=e+128|3;I(383,e+80|0,e+112|0,r|0);o=j[114626];j[114626]=0;if((o|0)==1){break d}ob(a+1304436|0,e+80|0);gb(e+80|0);qb(e+112|0);gb(d);d=Eb(e+80|0,12022);ob(a+1304448|0,d);gb(d);j[a+1304496>>2]=4;i[a+480188>>1]=k[e+168|0];i[a+480190>>1]=k[e+164|0];ug(e+112|0,2,e+128|4);qc(e+80|0,e+112|0);ob(a+1304400|0,e+80|0);gb(e+80|0);if(k[r|0]<=9){i[a+480188>>1]=4;cg(b,1);Oi(a,1)}d=k[r|0];i:{if(k[r|0]>=11){o=d>>>0>11?32:16;d=0;while(1){n=((d<<5)+a|0)+480284|0;g=gT(b)<<1;g=(g|0)>-128?g:-128;j:{if((g|0)<129){d=g+128|0;break j}j[((d<<5)+a|0)+480280>>2]=256;d=128}i[n>>1]=d;f=f+1|0;d=f&65535;if(o>>>0>d>>>0){continue}break}break i}if((d|0)!=10){break i}QS(b,e+80|0);d=0;while(1){i[((d<<5)+a|0)+480284>>1]=h[(e+80|0)+d|0]&1?64:192;d=d+1|0;if((d|0)!=16){continue}break}}k:{if(k[r|0]>=13){zt(e+80|0,b);f=Pc(e+80|0);o=a;n=e+80|0;d=k[n|0];if(d>>>0<=31){h[n|0]=125;d=125}j[o+480204>>2]=p(d,1e4);j[a+480196>>2]=k[f|0];break k}j[a+480196>>2]=6;j[a+480204>>2]=125e4}o=a+484360|0;bg(Fb(o),k[e+165|0]);u=mn(e+112|0);w=j[b+8>>2];q=k[r|0];l:{if(k[r|0]<14){break l}d=k[e+165|0];j[114626]=0;F(384,u|0,d|0);d=j[114626];j[114626]=0;if((d|0)!=1){break l}b=D()|0;C()|0;break e}m:{n:{o:{p:{q:{r:{s:{t:{u:{if(k[e+165|0]){d=0;while(1){A=ac(Fb(o),d),B=d,i[A>>1]=B;if(k[r|0]>=14){j[114626]=0;f=H(357,b|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break u}A=ac(u,d),B=f,i[A>>1]=B}f=l[a+480188>>1];j[114626]=0;E(338,b|0,f<<1)|0;f=j[114626];j[114626]=0;if((f|0)==1){break u}d=d+1|0;if(d>>>0<k[e+165|0]){continue}break}}d=l[a+480190>>1];j[114626]=0;j[e+80>>2]=0;v=K(385,e- -64|0,d|0,e+80|0)|0;d=j[114626];j[114626]=0;f=1;if((d|0)!=1){j[e+60>>2]=0;v:{if(l[a+480190>>1]){o=1;while(1){j[114626]=0;n=p(f,104)+a|0;g=n+484380|0;F(386,g|0,0);d=j[114626];j[114626]=0;if((d|0)==1){break v}j[114626]=0;s=H(387,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}j[114626]=0;K(388,b|0,((f<<5)+a|0)+946300|0,32)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}j[114626]=0;K(389,b|0,n+484423|0,13)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}j[114626]=0;d=H(390,b|0)|0;t=j[114626];j[114626]=0;if((t|0)==1){break g}t=f-1|0;A=xb(v,t),B=d,j[A>>2]=B;w:{if(k[r|0]<=9){j[114626]=0;f=H(357,b|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break w}break g}j[114626]=0;f=H(390,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}}j[g>>2]=f;j[114626]=0;d=H(357,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break g}j[n+484404>>2]=d;j[114626]=0;d=H(387,b|0)|0;f=j[114626];j[114626]=0;x:{y:{z:{if((f|0)!=1){j[114626]=0;h[e+80|0]=d;h[e+48|0]=64;d=E(391,e+80|0,e+48|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break z}i[n+484410>>1]=k[d|0]<<2;if(k[r|0]>9){break y}j[114626]=0;d=H(357,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break g}j[n+484384>>2]=d;j[114626]=0;d=H(357,b|0)|0;break x}b=D()|0;C()|0;break f}b=D()|0;C()|0;break f}j[114626]=0;d=H(390,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break g}j[n+484384>>2]=d;j[114626]=0;d=H(390,b|0)|0}f=j[114626];j[114626]=0;if((f|0)==1){break g}f=n+484388|0;j[f>>2]=d;if(s){s=n+484384|0;A:{if(!(d>>>0<=j[s>>2]+2>>>0|d>>>0>m[g>>2])){d=n+484414|0;i[d>>1]=l[d>>1]|2;break A}j[f>>2]=0;j[s>>2]=0}d=xb(v,t);j[114626]=0;d=E(392,e+60|0,d|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break g}j[e+60>>2]=j[d>>2]}o=o+1|0;f=o&65535;if(f>>>0<=l[a+480190>>1]){continue}break}}n=yt(e+48|0);d=k[e+166|0]|k[e+167|0]<<8;j[114626]=0;t=K(393,b|0,n|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break t}if(!t){break m}o=0;B:{if(!ad(n)){d=Lb(n);o=Mb(n);j[114626]=0;d=E(394,d|0,o|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break B}j[e+80>>2]=d;d=j[e+80>>2];o=k[d|0]|k[d+1|0]<<8}j[114626]=0;f=o;s=E(395,e+32|0,f|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){C:{if(f){d=0;while(1){j[114626]=0;E(396,b|0,e+24|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break s}j[114626]=0;I(341,e+80|0,b|0,p(k[e+24|0]|k[e+25|0]<<8|k[e+26|0]<<16,3)|0);g=j[114626];j[114626]=0;if((g|0)==1){break C}Ed(_b(s,d),e+80|0);jb(e+80|0);d=d+1|0;if((f|0)!=(d|0)){continue}break}}if(c&2){x=Mc(e+24|0,8,1,0,1);j[114626]=0;g=E(397,e+80|0,v|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break q}d=Lb(g);f=Mb(g);j[114626]=0;F(398,d|0,f|0);d=j[114626];j[114626]=0;if((d|0)==1){break r}d=Lb(g);f=Mb(g);j[114626]=0;d=E(399,d|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break r}j[e+16>>2]=d;A=e,B=Lb(g),j[A+8>>2]=B;D:{if(!rb(e+8|0,e+16|0)){break D}while(1){j[114626]=0;d=E(258,b|0,1)|0;f=j[114626];j[114626]=0;E:{if((f|0)!=1){if(!d){break D}d=0;if(!l[a+480190>>1]){break E}while(1){j[114626]=0;f=E(258,b|0,1)|0;y=j[114626];j[114626]=0;if((y|0)==1){break r}if(!f){break E}f=d+1|0;if(j[j[e+8>>2]>>2]!=j[xb(v,d)>>2]){d=f;if(d>>>0>=l[a+480190>>1]){break E}continue}break}j[114626]=0;K(400,x|0,(p(f,104)+a|0)+484380|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break E}break r}break r}LS(e+8|0);if(rb(e+8|0,e+16|0)){continue}break}}Ud(g)}if(!(c&1)){break n}c=k[e+165|0];j[114626]=0;g=a+484344|0;F(401,g|0,c|0);c=j[114626];j[114626]=0;F:{if((c|0)!=1){if(!k[e+165|0]){break n}w=w+((q>>>0>13)<<1)|0;c=0;while(1){G:{f=64;if(bc(u)>>>0>c>>>0){f=l[ac(u,c)>>1]}j[114626]=0;d=K(402,g|0,c&65535,f&65535)|0;f=j[114626];j[114626]=0;if((f|0)==1){break F}H:{if(d){d=l[a+480188>>1];f=k[r|0];j[114626]=0;E(256,b|0,w+p(((f>>>0>13)<<1)+(d<<1)|0,c)|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break F}f=yt(e+80|0);d=l[a+480188>>1];j[114626]=0;d=K(393,b|0,f|0,d|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break H}I:{if(!d){break I}d=0;if(!l[a+480188>>1]){break I}while(1){J:{q=ac(f,d);if(!(k[q|0]|k[q+1|0]<<8)){break J}q=ac(f,d);if((k[q|0]|k[q+1|0]<<8)>>>0>(k[e+166|0]|k[e+167|0]<<8)>>>0){break J}q=ac(f,d);q=ac(n,(k[q|0]|k[q+1|0]<<8)-1|0);q=(k[q|0]|k[q+1|0]<<8)-1&65535;if(q>>>0>=o>>>0){break J}x=Ib(g,c);q=_b(s,q);j[114626]=0;I(403,x|0,d&65535,q|0);q=j[114626];j[114626]=0;if((q|0)!=1){break J}break G}d=d+1|0;if(d>>>0<l[a+480188>>1]){continue}break}}jk(f)}c=c+1|0;if(c>>>0>=k[e+165|0]){break n}continue}}break}b=D()|0;C()|0;jk(f);break p}b=D()|0;C()|0;break p}b=D()|0;C()|0;break p}b=D()|0;C()|0;break p}b=D()|0;C()|0;break o}b=D()|0;C()|0;break o}b=D()|0;C()|0;break f}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}b=D()|0;C()|0;break o}b=D()|0;C()|0;break p}b=D()|0;C()|0;Ud(g);break p}b=D()|0;C()|0}Sc(s)}jk(n);break f}Sc(s)}jk(n);Ud(v);ff(u)}Za=e+176|0;return t|0}b=D()|0;C()|0}Ud(v)}ff(u);break a}b=D()|0;C()|0;qb(e+112|0);break b}b=D()|0;C()|0}gb(d)}G(b|0);z()}function dza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=Za-272|0;Za=d;rc(b);e=d+120|0;g=zya(b,e);if(!g){lN(e)}a:{b:{c:{d:{e:{if(!g){break e}if(!vN(d+120|0)){break e}if(!c){n=1;break e}od(a,4194304);e=Eb(d+40|0,16870);ob(a+1304436|0,e);gb(e);e=Eb(d+40|0,16866);ob(a+1304448|0,e);gb(e);j[a+1304496>>2]=4;s=a,t=kd(k[d+198|0]|k[d+199|0]<<8,k[d+200|0]|k[d+201|0]<<8,127),i[s+480188>>1]=t;e=k[d+189|0];j[a+480228>>2]=(e|0)==255?48:e;j[a+480196>>2]=k[d+187|0];j[a+480204>>2]=p(k[d+188|0],1e4);He(d+104|0,d+120|4,59,3);qc(d+40|0,d+104|0);ob(a+1304400|0,d+40|0);gb(d+40|0);f:{if((k[d+202|0]|k[d+203|0]<<8|(k[d+204|0]<<16|k[d+205|0]<<24))>>>0<5){break f}if(!xc(b,(k[d+202|0]|k[d+203|0]<<8|(k[d+204|0]<<16|k[d+205|0]<<24))-4|0)){break f}if(!vh(b,16904)){break f}lp(Fb(a+484360|0),b,k[d+192|0]|k[d+193|0]<<8,65535,65535)}g:{if((k[d+206|0]|k[d+207|0]<<8|(k[d+208|0]<<16|k[d+209|0]<<24))>>>0<5){break g}if(!xc(b,(k[d+206|0]|k[d+207|0]<<8|(k[d+208|0]<<16|k[d+209|0]<<24))-4|0)){break g}if(!vh(b,16909)){break g}while(1){e=(n<<5)+a|0;vg(e+480280|0);s=e+480284|0,t=((((dd(b)^-1)&15)<<8|8)>>>0)/15|0,i[s>>1]=t;n=n+1|0;if((n|0)!=32){continue}break}}h:{if((k[d+214|0]|k[d+215|0]<<8|(k[d+216|0]<<16|k[d+217|0]<<24))>>>0<5){break h}if(!xc(b,(k[d+214|0]|k[d+215|0]<<8|(k[d+216|0]<<16|k[d+217|0]<<24))-4|0)){break h}if(!vh(b,16914)){break h}cd(d+104|0,b,(k[d+196|0]|k[d+197|0]<<8)<<6);i:{if(!(k[d+196|0]|k[d+197|0]<<8)){break i}n=c&2;g=a+480190|0;q=d+53|0;while(1){j[114626]=0;e=E(975,d+104|0,d+40|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break d}if(!e){break i}e=k[d+85|0]|k[d+86|0]<<8;i[d+38>>1]=e;j:{if((e-1&65535)>>>0>3998){break j}if(ke((p(e,104)+a|0)+484380|0)){break j}j[114626]=0;e=E(452,g|0,d+38|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break c}i[a+480190>>1]=l[e>>1];j[114626]=0;F(976,d+40|0,(p(l[d+38>>1],104)+a|0)+484380|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;I(977,d+8|0,1,q|0);e=j[114626];j[114626]=0;k:{l:{if((e|0)==1){break l}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break l}j[114626]=0;E(369,((l[d+38>>1]<<5)+a|0)+946300|0,d+24|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break k}gb(d+24|0);if(!n){break j}e=k[d+77|0]|k[d+78|0]<<8|(k[d+79|0]<<16|k[d+80|0]<<24);j[114626]=0;E(256,b|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(978,d+24|0,d+40|0);e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;K(400,d+24|0,(p(l[d+38>>1],104)+a|0)+484380|0,b|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break j}}b=D()|0;C()|0;break b}b=D()|0;C()|0;break b}b=D()|0;C()|0;gb(d+24|0);break b}m=m+1|0;if((m&65535)>>>0<(k[d+196|0]|k[d+197|0]<<8)>>>0){continue}break}}jb(d+104|0)}n=1;if(!(c&1)){break e}m:{if((k[d+210|0]|k[d+211|0]<<8|(k[d+212|0]<<16|k[d+213|0]<<24))>>>0<5){break m}if(!xc(b,(k[d+210|0]|k[d+211|0]<<8|(k[d+212|0]<<16|k[d+213|0]<<24))-4|0)){break m}if(!vh(b,16919)){break m}o=a+484344|0;If(o,k[d+194|0]|k[d+195|0]<<8);if(!(k[d+194|0]|k[d+195|0]<<8)){break m}q=d+24|2;g=0;while(1){if(!Ws(b,d+24|0)){break m}if((k[d+24|0]|k[d+25|0]<<8)>>>0>3){cd(d+40|0,b,((k[d+24|0]|k[d+25|0]<<8)+15&131056)-4|0);c=k[q|0];j[114626]=0;c=K(402,o|0,g&65535,c|0)|0;e=j[114626];j[114626]=0;n:{if((e|0)!=1){o:{m=0;if(!c){break n}while(1){j[114626]=0;c=E(258,d+40|0,1)|0;e=j[114626];j[114626]=0;p:{q:{r:{if((e|0)!=1){if(!c|k[q|0]<=m>>>0){break q}j[114626]=0;e=H(387,d+40|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break o}if(e){break r}m=m+1|0;continue}break o}c=Ib(o,g);i[d+104>>1]=e&31;f=l[a+480188>>1];j[114626]=0;i[d+8>>1]=f-1;f=E(477,d+104|0,d+8|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break o}f=l[f>>1];j[114626]=0;c=K(471,c|0,m|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break o}if(e&128){j[114626]=0;F(472,d+104|0,d+40|0);f=j[114626];j[114626]=0;if((f|0)==1){break o}f=Pc(d+104|0);h[c|0]=k[d+104|0]+36;h[c+1|0]=k[f|0]}if(!(e&64)){break p}h[c+2|0]=1;j[114626]=0;f=H(387,d+40|0)|0;r=j[114626];j[114626]=0;s:{if((r|0)!=1){j[114626]=0;h[d+104|0]=f;h[d+8|0]=64;f=E(391,d+104|0,d+8|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break s}h[c+4|0]=k[f|0];break p}break o}break o}if(k[q|0]==64){break n}c=Ib(o,g);j[114626]=0;e=K(497,d+104|0,14,0)|0;m=j[114626];j[114626]=0;if((m|0)!=1){e=qi(Fe(e,k[q|0]-1|0));j[114626]=0;E(498,c|0,e|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break n}}break o}if(!(e&32)){continue}j[114626]=0;F(472,d+104|0,d+40|0);e=j[114626];j[114626]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{if((e|0)!=1){e=k[Pc(d+104|0)|0];h[c+5|0]=e;switch(k[d+104|0]-1|0){case 71:break u;case 70:break v;case 69:break w;case 60:break x;case 59:break y;case 52:break z;case 51:break A;case 50:break B;case 49:break C;case 42:break D;case 41:break E;case 40:break F;case 39:break G;case 30:break H;case 29:break I;case 22:break J;case 21:break K;case 20:break L;case 19:break M;case 16:break N;case 15:break O;case 14:break P;case 13:break Q;case 12:break R;case 11:break S;case 10:break T;case 9:break U;case 3:break V;case 2:break W;case 1:break X;case 0:break Y;default:break t}}break o}h[c+3|0]=11;h[c+5|0]=e<<4|15;continue}h[c+3|0]=11;h[c+5|0]=e<<4;continue}h[c+3|0]=11;h[c+5|0]=e|240;continue}h[c+3|0]=11;h[c+5|0]=e&15;continue}h[c+3|0]=2;h[c+5|0]=e|240;continue}h[c+3|0]=2;continue}h[c+3|0]=3;h[c+5|0]=e|240;continue}h[c+3|0]=3;continue}h[c+3|0]=4;continue}h[c+3|0]=20;h[c+5|0]=e|16;continue}h[c+3|0]=6;h[c+5|0]=e<<4;continue}h[c+3|0]=6;h[c+5|0]=e&15;continue}h[c+3|0]=5;continue}h[c+3|0]=20;h[c+5|0]=e|48;continue}h[c+3|0]=7;h[c+5|0]=e<<4;continue}h[c+3|0]=7;h[c+5|0]=e&15;continue}h[c+3|0]=8;continue}h[c+3|0]=20;h[c+5|0]=e|64;continue}h[c+3|0]=10;j[114626]=0;e=H(387,d+40|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){h[c+5|0]=e;j[114626]=0;E(338,d+40|0,1)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break o}h[c+3|0]=15;h[c+5|0]=e&15;continue}h[c+3|0]=20;h[c+5|0]=e|192;continue}h[c+3|0]=20;h[c+5|0]=e|208;continue}h[c+3|0]=12;continue}h[c+3|0]=14;continue}h[c+3|0]=20;h[c+5|0]=e|176;continue}h[c+3|0]=20;h[c+5|0]=e|224;continue}h[c+3|0]=16;continue}h[c+3|0]=17;continue}h[c+3|0]=1;continue}h[c+3|0]=20;h[c+5|0]=e&15|32;continue}h[c+3|0]=20;h[c+5|0]=e&15|128;continue}h[c+3|0]=0;continue}}}b=D()|0;C()|0;jb(d+40|0);break a}jb(d+40|0)}g=g+1|0;if(g>>>0<(k[d+194|0]|k[d+195|0]<<8)>>>0){continue}break}}if(!(k[d+218|0]|k[d+219|0]<<8|(k[d+220|0]<<16|k[d+221|0]<<24))){break e}xc(b,k[d+218|0]|k[d+219|0]<<8|(k[d+220|0]<<16|k[d+221|0]<<24));Yx(a+1304424|0,b,Of(b),4)}Za=d+272|0;return n|0}b=D()|0;C()|0;break b}b=D()|0;C()|0}jb(d+104|0)}G(b|0);z()}function K$(a,b,c,d,e,f,g,i,l,m,n){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0;o=Za-560|0;Za=o;j[o+548>>2]=n;j[o+552>>2]=b;j[o+96>>2]=2474;s=yd(o+136|0,o+144|0,o+96|0);b=j[s>>2];j[o+132>>2]=b;j[o+128>>2]=b+400;u=Db(o+96|0);r=Me(o+80|0);p=Me(o- -64|0);q=Me(o+48|0);t=Me(o+32|0);j[114626]=0;ba(2486,c|0,d|0,o+120|0,o+116|0,o+112|0,u|0,r|0,p|0,q|0,o+28|0);b=j[114626];j[114626]=0;if((b|0)!=1){a:{j[m>>2]=j[l>>2];v=e&512;w=v>>>9|0;n=0;e=0;while(1){b=e;b:{c:{d:{e:{if((n|0)==4){break e}j[114626]=0;c=E(2446,a|0,o+552|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(!c){break e}c=0;f:{g:{h:{i:{j:{switch(h[(o+120|0)+n|0]){case 1:if((n|0)==3){break c}j[114626]=0;c=H(2448,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;c=K(2487,i|0,8192,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(c){j[114626]=0;I(2488,o+16|0,a|0,0);c=j[114626];j[114626]=0;if((c|0)!=1){c=j[o+16>>2];j[114626]=0;F(112,t|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){break i}}break a}j[f>>2]=j[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((n|0)==3){break c}}while(1){j[114626]=0;c=E(2446,a|0,o+552|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(!c){break c}j[114626]=0;c=H(2448,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;c=K(2487,i|0,8192,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(!c){break c}j[114626]=0;I(2488,o+16|0,a|0,0);c=j[114626];j[114626]=0;if((c|0)!=1){c=j[o+16>>2];j[114626]=0;F(112,t|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}if((nb(p)|0)==(0-nb(q)|0)){break c}k:{if(nb(p)){if(nb(q)){break k}}if(nb(p)){j[114626]=0;c=H(2448,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if((c|0)==j[zb(p)>>2]){j[114626]=0;H(2450,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}e=nb(p)>>>0>1?p:b;break b}h[g|0]=1;break c}j[114626]=0;c=H(2448,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if((c|0)!=j[zb(q)>>2]){break c}j[114626]=0;H(2450,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}h[g|0]=1;e=nb(q)>>>0>1?q:b;break b}j[114626]=0;c=H(2448,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if((c|0)==j[zb(p)>>2]){j[114626]=0;H(2450,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}e=nb(p)>>>0>1?p:b;break b}j[114626]=0;c=H(2448,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if((c|0)==j[zb(q)>>2]){j[114626]=0;H(2450,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}h[g|0]=1;e=nb(q)>>>0>1?q:b;break b}j[f>>2]=j[f>>2]|4;a=0;break d}if(!(b|n>>>0<2)){e=0;if(!((n|0)==2&k[o+123|0]!=0|w)){break b}}y=o,A=nd(r),j[y+8>>2]=A;c=Cd(o+16|0,o+8|0);l:{if(!n|k[(n+o|0)+119|0]>1){break l}m:{while(1){y=o,A=tj(r),j[y+8>>2]=A;if(!rb(c,o+8|0)){break m}d=j[j[c>>2]>>2];j[114626]=0;d=K(2487,i|0,8192,d|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){if(!d){break m}Id(c);continue}break}break a}y=o,A=nd(r),j[y+8>>2]=A;c=Ms(c,o+8|0);if(nb(t)>>>0>=c>>>0){y=o,A=tj(t),j[y+8>>2]=A;c=mM(o+8|0,c);d=tj(t);e=nd(r);j[114626]=0;c=SC(c,d,e);d=j[114626];j[114626]=0;if((d|0)==1){break a}if(c){break l}}y=o,A=nd(r),j[y>>2]=A;Cd(o+8|0,o);j[o+16>>2]=j[o+8>>2]}j[o+8>>2]=j[o+16>>2];n:{while(1){y=o,A=tj(r),j[y>>2]=A;if(!rb(o+8|0,o)){break n}j[114626]=0;c=E(2446,a|0,o+552|0)|0;d=j[114626];j[114626]=0;o:{if((d|0)==1){break o}if(!c){break n}j[114626]=0;c=H(2448,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break o}if((c|0)!=j[j[o+8>>2]>>2]){break n}j[114626]=0;H(2450,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}Id(o+8|0);continue}break}break a}if(!v){break c}y=o,A=tj(r),j[y>>2]=A;if(!rb(o+8|0,o)){break c}j[f>>2]=j[f>>2]|4;a=0;break d}p:{while(1){q:{j[114626]=0;d=E(2446,a|0,o+552|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break q}if(!d){break p}j[114626]=0;e=H(2448,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;d=K(2487,i|0,2048,e|0)|0;x=j[114626];j[114626]=0;if((x|0)==1){break a}r:{if(d){d=j[m>>2];if((d|0)==j[o+548>>2]){j[114626]=0;I(2490,l|0,m|0,o+548|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[m>>2]}j[m>>2]=d+4;j[d>>2]=e;c=c+1|0;break r}if(!c|!nb(u)|(e|0)!=j[o+112>>2]){break p}e=j[o+132>>2];if((e|0)==j[o+128>>2]){j[114626]=0;I(2481,s|0,o+132|0,o+128|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}e=j[o+132>>2]}j[o+132>>2]=e+4;j[e>>2]=c;c=0}j[114626]=0;H(2450,a|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){continue}}break}break a}d=j[s>>2];s:{if(!c){break s}e=j[o+132>>2];if((d|0)==(e|0)){break s}if(j[o+128>>2]==(e|0)){j[114626]=0;I(2481,s|0,o+132|0,o+128|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}e=j[o+132>>2]}j[o+132>>2]=e+4;j[e>>2]=c}t:{if(j[o+28>>2]<1){break t}j[114626]=0;c=E(2447,a|0,o+552|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}u:{if(!c){j[114626]=0;c=H(2448,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if((c|0)==j[o+116>>2]){break u}}j[f>>2]=j[f>>2]|4;a=0;break d}j[114626]=0;H(2450,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}while(1){if(j[o+28>>2]<1){break t}j[114626]=0;c=E(2447,a|0,o+552|0)|0;d=j[114626];j[114626]=0;v:{if((d|0)==1){break v}w:{if(!c){j[114626]=0;c=H(2448,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break v}j[114626]=0;c=K(2487,i|0,2048,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break v}if(c){break w}}j[f>>2]=j[f>>2]|4;a=0;break d}if(j[m>>2]==j[o+548>>2]){j[114626]=0;I(2490,l|0,m|0,o+548|0);c=j[114626];j[114626]=0;if((c|0)==1){break v}}j[114626]=0;c=H(2448,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break v}d=j[m>>2];j[m>>2]=d+4;j[d>>2]=c;j[114626]=0;j[o+28>>2]=j[o+28>>2]-1;H(2450,a|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}e=b;if(j[l>>2]!=j[m>>2]){break b}j[f>>2]=j[f>>2]|4;a=0;break d}x:{if(!b){break x}e=1;while(1){if(nb(b)>>>0<=e>>>0){break x}j[114626]=0;c=E(2447,a|0,o+552|0)|0;d=j[114626];j[114626]=0;y:{if((d|0)==1){break y}z:{if(!c){j[114626]=0;c=H(2448,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break y}if((c|0)==j[Li(b,e)>>2]){break z}}j[f>>2]=j[f>>2]|4;a=0;break d}j[114626]=0;H(2450,a|0)|0;c=j[114626];j[114626]=0;e=e+1|0;if((c|0)!=1){continue}}break}break a}A:{if(j[s>>2]==j[o+132>>2]){break A}j[o+16>>2]=0;a=j[s>>2];j[114626]=0;le(u,a,j[o+132>>2],o+16|0);a=j[114626];j[114626]=0;if((a|0)!=1){if(!j[o+16>>2]){break A}j[f>>2]=j[f>>2]|4;a=0;break d}break a}a=1}pc(t);pc(q);pc(p);pc(r);gb(u);mc(s);Za=o+560|0;return a|0}e=b}n=n+1|0;continue}}}a=D()|0;C()|0;pc(t);pc(q);pc(p);pc(r);gb(u);mc(s);G(a|0);z()}function XV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,F=0,L=0,N=0;e=Za-1424|0;Za=e;rc(b);aq(a);a:{if(!qB(b,e+1408|0)){break a}if(!sB(e+1408|0)){break a}if(!pB(b,e+1392|0)){break a}if(!rB(e+1392|0)){break a}b:{if(!c){break b}B=e+1400|0;c=B;if((k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))>>>0>jj(b)>>>0){break a}c=B;u=e+1392|2;if((k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))+((k[u|0]|k[u+1|0]<<8)<<2)>>>0>jj(b)>>>0){break a}tu(a);su(e+40|0);ru(yg(a)+28|0,e+40|0);$p(e+40|0);q=j[yg(a)+28>>2];c=e+1392|4;Ln(q,k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24));Ab(e+1136|0,0,256);c:{d:{if(k[u|0]|k[u+1|0]<<8){o=e+1112|4;p=e+1128|0;A=e+1130|0;v=e+1126|0;i=e+1124|0;while(1){d=0;c=B;if(!xc(b,(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))+(F<<2)|0)){break a}if(!yb(b,4)){break a}f=hf(b);if(!xc(b,f)){break a}if(!qu(b,e+1112|0)){break a}x=UV(e+1096|0,k[i|0]|k[i+1|0]<<8);c=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if(!(k[i|0]|k[i+1|0]<<8)){break v}w:{while(1){d=uk(x,c);j[114626]=0;d=E(254,b|0,d|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break w}if(d){c=c+1|0;if(c>>>0>=(k[i|0]|k[i+1|0]<<8)>>>0){break v}continue}break}break u}d=D()|0;C()|0;break c}if(k[i|0]|k[i+1|0]<<8){d=j[x>>2]}else{d=0}c=k[i|0]|k[i+1|0]<<8;j[114626]=0;m=H(255,b|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break t}g=c<<3;c=f+20|0;if(m>>>0>g+c>>>0){n=c+((k[i|0]|k[i+1|0]<<8)<<3)|0;x:{if(!(h[v|0]&1)){f=0;if(!(k[i|0]|k[i+1|0]<<8)){break e}while(1){if(!d){break x}if(!Fn(q,d)){break x}j[114626]=0;c=E(256,b|0,n|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break s}if(!c){break x}m=fc(q,k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24));c=d;r=k[c+4|0]|k[c+5|0]<<8|(k[c+6|0]<<16|k[c+7|0]<<24);j[114626]=0;m=K(257,b|0,m|0,r|0)|0;r=j[114626];j[114626]=0;if((r|0)==1){break s}if((m|0)!=(k[c+4|0]|k[c+5|0]<<8|(k[c+6|0]<<16|k[c+7|0]<<24))){break x}d=d+8|0;f=f+1|0;if(f>>>0<(k[i|0]|k[i+1|0]<<8)>>>0){continue}break}break e}y:{z:{A:{B:{if(k[v|0]&4){if(!d){break y}if(!Fn(q,d)){break y}r=fc(q,k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24));y=k[d+4|0]|k[d+5|0]<<8|(k[d+6|0]<<16|k[d+7|0]<<24);m=k[A|0]|k[A+1|0]<<8;c=k[p|0]|k[p+1|0]<<8;j[114626]=0;c=E(256,b|0,c+n|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break r}if(!c){break y}c=k[o|0]|k[o+1|0]<<8|(k[o+2|0]<<16|k[o+3|0]<<24);f=k[p|0]|k[p+1|0]<<8;j[114626]=0;c=E(258,b|0,c-f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break r}if(!c){break y}c=k[o|0]|k[o+1|0]<<8|(k[o+2|0]<<16|k[o+3|0]<<24);f=k[p|0]|k[p+1|0]<<8;j[114626]=0;I(259,e+24|0,b|0,c-f|0);c=j[114626];j[114626]=0;if((c|0)==1){break d}s=Jl(e+40|0,e+24|0);jb(e+24|0);w=0;f=0;n=0;if(!(k[i|0]|k[i+1|0]<<8)){break h}while(1){C:{j[114626]=0;c=E(260,s|0,m+1|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break C}g=m&15;t=l[(g<<1)+11024>>1];D:{E:{if(t>>>0<=c>>>0){j[114626]=0;g=k[g+11104|0];L=E(260,s|0,g|0)|0;N=j[114626];j[114626]=0;if((N|0)==1){break j}c=L+(c-t<<g)|0;if((c|0)!=(m|0)){m=c&15;break D}j[114626]=0;c=E(260,s|0,4)|0;g=j[114626];j[114626]=0;if((g|0)==1){break j}if((c|0)==15){j[114626]=0;g=E(260,s|0,1)|0;c=j[114626];j[114626]=0;if((c|0)==1){break j}c=65535;if(!g){break E}jb(e+40|0);break e}c=c+65520|0}if(c>>>0>65535){break D}}c=c&1?0-(c+1>>>1|0)|0:c>>>1|0;g=f+r|0;t=g;F:{if(k[v|0]&2){w=c+w|0;c=w;break F}c=k[v+1|0]&2?c:c^32768}h[t|0]=c;h[g+1|0]=c>>>8;f=f+2|0}if(f>>>0>=y>>>0){n=n+1|0;if(n>>>0>=(k[i|0]|k[i+1|0]<<8)>>>0){break z}c=(n<<3)+d|0;if(!Fn(q,c)){break B}y=k[c+4|0]|k[c+5|0]<<8|(k[c+6|0]<<16|k[c+7|0]<<24);r=fc(q,k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24));f=0}if((k[i|0]|k[i+1|0]<<8)>>>0>n>>>0){continue}break h}break}d=J(77072)|0;break i}if(!d){break y}if(!Fn(q,d)){break y}w=fc(q,k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24));y=k[d+4|0]|k[d+5|0]<<8|(k[d+6|0]<<16|k[d+7|0]<<24);m=k[A|0]|k[A+1|0]<<8;if((k[p|0]|k[p+1|0]<<8)>>>0>256){break y}j[114626]=0;c=E(256,b|0,n|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break q}if(!c){break y}c=k[p|0]|k[p+1|0]<<8;j[114626]=0;c=K(261,b|0,e+1136|0,c|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break q}if(c>>>0<(k[p|0]|k[p+1|0]<<8)>>>0){break y}c=k[o|0]|k[o+1|0]<<8|(k[o+2|0]<<16|k[o+3|0]<<24);f=k[p|0]|k[p+1|0]<<8;j[114626]=0;c=E(258,b|0,c-f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break q}if(!c){break y}c=k[o|0]|k[o+1|0]<<8|(k[o+2|0]<<16|k[o+3|0]<<24);f=k[p|0]|k[p+1|0]<<8;j[114626]=0;I(259,e+24|0,b|0,c-f|0);c=j[114626];j[114626]=0;if((c|0)==1){break k}s=Jl(e+40|0,e+24|0);jb(e+24|0);r=0;f=0;n=0;if(!(k[i|0]|k[i+1|0]<<8)){break n}G:{while(1){H:{j[114626]=0;c=E(260,s|0,m+1|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break H}g=m&7;t=k[g+11056|0];I:{J:{if(t>>>0<=c>>>0){j[114626]=0;g=k[g+11064|0];L=E(260,s|0,g|0)|0;N=j[114626];j[114626]=0;if((N|0)==1){break p}c=L+(c-t<<g)|0;if((c|0)!=(m|0)){m=c&7;break I}j[114626]=0;c=E(260,s|0,3)|0;g=j[114626];j[114626]=0;if((g|0)==1){break p}if((c|0)==7){j[114626]=0;g=E(260,s|0,1)|0;c=j[114626];j[114626]=0;if((c|0)==1){break p}c=255;if(!g){break J}jb(e+40|0);break e}c=c+248|0}if(c>>>0>255){break I}}c=k[(e+1136|0)+c|0];g=c+r|0;t=c;c=(k[v|0]|k[v+1|0]<<8)&2;h[f+w|0]=c?g:t;r=c?g:r;f=f+1|0}if(f>>>0>=y>>>0){n=n+1|0;if(n>>>0>=(k[i|0]|k[i+1|0]<<8)>>>0){break G}c=(n<<3)+d|0;if(!Fn(q,c)){break A}y=k[c+4|0]|k[c+5|0]<<8|(k[c+6|0]<<16|k[c+7|0]<<24);w=fc(q,k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24));f=0}if((k[i|0]|k[i+1|0]<<8)>>>0>n>>>0){continue}break n}break}d=J(77072)|0;break o}jb(e+40|0);break e}jb(e+40|0);break u}jb(e+40|0);break u}jb(e+40|0);break e}}}}pu(x);d=0;break a}d=D()|0;C()|0;break c}d=D()|0;C()|0;break c}d=D()|0;C()|0;break c}d=D()|0;C()|0;break c}d=J(77072)|0}if((C()|0)!=(W(77072)|0)){break l}O(d|0)|0;j[114626]=0;M(20);c=j[114626];j[114626]=0;if((c|0)==1){break m}}jb(e+40|0);break e}d=D()|0;C()|0}jb(e+40|0);break c}d=D()|0;C()|0;break c}d=J(77072)|0}if((C()|0)!=(W(77072)|0)){break f}O(d|0)|0;j[114626]=0;M(20);c=j[114626];j[114626]=0;if((c|0)==1){break g}}jb(e+40|0);break e}d=D()|0;C()|0}jb(e+40|0);break c}pu(x);F=F+1|0;if(F>>>0<(k[u|0]|k[u+1|0]<<8)>>>0){continue}break}}xi(e+8|0,q);ou(e+16|0,e+8|0);b=Dn(e+40|0,e+16|0,0);Ed(yg(a)+12|0,b);jb(b);break b}d=D()|0;C()|0}pu(x);G(d|0);z()}d=1}Za=e+1424|0;return d|0}function Vr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;n=Za-32|0;Za=n;j[n+28>>2]=c;a:{if((c|0)<1){break a}q=j[b+104>>2];o=j[b+656>>2];if(!(!o|j[a+480180>>2]!=16777216)){u=j[o+44>>2]!=0}b:{if(!(!o|(c|0)>128)){r=l[Oc(o+236|0,c-1|0)>>1];c:{if((r-1&65535)>>>0<=3998){q=(p(r,104)+a|0)+484380|0;break c}mb(n+16|0,a+1074308|0,43);if(!kb(n+16|0)){break c}if(!Qi(b)){break a}}r=k[Pb(o+108|0,j[n+28>>2]-1|0)|0];j[n+28>>2]=r;break b}r=c}if((r|0)>=121){d:{if(!(j[a+480180>>2]&16777248?(r|0)!=255:0)){Cm(a,b);if(d){break d}mb(n+16|0,a+1074308|0,100);if(!kb(n+16|0)|!(k[a+480208|0]&4)|!k[b+811|0]){break d}j[b+88>>2]=j[b+88>>2]&-6145;break d}if(!l[a+480192>>1]){break d}j[b+88>>2]=j[b+88>>2]|4096}e:{if(j[n+28>>2]!=254){break e}f:{c=j[b+88>>2];if(!(c&512)){break f}c=j[b+88>>2];if(j[a+480180>>2]!=2){break f}j[b+88>>2]=c|2048;break e}j[b+88>>2]=c|2101248;g:{if(j[a+480180>>2]&16777248){if(!l[a+480192>>1]){break g}mb(n+16|0,a+1074308|0,50);if(kb(n+16|0)){break g}}j[b+688>>2]=0}mb(n+16|0,a+1074308|0,50);if(kb(n+16|0)){j[b+8>>2]=0;j[b+12>>2]=0}j[b+696>>2]=0}mb(n+16|0,a+1074308|0,20);if(!kb(n+16|0)){break a}h[b+819|0]=0;h[b+824|0]=0;break a}h:{i:{j:{if(u){if(d){s=k[b+819|0];if(s){break j}}j[b+708>>2]=0}if(d){break i}if(!(!q|!(j[a+480180>>2]&1048588))){j[b+772>>2]=h[q+36|0];j[b+768>>2]=h[q+37|0]}if(q){mb(n+16|0,a+1074308|0,24);r=0;t=1;if(!kb(n+16|0)){break h}j[b+704>>2]=j[q+24>>2];break h}r=0;break h}t=j[o+44>>2];i[n>>1]=s;i[n+14>>1]=r;j[n+16>>2]=0;r=(j[n+16>>2]+p(i[t+36>>1]+1|0,i[n+14>>1]-i[n>>1]|0)|0)-j[b+876>>2]|0;j[b+708>>2]=r;j[b+876>>2]=0-r}t=(q|0)!=0;r=1;if(ph(b)){break h}r=a+1074308|0;mb(n+16|0,r,54);if(kb(n+16|0)){j[b+700>>2]=0;break a}mb(n+16|0,r,39);r=(kb(n+16|0)^-1)&d}k:{if(Zs(a)){j[n+28>>2]=j[n+28>>2]+j[b+772>>2];Md(n+28|0,12,131);break k}gO(n+28|0)}s=a+1074308|0;mb(n+16|0,s,34);d=b;l:{if(kb(n+16|0)){c=op(c);break l}c=j[n+28>>2]}h[d+819|0]=c;h[b+872|0]=k[b+872|0]|8;if(!(j[a+480180>>2]&16777250?0:r)){h[b+825|0]=0}d=Zf(a,j[n+28>>2],j[b+768>>2],j[b+704>>2]);h[b+851|0]=0;mb(n+16|0,s,48);if(kb(n+16|0)){yK(a,b,o,q)}m:{if(e^1|r){break m}j[b+788>>2]=0;j[b+792>>2]=0;if(!o){break m}mb(n+16|0,s,29);if(kb(n+16|0)){h[b+820|0]=k[o+16|0]}if(!(k[o+60|0]&8)){$h(b+724|0)}if(!(k[o+80|0]&8)){$h(b+736|0)}if(!(k[o+100|0]&8)){$h(b+748|0)}if(k[o+20|0]){c=Tr(Bm(a));v=k[o+20|0];mb(n+16|0,s,28);w=((p(c,v)<<16>>16)/64<<16)+65536>>16;c=b;n:{if(kb(n+16|0)){v=j[b+764>>2];break n}v=(j[b+688>>2]+1|0)/2|0}i[c+788>>1]=(p(v,w)|0)/199}o:{if(!k[o+19|0]){break o}x=b,y=(p(Tr(Bm(a)),k[o+19|0])<<16>>16)/32|0,i[x+790>>1]=y;mb(n+16|0,s,28);if(kb(n+16|0)|l[b+796>>1]){break o}i[b+796>>1]=l[b+692>>1]+1}c=k[o+23|0];if(c){v=Tr(Bm(a));w=k[b+857|0];h[b+818|0]=w+1;i[b+792>>1]=(p(w,(p(c,v+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=k[o+24|0];if(!c){break m}v=Tr(Bm(a));w=k[b+858|0];h[b+817|0]=w+1;i[b+794>>1]=(p(w,(p(c,v+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!t){break a}t=0;p:{q:{if(!d){break q}r:{s:{t:{if(r){u:{if(!j[b+700>>2]){j[b+700>>2]=d;if(!u){break u}break t}if(u){break t}}j[b+708>>2]=d;break t}j[b+700>>2]=d;if(u){break s}mb(n+16|0,s,69);if(kb(n+16|0)){break s}mb(n,s,46);if(kb(n)|j[a+480180>>2]==1){break s}j[b+708>>2]=d;break s}if(j[b+76>>2]|j[a+480180>>2]&2){break r}}j[b+104>>2]=q;c=j[q>>2];j[b+84>>2]=c;j[b+76>>2]=c;j[b+80>>2]=0;j[b>>2]=0;j[b+4>>2]=0;v:{w:{if(!(j[a+480208>>2]&2097152)){mb(n+16|0,s,96);if(!kb(n+16|0)){break w}}if(k[b+811|0]){break w}j[n+16>>2]=j[b+76>>2]-1;x=b,y=j[tb(b+660|0,n+16|0)>>2],j[x+4>>2]=y;break v}j[b+660>>2]=0}c=l[q+34>>1];d=c&1023;u=d|j[b+88>>2]&-525056;j[b+88>>2]=u;x:{if(c&8){j[b+80>>2]=j[q+12>>2];c=j[q+16>>2];j[b+88>>2]=(d&16?u|4:u&-524295)|2;j[b+84>>2]=c;if(c>>>0>=m[b+76>>2]){break x}j[b+76>>2]=c;break x}if(!(d&2)){break x}j[b+80>>2]=j[q+4>>2];c=j[q+8>>2];j[b+84>>2]=c;if(c>>>0>=m[b+76>>2]){break x}j[b+76>>2]=c}mb(n+16|0,s,83);if(!(!kb(n+16|0)|j[b+80>>2])){c=j[q>>2];j[b+84>>2]=c;j[b+76>>2]=c}c=j[b+88>>2];if(c&128){j[b+88>>2]=c|128;j[b+4>>2]=j[b+76>>2]-1}y:{if(k[b+842|0]>3){break y}mb(n+16|0,s,21);if(!(kb(n+16|0)|!(j[a+480180>>2]&16777248)|j[a+480208>>2]&4)){h[b+839|0]=16;break y}if(j[a+480180>>2]==16){h[b+839|0]=32;break y}if(j[a+480180>>2]&67633152){break y}h[b+839|0]=0}mb(n+16|0,s,21);if(kb(n+16|0)|k[b+845|0]>3){break r}h[b+840|0]=0}d=j[b>>2];if(m[b+76>>2]<=m[b+4>>2]){c=d;d=j[b+80>>2];j[b>>2]=c;j[b+4>>2]=d}if(!r){break q}t=1;if(!(j[a+480180>>2]&17301536)|(j[b+696>>2]?0:k[b+89|0]&16)){break q}if(!(k[a+480208|0]&8)|!k[b+811|0]){break p}}if(!(j[b+696>>2]|(!(j[a+480180>>2]&17301536)|!(k[b+89|0]&16)))){_k(b);mb(n+16|0,s,21);if(!kb(n+16|0)){h[b+838|0]=0;j[b+780>>2]=0}j[b+696>>2]=65536;j[b+88>>2]=j[b+88>>2]&-4097}if(!(k[b+811|0]|(!t|!(k[a+480208|0]&8)))){t=1;break p}if(k[b+811|0]?0:j[a+480180>>2]&1048580){break p}j[b+696>>2]=65536;j[b+88>>2]=j[b+88>>2]&-4097}mb(n+16|0,s,40);z:{A:{if(kb(n+16|0)){if(t){if(!(!(k[a+480208|0]&8)|!k[b+811|0])){j[b+88>>2]=j[b+88>>2]&-4196353;q=1;break z}j[b+88>>2]=j[b+88>>2]&-4194305;q=1;break z}c=j[b+88>>2]&-4196353;break A}c=j[b+88>>2]&-4196353;j[b+88>>2]=c;q=1;if(t){break z}}i[b+862>>1]=65535;j[b+88>>2]=c&-6326273|2097152;mb(n+16|0,s,23);B:{if(kb(n+16|0)){break B}mb(n,s,22);if(kb(n)){break B}mb(n+16|0,s,52);if(kb(n+16|0)){break B}mb(n,s,71);if(kb(n)){break B}h[b+859|0]=0;i[b+798>>1]=0}if(e){h[b+838|0]=0;j[b+780>>2]=0}j[b+20>>2]=0;j[b+24>>2]=0;c=j[a+480208>>2]&8192;C:{if(o){D:{E:{if(!qA(o)){if(Mt(o)){break E}c=c>>>13^1;if(c){break D}c=(c|0)!=0;break C}x=b,y=rA(o),h[x+858|0]=y;if(!Mt(o)){break D}}x=b,y=sA(o),h[x+857|0]=y}c=1;d=k[o+25|0];if((d|0)==255){break C}h[b+865|0]=d;break C}j[b+788>>2]=0;j[b+792>>2]=0;c=!c}F:{if(k[b+857|0]>=127){mb(n+16|0,s,36);if(!kb(n+16|0)){break F}}q=0;if(!c){break z}if((Ho(a,b,1,256)|0)<0|!(k[b+89|0]&2)){break z}c=a+1304392|0;if(!bd(c)|(g|0)==65535){break z}No(j[c>>2],g,k[b+857|0]>>>1|0,1);break z}q=0}c=j[b+88>>2];if(f){c=c&-1025;j[b+88>>2]=c}G:{H:{if(k[a+24618|0]&16?c&1024:0){break H}a=j[b+104>>2];if(f?0:!(!a|!(k[a+35|0]&4))){break H}a=j[b+656>>2];if(!a|!(k[a+15|0]&2)){break G}}if(f){break G}j[b+700>>2]=0}if(q){break a}i[b+136>>1]=0;j[b+132>>2]=4194304;j[b+112>>2]=0;j[b+116>>2]=0}Za=n+32|0}function T$(a,b,c,d,e,f,g,i,l,m,n){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;o=Za-560|0;Za=o;j[o+548>>2]=n;j[o+552>>2]=b;j[o+104>>2]=2474;s=yd(o+136|0,o+144|0,o+104|0);b=j[s>>2];j[o+132>>2]=b;j[o+128>>2]=b+400;u=Db(o+104|0);r=Db(o+88|0);p=Db(o+72|0);q=Db(o+56|0);t=Db(o+40|0);j[114626]=0;ba(2477,c|0,d|0,o+120|0,o+119|0,o+118|0,u|0,r|0,p|0,q|0,o+36|0);b=j[114626];j[114626]=0;if((b|0)!=1){a:{j[m>>2]=j[l>>2];v=e&512;w=v>>>9|0;b=0;e=0;while(1){n=e;b:{c:{d:{e:{if((b|0)==4){break e}j[114626]=0;c=E(2414,a|0,o+552|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(!c){break e}c=0;f:{g:{h:{i:{j:{switch(h[(o+120|0)+b|0]){case 1:if((b|0)==3){break c}j[114626]=0;c=H(2416,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(ng(i,8192,c)){j[114626]=0;I(2478,o+24|0,a|0,0);c=j[114626];j[114626]=0;if((c|0)!=1){c=h[o+24|0];j[114626]=0;F(110,t|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){break i}}break a}j[f>>2]=j[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((b|0)==3){break c}}while(1){j[114626]=0;c=E(2414,a|0,o+552|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(!c){break c}j[114626]=0;c=H(2416,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(!ng(i,8192,c)){break c}j[114626]=0;I(2478,o+24|0,a|0,0);c=j[114626];j[114626]=0;if((c|0)!=1){c=h[o+24|0];j[114626]=0;F(110,t|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}if((nb(p)|0)==(0-nb(q)|0)){break c}k:{if(nb(p)){if(nb(q)){break k}}if(nb(p)){j[114626]=0;c=H(2416,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(k[Ub(p,0)|0]==(c&255)){j[114626]=0;H(2418,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}e=nb(p)>>>0>1?p:n;break b}h[g|0]=1;break c}j[114626]=0;c=H(2416,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(k[Ub(q,0)|0]!=(c&255)){break c}j[114626]=0;H(2418,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}h[g|0]=1;e=nb(q)>>>0>1?q:n;break b}j[114626]=0;c=H(2416,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(k[Ub(p,0)|0]==(c&255)){j[114626]=0;H(2418,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}e=nb(p)>>>0>1?p:n;break b}j[114626]=0;c=H(2416,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(k[Ub(q,0)|0]==(c&255)){j[114626]=0;H(2418,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}h[g|0]=1;e=nb(q)>>>0>1?q:n;break b}j[f>>2]=j[f>>2]|4;a=0;break d}if(!(n|b>>>0<2)){e=0;if(!((b|0)==2&k[o+123|0]!=0|w)){break b}}x=o,y=nd(r),j[x+16>>2]=y;c=Cd(o+24|0,o+16|0);l:{if(!b|k[(b+o|0)+119|0]>1){break l}while(1){m:{x=o,y=_e(r),j[x+16>>2]=y;if(!rb(c,o+16|0)){break m}if(!ng(i,8192,h[j[c>>2]])){break m}Xf(c);continue}break}x=o,y=nd(r),j[x+16>>2]=y;c=En(c,o+16|0);if(nb(t)>>>0>=c>>>0){x=o,y=_e(t),j[x+16>>2]=y;c=$e(o+16|0,0-c|0);d=_e(t);e=nd(r);j[114626]=0;c=XC(c,d,e);d=j[114626];j[114626]=0;if((d|0)==1){break a}if(c){break l}}x=o,y=nd(r),j[x+8>>2]=y;Cd(o+16|0,o+8|0);j[o+24>>2]=j[o+16>>2]}j[o+16>>2]=j[o+24>>2];n:{while(1){x=o,y=_e(r),j[x+8>>2]=y;if(!rb(o+16|0,o+8|0)){break n}j[114626]=0;c=E(2414,a|0,o+552|0)|0;d=j[114626];j[114626]=0;o:{if((d|0)==1){break o}if(!c){break n}j[114626]=0;c=H(2416,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break o}if(k[j[o+16>>2]]!=(c&255)){break n}j[114626]=0;H(2418,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}Xf(o+16|0);continue}break}break a}if(!v){break c}x=o,y=_e(r),j[x+8>>2]=y;if(!rb(o+16|0,o+8|0)){break c}j[f>>2]=j[f>>2]|4;a=0;break d}p:{while(1){q:{j[114626]=0;d=E(2414,a|0,o+552|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break q}if(!d){break p}j[114626]=0;e=H(2416,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}r:{if(ng(i,2048,e)){d=j[m>>2];if((d|0)==j[o+548>>2]){j[114626]=0;I(2480,l|0,m|0,o+548|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[m>>2]}j[m>>2]=d+1;h[d|0]=e;c=c+1|0;break r}if(!c|!nb(u)|k[o+118|0]!=(e&255)){break p}e=j[o+132>>2];if((e|0)==j[o+128>>2]){j[114626]=0;I(2481,s|0,o+132|0,o+128|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}e=j[o+132>>2]}j[o+132>>2]=e+4;j[e>>2]=c;c=0}j[114626]=0;H(2418,a|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){continue}}break}break a}d=j[s>>2];s:{if(!c){break s}e=j[o+132>>2];if((d|0)==(e|0)){break s}if(j[o+128>>2]==(e|0)){j[114626]=0;I(2481,s|0,o+132|0,o+128|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}e=j[o+132>>2]}j[o+132>>2]=e+4;j[e>>2]=c}t:{if(j[o+36>>2]<1){break t}j[114626]=0;c=E(2415,a|0,o+552|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}u:{if(!c){j[114626]=0;c=H(2416,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}if(k[o+119|0]==(c&255)){break u}}j[f>>2]=j[f>>2]|4;a=0;break d}j[114626]=0;H(2418,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}while(1){if(j[o+36>>2]<1){break t}j[114626]=0;c=E(2415,a|0,o+552|0)|0;d=j[114626];j[114626]=0;v:{if((d|0)==1){break v}w:{if(!c){j[114626]=0;c=H(2416,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break v}if(ng(i,2048,c)){break w}}j[f>>2]=j[f>>2]|4;a=0;break d}if(j[m>>2]==j[o+548>>2]){j[114626]=0;I(2480,l|0,m|0,o+548|0);c=j[114626];j[114626]=0;if((c|0)==1){break v}}j[114626]=0;c=H(2416,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break v}d=j[m>>2];j[m>>2]=d+1;h[d|0]=c;j[114626]=0;j[o+36>>2]=j[o+36>>2]-1;H(2418,a|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}e=n;if(j[l>>2]!=j[m>>2]){break b}j[f>>2]=j[f>>2]|4;a=0;break d}x:{if(!n){break x}e=1;while(1){if(nb(n)>>>0<=e>>>0){break x}j[114626]=0;b=E(2415,a|0,o+552|0)|0;c=j[114626];j[114626]=0;y:{if((c|0)==1){break y}z:{if(!b){j[114626]=0;b=H(2416,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break y}if(k[Ub(n,e)|0]==(b&255)){break z}}j[f>>2]=j[f>>2]|4;a=0;break d}j[114626]=0;H(2418,a|0)|0;b=j[114626];j[114626]=0;e=e+1|0;if((b|0)!=1){continue}}break}break a}A:{if(j[s>>2]==j[o+132>>2]){break A}j[o+24>>2]=0;a=j[s>>2];j[114626]=0;le(u,a,j[o+132>>2],o+24|0);a=j[114626];j[114626]=0;if((a|0)!=1){if(!j[o+24>>2]){break A}j[f>>2]=j[f>>2]|4;a=0;break d}break a}a=1}gb(t);gb(q);gb(p);gb(r);gb(u);mc(s);Za=o+560|0;return a|0}e=n}b=b+1|0;continue}}}a=D()|0;C()|0;gb(t);gb(q);gb(p);gb(r);gb(u);mc(s);G(a|0);z()}function BGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,J=0,L=0,M=0,N=0;e=Za-176|0;Za=e;a:{b:{c:{d:{e:{f:{g:{h:{if(!vh(b,14021)){break h}if(d){h[d|0]=1}r=a+1074308|0;Xs(r);i:{if(!yb(b,7)){break i}t=a+480216|0;u=a+480220|0;v=a+480224|0;w=a+1074368|0;x=a+480228|0;y=a+480232|0;A=a+480200|0;B=a+484360|0;s=a+480268|0;J=a+1304412|0;L=a+480248|0;while(1){f=hf(b);d=Of(b);if((f|0)==(k[14475]|k[14476]<<8|(k[14477]<<16|k[14478]<<24))){cg(b,6);break i}if(!(f&1616928864)|f&-2139062144){break i}if(!yb(b,d)){break i}cd(e+160|0,b,d);j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)<=1347243309){if((f|0)<=1146367533){if((f|0)<=1130917458){if((f|0)==1127099950){break y}if((f|0)!=1129797166){break j}j[114626]=0;j[e>>2]=0;I(672,e+160|0,d|0,e|0);d=j[114626];j[114626]=0;if((d|0)==1){break v}j[a+1074300>>2]=j[e>>2];break j}if((f|0)==1130917459){break q}if((f|0)!=1145525806){break j}j[114626]=0;I(672,e+160|0,d|0,A|0);d=j[114626];j[114626]=0;if((d|0)==1){break b}break j}if((f|0)<=1213486400){if((f|0)==1146367534){break A}if((f|0)!=1196316499|d>>>0<3){break j}j[114626]=0;F(673,e+144|0,e+160|0);d=j[114626];j[114626]=0;if((d|0)==1){break o}j[114626]=0;g=K(674,e|0,e+144|0,8)|0;d=j[114626];j[114626]=0;if((d|0)==1){break n}gb(e+144|0);j[114626]=0;f=H(255,e+160|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break m}j[114626]=0;I(675,e|0,L|0,f|0);d=j[114626];j[114626]=0;if((d|0)==1){break m}Xe(g);break j}if((f|0)==1213486401){break r}if((f|0)==1280530262){break u}if((f|0)!=1297303086){break j}Xs(r);n=0;break l}if((f|0)<=1380994349){if((f|0)<=1380340803){if((f|0)==1347243310){break w}if((f|0)!=1347244882){break j}j[114626]=0;I(676,e+160|0,d|0,s|0);d=j[114626];j[114626]=0;if((d|0)==1){break b}if(qn(k[s|0])){break j}h[s|0]=5;break j}if((f|0)==1380340804){break z}if((f|0)==1380986414){break s}if((f|0)!=1380991534){break j}j[114626]=0;I(672,e+160|0,d|0,t|0);d=j[114626];j[114626]=0;if((d|0)==1){break b}break j}if((f|0)<=1397768493){if((f|0)==1380994350){break k}if((f|0)!=1397052739|d>>>0<3){break j}j[114626]=0;f=H(357,e+160|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}if(!f|f>>>0>l[a+480190>>1]){break j}f=p(f,104)+a|0;d=f+484448|0;q=f+484484|0;while(1){j[114626]=0;g=H(390,e+160|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break p}j[d>>2]=g;d=d+4|0;if((q|0)!=(d|0)){continue}break}break j}if((f|0)==1397768494){break t}if((f|0)==1414344238){break x}if((f|0)!=1448301654){break j}j[114626]=0;I(672,e+160|0,d|0,y|0);d=j[114626];j[114626]=0;if((d|0)==1){break b}break j}j[114626]=0;I(672,e+160|0,d|0,e|0);d=j[114626];j[114626]=0;if((d|0)==1){break g}j[a+480204>>2]=p(j[e>>2],1e4)+(m[a+480204>>2]%1e4|0);break j}j[114626]=0;I(672,e+160|0,d|0,e|0);d=j[114626];j[114626]=0;if((d|0)!=1){d=j[a+480204>>2];j[a+480204>>2]=d-((d>>>0)%1e4|0)+m[e>>2]%1e4;break j}d=D()|0;C()|0;break a}if(c){break j}j[114626]=0;i[e>>1]=0;I(677,e+160|0,d|0,e|0);d=j[114626];j[114626]=0;if((d|0)!=1){M=a,N=kd(l[e>>1],l[a+480188>>1],127),i[M+480188>>1]=N;break j}d=D()|0;C()|0;break a}j[114626]=0;I(678,e+160|0,d|0,v|0);d=j[114626];j[114626]=0;if((d|0)==1){break b}break j}j[114626]=0;I(679,e+160|0,d|0,w|0);d=j[114626];j[114626]=0;if((d|0)==1){break b}break j}d=D()|0;C()|0;break a}j[114626]=0;j[e>>2]=0;I(672,e+160|0,d|0,e|0);d=j[114626];j[114626]=0;if((d|0)==1){break f}d=j[e>>2];if(!d){break j}j[a+1074304>>2]=d;break j}j[114626]=0;I(672,e+160|0,d|0,x|0);d=j[114626];j[114626]=0;if((d|0)!=1){break j}break b}if(j[a+480180>>2]==4){break j}j[114626]=0;I(677,e+160|0,d|0,e|0);d=j[114626];j[114626]=0;if((d|0)!=1){Ge(Fb(B),l[e>>1]);break j}d=D()|0;C()|0;break a}g=Db(e);j[114626]=0;f=H(255,e+160|0)|0;d=j[114626];j[114626]=0;B:{if((d|0)==1){break B}j[114626]=0;K(463,e+160|0,g|0,f|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break B}j[114626]=0;I(13,e+144|0,0,g|0);d=j[114626];j[114626]=0;if((d|0)==1){break B}ob(J,e+144|0);gb(e+144|0);gb(g);break j}d=D()|0;C()|0;gb(g);break a}if(d&1|d>>>0>126){break j}i[e>>1]=(d>>>1|0)- -64;j[114626]=0;i[e+144>>1]=127;f=E(477,e|0,e+144|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}q=l[f>>1];if(q>>>0<65){break j}n=64;while(1){j[114626]=0;F(472,e|0,e+160|0);d=j[114626];j[114626]=0;if((d|0)==1){break d}d=Pc(e);f=e;C:{if(k[e|0]==255){break C}d=k[d|0];o=(n<<5)+a|0;g=o+480284|0;i[g>>1]=128;i[o+480286>>1]=d;o=o+480280|0;j[o>>2]=0;j[o>>2]=(k[f|0]&128)<<3;d=k[f|0]&127;h[f|0]=d;if(d>>>0<65){i[g>>1]=d<<2;d=k[f|0]}if((d|0)!=100){break C}j[o>>2]=j[o>>2]|256}n=n+1|0;if((q|0)!=(n|0)){continue}break}break j}d=D()|0;C()|0;break a}d=D()|0;C()|0;break a}d=D()|0;C()|0;gb(e+144|0);break a}d=D()|0;C()|0;Xe(g);break a}D:{E:{F:while(1){j[114626]=0;f=E(258,e+160|0,1)|0;d=j[114626];j[114626]=0;if((d|0)==1){break E}if(!f|n>>>0>=110){break j}j[114626]=0;g=H(387,e+160|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break D}d=0;while(1){G:{if(!(!(g>>>d&1)|n>>>0>=110)){j[114626]=0;K(478,r|0,n|0,1)|0;f=j[114626];j[114626]=0;if((f|0)==1){break G}}n=n+1|0;d=d+1|0;if((d|0)!=8){continue}continue F}break}break}d=D()|0;C()|0;break a}d=D()|0;C()|0;break a}d=D()|0;C()|0;break a}j[114626]=0;I(672,e+160|0,d|0,u|0);d=j[114626];j[114626]=0;if((d|0)==1){break b}}jb(e+160|0);if(yb(b,7)){continue}break}}wn(a+480204|0,p(j[j[a+8>>2]+20>>2],1e4),p(j[j[a+8>>2]+24>>2],1e4));if(j[a+480224>>2]>=3){j[a+480224>>2]=0}if(j[a+1074368>>2]>=6){j[a+1074368>>2]=0}kc(a+480200|0,256);b=a+480248|0;if(ad(b)){break h}dz(b,j[a+480216>>2],16777216)}Za=e+176|0;return}d=D()|0;C()|0;break a}d=D()|0;C()|0;break a}d=D()|0;C()|0;break a}d=D()|0;C()|0;break a}d=D()|0;C()|0;break a}d=D()|0;C()|0}jb(e+160|0);G(d|0);z()}function Oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=q(0),f=q(0),g=q(0),i=q(0),l=q(0),m=0,o=q(0),p=q(0),r=q(0),s=q(0),t=0,u=0,v=q(0),w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=q(0),U=0,V=0,W=0,X=q(0);a:{if(!k[a+5046|0]){break a}i=n[a+4268>>2];WG(a);if(i==n[a+4268>>2]){break a}jw(a)}b:{if(!k[a+5045|0]){break b}w=a+44|0;if(!Yg(w)){break b}x=wd(w,0);B=wd(w,1);t=Rc(w,0);u=Rc(w,1);c:{if(!(!k[a+5044|0]|(!d|k[a+4264|0]&2))){n[t>>2]=n[a+5036>>2];n[u>>2]=n[a+5040>>2];h[a+5044|0]=0;B=B+4|0;x=x+4|0;u=u+4|0;t=t+4|0;m=d-1|0;break c}m=d}y=m;d:{if(!y){break d}S=a+4960|0;D=a+4648|0;E=a+4672|0;O=a+4936|0;F=a+4696|0;G=a+4720|0;H=a+4744|0;I=a+4768|0;P=a+4840|0;C=a+4504|0;J=a+4528|0;Q=a+4912|0;K=a+4552|0;L=a+4576|0;M=a+4600|0;N=a+4624|0;R=a+4816|0;z=a+4888|0;A=a+4864|0;while(1){i=n[x>>2];i=q(q(q(n[a+5008>>2]-i)*n[a+4276>>2])+i);n[a+5008>>2]=i;W=jc(A,j[a+4880>>2]),X=i,n[W>>2]=X;i=n[B>>2];i=q(q(q(n[a+5012>>2]-i)*n[a+4276>>2])+i);n[a+5012>>2]=i;W=jc(z,j[a+4904>>2]),X=i,n[W>>2]=X;i=Kg(A,j[a+4356>>2]);f=Kg(A,j[a+4360>>2]);e=Kg(A,j[a+4364>>2]);g=Kg(A,j[a+4368>>2]);i=q(q(q(i*q(.6800000071525574))+q(q(e+Kg(A,j[a+4372>>2]))*q(-.6200000047683716)))+q(q(g+f)*q(-.5)));if(h[a+4264|0]&1){f=i;i=q(n[jc(R,j[a+4836>>2])>>2]+q(f*q(.6180340051651001)));W=jc(R,j[a+4832>>2]),X=q(f-q(i*q(.6180340051651001))),n[W>>2]=X}T=n[a+4280>>2];W=a,X=q(Kg(A,j[a+4352>>2])+n[a+5020>>2]),n[W+5020>>2]=X;f=q(Kg(z,j[a+4376>>2])+n[a+5024>>2]);n[a+5024>>2]=f;e=n[a+5020>>2];g=n[a+4980>>2];r=n[jc(N,j[a+4644>>2])>>2];s=n[a+4444>>2];g=q(n[jc(N,j[a+4644>>2])>>2]+q(s*q(g-r)));n[a+4980>>2]=g;r=n[a+4272>>2];s=q(e*q(-.7070000171661377));o=q(f*q(.7070000171661377));e=q(s+o);f=q(q(r*e)+q(n[a+4440>>2]*g));W=jc(N,j[a+4640>>2]),X=q(e-q(r*f)),n[W>>2]=X;e=n[a+4976>>2];g=n[jc(M,j[a+4620>>2])>>2];r=n[a+4436>>2];e=q(n[jc(M,j[a+4620>>2])>>2]+q(r*q(e-g)));n[a+4976>>2]=e;g=n[a+4272>>2];e=q(q(g*f)+q(n[a+4432>>2]*e));W=jc(M,j[a+4616>>2]),X=q(f-q(g*e)),n[W>>2]=X;r=q(q(f*q(-.15000000596046448))+q(e*q(-.20000000298023224)));if(h[a+4264|0]&1){f=n[a+4972>>2];g=n[jc(L,j[a+4596>>2])>>2];l=n[a+4428>>2];f=q(n[jc(L,j[a+4596>>2])>>2]+q(l*q(f-g)));n[a+4972>>2]=f;g=n[a+4272>>2];f=q(q(g*e)+q(n[a+4424>>2]*f));W=jc(L,j[a+4592>>2]),X=q(e-q(g*f)),n[W>>2]=X;e=n[a+4968>>2];g=n[jc(K,j[a+4572>>2])>>2];l=n[a+4420>>2];e=q(n[jc(K,j[a+4572>>2])>>2]+q(l*q(e-g)));n[a+4968>>2]=e;g=n[a+4272>>2];e=q(q(g*f)+q(n[a+4416>>2]*e));W=jc(K,j[a+4568>>2]),X=q(f-q(g*e)),n[W>>2]=X;r=q(q(q(f*q(.3499999940395355))+r)+q(e*q(-.3799999952316284)))}o=q(s-o);W=jc(Q,j[a+4928>>2]),X=e,n[W>>2]=X;m=jc(Q,j[a+4932>>2]);f=q(n[a+4496>>2]*n[m>>2]);n[a+5028>>2]=q(q(n[a+5028>>2]-f)*n[a+4500>>2])+f;f=n[a+4964>>2];e=n[jc(J,j[a+4548>>2])>>2];g=n[a+4412>>2];f=q(n[jc(J,j[a+4548>>2])>>2]+q(g*q(f-e)));n[a+4964>>2]=f;e=q(n[a+4408>>2]*f);f=n[a+4272>>2];g=n[a+5028>>2];e=q(e+q(f*g));W=jc(J,j[a+4544>>2]),X=q(g-q(f*e)),n[W>>2]=X;f=n[a+4960>>2];g=n[jc(C,j[a+4524>>2])>>2];s=n[a+4404>>2];f=q(n[jc(C,j[a+4524>>2])>>2]+q(s*q(f-g)));n[a+4960>>2]=f;g=n[a+4272>>2];s=q(q(g*e)+q(n[a+4400>>2]*f));W=jc(C,j[a+4520>>2]),X=q(e-q(g*s)),n[W>>2]=X;n[a+5020>>2]=s;f=Kg(z,j[a+4380>>2]);g=Kg(z,j[a+4384>>2]);l=Kg(z,j[a+4388>>2]);v=Kg(z,j[a+4392>>2]);f=q(q(q(f*q(.7070000171661377))+q(q(l+Kg(z,j[a+4396>>2]))*q(-.5)))+q(q(v+g)*q(-.6000000238418579)));l=q(e*q(.3799999952316284));if(h[a+4264|0]&1){e=f;f=q(n[jc(P,j[a+4860>>2])>>2]+q(e*q(.6180340051651001)));W=jc(P,j[a+4856>>2]),X=q(e-q(f*q(.6180340051651001))),n[W>>2]=X}v=n[a+4280>>2];e=n[a+5004>>2];g=n[jc(I,j[a+4788>>2])>>2];p=n[a+4492>>2];e=q(n[jc(I,j[a+4788>>2])>>2]+q(p*q(e-g)));n[a+5004>>2]=e;p=n[a+4272>>2];g=q(q(p*o)+q(n[a+4488>>2]*e));W=jc(I,j[a+4784>>2]),X=q(o-q(p*g)),n[W>>2]=X;e=n[a+5e3>>2];o=n[jc(H,j[a+4764>>2])>>2];p=n[a+4484>>2];e=q(n[jc(H,j[a+4764>>2])>>2]+q(p*q(e-o)));n[a+5e3>>2]=e;o=n[a+4272>>2];e=q(q(o*g)+q(n[a+4480>>2]*e));W=jc(H,j[a+4760>>2]),X=q(g-q(o*e)),n[W>>2]=X;o=q(q(e*q(-.20000000298023224))+q(l+q(g*q(-.15000000596046448))));if(h[a+4264|0]&1){g=n[a+4996>>2];l=n[jc(G,j[a+4740>>2])>>2];p=n[a+4476>>2];g=q(n[jc(G,j[a+4740>>2])>>2]+q(p*q(g-l)));n[a+4996>>2]=g;l=n[a+4272>>2];g=q(q(l*e)+q(n[a+4472>>2]*g));W=jc(G,j[a+4736>>2]),X=q(e-q(l*g)),n[W>>2]=X;e=n[a+4992>>2];l=n[jc(F,j[a+4716>>2])>>2];p=n[a+4468>>2];e=q(n[jc(F,j[a+4716>>2])>>2]+q(p*q(e-l)));n[a+4992>>2]=e;l=n[a+4272>>2];e=q(q(l*g)+q(n[a+4464>>2]*e));W=jc(F,j[a+4712>>2]),X=q(g-q(l*e)),n[W>>2]=X;o=q(q(q(g*q(.3499999940395355))+o)+q(e*q(-.3799999952316284)))}U=B+4|0;V=x+4|0;g=q(v*f);W=jc(O,j[a+4952>>2]),X=e,n[W>>2]=X;m=jc(O,j[a+4956>>2]);f=q(n[a+4496>>2]*n[m>>2]);n[a+5032>>2]=q(q(n[a+5032>>2]-f)*n[a+4500>>2])+f;f=n[a+4988>>2];e=n[jc(E,j[a+4692>>2])>>2];l=n[a+4460>>2];f=q(n[jc(E,j[a+4692>>2])>>2]+q(l*q(f-e)));n[a+4988>>2]=f;e=n[a+4272>>2];l=n[a+5032>>2];f=q(q(n[a+4456>>2]*f)+q(e*l));W=jc(E,j[a+4688>>2]),X=q(l-q(e*f)),n[W>>2]=X;l=n[a+4284>>2];e=n[a+4984>>2];v=n[jc(D,j[a+4668>>2])>>2];p=n[a+4452>>2];e=q(n[jc(D,j[a+4668>>2])>>2]+q(p*q(e-v)));n[a+4984>>2]=e;v=n[a+4272>>2];e=q(q(v*f)+q(n[a+4448>>2]*e));W=jc(D,j[a+4664>>2]),X=q(f-q(v*e)),n[W>>2]=X;n[a+5024>>2]=e;e=q(e*q(.3799999952316284));i=q(q(l*q(q(q(f-s)*q(.3799999952316284))+r))+q(T*i));f=n[a+4288>>2];m=C;while(1){Rea(m);m=m+24|0;if((S|0)!=(m|0)){continue}break}f=q(q(f*q(o-e))+g);e:{f:{if(k[a+4264|0]&2){x=V;m=U;break f}n[t>>2]=q(n[a+5036>>2]+i)*q(.5);n[u>>2]=q(n[a+5040>>2]+f)*q(.5);n[a+5040>>2]=f;n[a+5036>>2]=i;if((y|0)==1){break e}y=y-1|0;x=x+8|0;u=u+4|0;t=t+4|0;m=B+8|0}B=m;n[t>>2]=i;n[u>>2]=f;u=u+4|0;t=t+4|0;y=y-1|0;if(y){continue}break d}break}h[a+5044|0]=1}Th(a,b,c,Rc(w,0),Rc(w,1),d)}}function Fo(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;n=Za-16|0;Za=n;o=l[a+480192>>1]>=c>>>0?j[((c<<2)+a|0)+900380>>2]:o;y=j[b+764>>2];g=k[b+824|0];a:{if(!g){mb(n+8|0,a+1074308|0,11);if(kb(n+8|0)){break a}}b:{c:{if(!o){break c}if(!Ld(g)){break c}d:{q=o+236|0;r=g-1|0;if(l[Oc(q,r)>>1]){break d}mb(n+8|0,a+1074308|0,43);if(!kb(n+8|0)){break d}if(ci(o)){break d}j[b+656>>2]=o;break a}if(k[Pb(o+108|0,r)|0]>120){break a}r=l[Oc(q,r)>>1];r=(r-1&65535)>>>0<3999?(p(r,104)+a|0)+484380|0:0;break b}r=(p(c,104)+a|0)+484380|0;if(!l[a+480192>>1]){break b}if(g>>>0>250){break a}mb(n+8|0,a+1074308|0,43);if(kb(n+8|0)){if(o){r=0;if(ci(o)){break b}}h[b+825|0]=0;j[b+656>>2]=0;break a}r=0}q=j[b+656>>2];x=j[a+480180>>2];t=!d;s=j[b+104>>2];u=!s|(r|0)==(s|0);v=u;g=0;e:{if(!o){break e}g=0;if((x|0)!=16777216){break e}g=j[o+44>>2]!=0}x=g;if(j[b+656>>2]==(o|0)?!(!g|v|t):0){break a}g=(r|0)!=(s|0);s=(s|0)!=0;v=d^1;f:{if(u|v){break f}t=a+1074308|0;mb(n+8|0,t,32);if(!(!kb(n+8|0)|!(k[a+480208|0]&8))){r=j[b+8>>2]|j[b+12>>2]?j[b+104>>2]:r}g:{if(j[a+480180>>2]==268435456|(j[a+480180>>2]&1048580?!(!o|(o|0)!=(q|0)):0)){break g}if(j[a+480180>>2]==1){if(ph(b)){break g}}mb(n+8|0,t,79);if(!kb(n+8|0)){break f}if(!ph(b)){break f}}w=1}t=g&s;h:{if(!j[b+16>>2]|(!t|(!l[a+480192>>1]|(o|0)!=(q|0)))){break h}mb(n+8|0,a+1074308|0,87);if(!kb(n+8|0)){break h}w=Lf(b+810|0)^1|w}i:{j:{k:{l:{if(!(ph(b)|!(j[a+480180>>2]&16777248))){if(!o){break l}if(!ci(o)){break l}}if((o|0)==(q|0)){break k}}m:{n:{if(!d){break n}mb(n+8|0,a+1074308|0,61);if(!kb(n+8|0)){break n}q=j[b+656>>2];if(q){break m}s=0;q=0;g=j[b+104>>2];if(g){break i}}s=1;break j}g=j[b+104>>2];s=0;break i}s=0}j[b+656>>2]=o;g=r;q=o}o:{p:{q:{if(!e){break q}r:{if(j[a+480180>>2]&3){if(g){if(ke(g)){break r}}if(!Qi(b)){break q}}if(!g){break p}}if(i[g+34>>1]<0){break q}j[b+688>>2]=l[g+30>>1]}o=(g|0)!=0;if(!(t&o&w)){break o}mb(n+8|0,a+1074308|0,85);if(kb(n+8|0)){j[b+768>>2]=h[g+37|0]}o=1;if(j[a+480180>>2]!=2){break o}if(!ke(g)){break o}j[b+704>>2]=j[g+24>>2];break o}if(!(!q|!k[q+34|0])){o=b;r=b;u=j[b+656>>2];s:{if(u){r=j[u+4>>2]<<2;break s}r=j[r+688>>2]}j[o+688>>2]=r;o=0;break o}o=0;j[b+688>>2]=0}if(w){break a}h[b+825|0]=0;t:{if(!q){break t}mb(n+8|0,a+1074308|0,29);if(z=0,A=!((kb(n+8|0)^1)&o),B=k[q+34|0]!=0|s,B?z:A){break t}h[b+820|0]=k[q+16|0]}eua(b,g,q);u:{if(j[a+480180>>2]&1048580?!e:0){break u}mb(n+8|0,a+1074308|0,48);if(kb(n+8|0)){break u}yK(a,b,q,g)}v:{w:{x:{if(!f){break x}e=a+1074308|0;mb(n+8|0,e,19);y:{z:{A:{B:{C:{D:{E:{F:{if(kb(n+8|0)){if(!j[b+76>>2]){r=1;break E}if(!(!c|v)){r=(k[a+480208|0]&8)>>>3|0;if(r){break E}break F}r=0;if(c){break F}break E}r=1;G:{if(!d|!(j[a+480180>>2]&17301536)|(!j[b+76>>2]|k[a+480208|0]&8)){break G}r=0;if(!(k[b+89|0]&16)){break G}r=!j[b+696>>2]}if(!(j[a+480180>>2]&17301536)|(!q|s)){break C}if(!r){break B}c=j[b+88>>2];f=c&6144;break D}if(d){break E}if(!(k[b+89|0]&24)){r=0;break E}r=(k[a+480208|0]&4)>>>2|0}if(!j[b+696>>2]|s){break C}if(!r){break B}c=j[b+88>>2];f=c&2048}j[b+88>>2]=c|2097152;if(!q){break y}if(f){break z}if(!(k[q+60|0]&8)){$h(b+724|0)}if(!(k[q+80|0]&8)){$h(b+736|0)}if(k[q+100|0]&8){break y}$h(b+748|0);break y}if(r){break A}}if(q){if(h[q+60|0]&1){break x}mb(n+8|0,e,32);if(kb(n+8|0)){$h(b+724|0);break x}_k(b);break x}c=0;if(!g){break w}break v}j[b+88>>2]=j[b+88>>2]|2097152;if(!q){break y}}_k(b)}mb(n+8|0,e,21);if(kb(n+8|0)){break x}h[b+838|0]=0;j[b+780>>2]=0}c=0;if(g){break v}if(!q){break w}c=1;if(ci(q)){break v}}j[b+764>>2]=0;j[b+104>>2]=0;break a}e=b;H:{I:{J:{K:{L:{if(!(!d|(o^1|j[b+104>>2]!=(g|0)))){if(j[b+76>>2]?j[a+480180>>2]&16777250:0){break a}if(j[a+480180>>2]!=4){break L}mb(n+8|0,a+1074308|0,40);if(!kb(n+8|0)|k[b+811|0]){break L}d=j[b+88>>2];break K}j[b+88>>2]=j[b+88>>2]&-6145;o=a+1074308|0;mb(n+8|0,o,18);e=b;M:{if(!(z=!kb(n+8|0),A=0,B=j[a+480180>>2]&16777248,B?z:A)){f=-640;if(!(j[b+104>>2]!=(g|0)|s)){break M}}f=-768}j[e+88>>2]=f&j[b+88>>2];N:{if(!q){break N}h[b+724|0]=k[q+60|0];h[b+736|0]=k[q+80|0];h[b+748|0]=k[q+100|0];O:{if((k[q+100|0]&17)!=17){break O}mb(n+8|0,o,36);if(kb(n+8|0)|k[b+857|0]){break O}h[b+857|0]=127}if(Mt(q)){z=b,A=sA(q),h[z+857|0]=A}if(!qA(q)){break N}z=b,A=rA(q),h[z+858|0]=A}if(c){break J}if(!d){break H}break I}d=j[b+88>>2]&-6145}j[e+88>>2]=d&-640;if(!c){break I}}j[b+76>>2]=0;j[b+104>>2]=0;break a}if(j[b+76>>2]){break H}c=a+1074308|0;mb(n+8|0,c,54);if(!kb(n+8|0)){mb(n,c,39);if(!kb(n)){break H}}j[b+8>>2]=0;j[b+12>>2]=0}P:{if(k[b+810|0]!=255){break P}mb(n+8|0,a+1074308|0,100);if(!kb(n+8|0)|(!(j[a+480208>>2]&4)|t^1)){break P}c=j[b+104>>2];if(c){j[b+88>>2]=j[b+88>>2]|l[c+34>>1]&1023}j[b+764>>2]=y;j[b+688>>2]=l[g+30>>1];if(!(k[g+34|0]&32)){break a}ns(b,l[g+28>>1],a);break a}j[b+104>>2]=g;j[b+76>>2]=j[g>>2];j[b+80>>2]=j[g+4>>2];j[b+84>>2]=j[g+8>>2];d=a+1074308|0;mb(n+8|0,d,83);if(!(!kb(n+8|0)|j[b+80>>2])){j[b+84>>2]=j[g>>2]}j[b+88>>2]=j[b+88>>2]|l[g+34>>1]&1023;mb(n+8|0,d,21);if(kb(n+8|0)){h[b+838|0]=0;j[b+780>>2]=0}c=b;Q:{R:{if(x){j[b+704>>2]=j[g+24>>2];h[b+872|0]=k[b+872|0]|8;e=0;break R}if(j[a+480180>>2]&5?!(t|v):0){break Q}j[b+704>>2]=j[g+24>>2];e=h[g+37|0]}j[c+768>>2]=e}j[b+772>>2]=h[g+36|0];mb(n+8|0,d,69);if(!(kb(n+8|0)|j[a+480180>>2]==1)){j[b+708>>2]=0}j[b+876>>2]=0;o=j[b+88>>2];if(o&8){j[b+80>>2]=j[g+12>>2];j[b+84>>2]=j[g+16>>2];o=o>>>2&4|o|2;j[b+88>>2]=o}S:{if(!(o&2)){o=j[b+76>>2];break S}o=j[b+76>>2];c=j[b+84>>2];if(o>>>0<=c>>>0){break S}j[b+76>>2]=c;o=c}if(!(j[a+480180>>2]&16777248)|m[b+4>>2]<o>>>0){break a}j[b>>2]=0;j[b+4>>2]=0}Za=n+16|0}function G2(a,b,c){var d=0,e=0,f=0,g=0,l=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=q(0),F=0;f=Za-304|0;Za=f;e=k[b|0];a:{if(!e){break a}b:{c:{d:{while(1){e:{f:{if($l(e&255)){while(1){e=b;b=b+1|0;if($l(k[e+1|0])){continue}break}Hg(a,0,0);while(1){b=j[a+4>>2];g:{if(b>>>0<m[a+104>>2]){j[a+4>>2]=b+1;b=k[b|0];break g}b=Lc(a)}if($l(b)){continue}break}b=j[a+4>>2];if(j[a+104>>2]){b=b-1|0;j[a+4>>2]=b}d=b-j[a+8>>2]|0;b=d;d=d>>31;g=b;l=l+j[a+124>>2]|0;b=v+j[a+120>>2]|0;l=b>>>0<v>>>0?l+1|0:l;v=g+b|0;l=d+l|0;l=b>>>0>v>>>0?l+1|0:l;break f}h:{i:{j:{e=k[b|0];if((e|0)==37){d=k[b+1|0];if((d|0)==42){break j}if((d|0)!=37){break i}}Hg(a,0,0);e=((e|0)==37)+b|0;b=j[a+4>>2];k:{if(b>>>0<m[a+104>>2]){j[a+4>>2]=b+1;b=k[b|0];break k}b=Lc(a)}if((b|0)!=k[e|0]){if(j[a+104>>2]){j[a+4>>2]=j[a+4>>2]-1}A=0;if((b|0)>=0){break a}break c}b=v+1|0;l=b>>>0<1?l+1|0:l;v=b;break f}t=0;e=b+2|0;break h}if(!(!Ig(d)|k[b+2|0]!=36)){t=F2(c,k[b+1|0]-48|0);e=b+3|0;break h}t=j[c>>2];c=c+4|0;e=b+1|0}A=0;b=0;if(Ig(k[e|0])){while(1){b=(k[e|0]+p(b,10)|0)-48|0;d=k[e+1|0];e=e+1|0;if(Ig(d)){continue}break}}d=e;g=k[d|0];l:{if((g|0)!=109){break l}u=0;A=(t|0)!=0;g=k[e+1|0];x=0;d=e+1|0}e=d+1|0;s=3;m:{n:{switch(g-65|0){case 39:g=d+2|0;d=k[d+1|0]==104;e=d?g:e;s=d?-2:-1;break m;case 43:g=d+2|0;d=k[d+1|0]==108;e=d?g:e;s=d?3:1;break m;case 51:case 57:s=1;break m;case 11:s=2;break m;case 41:break m;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break n;default:break c}}s=0;e=d}g=k[e|0];d=(g&47)==3;z=d?1:s;y=d?g|32:g;o:{if((y|0)==91){break o}p:{if((y|0)!=110){if((y|0)!=99){break p}b=(b|0)>1?b:1;break o}zD(t,z,v,l);break f}Hg(a,0,0);while(1){d=j[a+4>>2];q:{if(d>>>0<m[a+104>>2]){j[a+4>>2]=d+1;d=k[d|0];break q}d=Lc(a)}if($l(d)){continue}break}d=j[a+4>>2];if(j[a+104>>2]){d=d-1|0;j[a+4>>2]=d}d=d-j[a+8>>2]|0;g=d;d=d>>31;w=g;r=l+j[a+124>>2]|0;g=v+j[a+120>>2]|0;r=g>>>0<v>>>0?r+1|0:r;l=g;v=w+l|0;d=d+r|0;d=l>>>0>v>>>0?d+1|0:d;l=d}g=b;C=b>>31;Hg(a,b,C);d=j[a+104>>2];r=j[a+4>>2];r:{if(d>>>0>r>>>0){j[a+4>>2]=r+1;break r}if((Lc(a)|0)<0){break c}d=j[a+104>>2]}if(d){j[a+4>>2]=j[a+4>>2]-1}d=16;s:{t:{u:{v:{w:{x:{y:{switch(y-88|0){default:b=y-65|0;if(b>>>0>6|!(1<<b&113)){break s};case 9:case 13:case 14:case 15:DD(f,a,z,0);d=j[a+4>>2]-j[a+8>>2]|0;if(j[a+120>>2]==(0-d|0)&j[a+124>>2]==(0-((d>>31)+((d|0)!=0)|0)|0)){break b}if(!t){break s}r=j[f+8>>2];g=j[f+12>>2];d=j[f>>2];b=j[f+4>>2];switch(z|0){case 2:break u;case 1:break v;case 0:break w;default:break s};case 3:case 11:case 27:if((y&239)==99){Ab(f+32|0,-1,257);h[f+32|0]=0;if((y|0)!=115){break t}h[f+65|0]=0;h[f+46|0]=0;i[f+42>>1]=0;i[f+44>>1]=0;break t}w=k[e+1|0];r=(w|0)==94;Ab(f+32|0,r,257);h[f+32|0]=0;d=r?e+2|0:e+1|0;z:{A:{B:{e=k[(r?2:1)+e|0];if((e|0)!=45){if((e|0)==93){break B}s=(w|0)!=94;break z}s=(w|0)!=94;h[f+78|0]=s;break A}s=(w|0)!=94;h[f+126|0]=s}d=d+1|0}e=d;while(1){d=k[e|0];C:{if((d|0)!=45){if(!d){break c}if((d|0)!=93){break C}break t}d=45;w=k[e+1|0];if(!w|(w|0)==93){break C}r=e+1|0;e=k[e-1|0];D:{if(w>>>0<=e>>>0){d=w;break D}while(1){e=e+1|0;h[e+(f+32|0)|0]=s;d=k[r|0];if(e>>>0<d>>>0){continue}break}}e=r}h[(d+f|0)+33|0]=s;e=e+1|0;continue};case 23:d=8;break x;case 12:case 29:d=10;break x;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break s;case 0:case 24:case 32:break x;case 17:break y}}d=0}r=BD(a,d,0,-1,-1);g=ab;d=j[a+4>>2]-j[a+8>>2]|0;if(j[a+120>>2]==(0-d|0)&j[a+124>>2]==(0-((d>>31)+((d|0)!=0)|0)|0)){break b}if(!(!t|(y|0)!=112)){j[t>>2]=r;break s}zD(t,z,r,g);break s}D=t,E=AD(d,b,r,g),n[D>>2]=E;break s}D=t,F=tv(d,b,r,g),o[D>>3]=F;break s}j[t>>2]=d;j[t+4>>2]=b;j[t+8>>2]=r;j[t+12>>2]=g;break s}y=(y|0)==99;s=y?b+1|0:31;w=(z|0)!=1;E:{if(!w){d=t;if(A){d=_c(s<<2);if(!d){break d}}j[f+296>>2]=0;j[f+300>>2]=0;b=0;u=A;while(1){x=d;F:{while(1){d=j[a+4>>2];G:{if(d>>>0<m[a+104>>2]){j[a+4>>2]=d+1;d=k[d|0];break G}d=Lc(a)}if(!k[(d+f|0)+33|0]){break F}h[f+27|0]=d;d=Qn(f+28|0,f+27|0,1,f+296|0);if((d|0)==-2){continue}if((d|0)==-1){break e}if(x){j[(b<<2)+x>>2]=j[f+28>>2];b=b+1|0}if(u^1|(b|0)!=(s|0)){continue}break}s=s<<1|1;d=gq(x,s<<2);if(d){continue}break e}break}d=f+296|0;u=1;H:{if(!d){break H}u=!j[d>>2]}if(!u){break e}u=0;break E}if(A){b=0;d=_c(s);if(!d){break d}while(1){u=d;while(1){d=j[a+4>>2];I:{if(d>>>0<m[a+104>>2]){j[a+4>>2]=d+1;d=k[d|0];break I}d=Lc(a)}if(!k[(d+f|0)+33|0]){x=0;break E}h[b+u|0]=d;b=b+1|0;if((s|0)!=(b|0)){continue}break}x=0;s=s<<1|1;d=gq(u,s);if(d){continue}break}break c}b=0;if(t){while(1){d=j[a+4>>2];J:{if(d>>>0<m[a+104>>2]){j[a+4>>2]=d+1;d=k[d|0];break J}d=Lc(a)}if(k[(d+f|0)+33|0]){h[b+t|0]=d;b=b+1|0;continue}else{x=0;u=t;break E}}}while(1){b=j[a+4>>2];K:{if(b>>>0<m[a+104>>2]){j[a+4>>2]=b+1;b=k[b|0];break K}b=Lc(a)}if(k[(b+f|0)+33|0]){continue}break}u=0;x=0;b=0}d=j[a+4>>2];if(j[a+104>>2]){d=d-1|0;j[a+4>>2]=d}d=d-j[a+8>>2]|0;r=d;z=d+j[a+120>>2]|0;d=j[a+124>>2]+(d>>31)|0;d=r>>>0>z>>>0?d+1|0:d;r=z;if(!(d|r)|(y?(r|0)!=(g|0)|(d|0)!=(C|0):0)){break b}L:{if(!A){break L}if(!w){j[t>>2]=x;break L}j[t>>2]=u}if(y){break s}if(x){j[(b<<2)+x>>2]=0}if(!u){u=0;break s}h[b+u|0]=0}d=j[a+4>>2]-j[a+8>>2]|0;b=d;d=d>>31;g=b;l=l+j[a+124>>2]|0;b=v+j[a+120>>2]|0;l=b>>>0<v>>>0?l+1|0:l;v=g+b|0;l=d+l|0;l=b>>>0>v>>>0?l+1|0:l;B=((t|0)!=0)+B|0}b=e+1|0;e=k[e+1|0];if(e){continue}break a}break}u=0;break c}u=0;x=0}B=B?B:-1}if(!A){break a}Cb(u);Cb(x)}Za=f+304|0;return B}function sla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,i=0,n=0,o=0,q=0,r=0;e=Za-48|0;Za=e;d=a+1074304|0;if(!(j[d>>2]==18284544|m[a+1074304>>2]>=18285126)){rg(a+1074308|0,0)}f=a+1074308|0;mb(e+32|0,f,0);if(kb(e+32|0)){i=(j[a+480180>>2]&16777248)!=0}mb(e+32|0,f,0);if(kb(e+32|0)){o=j[a+480180>>2]==4}if(m[d>>2]<18874368){a:{if(!l[a+480192>>1]){break a}c=1;while(1){b:{b=j[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}j[e+32>>2]=p(k[b+20|0],100)>>>6;j[e+16>>2]=100;q=b,r=j[tb(e+32|0,e+16|0)>>2],h[q+20|0]=r;c:{d:{if(i){if(m[d>>2]<18350080){g=h[b+26|0];h[b+26|0]=(((g|0)>-1?1:-1)+g|0)/2}if(m[d>>2]<18285314){break d}break c}g=h[b+26|0];h[b+26|0]=(((g|0)>-1?1:-1)+g|0)/2}nM(Ht(b,2),4,j[a+480180>>2])}e:{if(!k[b+34|0]|(m[d>>2]<18284544|m[d>>2]>=18285136)){break e}if(!ci(b)){break e}vb(f,2,1)}if(!(k[b+24|0]|(k[b+23|0]|(k[b+19|0]|k[b+20|0])))|m[d>>2]>=18285136){break b}vb(f,1,1);break a}c=c+1|0;if(l[a+480192>>1]>=(c&65535)>>>0){continue}break}}f:{if(!(j[a+480180>>2]&16777248)){break f}b=1;if(!l[a+480190>>1]|(i^1?0:m[d>>2]>=18285314)){break f}while(1){c=p(b&65535,104)+a|0;g=c+484419|0;if(!(k[g|0]|!(k[c+484421|0]|k[c+484420|0]))){h[g|0]=255}b=b+1|0;if(l[a+480190>>1]>=(b&65535)>>>0){continue}break}}pwa(a+901404|0)}g:{if(j[d>>2]==18874368|m[d>>2]>=18874896|(!(j[a+480180>>2]&16777252)|!l[a+480192>>1])){break g}b=1;c=0;while(1){h:{g=j[(((b&65535)<<2)+a|0)+900380>>2];if(!(k[g+31|0]?g:0)){b=b+1|0;if(l[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break h}break g}h[g+33|0]=13;c=1;b=b+1|0;if(l[a+480192>>1]>=(b&65535)>>>0){continue}}break}vb(f,3,1)}i:{if(!(j[a+480180>>2]&16777248)|(j[d>>2]==19005440|m[d>>2]>=19006226)){break i}mb(e+32|0,f,0);if(!kb(e+32|0)){mb(e+16|0,f,1);if(!kb(e+16|0)){break i}}if(!l[a+480192>>1]){break i}b=1;while(1){c=j[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!k[c+19|0]|!(h[c+80|0]&1))){h[c+19|0]=0}b=b+1|0;if(l[a+480192>>1]>=(b&65535)>>>0){continue}break}}j:{k:{l:{if(m[d>>2]<19007233){c=a+946300|0;b=a+906300|0;while(1){g=b+80|0;rla(e+16|0,g);j[114626]=0;L(438,e+32|0,0,7,e+16|0);n=j[114626];j[114626]=0;if((n|0)==1){break k}gb(e+16|0);j[114626]=0;E(506,g|0,e+32|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break l}gb(e+32|0);b=b+160|0;if((c|0)!=(b|0)){continue}break}}if(!(j[a+480180>>2]!=4|m[d>>2]<19007257|(j[a+1074368>>2]!=4|m[d>>2]>=19071236))){jx(a,5)}if(!(!l[a+480192>>1]|(j[d>>2]==19202048|m[d>>2]>=19202055))){c=1;while(1){n=(((c&65535)<<2)+a|0)+900380|0;b=j[n>>2];m:{if(!b|!k[b+20|0]|!k[b+31|0]){break m}b=b+236|0;g=rs(b);if((b|0)!=(g|0)){while(1){if(l[b>>1]){break m}b=b+2|0;if((g|0)!=(b|0)){continue}break}}h[j[n>>2]+20|0]=0}c=c+1|0;if(l[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(!(!l[a+480192>>1]|m[d>>2]>=19267584)){c=1;while(1){b=j[(((c&65535)<<2)+a|0)+900380>>2];n:{if(!b){break n}g=h[b+26|0];h[b+26|0]=(((g|0)>-1?1:-1)+g|0)/2;if(m[d>>2]>=18350080?i:0){break n}h[b+19|0]=k[b+19|0]+3>>>2}c=c+1|0;if(l[a+480192>>1]>=(c&65535)>>>0){continue}break}}o:{if(!l[a+480192>>1]|m[d>>2]>=19398674){break o}b=1;while(1){c=j[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|k[c+65|0]==255)){vb(f,94,1);break o}b=b+1|0;if(l[a+480192>>1]>=(b&65535)>>>0){continue}break}}p:{if(!l[a+480192>>1]|m[d>>2]>=19399428){break p}b=1;while(1){c=j[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|k[c+36|0]>1)){vb(f,101,1);break p}b=b+1|0;if(l[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=qla(e+8|0,a);c=j[b+4>>2];j[e>>2]=j[b>>2];j[e+4>>2]=c;pla(e+32|0,a+484344|0,e);q:{r:{if(!i){break r}b=j[d>>2];if(b>>>0>=19267584){break r}vb(f,8,(b|0)==18284544|b>>>0>18285313);b=30904;while(1){c=j[d>>2];i=j[b+4>>2];vb(f,j[b>>2],c>>>0>=i>>>0|(c|0)==(i&-65536));b=b+8|0;if((b|0)!=31240){continue}break}break q}if(!o){break q}b=j[d>>2];if(b>>>0>=19267584){break q}vb(f,8,b>>>0>18285313);b=31256;while(1){vb(f,j[b>>2],m[d>>2]>=m[b+4>>2]);b=b+8|0;if((b|0)!=31488){continue}break}}s:{if(j[a+480180>>2]&16777248){b=31488;while(1){c=j[d>>2];i=j[b+4>>2];g=i&-65536;if(!(c>>>0<=g>>>0|c>>>0>=i>>>0?c>>>0>=g>>>0:0)){rg(f,j[b>>2])}b=b+8|0;if((b|0)!=31536){continue}break}break s}if(j[a+480180>>2]==4){b=31536;while(1){if(m[d>>2]<m[b+4>>2]){rg(f,j[b>>2])}b=b+8|0;if((b|0)!=31592){continue}break}break s}if(j[a+480180>>2]!=2){break s}b=31600;while(1){if(m[d>>2]<m[b+4>>2]){rg(f,j[b>>2])}b=b+8|0;if((b|0)!=31680){continue}break}}if(!(j[a+480180>>2]!=4|m[d>>2]>=18415616)){vb(f,98,1)}if(!(m[d>>2]<19333159|m[d>>2]>=19333193)){b=0;while(1){c=b+77|0;mb(e+32|0,f,c);vb(f,b+86|0,kb(e+32|0));rg(f,c);b=b+1|0;if((b|0)!=5){continue}break}}t:{if(m[d>>2]<18284544){vb(f,8,1);break t}if(m[d>>2]<18284544|m[d>>2]>18874627|j[d>>2]==18874368){break t}vb(f,6,1)}u:{if(m[d>>2]<19136512){rg(f,7);break u}if(!(j[a+480180>>2]&16777248)|(m[d>>2]<19136512|m[d>>2]>=19267584)){break u}vb(f,7,1)}mb(e+32|0,f,31);v:{if(!kb(e+32|0)|m[d>>2]<19071234|(!l[a+480192>>1]|m[d>>2]>=19398723)){break v}b=1;while(1){w:{c=j[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break w}i=k[c+65|0];if(!(k[c+60|0]&4)|(i|0)==255|i>>>0<=k[c- -64|0]){break w}vb(f,97,1);break v}b=b+1|0;if(l[a+480192>>1]>=(b&65535)>>>0){continue}break}}x:{if(!l[a+480192>>1]|j[a+480180>>2]!=16777216|(m[d>>2]<19398688|m[d>>2]>19485952)){break x}if(!l[a+480190>>1]){break x}b=1;while(1){if(!(k[(p(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(l[a+480190>>1]>=(b&65535)>>>0){continue}break x}break}vb(f,109,1)}Za=e+48|0;return}a=D()|0;C()|0;gb(e+32|0);break j}a=D()|0;C()|0;gb(e+16|0)}G(a|0);z()}function D4(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,l=0,m=0,n=0,o=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;o=Za-560|0;Za=o;j[o+44>>2]=0;YMa(+b);g=VMa(1)|0;VMa(0)|0;a:{if((g|0)<-1?1:(g|0)<=-1){B=1;b=-b;YMa(+b);g=VMa(1)|0;VMa(0)|0;w=55648;break a}B=1;w=55651;if(e&2048){break a}w=55654;if(e&1){break a}B=0;A=1;w=55649}b:{if((g&2146435072)==2146435072){n=B+3|0;of(a,32,c,n,e&-65537);ve(a,w,B);d=f&32;ve(a,b!=b?d?55675:55679:d?55667:55671,3);break b}x=o+16|0;c:{d:{e:{b=yE(b,o+44|0);b=b+b;if(b!=0){g=j[o+44>>2];j[o+44>>2]=g-1;C=f|32;if((C|0)!=97){break e}break c}C=f|32;if((C|0)==97){break c}n=j[o+44>>2];q=(d|0)<0?6:d;break d}n=g-29|0;j[o+44>>2]=n;b=b*268435456;q=(d|0)<0?6:d}t=(n|0)<0?o+48|0:o+336|0;m=t;while(1){d=m;if(b<4294967296&b>=0){g=~~b>>>0}else{g=0}j[d>>2]=g;m=m+4|0;b=(b- +(g>>>0))*1e9;if(b!=0){continue}break}f:{if((n|0)<1){d=n;g=m;i=t;break f}i=t;d=n;while(1){s=(d|0)<29?d:29;g=m-4|0;g:{if(i>>>0>g>>>0){break g}d=s;l=0;while(1){v=g;D=l;E=j[g>>2];u=d&31;if((d&63)>>>0>=32){l=E<<u;E=0}else{l=(1<<u)-1&E>>>32-u;E=E<<u}u=D+E|0;l=l+F|0;l=u>>>0<E>>>0?l+1|0:l;l=RMa(u,l,1e9,0);D=v;v=OMa(l,ab,1e9,0);j[D>>2]=u-v;g=g-4|0;if(i>>>0<=g>>>0){continue}break}if(!l){break g}i=i-4|0;j[i>>2]=l}while(1){g=m;if(i>>>0<g>>>0){m=g-4|0;if(!j[m>>2]){continue}}break}d=j[o+44>>2]-s|0;j[o+44>>2]=d;m=g;if((d|0)>0){continue}break}}if((d|0)<=-1){y=((q+25|0)/9|0)+1|0;s=(C|0)==102;while(1){l=(d|0)<-9?9:0-d|0;h:{if(g>>>0<=i>>>0){i=j[i>>2]?i:i+4|0;break h}v=1e9>>>l|0;u=-1<<l^-1;d=0;m=i;while(1){D=d;d=j[m>>2];j[m>>2]=D+(d>>>l|0);d=p(v,d&u);m=m+4|0;if(m>>>0<g>>>0){continue}break}i=j[i>>2]?i:i+4|0;if(!d){break h}j[g>>2]=d;g=g+4|0}d=j[o+44>>2]+l|0;j[o+44>>2]=d;m=s?t:i;g=g-m>>2>(y|0)?m+(y<<2)|0:g;if((d|0)<0){continue}break}}m=0;i:{if(g>>>0<=i>>>0){break i}m=p(t-i>>2,9);d=10;l=j[i>>2];if(l>>>0<10){break i}while(1){m=m+1|0;d=p(d,10);if(l>>>0>=d>>>0){continue}break}}d=(q-((C|0)==102?0:m)|0)-((C|0)==103&(q|0)!=0)|0;if((d|0)<(p(g-t>>2,9)-9|0)){l=d+9216|0;s=(l|0)/9|0;n=((s<<2)+((n|0)<0?o+48|4:o+340|0)|0)-4096|0;d=10;l=l-p(s,9)|0;if((l|0)<=7){while(1){d=p(d,10);l=l+1|0;if((l|0)!=8){continue}break}}s=j[n>>2];v=(s>>>0)/(d>>>0)|0;y=n+4|0;l=s-p(d,v)|0;j:{if(l?0:(y|0)==(g|0)){break j}u=d>>>1|0;z=l>>>0<u>>>0?.5:(g|0)==(y|0)?(u|0)==(l|0)?1:1.5:1.5;b=v&1?9007199254740994:9007199254740992;if(!(k[w|0]!=45|A)){z=-z;b=-b}l=s-l|0;j[n>>2]=l;if(b+z==b){break j}d=d+l|0;j[n>>2]=d;if(d>>>0>=1e9){while(1){j[n>>2]=0;n=n-4|0;if(n>>>0<i>>>0){i=i-4|0;j[i>>2]=0}d=j[n>>2]+1|0;j[n>>2]=d;if(d>>>0>999999999){continue}break}}m=p(t-i>>2,9);d=10;l=j[i>>2];if(l>>>0<10){break j}while(1){m=m+1|0;d=p(d,10);if(l>>>0>=d>>>0){continue}break}}d=n+4|0;g=d>>>0<g>>>0?d:g}while(1){d=g;n=g>>>0<=i>>>0;if(!n){g=d-4|0;if(!j[g>>2]){continue}}break}k:{if((C|0)!=103){A=e&8;break k}g=q?q:1;l=(g|0)>(m|0)&(m|0)>-5;q=(l?m^-1:-1)+g|0;f=(l?-1:-2)+f|0;A=e&8;if(A){break k}g=-9;l:{if(n){break l}s=j[d-4>>2];if(!s){break l}l=10;g=0;if((s>>>0)%10|0){break l}while(1){n=g;g=g+1|0;l=p(l,10);if(!((s>>>0)%(l>>>0)|0)){continue}break}g=n^-1}n=p(d-t>>2,9);if((f&-33)==70){A=0;g=(g+n|0)-9|0;g=(g|0)>0?g:0;q=(g|0)>(q|0)?q:g;break k}A=0;g=((m+n|0)+g|0)-9|0;g=(g|0)>0?g:0;q=(g|0)>(q|0)?q:g}s=q|A;v=(s|0)!=0;D=a;l=c;u=f&-33;g=(m|0)>0?m:0;m:{if((u|0)==70){break m}g=m>>31;g=gm(g+m^g,0,x);if((x-g|0)<=1){while(1){g=g-1|0;h[g|0]=48;if((x-g|0)<2){continue}break}}y=g-2|0;h[y|0]=f;h[g-1|0]=(m|0)<0?45:43;g=x-y|0}n=(g+(v+(q+B|0)|0)|0)+1|0;of(D,32,l,n,e);ve(a,w,B);of(a,48,c,n,e^65536);n:{o:{p:{if((u|0)==70){f=o+16|8;m=o+16|9;l=i>>>0>t>>>0?t:i;i=l;while(1){g=gm(j[i>>2],0,m);q:{if((i|0)!=(l|0)){if(o+16>>>0>=g>>>0){break q}while(1){g=g-1|0;h[g|0]=48;if(o+16>>>0<g>>>0){continue}break}break q}if((g|0)!=(m|0)){break q}h[o+24|0]=48;g=f}ve(a,g,m-g|0);i=i+4|0;if(t>>>0>=i>>>0){continue}break}if(s){ve(a,55683,1)}if((q|0)<1|d>>>0<=i>>>0){break p}while(1){g=gm(j[i>>2],0,m);if(g>>>0>o+16>>>0){while(1){g=g-1|0;h[g|0]=48;if(o+16>>>0<g>>>0){continue}break}}ve(a,g,(q|0)<9?q:9);g=q-9|0;i=i+4|0;if(d>>>0<=i>>>0){break o}f=(q|0)>9;q=g;if(f){continue}break}break o}r:{if((q|0)<0){break r}t=d>>>0>i>>>0?d:i+4|0;d=o+16|8;f=o+16|9;m=i;while(1){g=gm(j[m>>2],0,f);if((f|0)==(g|0)){h[o+24|0]=48;g=d}s:{if((i|0)!=(m|0)){if(o+16>>>0>=g>>>0){break s}while(1){g=g-1|0;h[g|0]=48;if(o+16>>>0<g>>>0){continue}break}break s}ve(a,g,1);g=g+1|0;if((q|0)<1?!A:0){break s}ve(a,55683,1)}v=g;g=f-g|0;ve(a,v,(g|0)<(q|0)?g:q);q=q-g|0;m=m+4|0;if(t>>>0<=m>>>0){break r}if((q|0)>-1){continue}break}}of(a,48,q+18|0,18,0);ve(a,y,x-y|0);break n}g=q}of(a,48,g+9|0,9,0)}break b}n=f&32;q=n?w+9|0:w;t:{if(d>>>0>11){break t}g=12-d|0;if(!g){break t}z=8;while(1){z=z*16;g=g-1|0;if(g){continue}break}if(k[q|0]==45){b=-(z+(-b-z));break t}b=b+z-z}i=j[o+44>>2];g=i>>31;g=gm(g^g+i,0,x);if((x|0)==(g|0)){h[o+15|0]=48;g=o+15|0}t=B|2;i=j[o+44>>2];m=g-2|0;h[m|0]=f+15;h[g-1|0]=(i|0)<0?45:43;l=e&8;i=o+16|0;while(1){f=i;v=i;i=n;if(r(b)<2147483648){g=~~b}else{g=-2147483648}h[v|0]=i|k[g+55632|0];i=f+1|0;b=(b- +(g|0))*16;if(!((i-(o+16|0)|0)!=1|(b==0?!(l|(d|0)>0):0))){h[f+1|0]=46;i=f+2|0}if(b!=0){continue}break}d=!d|((i-o|0)-18|0)>=(d|0)?((x-(o+16|0)|0)-m|0)+i|0:((d+x|0)-m|0)+2|0;n=d+t|0;of(a,32,c,n,e);ve(a,q,t);of(a,48,c,n,e^65536);f=i-(o+16|0)|0;ve(a,o+16|0,f);g=d;d=x-m|0;of(a,48,g-(d+f|0)|0,0,0);ve(a,m,d)}of(a,32,c,n,e^8192);Za=o+560|0;return((c|0)>(n|0)?c:n)|0}function nBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0;d=Za-224|0;Za=d;rc(b);a:{b:{c:{d:{e:{f:{if(!ct(b,d+208|0)){break f}if(!tO(d+208|0)){break f}m=zh(d+192|0);n=Qc(d+176|0);Ab(d+112|0,0,64);j[114626]=0;f=E(885,b|0,d+104|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}g:{if(!f){break g}f=d+104|4;g=k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24);g=(g<<8&16711680|g<<24|(g>>>8&65280|g>>>24))-4|0;g=g<<24|g<<8&16711680|(g>>>8&65280|g>>>24);h[f|0]=g;h[f+1|0]=g>>>8;h[f+2|0]=g>>>16;h[f+3|0]=g>>>24;g=0;h:{i:{j:{while(1){e=k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24);e=(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))-8|0;e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);h[f|0]=e;h[f+1|0]=e>>>8;h[f+2|0]=e>>>16;h[f+3|0]=e>>>24;k:{if(c){break k}e=d+104|0;if((k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))!=1413764176){break k}g=1;break g}e=k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24);j[114626]=0;I(341,d+24|0,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));e=j[114626];j[114626]=0;l:{m:{n:{o:{p:{if((e|0)!=1){j[114626]=0;e=H(337,d+24|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break o}if(e){break p}jb(d+24|0);break l}a=D()|0;C()|0;break a}e=d+104|0;e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if((e|0)<=1347699795){if((e|0)==1129139796){break n}if((e|0)!=1229866575){break m}j[114626]=0;q=E(886,d+24|0,d+112|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break o}break m}if((e|0)!=1347699796){if((e|0)!=1447383635){break m}j[114626]=0;E(338,d+24|0,4)|0;e=j[114626];j[114626]=0;if((e|0)==1){break o}j[114626]=0;e=E(887,d+24|0,16119)|0;o=j[114626];j[114626]=0;if((o|0)==1){break o}if(!e){break m}e=k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24);if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0<7){break m}e=k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24);j[114626]=0;P(888,d+24|0,n|0,2,(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))-6|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break o}break m}j[114626]=0;g=K(889,a|0,d+24|0,c|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break m}}a=D()|0;C()|0;jb(d+24|0);break a}rO(m,d+24|0)}jb(d+24|0);j[114626]=0;e=E(885,b|0,d+104|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break j}if(e){continue}}break}if(Ec(n)){j[114626]=0;b=E(2,d+24|0,16122)|0;c=j[114626];j[114626]=0;if((c|0)==1){break i}ob(n,b);gb(b)}if(!(g&q&1)){break h}b=d+154|0;b=k[b|0]|k[b+1|0]<<8;j[114626]=0;f=b&1;K(478,a+1074308|0,5,!f|0)|0;b=j[114626];j[114626]=0;q:{r:{s:{if((b|0)!=1){b=d+150|0;if(k[b|0]|k[b+1|0]<<8){i[d+24>>1]=64;b=k[b|0]|k[b+1|0]<<8;j[114626]=0;i[d+88>>1]=(b<<8&16711680|b<<24)>>>16;b=E(477,d+24|0,d+88|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break s}j[a+480228>>2]=l[b>>1]}b=d+152|0;if(!(!f|!(k[b|0]|k[b+1|0]<<8))){b=k[b|0]|k[b+1|0]<<8;j[a+480204>>2]=p((b<<24|b<<8&16711680)>>>16|0,1e4)}if(k[d+112|0]){j[114626]=0;I(745,d+88|0,2,d+112|0);b=j[114626];j[114626]=0;if((b|0)==1){break r}j[114626]=0;F(415,d+24|0,d+88|0);b=j[114626];j[114626]=0;if((b|0)==1){break r}ob(a+1304400|0,d+24|0);gb(d+24|0)}b=l[d+158>>1];i[d+86>>1]=b;i[d+22>>1]=b;if(!Zo(d+22|0,1,12)){break h}b=l[d+156>>1];i[d+84>>1]=b;i[d+20>>1]=b;if(!Zo(d+20|0,1,31)){break h}b=l[d+162>>1];i[d+82>>1]=b;i[d+18>>1]=b;if(!Zo(d+18|0,0,23)){break h}b=l[d+164>>1];i[d+80>>1]=b;i[d+16>>1]=b;if(!Zo(d+16|0,0,59)){break h}b=l[d+166>>1];i[d+78>>1]=b;i[d+14>>1]=b;if(Zo(d+14|0,0,59)){break q}break h}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}b=pp(d+24|0);c=d+160|0;c=k[c|0]|k[c+1|0]<<8;j[b+20>>2]=(c<<24|c<<8&16711680)>>>16;c=d+158|0;c=k[c|0]|k[c+1|0]<<8;j[b+16>>2]=((c<<24|c<<8&16711680)>>>16|0)-1;c=d+156|0;c=k[c|0]|k[c+1|0]<<8;j[b+12>>2]=(c<<24|c<<8&16711680)>>>16;c=d+162|0;c=k[c|0]|k[c+1|0]<<8;j[b+8>>2]=(c<<24|c<<8&16711680)>>>16;c=d+164|0;c=k[c|0]|k[c+1|0]<<8;j[b+4>>2]=(c<<24|c<<8&16711680)>>>16;c=d+166|0;c=k[c|0]|k[c+1|0]<<8;j[b>>2]=(c<<24|c<<8&16711680)>>>16;j[114626]=0;F(663,a+1304500|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break h}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}if(g&1){j[114626]=0;b=H(337,m|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break c}if(b){b=Db(d+24|0);j[114626]=0;K(481,m|0,b|0,32)|0;c=j[114626];j[114626]=0;if((c|0)==1){break b}if(_s(b,16126)){j[114626]=0;I(13,d+88|0,2,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}ob(a+1304412|0,d+88|0);gb(d+88|0)}j[114626]=0;c=H(890,m|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}if(!c){j[114626]=0;c=H(540,m|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}j[114626]=0;U(547,a+1304424|0,m|0,c|0,40,0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break b}}gb(b)}j[114626]=0;b=E(2,d+88|0,16141)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}j[114626]=0;I(720,d+24|0,b|0,n|0);c=j[114626];j[114626]=0;if((c|0)==1){break d}ob(a+1304460|0,d+24|0);gb(d+24|0);gb(b)}j[a+480208>>2]=j[a+480208>>2]|2097152;j[114626]=0;a=a+1074308|0;K(478,a|0,84,1)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}j[114626]=0;K(478,a|0,83,1)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}j[114626]=0;K(478,a|0,85,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}}gb(n);jb(m)}Za=d+224|0;return g&1}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(b);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(b)}gb(n);jb(m);G(a|0);z()}function kG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,l=0;e=Za-448|0;Za=e;a:{if(Pi(b)){break a}g=k[Fj(b)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;Pj(e+184|0,b,j[b+4>>2]-1|0);f=j[e+188>>2];j[b>>2]=j[e+184>>2];j[b+4>>2]=f}ld(e+184|0);f=j[e+184>>2];ld(e+416|0);h=Ej(f,j[e+420>>2],b);ld(e+184|0);f=j[b>>2];g=j[b+4>>2];c:{d:{e:{f:{if((h|0)==j[e+188>>2]){j[e+440>>2]=f;j[e+444>>2]=g;a=Zb(e+432|0,38235);f=j[e+444>>2];j[e+16>>2]=j[e+440>>2];j[e+20>>2]=f;f=j[a+4>>2];j[e+8>>2]=j[a>>2];j[e+12>>2]=f;if(nc(e+16|0,e+8|0)){a=R(8)|0;j[114626]=0;d=E(2134,e+416|0,c|0)|0;b=j[114626];j[114626]=0;g:{h:{i:{if((b|0)!=1){j[114626]=0;I(2111,e+184|0,39300,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break i}Wb(a,e+184|0);c=0;j[114626]=0;I(2002,a|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break c}b=D()|0;C()|0;gb(e+184|0);break h}b=D()|0;C()|0;break g}b=D()|0;c=1;C()|0}gb(d);if(!c){break d}}S(a|0);break d}if(!d){break f}d=R(8)|0;j[114626]=0;f=E(2134,e+384|0,b|0)|0;b=j[114626];j[114626]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){j[114626]=0;I(2111,e+400|0,39179,f|0);a=j[114626];j[114626]=0;if((a|0)==1){break r}j[114626]=0;I(2129,e+416|0,e+400|0,39315);b=j[114626];j[114626]=0;a=1;if((b|0)==1){break q}j[114626]=0;c=E(2134,e+368|0,c|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break p}j[114626]=0;I(138,e+184|0,e+416|0,c|0);b=j[114626];j[114626]=0;a=1;if((b|0)==1){break o}Wb(d,e+184|0);j[114626]=0;I(2002,d|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(e+184|0);a=0;break n}b=D()|0;C()|0;break j}b=D()|0;a=1;C()|0;break k}b=D()|0;C()|0;break l}b=D()|0;a=1;C()|0;break m}b=D()|0;C()|0}gb(c)}gb(e+416|0)}gb(e+400|0)}gb(f)}if(!a){break d}S(d|0);break d}j[e+360>>2]=f;j[e+364>>2]=g;d=Zb(e+352|0,38235);f=j[e+364>>2];j[e+176>>2]=j[e+360>>2];j[e+180>>2]=f;f=j[d+4>>2];j[e+168>>2]=j[d>>2];j[e+172>>2]=f;if(nc(e+176|0,e+168|0)){a=R(8)|0;j[114626]=0;d=E(2134,e+416|0,c|0)|0;b=j[114626];j[114626]=0;s:{t:{u:{if((b|0)!=1){j[114626]=0;I(2111,e+184|0,39300,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break u}Wb(a,e+184|0);c=0;j[114626]=0;I(2002,a|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break c}b=D()|0;C()|0;gb(e+184|0);break t}b=D()|0;C()|0;break s}b=D()|0;c=1;C()|0}gb(d);if(!c){break d}}S(a|0);break d}d=j[b+4>>2];j[e+344>>2]=j[b>>2];j[e+348>>2]=d;d=Zb(e+336|0,39058);f=j[e+348>>2];j[e+160>>2]=j[e+344>>2];j[e+164>>2]=f;f=j[d+4>>2];j[e+152>>2]=j[d>>2];j[e+156>>2]=f;if(nc(e+160|0,e+152|0)){b=j[c+4>>2];j[e+328>>2]=j[c>>2];j[e+332>>2]=b;b=Zb(e+320|0,39251);d=j[e+332>>2];j[e+64>>2]=j[e+328>>2];j[e+68>>2]=d;d=j[b+4>>2];j[e+56>>2]=j[b>>2];j[e+60>>2]=d;if(nc(e- -64|0,e+56|0)){j[a+52>>2]=0;break f}b=j[c+4>>2];j[e+312>>2]=j[c>>2];j[e+316>>2]=b;b=Zb(e+304|0,39259);d=j[e+316>>2];j[e+48>>2]=j[e+312>>2];j[e+52>>2]=d;d=j[b+4>>2];j[e+40>>2]=j[b>>2];j[e+44>>2]=d;if(nc(e+48|0,e+40|0)){j[a+52>>2]=1;break f}b=j[c+4>>2];j[e+296>>2]=j[c>>2];j[e+300>>2]=b;b=Zb(e+288|0,39268);d=j[e+300>>2];j[e+32>>2]=j[e+296>>2];j[e+36>>2]=d;d=j[b+4>>2];j[e+24>>2]=j[b>>2];j[e+28>>2]=d;if(nc(e+32|0,e+24|0)){j[a+52>>2]=2;break f}a=R(8)|0;j[114626]=0;d=E(2134,e+416|0,c|0)|0;b=j[114626];j[114626]=0;v:{w:{x:{if((b|0)!=1){j[114626]=0;I(2111,e+184|0,39362,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break x}Wb(a,e+184|0);c=0;j[114626]=0;I(2002,a|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break c}b=D()|0;C()|0;gb(e+184|0);break w}b=D()|0;C()|0;break v}b=D()|0;c=1;C()|0}gb(d);if(!c){break d}}S(a|0);break d}d=j[b+4>>2];j[e+280>>2]=j[b>>2];j[e+284>>2]=d;b=Zb(e+272|0,39101);d=j[e+284>>2];j[e+144>>2]=j[e+280>>2];j[e+148>>2]=d;d=j[b+4>>2];j[e+136>>2]=j[b>>2];j[e+140>>2]=d;if(!nc(e+144|0,e+136|0)){break f}b=j[c+4>>2];j[e+264>>2]=j[c>>2];j[e+268>>2]=b;b=Zb(e+256|0,39273);d=j[e+268>>2];j[e+128>>2]=j[e+264>>2];j[e+132>>2]=d;d=j[b+4>>2];j[e+120>>2]=j[b>>2];j[e+124>>2]=d;b=0;y:{if(nc(e+128|0,e+120|0)){break y}b=j[c+4>>2];j[e+248>>2]=j[c>>2];j[e+252>>2]=b;b=Zb(e+240|0,39278);d=j[e+252>>2];j[e+112>>2]=j[e+248>>2];j[e+116>>2]=d;d=j[b+4>>2];j[e+104>>2]=j[b>>2];j[e+108>>2]=d;b=1;if(nc(e+112|0,e+104|0)){break y}b=j[c+4>>2];j[e+232>>2]=j[c>>2];j[e+236>>2]=b;b=Zb(e+224|0,39284);d=j[e+236>>2];j[e+96>>2]=j[e+232>>2];j[e+100>>2]=d;d=j[b+4>>2];j[e+88>>2]=j[b>>2];j[e+92>>2]=d;b=2;if(nc(e+96|0,e+88|0)){break y}b=j[c+4>>2];j[e+216>>2]=j[c>>2];j[e+220>>2]=b;b=Zb(e+208|0,39295);c=j[e+220>>2];j[e+80>>2]=j[e+216>>2];j[e+84>>2]=c;c=j[b+4>>2];j[e+72>>2]=j[b>>2];j[e+76>>2]=c;b=3;if(nc(e+80|0,e+72|0)){break y}a=R(8)|0;j[114626]=0;c=E(85,e+184|0,39387)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(c);break d}j[a+56>>2]=b;b=a+24|0;if(!j[j[b>>2]+24668>>2]){break f}c=j[b>>2];d=c+24664|0;f=j[d+4>>2];j[e+200>>2]=j[d>>2];j[e+204>>2]=f;d=c+24656|0;f=j[d+4>>2];j[e+192>>2]=j[d>>2];j[e+196>>2]=f;d=j[c+24652>>2];j[e+184>>2]=j[c+24648>>2];j[e+188>>2]=d;i=e,l=SF(j[a+56>>2]),j[i+204>>2]=l;if(!cw(e+184|0,j[b>>2]+24648|0)){break f}$w(j[b>>2],e+184|0)}Za=e+448|0;return}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function vBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=Za-1824|0;Za=d;rc(b);f=d+1224|0;e=_Aa(b,f);if(!e){mO(f)}a:{if(!e){break a}if(!wO(d+1224|0)){break a}if(!Ay(b,16,0)){break a}j[d+1216>>2]=j[d+1240>>2];f=j[d+1228>>2];j[d+1200>>2]=j[d+1224>>2];j[d+1204>>2]=f;f=d+1232|0;e=j[f+4>>2];j[d+1208>>2]=j[f>>2];j[d+1212>>2]=e;od(a,1);f=a+1074308|0;rg(f,83);vb(f,84,1);vb(f,85,1);i[a+480188>>1]=4;j[d+1196>>2]=0;i[a+480190>>1]=15;xc(b,20);s=a+480188|0;g=1;r=1;f=0;while(1){m=p(g,104)+a|0;o=m+484380|0;e=((g<<5)+a|0)+946300|0;Cy(b,d+16|0,o,e,1);n=j[o>>2];b:{if(!k[Pb(e,0)|0]){break b}c:{if(Yc(e,15730,3)){if(Yc(e,15734,3)){break c}}if(k[Pb(e,5)|0]==58){break b}}r=0}e=k[d+44|0]|k[d+45|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0>=2){e=k[d+42|0]|k[d+43|0]<<8;j[m+484384>>2]=(e<<24|e<<8&16711680)>>>16;e=k[d+44|0]|k[d+45|0]<<8;q=(e<<24|e<<8&16711680)>>>15|0;e=k[d+42|0]|k[d+43|0]<<8;j[m+484388>>2]=q+((e<<8&16711680|e<<24)>>>16|0);Nm(o)}e=k[d+38|0]|k[d+39|0]<<8;d:{if((e<<24|e<<8&16711680)>>>16>>>0<=4999){e=k[d+42|0]|k[d+43|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0<1e4){break d}}j[d+1064>>2]=5;z=d,A=j[zf(d+1196|0,d+1064|0)>>2],j[z+1196>>2]=A}f=f+n|0;g=g+1|0;if((g|0)!=16){continue}break}By(b,d+1064|0);q=a+484360|0;fn(Fb(q),d+1064|2,128,65535,65535);g=0;s=BO(b,Fb(q),k[d+1064|0],f,s,0);e=d+1064|1;if(k[d+1064|0]?0:!(k[e|0]|s>>>0>1)){break a}if(ef(b)+65536>>>0<(s<<10)+f>>>0){break a}if(!c){g=1;break a}if(!k[e|0]){h[e|0]=120}if(!Yc(d+1200|0,15738,6)){h[e|0]=120}j[a+480204>>2]=125e4;e:{if(k[e|0]==120){break e}f=a;w=145364549.18032786/+(240-k[e|0]|0);f:{if(w<4294967296&w>=0){e=~~w>>>0;break f}e=0}j[f+480204>>2]=e;if(j[d+1196>>2]>=2){j[d+16>>2]=r&1?4:5;z=d,A=j[zf(d+1196|0,d+16|0)>>2],j[z+1196>>2]=A;break e}j[d+16>>2]=r&1?1:2;z=d,A=j[zf(d+1196|0,d+16|0)>>2],j[z+1196>>2]=A}j[a+480260>>2]=452;j[a+480264>>2]=3424;j[a+480228>>2]=64;j[a+480208>>2]=j[a+480208>>2]|2097152;en(d+1048|0,3,d+1200|0);qc(d+16|0,d+1048|0);ob(a+1304400|0,d+16|0);gb(d+16|0);Oi(a,0);x=j[b+8>>2];i[d+1046>>1]=0;g:{if(s){y=r&1;r=0;while(1){z=d,A=yy(Lb(Fb(q)),Mb(Fb(q)),d+1046|0),j[z+16>>2]=A;z=d,A=Mb(Fb(q)),j[z+1048>>2]=A;f=rb(d+16|0,d+1048|0);vO(b,d+16|0);if(f){r=wy(d+16|0,0)+r|0;if(r>>>0>512){break g}}o=0;f=0;t=0;while(1){g=0;while(1){e=f;m=Be(uO(d+16|0,o),g);u=k[Pb(m,2)|0]&15;n=k[Pb(m,3)|0];f=0;h:{if(!(e&255)|(k[m|0]|k[m+1|0]<<8|(k[m+2|0]<<16|k[m+3|0]<<24))){break h}f=e+1|0;if((f&255)>>>0<33){break h}j[d+1196>>2]=6}i:{j:{k:{switch(u-1|0){case 0:case 1:e=j[d+1196>>2];if((e|0)==1?n>>>0>=32:0){break j}m=(u|0)!=1;if(!(m|(n-1&255)>>>0>1)){j[d+1048>>2]=2;z=d,A=j[zf(d+1196|0,d+1048|0)>>2],j[z+1196>>2]=A;break i}if(m|((n|0)!=55?(n|0)!=71:0)){break i}if((e|0)<=2){break j}break i;case 10:j[d+1196>>2]=6;break i;case 11:case 12:case 13:j[d+1048>>2]=2;z=d,A=j[zf(d+1196|0,d+1048|0)>>2],j[z+1196>>2]=A;if((u|0)!=13){break i}t=((n|o)!=0)+t|0;f=1;break i;case 14:break k;default:break i}}j[d+1048>>2]=3;z=d,A=j[zf(d+1196|0,d+1048|0)>>2],j[z+1196>>2]=A;break i}j[d+1196>>2]=y}g=g+1|0;if((g|0)!=4){continue}break}o=o+1|0;if((o|0)!=64){continue}break}if((t-1&255)>>>0<2){j[d+1196>>2]=6}v=(t&255)+v|0;f=l[d+1046>>1]+1|0;i[d+1046>>1]=f;if(s>>>0>(f&65535)>>>0){continue}break}}if(!(j[d+1196>>2]!=6|s+32>>>0>=v>>>0)){j[d+1196>>2]=5}xc(b,x);u=c&1;if(u){If(a+484344|0,s)}if(s){t=a+484344|0;r=0;while(1){vO(b,d+16|0);l:{if(!u){break l}if(!Wf(t,r&65535,64)){break l}j[d+1048>>2]=0;o=0;while(1){v=Se(Ib(t,r),o,0);m=0;while(1){f=Be(uO(d+16|0,o),m);f=k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24);j[d+8>>2]=f;j[d+12>>2]=f;e=v+p(m,6)|0;Fs(d+8|0,e);m:{n:{o:{p:{f=k[e+5|0];if(f){n=e+3|0;q=(d+1048|0)+m|0;g=k[e+3|0];if((g|0)!=14){break p}h[q|0]=0;g=14;break o}n=(d+1048|0)+m|0;h[n|0]=0;g=k[e+3|0];if(!g){break n}n=e+3|0;break o}q=k[q|0];if(!q){break o}if(q>>>0>=16){h[e+2|0]=3;h[e+4|0]=q>>>4;break o}h[e+2|0]=4;h[e+4|0]=q}q:{r:{s:{switch(g-12|0){case 1:if(j[d+1196>>2]!=6){g=10;h[n|0]=10;break r}f=0;h[e+5|0]=0;g=13;break r;case 0:f=f&127;h[e+5|0]=f;g=12;break r;case 2:if(j[d+1196>>2]>3?f>>>0<=1:0){break q}g=10;h[n|0]=10;h[(d+1048|0)+m|0]=f;break r;case 3:break s;default:break r}}g=15;f=f&15;h[e+5|0]=f}if(j[d+1196>>2]>1){break q}t:{u:{v:{switch(g|0){case 0:if(f>>>0>2){break u}break;case 2:break t;case 1:break u;default:break v}}h[n|0]=0;break m}h[n|0]=1;break m}g=f&15;if(g){h[n|0]=2;h[e+5|0]=g;break m}if(!(f&240)){break m}h[n|0]=3;h[e+5|0]=f>>>4;break m}Yi(e);break m}h[n|0]=0}m=m+1|0;if((m|0)!=4){continue}break}o=o+1|0;if((o|0)!=64){continue}break}}r=r+1|0;if((s|0)!=(r|0)){continue}break}}e=j[d+1196>>2];f=15744;w:{if(e>>>0>=7){break w}f=j[(e<<2)+77496>>2]}e=Eb(d+16|0,16009);ob(a+1304436|0,e);gb(e);e=Eb(d+16|0,16022);ob(a+1304448|0,e);gb(e);vc(a+1304460|0,f);j[a+1304496>>2]=2;g=1;if(!(c&2)){break a}m=1;while(1){c=p(m,104)+a|0;f=c+484384|0;Jb(b,j[f>>2]);e=j[f>>2];j[f>>2]=0;f=c+484380|0;j[f>>2]=j[f>>2]-e;c=c+484388|0;j[c>>2]=j[c>>2]-e;Mc(d+16|0,8,1,1,0);$f(d+16|0,f,b);m=m+1|0;if((m|0)!=16){continue}break}break a}g=0}Za=d+1824|0;return g|0}function lya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=Za-352|0;Za=d;xc(b,60);e=15;a:{if(!vh(b,17212)){xc(b,124);e=31;if(!vh(b,17217)){break a}}od(a,536870912);i[a+480190>>1]=e;rc(b);b:{if(l[a+480190>>1]){while(1){e=Dz(b);j[(d+224|0)+(f<<2)>>2]=e;if(e>>>0>131072){break b}f=f+1|0;if(f>>>0<l[a+480190>>1]){continue}break}}j[a+480260>>2]=56;j[a+480264>>2]=13696;j[a+480196>>2]=6;f=0;i[a+480192>>1]=0;i[a+480188>>1]=4;j[a+480228>>2]=64;Oi(a,1);Jb(b,4);e=tp(b);if(e>>>0<178){break a}f=a;s=177693e5/+(e>>>0);c:{if(s<4294967296&s>=0){e=~~s>>>0;break c}e=0}j[f+480204>>2]=e;Jb(b,14);d:{e:{f:{if(l[a+480190>>1]){r=d+78|0;m=1;e=0;n=1;while(1){xO(b,d+56|0);kya(d+56|0,(p(m,104)+a|0)+484380|0,j[((m<<2)+d|0)+220>>2]);f=d+56|0;while(1){if((k[f|0]-1&255)>>>0<=30){h[f|0]=32;e=e+1|0}f=f+1|0;if((r|0)!=(f|0)){continue}break}if(e>>>0>127){break b}on(d+192|0,3,d+56|0);qc(d+208|0,d+192|0);j[114626]=0;E(369,((m<<5)+a|0)+946300|0,d+208|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break f}gb(d+208|0);n=n+1|0;m=n&65535;if(m>>>0<=l[a+480190>>1]){continue}break}}e=Eb(d+56|0,17222);j[114626]=0;f=a+946332|0;m=E(998,f|0,e|0)|0;n=j[114626];j[114626]=0;r=1;g:{h:{i:{j:{if((n|0)!=1){if(!m){j[114626]=0;m=E(85,d+208|0,17233)|0;n=j[114626];j[114626]=0;if((n|0)==1){break j}j[114626]=0;r=E(998,f|0,m|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break i}gb(m)}gb(e);f=0;if(!By(b,d+56|0)){break a}if(!cN(d+56|0)){break a}if(c){break g}break d}f=D()|0;C()|0;break h}f=D()|0;C()|0;break h}f=D()|0;C()|0;gb(m)}gb(e);break e}i[d+54>>1]=0;if(k[d+56|0]){while(1){i[d+208>>1]=k[(d+f|0)+58|0]+1;w=d,x=l[ui(d+54|0,d+208|0)>>1],i[w+54>>1]=x;f=f+1|0;if(f>>>0<k[d+56|0]){continue}break}}f=d+56|1;e=k[f|0];m=k[d+56|0];n=a+484360|0;Ge(Fb(n),e>>>0<m>>>0?k[f|0]:0);fn(Fb(n),d+56|2,k[d+56|0],65535,65535);if(l[a+480190>>1]==31){Jb(b,4)}j[d+48>>2]=0;j[d+44>>2]=0;j[d+40>>2]=0;h[d+39|0]=0;t=c&1;if(t){If(a+484344|0,l[d+54>>1])}if(l[d+54>>1]){u=a+484344|0;m=0;while(1){k:{l:{if(t){n=0;if(Wf(u,m&65535,64)){break l}}Jb(b,1024);break k}while(1){v=Se(Ib(u,m),n,0);f=0;while(1){nn(d+208|0,b);e=p(f,6)+v|0;m:{n:{if(k[Pb(d+208|0,0)|0]!=255){break n}h[(d+48|0)+f|0]=0;h[(d+40|0)+f|0]=0;o:{if(!r){break o}if(k[Pb(d+208|0,1)|0]!=252){break o}w=Pb(d+208|0,1),x=254,h[w|0]=x}p:{switch(k[Pb(d+208|0,1)|0]-252|0){case 2:h[e+3|0]=13;break m;case 1:break m;case 0:break p;default:break n}}h[e+3|0]=14;h[d+39|0]=9;break m}g=j[d+208>>2];j[d+32>>2]=g;j[d+12>>2]=g;Fs(d+12|0,e);g=k[e|0];q:{if(!g){break q}h[(d+40|0)+f|0]=0;h[(d+48|0)+f|0]=g;if(g>>>0>48){break q}h[d+192|0]=8;w=d,x=k[Wg(d+39|0,d+192|0)|0],h[w+39|0]=x}r:{s:{t:{u:{v:{switch(k[e+3|0]){case 0:if(k[e+5|0]){break s}break r;case 1:h[e+3|0]=1;break m;case 2:g=k[e+5|0];if(g&240){h[e+3|0]=3;h[e+5|0]=g>>>4;break m}g=g&15;if(g){h[e+3|0]=2;h[e+5|0]=g;break m}h[e+5|0]=0;break s;case 3:if(k[(d+40|0)+f|0]){break t}h[e+3|0]=19;h[e+5|0]=0;break m;case 4:if(k[(d+40|0)+f|0]){break t}h[e+3|0]=19;h[e+5|0]=1;break m;case 5:if(!k[e+1|0]){break t}h[e+3|0]=13;h[d+192|0]=63;h[d+31|0]=k[e+5|0]+(l[(p(k[e+1|0],104)+a|0)+484410>>1]>>>2|0);g=k[Yb(d+192|0,d+31|0)|0];h[e+5|0]=g;if(!k[(d+40|0)+f|0]){break u}h[e+4|0]=g;h[e+2|0]=1;h[e+5|0]=0;break s;case 6:g=k[e+1|0];if(!g){break t}h[e+3|0]=13;g=l[(p(g,104)+a|0)+484410>>1]>>>2|0;o=k[e+5|0];g=g>>>0<o>>>0?0:g-o|0;h[e+5|0]=g;if(!k[(d+40|0)+f|0]){break u}h[e+4|0]=g;h[e+2|0]=1;h[e+5|0]=0;break s;case 8:o=k[(d+48|0)+f|0];g=k[e+5|0];q=o+(g>>>4|0)|0;h[(d+44|0)+f|0]=q;h[e+3|0]=2;g=g&15;h[(d+40|0)+f|0]=g;w=e,x=bN(g,o,q&255),h[w+5|0]=x;break u;case 9:h[d+192|0]=8;w=d,x=k[Wg(d+39|0,d+192|0)|0],h[w+39|0]=x;break s;case 7:break v;default:break s}}g=k[(d+48|0)+f|0];o=k[e+5|0];q=g-(o>>>4|0)|0;h[(d+44|0)+f|0]=q;h[e+3|0]=3;o=o&15;h[(d+40|0)+f|0]=o;w=e,x=bN(o,q&255,g),h[w+5|0]=x}if(k[e+3|0]){break m}break r}h[e+5|0]=0}h[e+3|0]=0}o=k[(d+40|0)+f|0];if(!o){break m}q=(d+44|0)+f|0;g=k[q|0];if(g){h[(d+48|0)+f|0]=g;h[e|0]=g;h[e+5|0]=o;h[q|0]=0}h[e+3|0]=4}f=f+1|0;if((f|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}m=m+1|0;if(m>>>0<l[d+54>>1]){continue}break}}e=l[a+480190>>1];w:{x:{y:{z:{A:{B:{if(c&2){if(!(e&65535)){break B}f=1;while(1){c=(p(f&65535,104)+a|0)+484380|0;if(j[c>>2]){$f(Mc(d+208|0,8,1,0,0),c,b);e=l[a+480190>>1]}f=f+1|0;if((f&65535)>>>0<=(e&65535)>>>0){continue}break}}if((e&65535)==15){break A}}f=0;j[114626]=0;E(2,d+208|0,17255)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break z}f=D()|0;C()|0;break e}b=Eb(d+16|0,17242);j[114626]=0;F(219,d+192|0,b|0);c=j[114626];j[114626]=0;f=1;if((c|0)==1){break x}j[114626]=0;I(536,d+208|0,d+192|0,d+39|0);c=j[114626];j[114626]=0;if((c|0)==1){break y}}ob(a+1304436|0,d+208|0);gb(d+208|0);if(f){qb(d+192|0);gb(d+16|0)}vc(a+1304448|0,l[a+480190>>1]==15?17286:17290);j[a+1304496>>2]=2;break d}f=D()|0;C()|0;qb(d+192|0);break w}f=D()|0;C()|0}gb(b);break e}f=D()|0;C()|0;gb(d+208|0)}G(f|0);z()}f=1;break a}f=0}Za=d+352|0;return f|0}function uma(a){var b=0,c=0,d=0,e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=Za-16|0;Za=g;c=a+1074392|0;b=j[c>>2]+1|0;j[c>>2]=b;a:{b:{c:{if(Yk(a)>>>0>b>>>0){break c}v=a+1074984|0;q=a+1074308|0;o=a+1304360|0;n=a+484344|0;d=a+484360|0;f=a+1074438|0;s=a+1074424|0;t=a+480210|0;while(1){r=0;d:{if(!j[a+1074396>>2]){break d}r=0;if(!(k[t|0]&8)){break d}r=j[a+480180>>2]==1}e:{if(j[a+480180>>2]!=2|(k[t|0]&8?0:j[a+1074428>>2])){break e}b=0;if(!l[a+480188>>1]){break e}while(1){j[(p(b,896)+a|0)+1075788>>2]=0;b=b+1|0;if(b>>>0<l[a+480188>>1]){continue}break}}j[a+1074400>>2]=0;j[a+1074392>>2]=0;j[a+1074396>>2]=0;j[a+1074424>>2]=j[a+1074428>>2];c=l[a+1074440>>1];i[a+1074438>>1]=c;if(!(k[a+480208|0]&32)){b=a;f:{if(bc(Fb(d))>>>0>c>>>0){c=l[ac(Fb(d),l[f>>1])>>1];break f}c=65535}i[b+1074436>>1]=c;g:{if(me(n)>>>0<=(c&65535)>>>0){break g}if(th(Ib(n,l[a+1074436>>1]))){break g}i[a+1074436>>1]=65534}if(l[a+1074436>>1]>=me(n)>>>0){while(1){h:{i:{j:{k:{if(l[a+1074436>>1]!=65535){b=l[f>>1];if(bc(Fb(d))>>>0>b>>>0){break k}}b=l[Fb(d)+28>>1];if(b){break i}b=l[f>>1];if(bc(Fb(d))>>>0<b>>>0){break j}c=l[f>>1];if(!c){break j}while(1){b=c;c=b-1|0;e=c&65535;if(!e){break j}if(l[ac(Fb(d),e)>>1]!=65535){continue}break}break i}b=l[f>>1]+1|0;i[f>>1]=b;break h}b=0}i[a+1074438>>1]=b;j[a+480208>>2]=j[a+480208>>2]&-524289;l:{if(bc(Fb(d))>>>0<=(b&65535)>>>0){break l}while(1){if(l[ac(Fb(d),l[f>>1])>>1]!=65534){break l}b=l[f>>1]+1|0;i[f>>1]=b;if(bc(Fb(d))>>>0>(b&65535)>>>0){continue}break}}b=l[f>>1];m:{if(bc(Fb(d))>>>0<=b>>>0){break m}if(!Po(Fb(d),l[f>>1])){break m}b=l[f>>1];break h}Si(o,1);break b}c=a;n:{if(bc(Fb(d))>>>0>(b&65535)>>>0){b=l[ac(Fb(d),l[f>>1])>>1];break n}b=65535}i[c+1074436>>1]=b;o:{if(me(n)>>>0<=(b&65535)>>>0){break o}if(th(Ib(n,l[a+1074436>>1]))){break o}i[a+1074436>>1]=65534}if(l[a+1074436>>1]>=me(n)>>>0){continue}break}}i[a+1074440>>1]=l[a+1074438>>1]}if(!tg(n,l[a+1074436>>1])){break b}if(m[a+1074424>>2]>=m[Ib(n,l[a+1074436>>1])+12>>2]){j[s>>2]=0}if(j[a+480272>>2]==-1){b=0}else{b=(k[a+480208|0]&32)>>>5|0}if(r){c=o+12|0;if(ad(c)){c=-1}else{c=j[Ri(c)>>2]}c=(c|0)==j[s>>2]}else{c=1}p:{if(b|c^1){break p}if(!eL(o,l[f>>1],j[s>>2],1)){break p}b=j[a+480272>>2];if(b){if((b|0)>=1){j[a+480272>>2]=b-1}Si(o,1);cJ(o,l[f>>1],j[s>>2]);break p}q:{if(k[t|0]&64){if(dL(o,f,s,1)){break q}i[a+1074438>>1]=0;i[a+1074440>>1]=0;j[a+1074424>>2]=0;j[a+1074428>>2]=0;b=k[d+16|0];if((b|0)>=(rh(d)-1|0)){Oo(d,0);Si(o,1);a=0;break a}Oo(d,k[d+16|0]+1&255);Si(o,1);break q}Si(o,1);break b}b=0;while(1){Pm((p(b,896)+a|0)+1074984|0,a,b&65535);b=b+1|0;if((b|0)!=256){continue}break}xJ(a);j[a+1074416>>2]=j[a+480196>>2];j[a+1074420>>2]=j[a+480204>>2];j[a+1074444>>2]=j[a+480200>>2];i[a+1074440>>1]=l[a+1074438>>1];j[a+1074428>>2]=j[a+1074424>>2];c=o;u=bc(Fb(d));b=l[a+1074438>>1];if(u>>>0>b>>>0){w=a,x=l[ac(Fb(d),l[a+1074438>>1])>>1],i[w+1074436>>1]=x;b=l[a+1074438>>1]}cJ(c,b&65535,j[a+1074424>>2]);if(!tg(n,l[a+1074436>>1])){break b}}b=j[a+1074424>>2]+1|0;j[a+1074428>>2]=b;r:{if(b>>>0<m[Ib(n,l[a+1074436>>1])+12>>2]){break r}if(!(k[a+480208|0]&32)){i[a+1074440>>1]=l[a+1074438>>1]+1}j[a+1074428>>2]=0;mb(g+8|0,q,63);if(!kb(g+8|0)){break r}b=j[a+1074432>>2];j[a+1074432>>2]=0;j[a+1074428>>2]=b}c=Se(Ib(n,l[a+1074436>>1]),j[a+1074424>>2],0);b=l[a+480188>>1];if(b){u=(p(b,896)+a|0)+1074984|0;b=v;while(1){mb(g+8|0,q,82);s:{if(!kb(g+8|0)|k[b+827|0]!=1){break s}e=k[c+3|0];if((e|0)!=3?(e|0)!=2:0){break s}w=b,x=Zf(a,k[b+822|0],j[b+768>>2],j[b+704>>2]),j[w+700>>2]=x}mb(g+8|0,q,91);t:{if(!kb(g+8|0)){break t}if(Lf(c)){break t}if(!Lf(b+810|0)|k[b+813|0]!=19){break t}e=k[b+815|0];if((e&240)!=208|m[a+1074416>>2]>(e&15)>>>0){break t}w=b,x=Zf(a,k[b+810|0],j[b+768>>2],0),j[w+700>>2]=x}mb(g+8|0,q,92);u:{if(!kb(g+8|0)){break u}mb(g,q,5);if(kb(g)|j[a+1074416>>2]!=1|k[b+813|0]!=17){break u}j[a+1074420>>2]=p(k[b+815|0],1e4)}e=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);h[b+810|0]=e;h[b+811|0]=e>>>8;h[b+812|0]=e>>>16;h[b+813|0]=e>>>24;e=k[c+4|0]|k[c+5|0]<<8;h[b+814|0]=e;h[b+815|0]=e>>>8;e=j[b+676>>2];j[b+20>>2]=j[b+672>>2];j[b+24>>2]=e;j[b+88>>2]=j[b+88>>2]&-393217;mb(g+8|0,q,21);if(!kb(g+8|0)){h[b+851|0]=0}j[b+884>>2]=0;h[b+827|0]=0;c=c+6|0;b=b+896|0;if((u|0)!=(b|0)){continue}break}}Eoa(a);if(!r){break c}b=j[a+1074416>>2]+1|0;j[a+1074392>>2]=b;if(Yk(a)>>>0<=b>>>0){continue}break}}if(!j[a+1074416>>2]){j[a+1074416>>2]=1}b=j[a+480208>>2];v:{if(j[a+1074392>>2]){j[a+480208>>2]=b&-4097;if(j[a+480180>>2]&1048580|(k[a+480210|0]&32?0:j[a+480180>>2]==1)){break v}if(m[a+1074392>>2]>=Yk(a)>>>0|m[a+1074392>>2]%(j[a+1074400>>2]+j[a+1074416>>2]>>>0)){break v}j[a+480208>>2]=j[a+480208>>2]|4096;break v}j[a+480208>>2]=b&-528385|4096}a=Qoa(a);break a}a=0}Za=g+16|0;return a}function iHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,I=0;d=Za-1328|0;Za=d;rc(b);m=d+752|0;f=aHa(b,m);if(!f){xQ(m)}a:{b:{c:{if(!f){break c}if(!BQ(d+752|0)){break c}if(!yb(b,Wc(AQ(d+752|0),ab))){break c}if(!c){e=1;break c}v=Ys(d+744|0);w=1;d:{while(1){m=(e<<5)+a|0;f=m+480280|0;vg(f);n=(d+752|0)+(e<<4)|0;i[m+480284>>1]=((k[n+78|0]<<8&65280)>>>0)/255;dk(d+480|0,1,n- -64|0);qc(d+96|0,d+480|0);j[114626]=0;E(378,m+480289|0,d+96|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break b}gb(d+96|0);e:{f:{switch(k[n+79|0]){case 0:o=e+1|0;break e;case 1:j[f>>2]=1024;o=g+1|0;break e;case 2:break f;default:break d}}j[f>>2]=1024;rj(d+96|0,v,e);Qd(d+96|0,1)}w=e>>>0<31;g=g+1|0;e=e+1|0;if((e|0)!=32){continue}break}od(a,33554432);i[a+480188>>1]=o&255;e=Eb(d+96|0,13326);ob(a+1304436|0,e);gb(e);e=Eb(d+96|0,13340);ob(a+1304448|0,e);gb(e);j[a+1304496>>2]=4;g:{if(k[d+831|0]){break g}f=1;while(1){if(k[((f<<4)+d|0)+831|0]!=1){break g}e=1;f=f+1|0;if((f|0)!=16){continue}break}while(1){g=((e<<5)+a|0)+480280|0;j[g>>2]=j[g>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}ug(d+480|0,1,d+752|0);qc(d+96|0,d+480|0);ob(a+1304400|0,d+96|0);gb(d+96|0);j[a+480208>>2]=j[a+480208>>2]&-17|(k[d+790|0]|k[d+791|0]<<8)<<4&16;j[a+480196>>2]=k[d+800|0];j[a+480204>>2]=p(k[d+801|0],1e4);B=a,I=kd(k[d+802|0],0,64)<<2,j[B+480200>>2]=I;B=a,I=kd(k[d+803|0],4,127),j[B+480228>>2]=I;e=k[d+788|0]|k[d+789|0]<<8;i[a+480190>>1]=0;i[a+480192>>1]=e;Yz(b,d+480|0);At(Fb(a+484360|0),d+480|0,k[d+784|0]|k[d+785|0]<<8,65535,255);x=c&1;if(x){If(a+484344|0,k[d+786|0]|k[d+787|0]<<8)}if(k[d+786|0]|k[d+787|0]<<8){y=a+484344|0;o=0;while(1){e=Of(b);t=Of(b);cd(d+96|0,b,e-4|0);h:{if(!x){break h}j[114626]=0;e=K(402,y|0,o&65535,t|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){i:{if(!e){break h}r=0;s=bj(d+16|0);if(!t){break h}while(1){j:{j[114626]=0;m=H(387,d+96|0)|0;e=j[114626];j[114626]=0;k:{l:{if((e|0)!=1){if(m){break l}r=r+1|0;break k}break i}e=s;u=m&31;if(u>>>0<l[a+480188>>1]){e=Ib(y,o);j[114626]=0;e=K(471,e|0,r|0,u|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break i}}m:{if(!(m&32)){break m}j[114626]=0;F(472,d+32|0,d+96|0);f=j[114626];j[114626]=0;g=e;n:{o:{if((f|0)!=1){n=Pc(d+32|0);f=k[d+32|0];h[e|0]=f;h[e+1|0]=k[n|0];if((f|0)!=160){break o}f=255;break n}break i}if((f|0)!=255){h[e|0]=(p(f>>>4|0,12)+(f&15)|0)+13;j[114626]=0;n=H(615,e|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){f=0;if(!n){break n}break m}break i}f=0}h[g|0]=f}g=m&192;p:{if(!g){break p}if((g|0)==192){j[114626]=0;F(595,d+32|0,d+96|0);g=j[114626];j[114626]=0;q:{r:{s:{if((g|0)!=1){n=Pc(d+32|0);f=Bf(d+32|0);g=pi(d+32|0);q=d+32|0;A=k[q|0];if((A|0)!=12){break s}j[114626]=0;h[d+8|0]=64;m=E(391,n|0,d+8|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break i}h[e+4|0]=k[m|0];m=1;break r}break i}m=k[f|0];t:{if((m|0)==12){j[114626]=0;h[d+8|0]=64;g=E(391,g|0,d+8|0)|0;m=j[114626];j[114626]=0;if((m|0)!=1){h[e+4|0]=k[g|0];m=1;break t}break i}if((A|0)==10){h[e+4|0]=(k[n|0]<<6>>>0)/255;m=2;break r}if((m|0)!=10){break q}h[e+4|0]=(k[g|0]<<6>>>0)/255;m=2}f=q;g=n}h[e+2|0]=m;m=k[f|0]}h[e+3|0]=m;h[e+5|0]=k[g|0];break p}j[114626]=0;F(472,d+32|0,d+96|0);g=j[114626];j[114626]=0;if((g|0)==1){break i}g=Pc(d+32|0);h[e+3|0]=k[d+32|0];h[e+5|0]=k[g|0]}if(k[e+3|0]){j[114626]=0;N(616,e|0);g=j[114626];j[114626]=0;if((g|0)==1){break i}}rj(d+32|0,v,u);if(!kb(d+32|0)){break k}j[114626]=0;g=H(617,e|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break j}if(!g){break k}h[e+3|0]=0}if(r>>>0<t>>>0){continue}break h}break}}}e=D()|0;C()|0;jb(d+96|0);break a}jb(d+96|0);o=o+1|0;if(o>>>0<(k[d+786|0]|k[d+787|0]<<8)>>>0){continue}break}}if(!l[a+480192>>1]){break d}n=c&2;m=0;g=1;while(1){m=m+1|0;s=m&65535;c=sJ(a,s,0);if(!(!c|!cHa(b,d+96|0))){fHa(d+96|0,c,g&65535);e=0;u:{if(!(k[d+474|0]|k[d+475|0]<<8)){break u}while(1){v:{mp(b,d+32|0);w:{if((k[d+92|0]|k[d+93|0]<<8|(k[d+94|0]<<16|k[d+95|0]<<24))!=808538953){break w}f=e+g|0;c=f&65535;if(c>>>0>3999){break w}i[a+480190>>1]=f;f=p(c,104)+a|0;q=f+484380|0;eHa(d+32|0,q);nA(d+16|0,f+484423|0);j[114626]=0;E(369,((c<<5)+a|0)+946300|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break v}gb(d+16|0);if(!(k[d+48|0]|k[d+49|0]<<8|(k[d+50|0]<<16|k[d+51|0]<<24))){break w}cd(d+16|0,b,k[d+48|0]|k[d+49|0]<<8|(k[d+50|0]<<16|k[d+51|0]<<24));x:{if(!n){break x}c=Mc(d+8|0,i[f+484414>>1]&1?16:8,1,0,0);j[114626]=0;K(400,c|0,q|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break x}e=D()|0;C()|0;jb(d+16|0);break a}jb(d+16|0)}e=e+1|0;if(e>>>0<(k[d+474|0]|k[d+475|0]<<8)>>>0){continue}break u}break}e=D()|0;C()|0;gb(d+16|0);break a}g=(k[d+474|0]|k[d+475|0]<<8)+g|0}if(s>>>0<l[a+480192>>1]){continue}break}}e=w^1}Za=d+1328|0;return e&1}e=D()|0;C()|0;gb(d+96|0)}G(e|0);z()}function wv(a,b,c,d,e,f,g){var l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=Za-80|0;Za=l;j[l+76>>2]=b;B=l+55|0;y=l+56|0;b=0;a:{b:while(1){c:{if((w|0)<0){break c}if((2147483647-w|0)<(b|0)){j[114600]=61;w=-1;break c}w=b+w|0}d:{e:{f:{q=j[l+76>>2];b=q;m=k[b|0];if(m){while(1){g:{m=m&255;h:{if(!m){m=b;break h}if((m|0)!=37){break g}m=b;while(1){if(k[b+1|0]!=37){break h}n=b+2|0;j[l+76>>2]=n;m=m+1|0;r=k[b+2|0];b=n;if((r|0)==37){continue}break}}b=m-q|0;if(a){ve(a,q,b)}if(b){continue b}m=l;n=!Ig(h[j[l+76>>2]+1|0]);b=j[l+76>>2];i:{if(!(n|k[b+2|0]!=36)){x=h[b+1|0]-48|0;z=1;b=b+3|0;break i}x=-1;b=b+1|0}j[m+76>>2]=b;s=0;t=h[b|0];n=t-32|0;j:{if(n>>>0>31){m=b;break j}m=b;n=1<<n;if(!(n&75913)){break j}while(1){m=b+1|0;j[l+76>>2]=m;s=n|s;t=h[b+1|0];n=t-32|0;if(n>>>0>=32){break j}b=m;n=1<<n;if(n&75913){continue}break}}k:{if((t|0)==42){n=l;l:{m:{if(!Ig(h[m+1|0])){break m}b=j[l+76>>2];if(k[b+2|0]!=36){break m}j[((h[b+1|0]<<2)+e|0)-192>>2]=10;u=j[((h[b+1|0]<<3)+d|0)-384>>2];z=1;b=b+3|0;break l}if(z){break f}z=0;u=0;if(a){b=j[c>>2];j[c>>2]=b+4;u=j[b>>2]}b=j[l+76>>2]+1|0}j[n+76>>2]=b;if((u|0)>-1){break k}u=0-u|0;s=s|8192;break k}u=wE(l+76|0);if((u|0)<0){break f}b=j[l+76>>2]}r=-1;n:{if(k[b|0]!=46){break n}if(k[b+1|0]==42){o:{if(!Ig(h[b+2|0])){break o}b=j[l+76>>2];if(k[b+3|0]!=36){break o}j[((h[b+2|0]<<2)+e|0)-192>>2]=10;r=j[((h[b+2|0]<<3)+d|0)-384>>2];b=b+4|0;j[l+76>>2]=b;break n}if(z){break f}if(a){b=j[c>>2];j[c>>2]=b+4;b=j[b>>2]}else{b=0}r=b;b=j[l+76>>2]+2|0;j[l+76>>2]=b;break n}j[l+76>>2]=b+1;r=wE(l+76|0);b=j[l+76>>2]}m=0;while(1){A=m;v=-1;if(h[b|0]-65>>>0>57){break a}t=b+1|0;j[l+76>>2]=t;m=h[b|0];b=t;m=k[(m+p(A,58)|0)+55103|0];if(m-1>>>0<8){continue}break}p:{q:{if((m|0)!=19){if(!m){break a}if((x|0)>=0){j[(x<<2)+e>>2]=m;b=(x<<3)+d|0;m=j[b+4>>2];j[l+64>>2]=j[b>>2];j[l+68>>2]=m;break q}if(!a){break d}vE(l- -64|0,m,c,g);t=j[l+76>>2];break p}if((x|0)>-1){break a}}b=0;if(!a){continue b}}n=s&-65537;m=s&8192?n:s;v=0;x=55136;s=y;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{b=h[t-1|0];b=A?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break e;default:break G}}H:{switch(b-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break e;default:break H}}if((b|0)==83){break w}break e}b=j[l+64>>2];q=j[l+68>>2];n=55136;break z}b=0;I:{switch(A&255){case 0:j[j[l+64>>2]>>2]=w;continue b;case 1:j[j[l+64>>2]>>2]=w;continue b;case 2:m=j[l+64>>2];j[m>>2]=w;j[m+4>>2]=w>>31;continue b;case 3:i[j[l+64>>2]>>1]=w;continue b;case 4:h[j[l+64>>2]]=w;continue b;case 6:j[j[l+64>>2]>>2]=w;continue b;case 7:break I;default:continue b}}m=j[l+64>>2];j[m>>2]=w;j[m+4>>2]=w>>31;continue b}r=r>>>0>8?r:8;m=m|8;b=120}q=F4(j[l+64>>2],j[l+68>>2],y,b&32);if(!(m&8)|!(j[l+64>>2]|j[l+68>>2])){break y}x=(b>>>4|0)+55136|0;v=2;break y}q=E4(j[l+64>>2],j[l+68>>2],y);if(!(m&8)){break y}b=y-q|0;r=(b|0)<(r|0)?r:b+1|0;break y}n=j[l+68>>2];q=n;b=j[l+64>>2];if((n|0)<-1?1:(n|0)<=-1){q=0-(q+((b|0)!=0)|0)|0;b=0-b|0;j[l+64>>2]=b;j[l+68>>2]=q;v=1;n=55136;break z}if(m&2048){v=1;n=55137;break z}v=m&1;n=v?55138:55136}x=n;q=gm(b,q,y)}m=(r|0)>-1?m&-65537:m;b=j[l+68>>2];n=b;t=j[l+64>>2];if(!(!!(b|t)|r)){r=0;q=y;break e}b=!(n|t)+(y-q|0)|0;r=(b|0)<(r|0)?r:b;break e}b=j[l+64>>2];q=b?b:55146;b=Tq(q,0,r);s=b?b:r+q|0;m=n;r=b?b-q|0:r;break e}n=j[l+64>>2];if(r){break u}b=0;of(a,32,u,0,m);break t}j[l+12>>2]=0;j[l+8>>2]=j[l+64>>2];j[l+64>>2]=l+8;r=-1;n=l+8|0}b=0;J:{while(1){q=j[n>>2];if(!q){break J}q=zE(l+4|0,q);s=(q|0)<0;if(!(s|q>>>0>r-b>>>0)){n=n+4|0;b=b+q|0;if(r>>>0>b>>>0){continue}break J}break}v=-1;if(s){break a}}of(a,32,u,b,m);if(!b){b=0;break t}t=0;n=j[l+64>>2];while(1){q=j[n>>2];if(!q){break t}q=zE(l+4|0,q);t=q+t|0;if((t|0)>(b|0)){break t}ve(a,l+4|0,q);n=n+4|0;if(b>>>0>t>>>0){continue}break}}of(a,32,u,b,m^8192);b=(b|0)<(u|0)?u:b;continue b}b=bb[f|0](a,o[l+64>>3],u,r,m,b)|0;continue b}h[l+55|0]=j[l+64>>2];r=1;q=B;m=n;break e}n=b+1|0;j[l+76>>2]=n;m=k[b+1|0];b=n;continue}}v=w;if(a){break a}if(!z){break d}b=1;while(1){a=j[(b<<2)+e>>2];if(a){vE((b<<3)+d|0,a,c,g);v=1;b=b+1|0;if((b|0)!=10){continue}break a}break}v=1;if(b>>>0>=10){break a}while(1){if(j[(b<<2)+e>>2]){break f}b=b+1|0;if((b|0)!=10){continue}break}break a}v=-1;break a}s=s-q|0;r=(r|0)<(s|0)?s:r;n=r+v|0;b=(n|0)>(u|0)?n:u;of(a,32,b,n,m);ve(a,x,v);of(a,48,b,n,m^65536);of(a,48,r,s,0);ve(a,q,s);of(a,32,b,n,m^8192);continue}break}v=0}Za=l+80|0;return v}function xya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,J=0,M=0;d=Za-768|0;Za=d;rc(b);e=d+160|0;f=sya(b,e);if(!f){hN(e)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}if(!jN(d+160|0)){break n}if(!yb(b,Wc(iN(d+160|0),ab))){break n}if(!c){u=1;break n}od(a,262144);bt(d+104|0,2,d+160|0);qc(d+24|0,d+104|0);ob(a+1304400|0,d+24|0);gb(d+24|0);e=Eb(d+24|0,16992);ob(a+1304436|0,e);gb(e);e=Eb(d+24|0,17004);ob(a+1304448|0,e);gb(e);f=Eb(d+144|0,17008);j[114626]=0;F(219,d+104|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}h[d+8|0]=k[d+190|0];e=k[d+189|0];j[114626]=0;h[d+127|0]=e;F(989,d+128|0,d+127|0);e=j[114626];j[114626]=0;if((e|0)==1){break e}e=0;j[114626]=0;L(451,d+24|0,d+104|0,d+8|0,d+128|0);g=j[114626];j[114626]=0;if((g|0)==1){break f}ob(a+1304460|0,d+24|0);gb(d+24|0);gb(d+128|0);qb(d+104|0);gb(f);j[a+480208>>2]=12;j[a+1304496>>2]=4;i[a+480188>>1]=k[d+198|0]|k[d+199|0]<<8;i[d+24>>1]=k[d+194|0]|k[d+195|0]<<8;i[d+104>>1]=3999;J=a,M=l[gf(d+24|0,d+104|0)>>1],i[J+480190>>1]=M;mz(Fb(a+484360|0),d+256|0,k[d+192|0]|k[d+193|0]<<8,255,254);if(l[a+480188>>1]){while(1){f=(e<<5)+a|0;vg(f+480280|0);i[f+480284>>1]=(k[(d+e|0)+224|0]<<4|4)&244;e=e+1|0;if(e>>>0<l[a+480188>>1]){continue}break}}cd(d+104|0,b,p(k[d+194|0]|k[d+195|0]<<8,80));if(l[a+480190>>1]){g=c&2;o=d+72|0;e=0;while(1){j[114626]=0;E(990,d+104|0,d+24|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break m}j[114626]=0;I(577,d+8|0,2,o|0);f=j[114626];j[114626]=0;o:{p:{q:{if((f|0)==1){break q}j[114626]=0;F(415,d+128|0,d+8|0);f=j[114626];j[114626]=0;if((f|0)==1){break q}j[114626]=0;e=e+1|0;E(369,((e<<5)+a|0)+946300|0,d+128|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break p}gb(d+128|0);j[114626]=0;f=(p(e,104)+a|0)+484380|0;I(991,d+128|0,d+24|0,f|0);m=j[114626];j[114626]=0;r:{if((m|0)==1){break r}if(!g|!j[f>>2]){break o}m=k[d+42|0]|k[d+43|0]<<8|(k[d+44|0]<<16|k[d+45|0]<<24);j[114626]=0;m=E(256,b|0,m|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break r}if(!m){break o}j[114626]=0;K(400,d+128|0,f|0,b|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){break o}}a=D()|0;C()|0;break g}a=D()|0;C()|0;break g}a=D()|0;C()|0;gb(d+128|0);break g}if(l[a+480190>>1]>e>>>0){continue}break}}u=1;s:{if(!(c&1)){break s}c=k[d+196|0]|k[d+197|0]<<8;j[114626]=0;q=a+484344|0;F(401,q|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break l}if(!(k[d+196|0]|k[d+197|0]<<8)){break s}v=d+24|4;w=d+24|2;x=d+24|5;y=d+24|3;A=d+24|1;o=0;while(1){j[114626]=0;c=K(402,q|0,o&65535,64)|0;e=j[114626];j[114626]=0;if((e|0)==1){break k}t:{if(!c){break t}c=(o<<1)+d|0;e=c+512|0;if(!(k[e|0]|k[e+1|0]<<8)){break t}c=k[c+512|0]|k[c+513|0]<<8;j[114626]=0;c=E(256,b|0,c<<4)|0;e=j[114626];j[114626]=0;if((e|0)==1){break k}if(!c){break t}r=0;c=Ib(q,o);j[114626]=0;s=K(471,c|0,0,0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break h}while(1){j[114626]=0;c=E(258,b|0,1)|0;e=j[114626];j[114626]=0;u:{v:{w:{if((e|0)!=1){if(!c){break t}j[114626]=0;m=H(387,b|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break w}if(m){break v}r=r+1|0;s=p(l[a+480188>>1],6)+s|0;break u}a=D()|0;C()|0;break g}a=D()|0;C()|0;break g}i[d+28>>1]=0;j[d+24>>2]=0;c=m&31;f=p(c,6)+s|0;t=bj(d+24|0);g=c>>>0<l[a+480188>>1];x:{y:{z:{A:{B:{C:{D:{if(!(m&32)){break D}j[114626]=0;F(472,d+128|0,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break C}e=Pc(d+128|0);n=g?f:d+24|0;c=k[d+128|0];h[n|0]=c;h[(g?f+1|0:A)|0]=k[e|0];E:{if(c){if((c|0)==254){break E}if(c>>>0<121){break D}}c=0}h[n|0]=c}if(!(m&64)){break x}j[114626]=0;F(472,d+128|0,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break j}B=Pc(d+128|0);c=g?f+3|0:y;e=k[d+128|0];h[c|0]=e;n=g?f+5|0:x;h[n|0]=k[B|0];if(e>>>0>15){break B}j[114626]=0;N(574,(g?f:t)|0);e=j[114626];j[114626]=0;if((e|0)!=1){break A}a=D()|0;C()|0;break g}a=D()|0;C()|0;break g}if(e>>>0>23){break y}t=c;c=k[e+17010|0];h[t|0]=c;break z}c=k[c|0]}c=c&255;if((c|0)!=23){if((c|0)!=9){break x}c=k[n|0];F:{G:{if(c>>>0>=136){e=c&127;break G}e=128;if(c>>>0<129){break F}}h[n|0]=e;c=e}h[n|0]=(p(c&127,255)>>>0)/127;break x}j[114626]=0;h[d+8|0]=64;c=E(391,n|0,d+8|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){h[n|0]=k[c|0]<<1;break x}a=D()|0;C()|0;break g}h[c|0]=0}if(!(m&128)){break u}h[(g?f+2|0:w)|0]=1;j[114626]=0;c=H(387,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break i}h[(g?f+4|0:v)|0]=c}if(r>>>0<64){continue}break}}o=o+1|0;if(o>>>0<(k[d+196|0]|k[d+197|0]<<8)>>>0){continue}break}}jb(d+104|0)}Za=d+768|0;return u|0}a=D()|0;C()|0;break g}a=D()|0;C()|0;break g}a=D()|0;C()|0;break g}a=D()|0;C()|0;break g}a=D()|0;C()|0;break g}a=D()|0;C()|0}jb(d+104|0);break a}a=D()|0;C()|0;gb(d+128|0);break d}a=D()|0;C()|0}qb(d+104|0);break b}a=D()|0;C()|0}gb(f)}G(a|0);z()}function qLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,m=0,n=0,o=0,q=0,r=0;e=Za-128|0;Za=e;rc(b);a:{if(!hS(b,12168)){break a}if(!Uz(b,e+112|0)){break a}if(!jS(e+112|0)){break a}if(!yb(b,Wc(iS(e+112|0),ab))){break a}if(!Jb(b,k[e+121|0]|k[e+122|0]<<8)){break a}b:{if(!c){break b}od(a,4096);j[a+480208>>2]=12;i[a+480188>>1]=(k[e+112|2]&31)+1;f=e+112|3;i[a+480190>>1]=k[f|0];Oi(a,1);d=Eb(e+56|0,12176);ob(a+1304436|0,d);gb(d);d=Eb(e+56|0,12194);ob(a+1304448|0,d);gb(d);d=Eb(e+80|0,12198);j[114626]=0;F(219,e+96|0,d|0);g=j[114626];j[114626]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((g|0)!=1){j[114626]=0;L(427,e+56|0,e+96|0,e+112|1,e+112|0);g=j[114626];j[114626]=0;if((g|0)==1){break o}ob(a+1304460|0,e+56|0);gb(e+56|0);qb(e+96|0);gb(d);j[a+1304496>>2]=4;o=oLa(e+96|0,k[f|0]);if(l[a+480190>>1]){f=1;d=1;while(1){j[114626]=0;E(428,b|0,e+56|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break k}j[114626]=0;F(429,e+56|0,(p(f,104)+a|0)+484380|0);g=j[114626];j[114626]=0;if((g|0)==1){break k}g=k[e+72|0];Nd(e+40|0,o,f-1|0);Qd(e+40|0,(g&3)!=0);d=d+1|0;f=d&65535;if(f>>>0<=l[a+480190>>1]){continue}break}}j[114626]=0;K(430,b|0,a+1304400|0,-1)|0;f=j[114626];j[114626]=0;d=1;if((f|0)!=1){if(l[a+480190>>1]){while(1){j[114626]=0;K(431,b|0,(((d&65535)<<5)+a|0)+946300|0,-1)|0;f=j[114626];j[114626]=0;if((f|0)==1){break m}d=d+1|0;if(l[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(l[a+480188>>1]){d=0;while(1){j[114626]=0;f=(d<<5)+a|0;N(432,f+480280|0);g=j[114626];j[114626]=0;if((g|0)==1){break e}j[114626]=0;K(433,b|0,f+480289|0,-1)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}d=d+1|0;if(d>>>0<l[a+480188>>1]){continue}break}}f=e+112|4;d=k[f|0]|k[f+1|0]<<8;j[114626]=0;n=a+484344|0;F(401,n|0,d|0);d=j[114626];j[114626]=0;if((d|0)!=1){break l}}b=D()|0;C()|0;break d}b=D()|0;C()|0;break n}b=D()|0;C()|0;qb(e+96|0)}gb(d);break c}b=D()|0;C()|0;break d}if(k[f|0]|k[f+1|0]<<8){d=0;while(1){j[114626]=0;K(434,b|0,e+56|0,-1)|0;g=j[114626];j[114626]=0;p:{q:{if((g|0)==1){break q}j[114626]=0;g=K(402,n|0,d&65535,64)|0;h=j[114626];j[114626]=0;if((h|0)==1){break q}if(!g){break p}g=Ib(n,d);j[114626]=0;E(435,g|0,e+56|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){break p}}b=D()|0;C()|0;break d}d=d+1|0;if(d>>>0<(k[f|0]|k[f+1|0]<<8)>>>0){continue}break}}j[114626]=0;h=H(357,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}r:{if(!h){break r}j[114626]=0;d=E(258,b|0,h|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break f}if(!d){break r}g=Wt(e+56|0);j[114626]=0;K(436,b|0,g|0,h|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break h}d=Db(e+40|0);j[114626]=0;F(111,d|0,h|0);h=j[114626];j[114626]=0;if((h|0)==1){break i}q=e,r=Lb(g),j[q>>2]=r;q=e,r=Mb(g),j[q+32>>2]=r;if(rb(e,e+32|0)){while(1){s:{h=k[j[e>>2]];if(h&128){q=e,r=_e(d),j[q+16>>2]=r;Cd(e+24|0,e+16|0);j[114626]=0;P(437,d|0,j[e+24>>2],h&127,32)|0;h=j[114626];j[114626]=0;if((h|0)!=1){break s}break i}j[114626]=0;F(110,d|0,h<<24>>24);h=j[114626];j[114626]=0;if((h|0)!=1){break s}break i}Xf(e);if(rb(e,e+32|0)){continue}break}}j[114626]=0;L(438,e|0,4,5,d|0);h=j[114626];j[114626]=0;if((h|0)==1){break i}ob(d,e);gb(e);h=zb(d);j[114626]=0;h=H(439,h|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break i}m=nb(d);j[114626]=0;U(440,a+1304424|0,h|0,m|0,76,0)|0;h=j[114626];j[114626]=0;if((h|0)==1){break i}gb(d);Od(g)}d=Fb(a+484360|0);g=e+112|6;g=k[g|0]|k[g+1|0]<<8;j[114626]=0;U(441,d|0,b|0,g|0,65535,65535)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}t:{u:{v:{w:{if(!(k[f|0]|k[f+1|0]<<8)){break w}g=c&1;d=0;while(1){j[114626]=0;h=E(258,b|0,4)|0;m=j[114626];j[114626]=0;x:{if((m|0)!=1){if(h){break x}break w}b=D()|0;C()|0;break d}j[114626]=0;h=H(390,b|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break u}j[114626]=0;I(341,e+56|0,b|0,h|0);h=j[114626];j[114626]=0;if((h|0)==1){break t}y:{if(!g){break y}j[114626]=0;h=E(442,n|0,d&65535)|0;m=j[114626];j[114626]=0;if((m|0)==1){break v}if(!h){break y}h=Ib(n,d);j[114626]=0;I(443,h|0,0,e+56|0);h=j[114626];j[114626]=0;if((h|0)==1){break v}}jb(e+56|0);d=d+1|0;if(d>>>0<(k[f|0]|k[f+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!l[a+480190>>1])){f=1;d=1;while(1){c=p(f,104)+a|0;g=l[c+484414>>1];Nd(e+56|0,o,f-1|0);f=Mc(e+40|0,g&1?16:8,1,0,kb(e+56|0)?6:0);j[114626]=0;K(400,f|0,c+484380|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break j}d=d+1|0;f=d&65535;if(f>>>0<=l[a+480190>>1]){continue}break}}Vd(o);break b}b=D()|0;C()|0;jb(e+56|0);break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;gb(d);break g}b=D()|0;C()|0}Od(g);break d}b=D()|0;C()|0;break d}b=D()|0;C()|0}Vd(o)}G(b|0);z()}f=1}Za=e+128|0;return f|0}function $c(a,b,c,d,e,f,g,h,i){var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;m=Za-96|0;Za=m;q=c;w=(g&131071)<<15|f>>>17;k=i&65535;u=k;l=h;D=l<<15|g>>>17;o=(e^i)&-2147483648;p=e&65535;y=p;n=d;z=p;p=0;E=(k&131071)<<15|l>>>17;F=i>>>16&32767;M=e>>>16&32767;a:{b:{if(M-1>>>0<=32765){k=0;if(F-1>>>0<32766){break b}}r=e&2147483647;x=r;k=d;if(!(!k&(r|0)==2147418112?!(b|c):r>>>0<2147418112)){A=d;o=e|32768;break a}e=i&2147483647;r=e;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){A=h;o=i|32768;b=f;c=g;break a}if(!(b|k|(x^2147418112|c))){if(!(d|f|(g|r))){o=2147450880;b=0;c=0;break a}o=o|2147418112;b=0;c=0;break a}if(!(d|f|(r^2147418112|g))){d=b|k;e=c|x;b=0;c=0;if(!(d|e)){o=2147450880;break a}o=o|2147418112;break a}if(!(b|k|(c|x))){b=0;c=0;break a}if(!(d|f|(g|r))){b=0;c=0;break a}if((x|0)==65535|x>>>0<65535){h=b;i=c;d=!(n|y);e=d<<6;k=s(d?b:n)+32|0;b=s(d?c:y);b=e+((b|0)==32?k:b)|0;We(m+80|0,h,i,n,y,b-15|0);n=j[m+88>>2];q=j[m+84>>2];z=j[m+92>>2];v=16-b|0;b=j[m+80>>2]}k=v;if(r>>>0>65535){break b}c=!(l|u);d=c<<6;e=s(c?f:l)+32|0;c=s(c?g:u);c=d+((c|0)==32?e:c)|0;i=c;We(m- -64|0,f,g,l,u,c-15|0);e=j[m+76>>2];c=e;h=j[m+72>>2];d=h;d=d<<15;e=j[m+68>>2];D=e>>>17|d;d=0;f=j[m+64>>2];w=d|((e&131071)<<15|f>>>17);E=(c&131071)<<15|h>>>17;k=(v-i|0)+16|0}v=k;d=w;c=b;u=0;r=OMa(d,0,b,u);b=ab;G=b;e=f;B=e<<15&-32768;l=q;g=OMa(B,0,l,0);f=g+r|0;e=ab+b|0;e=f>>>0<g>>>0?e+1|0:e;h=f;k=f;i=0;g=OMa(c,u,B,C);f=i+g|0;b=k;k=k+ab|0;k=f>>>0<g>>>0?k+1|0:k;w=f;g=k;J=(b|0)==(k|0)&f>>>0<i>>>0|b>>>0>k>>>0;N=OMa(d,t,l,H);K=ab;q=n;f=OMa(B,C,n,0);b=f+N|0;k=ab+K|0;O=b;n=OMa(D,0,c,u);i=b+n|0;b=b>>>0<f>>>0?k+1|0:k;f=b+ab|0;x=i;f=i>>>0<n>>>0?f+1|0:f;y=f;k=f;f=(e|0)==(G|0)&h>>>0<r>>>0|e>>>0<G>>>0;h=e+x|0;k=f+k|0;r=h;k=h>>>0<e>>>0?k+1|0:k;n=k;e=h;h=k;Q=OMa(d,t,q,P);G=ab;f=B;I=z|65536;B=p;i=OMa(f,C,I,p);f=i+Q|0;k=ab+G|0;k=f>>>0<i>>>0?k+1|0:k;R=f;C=OMa(D,S,l,H);i=f+C|0;p=k;f=k+ab|0;f=i>>>0<C>>>0?f+1|0:f;L=i;E=E&2147483647|-2147483648;i=OMa(c,u,E,0);c=L+i|0;u=f;k=f+ab|0;C=c;c=c>>>0<i>>>0?k+1|0:k;z=J;i=0;f=i+e|0;k=h+C|0;J=f;h=f;e=z+f|0;z=f>>>0<i>>>0?k+1|0:k;f=z;f=e>>>0<h>>>0?f+1|0:f;h=e;i=f;v=(v+(F+M|0)|0)-16383|0;f=OMa(q,P,D,S);e=ab;t=OMa(d,t,I,B);d=t+f|0;k=ab+e|0;k=d>>>0<t>>>0?k+1|0:k;t=d;f=(e|0)==(k|0)&f>>>0>d>>>0|e>>>0>k>>>0;e=k;F=f;f=OMa(E,T,l,H);d=f+d|0;k=ab+k|0;k=d>>>0<f>>>0?k+1|0:k;f=d;d=k;l=(k|0)==(e|0)&f>>>0<t>>>0|e>>>0>k>>>0;k=F+l|0;e=0;e=k>>>0<l>>>0?1:e;t=f;l=d;F=k;f=(b|0)==(y|0)&x>>>0<O>>>0|b>>>0>y>>>0;b=f+((b|0)==(K|0)&N>>>0>O>>>0|b>>>0<K>>>0)|0;k=0;k=b>>>0<f>>>0?1:k;f=b;b=t+f|0;k=d+k|0;k=b>>>0<f>>>0?k+1|0:k;H=b;d=k;k=(k|0)==(l|0)&b>>>0<t>>>0|k>>>0<l>>>0;b=F+k|0;f=e;f=b>>>0<k>>>0?f+1|0:f;e=OMa(E,T,I,B);b=e+b|0;k=ab+f|0;t=b;e=b>>>0<e>>>0?k+1|0:k;l=OMa(E,T,q,P);f=ab;q=OMa(D,S,I,B);b=q+l|0;k=ab+f|0;k=b>>>0<q>>>0?k+1|0:k;q=b;b=k;k=(f|0)==(k|0)&l>>>0>q>>>0|f>>>0>k>>>0;l=b+t|0;e=e+k|0;e=l>>>0<b>>>0?e+1|0:e;t=l;l=0;b=l+H|0;k=d+q|0;k=b>>>0<l>>>0?k+1|0:k;f=k;l=(d|0)==(k|0)&b>>>0<H>>>0|d>>>0>k>>>0;d=t+l|0;k=e;D=d;d=d>>>0<l>>>0?k+1|0:k;q=b;l=f;f=(p|0)==(u|0)&R>>>0>L>>>0|p>>>0>u>>>0;e=f+((p|0)==(G|0)&Q>>>0>R>>>0|p>>>0<G>>>0)|0;f=e;e=f+((c|0)==(u|0)&C>>>0<L>>>0|c>>>0<u>>>0)|0;f=e;b=c+b|0;e=f+l|0;e=b>>>0<c>>>0?e+1|0:e;p=b;c=b;b=e;e=(e|0)==(l|0)&c>>>0<q>>>0|e>>>0<l>>>0;c=e+D|0;k=d;k=c>>>0<e>>>0?k+1|0:k;d=c;l=d;e=(n|0)==(z|0)&r>>>0>J>>>0|n>>>0>z>>>0;d=e+((n|0)==(y|0)&r>>>0<x>>>0|n>>>0<y>>>0)|0;f=0;f=d>>>0<e>>>0?1:f;n=d;d=d+p|0;e=b+f|0;e=d>>>0<n>>>0?e+1|0:e;c=(b|0)==(e|0)&d>>>0<p>>>0|b>>>0>e>>>0;b=l+c|0;k=b>>>0<c>>>0?k+1|0:k;c=k;c:{if(k&65536){v=v+1|0;break c}n=g>>>31|0;k=c<<1|b>>>31;b=b<<1|e>>>31;c=k;k=e<<1|d>>>31;d=d<<1|i>>>31;e=k;p=w;k=g<<1|p>>>31;w=p<<1;g=k;k=i<<1|h>>>31;h=h<<1|n;i=k}if((v|0)>=32767){o=o|2147418112;b=0;c=0;break a}d:{if((v|0)<=0){f=1-v|0;if(f>>>0>=128){b=0;c=0;break a}k=v+127|0;We(m+48|0,w,g,h,i,k);We(m+32|0,d,e,b,c,k);fm(m+16|0,w,g,h,i,f);fm(m,d,e,b,c,f);w=(j[m+48>>2]|j[m+56>>2])!=0|(j[m+52>>2]|j[m+60>>2])!=0|(j[m+32>>2]|j[m+16>>2]);g=j[m+36>>2]|j[m+20>>2];h=j[m+40>>2]|j[m+24>>2];i=j[m+44>>2]|j[m+28>>2];d=j[m>>2];e=j[m+4>>2];c=j[m+12>>2];b=j[m+8>>2];break d}c=c&65535|v<<16}A=b|A;o=c|o;if(!(!h&(i|0)==-2147483648?!(g|w):(i|0)>-1)){k=e;b=d+1|0;k=b>>>0<1?k+1|0:k;f=b;c=k;f=(e|0)==(k|0)&d>>>0>f>>>0|e>>>0>k>>>0;d=f+A|0;e=o;A=d;o=d>>>0<f>>>0?e+1|0:e;break a}if(h|w|(i^-2147483648|g)){b=d;c=e;break a}c=d&1;b=c+d|0;k=e;k=b>>>0<c>>>0?k+1|0:k;f=b;c=k;e=(e|0)==(k|0)&d>>>0>f>>>0|e>>>0>k>>>0;d=e+A|0;k=o;A=d;o=d>>>0<e>>>0?k+1|0:k}j[a>>2]=b;j[a+4>>2]=c;j[a+8>>2]=A;j[a+12>>2]=o;Za=m+96|0}function Ena(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,m=0,n=0,o=0,q=0;f=Za-208|0;Za=f;i[a+480212>>1]=0;j[a+480240>>2]=65536;j[a+480244>>2]=65536;KJ(a+900380|0);JJ(a+946300|0);d=MJ(f+48|0);j[114626]=0;e=a+906300|0;I(1402,e|0,e+4e4|0,d|0);e=j[114626];j[114626]=0;a:{b:{c:{d:{if((e|0)!=1){ym(d);e:{if(Sp(b)){e=0;m=f+48|0;yna(m);f:{g:{h:{if(c&16){break h}j[114626]=0;g=(c|0)!=0;h=K(1403,m|0,b|0,g|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}d=4;i:{if(h){break i}j[114626]=0;h=K(1404,m|0,b|0,g|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}d=5;if(h){break i}j[114626]=0;h=K(1405,m|0,b|0,g|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}d=6;if(h){break i}h=0;j[114626]=0;g=K(1406,m|0,b|0,g|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}d=3;if(!g){break h}}if(!c){e=1;break b}if(!ad(m)){rO(b,$z(m,0)+12|0)}h=d}if(c&32){break b}d=77936;j:{k:{while(1){g=j[d+8>>2];n=(g>>1)+a|0;e=j[d+4>>2];e=g&1?j[j[n>>2]+e>>2]:e;j[114626]=0;e=K(e|0,n|0,b|0,c|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){if(e){break j}d=d+12|0;if((d|0)==78392){break k}continue}break}a=J(71396)|0;break f}j[a+480180>>2]=0;j[a+480184>>2]=0}if(!c){break b}if(!(j[a+480184>>2]|!h)){j[a+480184>>2]=h}hx(m);break e}a=J(71396)|0}b=C()|0;hx(m);if((W(71396)|0)!=(b|0)){break c}O(a|0)|0;j[114626]=0;M(81);a=j[114626];j[114626]=0;if((a|0)==1){a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){break c}a=J(0)|0;C()|0;ib(a)}z()}od(a,0);j[a+1074300>>2]=19465728}d=0;while(1){b=(d<<5)+a|0;Sf(b+480286|0,64);b=b+480284|0;if(l[b>>1]>=257){i[b>>1]=128}Pm((p(d,896)+a|0)+1074984|0,a,d&65535);d=d+1|0;if((d|0)!=127){continue}break}if(l[a+480190>>1]){h=a+1304392|0;d=1;while(1){g=p(d&65535,104)+a|0;n=g+484380|0;l:{if(ke(n)){Sx(n,a,0);break l}e=g+484414|0;b=l[e>>1];if(b&16384){break l}j[n>>2]=0;j[n+4>>2]=0;j[n+16>>2]=0;j[n+8>>2]=0;j[n+12>>2]=0;i[e>>1]=b&65505}b=g+484412|0;if(l[b>>1]>=65){i[b>>1]=64}m:{if(!(k[g+484415|0]&2)){break m}if(!Ti(h)){break m}Cna(a)}d=d+1|0;if(l[a+480190>>1]>=(d&65535)>>>0){continue}break}}d=0;e=0;while(1){b=j[(((d&65535)<<2)+a|0)+900380>>2];if(b){Tta(b,j[a+480180>>2]);e=d}d=d+1|0;if(l[a+480192>>1]>=(d&65535)>>>0){continue}break}i[a+480192>>1]=e;d=j[a+480204>>2];if(d>>>0<1e4){j[a+480204>>2]=125e4;d=125e4}h=j[a+480196>>2];if(!h){j[a+480196>>2]=6;h=6}e=j[a+480220>>2];b=j[a+480216>>2];if(e>>>0<b>>>0){j[a+480220>>2]=b;e=b}j[a+1074420>>2]=d;d=a+1074416|0;j[d>>2]=h;j[a+1074412>>2]=e;j[a+1074408>>2]=b;j[a+1074444>>2]=j[a+480200>>2];wx(a+1074376|0);j[a+1074440>>2]=-65536;b=a+1074384|0;j[b>>2]=0;j[b+4>>2]=0;j[a+1074380>>2]=0;b=a+1074424|0;j[b>>2]=0;j[b+4>>2]=0;b=a+1074432|0;j[b>>2]=0;j[b+4>>2]=0;b=a+1074396|0;j[b>>2]=0;j[b+4>>2]=0;i[a+480276>>1]=0;j[a+1074392>>2]=j[d>>2];qo(a);Si(a+1304360|0,1);b=a+484360|0;o=f,q=Lb(b),j[o+48>>2]=q;o=f,q=Mb(b),j[o+32>>2]=q;if(!rb(f+48|0,f+32|0)){break d}while(1){e=j[f+48>>2];bg(e,Ui(e));b=l[e+28>>1];if(bc(e)>>>0<=b>>>0){Ge(e,0)}Qx(f+48|0);if(rb(f+48|0,f+32|0)){continue}break}break d}a=D()|0;C()|0;ym(d);break c}g=f+48|0;wna(g);n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c&12)==12){d=0;while(1){c=p(d,160)+a|0;h=c+906300|0;b=h+16|0;e=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);b=h+20|0;w:{if(!(e|(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24)))){break w}j[114626]=0;E(1407,h|0,a|0)|0;b=j[114626];j[114626]=0;x:{if((b|0)!=1){e=j[h>>2];if(!e){break x}c=j[c+906448>>2];b=j[j[e>>2]+56>>2];j[114626]=0;F(b|0,e|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){break w}}a=D()|0;C()|0;break n}o=f,q=Bna(Lb(g),Mb(g),h),j[o+32>>2]=q;o=f,q=Mb(g),j[o+16>>2]=q;if(rb(f+32|0,f+16|0)){break w}j[114626]=0;j[f+32>>2]=c+906316;F(1408,g|0,f+32|0);b=j[114626];j[114626]=0;if((b|0)==1){break o}j[114626]=0;c=E(2,f+16|0,20526)|0;b=j[114626];j[114626]=0;if((b|0)==1){break v}b=BJ(h);j[114626]=0;I(6,f|0,0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break u}j[114626]=0;I(3,f+32|0,c|0,f|0);b=j[114626];j[114626]=0;if((b|0)==1){break t}j[114626]=0;I(647,a|0,2,f+32|0);b=j[114626];j[114626]=0;if((b|0)==1){break s}gb(f+32|0);gb(f);gb(c)}d=d+1|0;if((d|0)!=250){continue}break}}b=j[a+1074368>>2];j[114626]=0;F(1409,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break p}b=j[a+480180>>2];y:{if(!b){break y}Kr(a+8|0,to(a));if(!j[a+1074304>>2]){break y}j[114626]=0;N(1410,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break p}}AJ(g);e=(b|0)!=0;break a}a=D()|0;C()|0;break n}a=D()|0;C()|0;break q}a=D()|0;C()|0;break r}a=D()|0;C()|0;gb(f+32|0)}gb(f)}gb(c);break n}a=D()|0;C()|0;break n}a=D()|0;C()|0}AJ(g)}G(a|0);z()}hx(m)}Za=f+208|0;return e|0}function u5(a,b,c,d,e,f,g){var m=0,o=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0,B=0,C=q(0),D=0,E=0,F=0,G=q(0),H=0,I=0,J=0,K=0,L=q(0),M=0,N=0,O=0,P=0;u=Za-2368|0;Za=u;A=j[a+404>>2];D=k[c+1|0];H=A+p(D,40)|0;I=j[((k[c|0]<<2)+a|0)+104>>2];a:{t=j[a+4>>2];b:{if((t|0)>=1){while(1){m=k[(j[H+4>>2]+p(B,3)|0)+2|0];K=(u+1344|0)+(B<<2)|0;j[K>>2]=0;m=k[(m+H|0)+9|0];if(!l[((m<<1)+a|0)+132>>1]){Nb(a,21);a=0;break b}o=j[a+260>>2];c:{d:{if(Tb(a,1)){s=2;v=j[((B<<2)+a|0)+996>>2];t=o+p(m,1596)|0;J=j[(k[t+1588|0]<<2)+50668>>2];m=Nk(J)-1|0;O=v,P=Tb(a,m),i[O>>1]=P;O=v,P=Tb(a,m),i[O+2>>1]=P;w=0;if(k[t|0]){while(1){M=k[(t+w|0)+1|0];m=t+M|0;y=k[m+33|0];o=0;E=k[m+49|0];e:{if(!E){break e}m=j[a+124>>2]+p(k[m+65|0],2096)|0;if(j[a+1396>>2]<=9){Dj(a)}r=j[a+1392>>2];o=i[(m+((r&1023)<<1)|0)+36>>1];f:{if((o|0)>=0){x=r;r=k[o+j[m+8>>2]|0];j[a+1392>>2]=x>>>r;x=j[a+1396>>2]-r|0;r=(x|0)<0;j[a+1396>>2]=r?0:x;o=r?-1:o;break f}o=Mk(a,m)}if(!k[m+23|0]){break e}o=j[j[m+2088>>2]+(o<<2)>>2]}if(y){N=-1<<E^-1;y=s+y|0;while(1){m=0;r=i[((t+(M<<4)|0)+((o&N)<<1)|0)+82>>1];g:{if((r|0)<0){break g}r=j[a+124>>2]+p(r&65535,2096)|0;if(j[a+1396>>2]<=9){Dj(a)}x=j[a+1392>>2];m=i[(r+((x&1023)<<1)|0)+36>>1];h:{if((m|0)>=0){F=x;x=k[m+j[r+8>>2]|0];j[a+1392>>2]=F>>>x;F=j[a+1396>>2]-x|0;x=(F|0)<0;j[a+1396>>2]=x?0:F;m=x?-1:m;break h}m=Mk(a,r)}if(!k[r+23|0]){break g}m=j[j[r+2088>>2]+(m<<2)>>2]}o=o>>E;i[v+(s<<1)>>1]=m;s=s+1|0;if((y|0)!=(s|0)){continue}break}s=y}w=w+1|0;if(w>>>0<k[t|0]){continue}break}}if(j[a+1396>>2]!=-1){break d}}j[K>>2]=1;break c}i[u+320>>1]=257;y=t+1592|0;s=j[t+1592>>2];if((s|0)>=3){o=2;while(1){s=o<<1;w=s+t|0;E=k[w+1088|0];m=E<<1;r=t+338|0;F=l[s+r>>1];K=l[m+r>>1];x=r;w=k[w+1089|0];r=w<<1;m=g5(F,K,l[x+r>>1],i[m+v>>1],i[r+v>>1]);x=s+v|0;r=l[x>>1];i:{j:{if(r){h[w+(u+320|0)|0]=1;h[E+(u+320|0)|0]=1;h[(u+320|0)+o|0]=1;s=r<<16>>16;w=J-m|0;if((s|0)>=((m|0)>(w|0)?w:m)<<1){if((m|0)<(w|0)){break i}m=(r^-1)+J|0;break j}if(s&1){m=m-(s+1>>>1|0)|0;break j}m=(s>>1)+m|0;break j}h[(u+320|0)+o|0]=0}i[x>>1]=m}s=j[y>>2];o=o+1|0;if((s|0)>(o|0)){continue}break}}m=0;if((s|0)<=0){break c}while(1){if(!k[(u+320|0)+m|0]){i[v+(m<<1)>>1]=65535;s=j[y>>2]}m=m+1|0;if((s|0)>(m|0)){continue}break}}t=j[a+4>>2];B=B+1|0;if((t|0)>(B|0)){continue}break}}k:{l:{o=j[a+80>>2];if(!(j[a+84>>2]!=j[a+92>>2]?o:0)){Vb(u+320|0,u+1344|0,t<<2);m=l[H>>1];if(m){y=m>>>0>1?m:1;v=j[(A+p(D,40)|0)+4>>2];m=0;while(1){r=v+p(m,3)|0;s=k[r+1|0];r=(u+1344|0)+(k[r|0]<<2)|0;if(!(j[(u+1344|0)+(s<<2)>>2]?j[r>>2]:0)){j[(u+1344|0)+(s<<2)>>2]=0;j[r>>2]=0}m=m+1|0;if((y|0)!=(m|0)){continue}break}}y=I>>1;v=A+p(D,40)|0;if(k[v+8|0]){s=0;while(1){o=0;if((t|0)>=1){w=j[v+4>>2];m=0;while(1){if(k[(w+p(m,3)|0)+2|0]==(s|0)){J=o+u|0;r=m<<2;m:{if(j[r+(u+1344|0)>>2]){B=1;r=0;break m}B=0;r=j[(a+r|0)+800>>2]}h[J|0]=B;j[(u+256|0)+(o<<2)>>2]=r;o=o+1|0}m=m+1|0;if((t|0)>(m|0)){continue}break}}f5(a,u+256|0,o,y,k[(s+v|0)+24|0],u);s=s+1|0;if(s>>>0<k[v+8|0]){t=j[a+4>>2];continue}break}o=j[a+80>>2]}if(!(j[a+84>>2]!=j[a+92>>2]?o:0)){o=l[H>>1];if(o){v=(y|0)>1?y:1;r=A+p(D,40)|0;t=a+800|0;while(1){s=o;o=o-1|0;if((I|0)>=2){m=j[r+4>>2]+p(o,3)|0;B=j[t+(k[m+1|0]<<2)>>2];D=j[t+(k[m|0]<<2)>>2];m=0;while(1){A=m<<2;w=A+B|0;G=n[w>>2];A=A+D|0;C=n[A>>2];n:{if(!(C<=q(0))){if(!(G<=q(0))){L=q(C-G);break n}L=C;C=q(G+C);break n}if(!(G<=q(0))){L=q(G+C);break n}L=C;C=q(C-G)}n[A>>2]=C;n[w>>2]=L;m=m+1|0;if((v|0)!=(m|0)){continue}break}}if((s|0)>1){continue}break}}if(j[a+4>>2]<1){break k}s=y<<2;m=0;while(1){t=m<<2;v=t+a|0;o=v;o:{if(j[t+(u+320|0)>>2]){Ab(j[o+800>>2],0,s);break o}e5(a,H,m,I,j[o+800>>2],j[v+996>>2])}m=m+1|0;o=j[a+4>>2];if((m|0)<(o|0)){continue}break}break l}X(50440,50496,3319,50688);z()}X(50440,50496,3286,50688);z()}m=0;if((o|0)<=0){break k}while(1){d5(j[((m<<2)+a|0)+800>>2],I,a,k[c|0]);m=m+1|0;if((m|0)<j[a+4>>2]){continue}break}}OE(a);p:{if(k[a+1377|0]){j[a+1060>>2]=0-y;h[a+1377|0]=0;j[a+1064>>2]=1;j[a+1412>>2]=I-f;break p}c=j[a+1412>>2];if(!c){break p}m=e-d|0;if((m|0)<=(c|0)){j[a+1412>>2]=c-m;j[g>>2]=e;d=e;break p}d=c+d|0;j[g>>2]=d;j[a+1412>>2]=0}c=j[a+1064>>2];q:{r:{s:{if(j[a+1388>>2]==j[a+1404>>2]){t:{if(!c|!(k[a+1375|0]&4)){break t}c=j[a+1408>>2];g=j[a+1060>>2];if(c>>>0>=g+(f-d|0)>>>0){break t}e=b;b=c-g|0;b=(b>>>0>c>>>0?0:b)+d|0;b=(b|0)>(f|0)?f:b;j[e>>2]=b;j[a+1060>>2]=b+j[a+1060>>2];break q}j[a+1064>>2]=1;j[a+1060>>2]=j[a+1408>>2]+(d-y|0);break s}if(!c){break r}}j[a+1060>>2]=j[a+1060>>2]+(e-d|0)}if(j[a+84>>2]!=j[a+92>>2]?j[a+80>>2]:0){break a}j[b>>2]=f}a=1}Za=u+2368|0;return a}X(50440,50496,3435,50688);z()}function aAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=Za-80|0;Za=e;rc(b);a:{b:{c:{d:{e:{if(VN(b,16628)){g=kp(e- -64|0);h=kp(e+48|0);q=Bs(e+32|0);j[114626]=0;F(447,a|0,32768);d=j[114626];j[114626]=0;if((d|0)==1){break b}j[114626]=0;d=E(2,e+8|0,16637)|0;m=j[114626];j[114626]=0;if((m|0)==1){break c}ob(a+1304436|0,d);gb(d);j[114626]=0;d=E(2,e+8|0,16647)|0;m=j[114626];j[114626]=0;if((m|0)==1){break d}ob(a+1304448|0,d);gb(d);j[a+1304496>>2]=2;n=a+484360|0;m=e+24|4;f:{g:{h:{i:{j:{while(1){j[114626]=0;d=E(258,b|0,8)|0;f=j[114626];j[114626]=0;if((f|0)==1){break i}k:{l:{m:{n:{if(!d){break n}j[114626]=0;d=E(923,b|0,e+24|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break m}if(!d){break n}d=m;d=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);j[114626]=0;I(341,e+8|0,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24));d=j[114626];j[114626]=0;if((d|0)==1){break l}j[114626]=0;d=H(337,e+8|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}if(d){break k}jb(e+8|0)}if(l[a+480188>>1]){break j}d=0;break f}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}o:{p:{q:{r:{s:{t:{d=e+24|0;d=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);if((d|0)<=1347175757){if((d|0)==1129140036){break t}if((d|0)==1346458708){break r}if((d|0)!=1346522948){break p}if(Xc(g)>>>0>255){break p}j[114626]=0;F(601,g|0,e+8|0);d=j[114626];j[114626]=0;if((d|0)==1){break e}break p}if((d|0)<=1396854595){if((d|0)==1347175758){break s}if(l[a+480190>>1]|(d|0)!=1396788560){break p}j[114626]=0;I(924,e+8|0,q|0,a|0);d=j[114626];j[114626]=0;if((d|0)==1){break e}break p}if((d|0)==1396854596){break q}if((d|0)!=1397769541){break p}j[114626]=0;d=H(255,e+8|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}if(d>>>0<2){break p}j[114626]=0;d=H(484,e+8|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}t=a,u=kd(d,1,255),j[t+480196>>2]=u;break p}if(l[a+480188>>1]){break p}j[114626]=0;d=H(255,e+8|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}f=0;if(d>>>0<8){break p}while(1){j[114626]=0;o=H(387,e+8|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break o}j[114626]=0;r=H(387,e+8|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}d=l[a+480188>>1];if(o|r){j[114626]=0;N(432,((d<<5)+a|0)+480280|0);d=j[114626];j[114626]=0;if((d|0)==1){break e}o=l[a+480188>>1];d=o+1|0;i[a+480188>>1]=d;i[((o<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64}j[114626]=0;N(432,(((d&65535)<<5)+a|0)+480280|0);d=j[114626];j[114626]=0;if((d|0)==1){break e}d=l[a+480188>>1];i[a+480188>>1]=d+1;i[((d<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64;f=f+1|0;if((f|0)!=4){continue}break}if(c){break p}jb(e+8|0);break g}j[114626]=0;d=H(255,e+8|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}if(d>>>0<2){break p}j[114626]=0;s=H(484,e+8|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}break p}d=Fb(n);j[114626]=0;f=H(255,e+8|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break e}j[114626]=0;U(581,d|0,e+8|0,f|0,255,254)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break p}break e}if(Xc(h)>>>0>3998){break p}j[114626]=0;d=H(255,e+8|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}if(!d){break p}j[114626]=0;F(601,h|0,e+8|0);d=j[114626];j[114626]=0;if((d|0)==1){break e}}jb(e+8|0);continue}break}break e}j[a+480200>>2]=256;j[a+480204>>2]=125e4;j[a+480260>>2]=452;j[a+480264>>2]=3424;j[a+480228>>2]=48;j[a+480232>>2]=48;b=Fb(n);j[114626]=0;F(925,b|0,s&65535);b=j[114626];j[114626]=0;if((b|0)==1){break b}u:{if(!(c&1)){break u}d=0;b=Xc(g);j[114626]=0;F(401,a+484344|0,b&65535);b=j[114626];j[114626]=0;if((b|0)==1){break b}if(!Xc(g)){break u}b=0;while(1){d=_b(g,d);j[114626]=0;I(926,d|0,b&65535,a|0);d=j[114626];j[114626]=0;if((d|0)==1){break h}b=b+1|0;d=b&65535;if(Xc(g)>>>0>d>>>0){continue}break}}d=1;if(l[a+480190>>1]<2){break f}m=c&2;f=1;b=0;v:{while(1){if(!m|Xc(h)>>>0<=b>>>0){break g}w:{c=(p(f,104)+a|0)+484380|0;if(j[c>>2]){d=_b(h,b);j[114626]=0;d=H(255,d|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break w}kc(c,d);Nd(e+8|0,q,f-1|0);d=Mc(e+24|0,8,1,1,kb(e+8|0)?10:0);n=_b(h,b);j[114626]=0;K(400,d|0,c|0,n|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break v}b=b+1|0}d=1;f=f+1|0;if(f>>>0<l[a+480190>>1]){continue}break f}break}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}d=1}Vd(q);Sc(h);Sc(g)}Za=e+80|0;return d|0}a=D()|0;C()|0;jb(e+8|0);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0}Vd(q);Sc(h);Sc(g);G(a|0);z()}function iW(a,b){var c=0,d=0,e=0,f=0;c=Za-176|0;Za=c;f=Av(c+160|0);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{d=j[b>>2];if(d&1){j[114626]=0;j[c+144>>2]=19465728;F(242,c+96|0,c+144|0);d=j[114626];j[114626]=0;if((d|0)==1){break o}j[114626]=0;F(201,f|0,c+96|0);d=j[114626];j[114626]=0;if((d|0)==1){break n}gb(c+96|0);d=j[b>>2]}if(!(d&4)){break l}j[114626]=0;d=T(243)|0;e=j[114626];j[114626]=0;if((e|0)==1){break k}if(!d){break m}break l}b=D()|0;C()|0;break a}b=D()|0;C()|0;gb(c+96|0);break a}j[114626]=0;N(244,c+96|0);d=j[114626];j[114626]=0;p:{if((d|0)!=1){j[114626]=0;F(201,f|0,c+96|0);d=j[114626];j[114626]=0;if((d|0)==1){break p}gb(c+96|0);break l}b=D()|0;C()|0;break a}b=D()|0;C()|0;gb(c+96|0);break a}q:{d=j[b>>2];if(!(d&8)){break q}j[114626]=0;d=E(2,c+128|0,7142)|0;e=j[114626];j[114626]=0;r:{s:{t:{u:{v:{if((e|0)!=1){j[114626]=0;F(219,c+144|0,d|0);e=j[114626];j[114626]=0;if((e|0)==1){break v}j[114626]=0;I(245,c+96|0,c+144|0,7152);e=j[114626];j[114626]=0;if((e|0)==1){break u}j[114626]=0;F(201,f|0,c+96|0);e=j[114626];j[114626]=0;if((e|0)==1){break t}gb(c+96|0);qb(c+144|0);gb(d);d=j[b>>2];break q}b=D()|0;C()|0;break a}b=D()|0;C()|0;break r}b=D()|0;C()|0;break s}b=D()|0;C()|0;gb(c+96|0)}qb(c+144|0)}gb(d);break a}w:{if(!(d&16)){break w}j[114626]=0;N(236,c+96|0);d=j[114626];j[114626]=0;x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{if((d|0)!=1){j[114626]=0;F(246,c+144|0,c+96|0);d=j[114626];j[114626]=0;if((d|0)==1){break y}d=Ec(c+144|0);gb(c+144|0);if(!d){j[114626]=0;d=E(2,c- -64|0,7156)|0;e=j[114626];j[114626]=0;if((e|0)==1){break V}j[114626]=0;F(219,c+80|0,d|0);e=j[114626];j[114626]=0;if((e|0)==1){break U}j[114626]=0;F(246,c+48|0,c+96|0);e=j[114626];j[114626]=0;if((e|0)==1){break T}j[114626]=0;I(247,c+144|0,c+80|0,c+48|0);e=j[114626];j[114626]=0;if((e|0)==1){break S}j[114626]=0;F(201,f|0,c+144|0);e=j[114626];j[114626]=0;if((e|0)==1){break R}gb(c+144|0);gb(c+48|0);qb(c+80|0);gb(d)}if(!Ec(zg(c+96|0))){j[114626]=0;d=E(2,c+32|0,7160)|0;e=j[114626];j[114626]=0;if((e|0)==1){break N}j[114626]=0;F(219,c+80|0,d|0);e=j[114626];j[114626]=0;if((e|0)==1){break M}e=zg(c+96|0);j[114626]=0;I(247,c+144|0,c+80|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break L}j[114626]=0;F(201,f|0,c+144|0);e=j[114626];j[114626]=0;if((e|0)==1){break K}gb(c+144|0);qb(c+80|0);gb(d)}j[114626]=0;F(248,c+144|0,c+96|0);d=j[114626];j[114626]=0;if((d|0)==1){break H}d=Ec(c+144|0);gb(c+144|0);if(!d){j[114626]=0;d=E(2,c+16|0,7156)|0;e=j[114626];j[114626]=0;if((e|0)==1){break G}j[114626]=0;F(219,c+80|0,d|0);e=j[114626];j[114626]=0;if((e|0)==1){break F}j[114626]=0;F(248,c+48|0,c+96|0);e=j[114626];j[114626]=0;if((e|0)==1){break E}j[114626]=0;I(247,c+144|0,c+80|0,c+48|0);e=j[114626];j[114626]=0;if((e|0)==1){break D}j[114626]=0;F(201,f|0,c+144|0);e=j[114626];j[114626]=0;if((e|0)==1){break C}gb(c+144|0);gb(c+48|0);qb(c+80|0);gb(d)}Je(c+96|0);d=j[b>>2];break w}b=D()|0;C()|0;break a}b=D()|0;C()|0;break x}b=D()|0;C()|0;break O}b=D()|0;C()|0;break P}b=D()|0;C()|0;break Q}b=D()|0;C()|0;gb(c+144|0)}gb(c+48|0)}qb(c+80|0)}gb(d);break x}b=D()|0;C()|0;break x}b=D()|0;C()|0;break I}b=D()|0;C()|0;break J}b=D()|0;C()|0;gb(c+144|0)}qb(c+80|0)}gb(d);break x}b=D()|0;C()|0;break x}b=D()|0;C()|0;break x}b=D()|0;C()|0;break z}b=D()|0;C()|0;break A}b=D()|0;C()|0;break B}b=D()|0;C()|0;gb(c+144|0)}gb(c+48|0)}qb(c+80|0)}gb(d);break x}b=D()|0;C()|0}Je(c+96|0);break a}W:{if(!(d&32)){break W}j[114626]=0;d=T(243)|0;e=j[114626];j[114626]=0;if((e|0)==1){break k}if(d){break W}Qc(c+96|0);j[114626]=0;F(201,f|0,c+96|0);d=j[114626];j[114626]=0;if((d|0)==1){break b}gb(c+96|0)}if(k[b|0]&64){j[114626]=0;N(249,c+96|0);b=j[114626];j[114626]=0;if((b|0)==1){break j}j[114626]=0;F(201,f|0,c+96|0);b=j[114626];j[114626]=0;if((b|0)==1){break i}gb(c+96|0)}j[114626]=0;d=E(2,c+96|0,7166)|0;b=j[114626];j[114626]=0;if((b|0)==1){break h}j[114626]=0;I(250,c|0,f|0,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;e=E(2,c+144|0,10991)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}j[114626]=0;I(251,a|0,c|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break e}gb(e);gb(c);gb(d);Ok(f);Za=c+176|0;return}b=D()|0;C()|0;break a}b=D()|0;C()|0;break a}b=D()|0;C()|0;gb(c+96|0);break a}b=D()|0;C()|0;break a}b=D()|0;C()|0;break c}b=D()|0;C()|0;break d}b=D()|0;C()|0;gb(e)}gb(c)}gb(d);break a}b=D()|0;C()|0;gb(c+96|0)}Ok(f);G(b|0);z()}function yKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=Za-3040|0;Za=e;rc(b);l=e+1080|0;f=vKa(b,l);if(!f){PR(l)}a:{if(!f){break a}if(!TR(e+1080|0)){break a}if(!c){d=1;break a}if(!yb(b,Wc(1024,0))){break a}SR(b,e+560|0);SR(b,e+48|0);while(1){l=g<<2;f=l+(e+560|0)|0;if((k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24))>>>0>16777215){break a}l=l+(e+48|0)|0;if((k[l|0]|k[l+1|0]<<8|(k[l+2|0]<<16|k[l+3|0]<<24))>>>0<3|(k[l|0]|k[l+1|0]<<8|(k[l+2|0]<<16|k[l+3|0]<<24))>>>0>4096){break a}if(!RR(b,((k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24))+(k[l|0]|k[l+1|0]<<8|(k[l+2|0]<<16|k[l+3|0]<<24))|0)+2978|0)){break a}g=g+1|0;if((g|0)!=128){continue}break}od(a,2);_h(a);d=Eb(e+16|0,12301);ob(a+1304436|0,d);gb(d);d=Eb(e+16|0,12306);ob(a+1304448|0,d);gb(d);d=Eb(e+16|0,12310);ob(a+1304460|0,d);gb(d);j[a+1304496>>2]=4;d=k[e+1080|0];j[a+480204>>2]=143e4;j[a+480196>>2]=d;m=a+484360|0;Ge(Fb(m),k[e+1081|0]);j[a+480188>>2]=4194317;vb(a+1074308|0,95,1);d=0;while(1){i[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){g=d+1|0;l=p(g,104)+a|0;f=l+484380|0;md(f,2);si(e+32|0,1,(p(d,13)+e|0)+1082|0);qc(e+16|0,e+32|0);j[114626]=0;E(369,((g<<5)+a|0)+946300|0,e+16|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break e}gb(e+16|0);r=f;d=(e+1080|0)+(d<<4)|0;f=d+422|0;j[r>>2]=k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24);if((k[d+430|0]|k[d+431|0]<<8|(k[d+432|0]<<16|k[d+433|0]<<24))>>>0<=(k[d+422|0]|k[d+423|0]<<8|(k[d+424|0]<<16|k[d+425|0]<<24))>>>0){j[l+484384>>2]=k[d+426|0]|k[d+427|0]<<8|(k[d+428|0]<<16|k[d+429|0]<<24);d=k[d+430|0]|k[d+431|0]<<8|(k[d+432|0]<<16|k[d+433|0]<<24);i[l+484414>>1]=2;j[l+484388>>2]=d}j[l+484404>>2]=8287;d=g;if((d|0)!=32){continue}break}g=0;while(1){d=g+33|0;l=(p(d,104)+a|0)+484380|0;md(l,2);si(e+32|0,1,(p(g,13)+e|0)+2010|0);qc(e+16|0,e+32|0);j[114626]=0;E(369,((d<<5)+a|0)+946300|0,e+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break d}gb(e+16|0);j[e+24>>2]=0;j[e+16>>2]=0;j[e+20>>2]=0;d=(e+1080|0)+p(g,11)|0;f=k[d+1347|0];t=Pb(e+16|0,0),u=f,h[t|0]=u;f=k[d+1352|0];t=Pb(e+16|0,1),u=f,h[t|0]=u;f=k[d+1348|0];t=Pb(e+16|0,2),u=f,h[t|0]=u;f=k[d+1353|0];t=Pb(e+16|0,3),u=f,h[t|0]=u;f=k[d+1349|0];t=Pb(e+16|0,4),u=f,h[t|0]=u;f=k[d+1354|0];t=Pb(e+16|0,5),u=f,h[t|0]=u;f=k[d+1350|0];t=Pb(e+16|0,6),u=f,h[t|0]=u;f=k[d+1355|0];t=Pb(e+16|0,7),u=f,h[t|0]=u;f=k[d+1351|0];t=Pb(e+16|0,8),u=f,h[t|0]=u;f=k[d+1356|0];t=Pb(e+16|0,9),u=f,h[t|0]=u;d=k[d+1346|0];t=Pb(e+16|0,10),u=d,h[t|0]=u;j[e+8>>2]=j[e+24>>2];d=j[e+20>>2];j[e>>2]=j[e+16>>2];j[e+4>>2]=d;Ro(l,1,e);g=g+1|0;if((g|0)!=32){continue}break}At(Fb(m),e+2778|0,256,255,65535);o=a+484344|0;If(o,128);r=c&1;l=0;f:{while(1){g=l<<2;d=g+(e+560|0)|0;xc(b,(k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24))+2978|0);d=g+(e+48|0)|0;cd(e+16|0,b,k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24));g:{if(!r){break g}j[114626]=0;d=K(402,o|0,l&65535,64)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!d){break g}d=0;f=Ib(o,l);while(1){j[114626]=0;g=E(258,e+16|0,1)|0;m=j[114626];j[114626]=0;h:{i:{if((m|0)!=1){if(!g){break g}j[114626]=0;g=H(387,e+16|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break c}if(g>>>0>12){break i}j[114626]=0;m=K(471,f|0,d|0,g|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break c}j[114626]=0;F(472,e+32|0,e+16|0);n=j[114626];j[114626]=0;if((n|0)==1){break c}n=Pc(e+32|0);q=e+32|0;s=k[q|0];g=g>>>0>3;h[m|0]=((s&15)+(g?13:37)|0)+p(s>>>4&7,12);h[m+1|0]=((k[n|0]>>>4|0)+(g?33:1)|0)+(k[q|0]>>>3&16);QR(m,k[n|0],g);break h}break c}m=g-32|0;if((m&255)>>>0<=12){j[114626]=0;m=K(471,f|0,d|0,m&65535)|0;n=j[114626];j[114626]=0;if((n|0)==1){break c}j[114626]=0;n=H(387,e+16|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break c}QR(m,n,g>>>0>35);break h}if((g|0)!=64){if((g|0)!=96){break f}if(!d){break g}j[114626]=0;d=K(471,f|0,d-1|0,0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}h[d+3|0]=14;break g}j[114626]=0;g=H(387,e+16|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break c}d=d+g|0}if(d>>>0<64){continue}break}}jb(e+16|0);l=l+1|0;if((l|0)!=128){continue}break}d=1;if(!(c&2)){break a}g=1;while(1){$f(Mc(e+16|0,8,1,0,1),(p(g,104)+a|0)+484380|0,b);g=g+1|0;if((g|0)!=33){continue}break}break a}jb(e+16|0);d=0;break a}d=D()|0;C()|0;gb(e+16|0);break b}d=D()|0;C()|0;gb(e+16|0);break b}d=D()|0;C()|0;jb(e+16|0)}G(d|0);z()}Za=e+3040|0;return d|0}function nG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-416|0;Za=e;h[e+415|0]=c;a:{if(Pi(b)){break a}f=k[Fj(b)|0];c=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}c=0}d=c;Pj(e+160|0,b,j[b+4>>2]-1|0);c=j[e+164>>2];j[b>>2]=j[e+160>>2];j[b+4>>2]=c}ld(e+160|0);c=j[e+160>>2];ld(e+376|0);g=Ej(c,j[e+380>>2],b);ld(e+160|0);c=j[b>>2];f=j[b+4>>2];c:{d:{e:{f:{if((g|0)==j[e+164>>2]){j[e+400>>2]=c;j[e+404>>2]=f;a=Zb(e+392|0,38235);c=j[e+404>>2];j[e+8>>2]=j[e+400>>2];j[e+12>>2]=c;c=j[a+4>>2];j[e>>2]=j[a>>2];j[e+4>>2]=c;if(nc(e+8|0,e)){a=R(8)|0;j[114626]=0;F(2133,e+376|0,e+415|0);b=j[114626];j[114626]=0;g:{h:{i:{if((b|0)!=1){j[114626]=0;I(2111,e+160|0,39300,e+376|0);b=j[114626];j[114626]=0;if((b|0)==1){break i}Wb(a,e+160|0);d=0;j[114626]=0;I(2002,a|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break e}b=D()|0;C()|0;gb(e+160|0);break h}b=D()|0;C()|0;break g}b=D()|0;d=1;C()|0}gb(e+376|0);if(!d){break f}}S(a|0);break f}if(!d){break c}a=R(8)|0;j[114626]=0;d=E(2134,e+344|0,b|0)|0;b=j[114626];j[114626]=0;c=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){j[114626]=0;I(2111,e+360|0,39179,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break r}j[114626]=0;I(2129,e+376|0,e+360|0,39315);b=j[114626];j[114626]=0;if((b|0)==1){break q}j[114626]=0;F(2133,e+328|0,e+415|0);b=j[114626];j[114626]=0;if((b|0)==1){break p}j[114626]=0;I(138,e+160|0,e+376|0,e+328|0);b=j[114626];j[114626]=0;if((b|0)==1){break o}Wb(a,e+160|0);j[114626]=0;I(2002,a|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break e}b=D()|0;C()|0;gb(e+160|0);c=0;break n}b=D()|0;C()|0;break j}b=D()|0;C()|0;break k}b=D()|0;C()|0;break l}b=D()|0;C()|0;break m}b=D()|0;C()|0}gb(e+328|0)}gb(e+376|0)}gb(e+360|0)}gb(d)}if(!c){break f}S(a|0);break f}j[e+320>>2]=c;j[e+324>>2]=f;c=Zb(e+312|0,38235);d=j[e+324>>2];j[e+152>>2]=j[e+320>>2];j[e+156>>2]=d;d=j[c+4>>2];j[e+144>>2]=j[c>>2];j[e+148>>2]=d;if(!nc(e+152|0,e+144|0)){break d}a=R(8)|0;j[114626]=0;F(2133,e+376|0,e+415|0);b=j[114626];j[114626]=0;s:{t:{u:{if((b|0)!=1){j[114626]=0;I(2111,e+160|0,39300,e+376|0);b=j[114626];j[114626]=0;if((b|0)==1){break u}Wb(a,e+160|0);d=0;j[114626]=0;I(2002,a|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break e}b=D()|0;C()|0;gb(e+160|0);break t}b=D()|0;C()|0;break s}b=D()|0;d=1;C()|0}gb(e+376|0);if(!d){break f}}S(a|0)}G(b|0)}z()}c=j[b+4>>2];j[e+304>>2]=j[b>>2];j[e+308>>2]=c;c=Zb(e+296|0,38917);d=j[e+308>>2];j[e+136>>2]=j[e+304>>2];j[e+140>>2]=d;d=j[c+4>>2];j[e+128>>2]=j[c>>2];j[e+132>>2]=d;v:{if(!nc(e+136|0,e+128|0)){c=j[b+4>>2];j[e+288>>2]=j[b>>2];j[e+292>>2]=c;c=Zb(e+280|0,39214);d=j[e+292>>2];j[e+120>>2]=j[e+288>>2];j[e+124>>2]=d;d=j[c+4>>2];j[e+112>>2]=j[c>>2];j[e+116>>2]=d;if(!nc(e+120|0,e+112|0)){break v}}h[a+60|0]=k[e+415|0];break c}c=j[b+4>>2];j[e+272>>2]=j[b>>2];j[e+276>>2]=c;c=Zb(e+264|0,38935);d=j[e+276>>2];j[e+104>>2]=j[e+272>>2];j[e+108>>2]=d;d=j[c+4>>2];j[e+96>>2]=j[c>>2];j[e+100>>2]=d;w:{if(!nc(e+104|0,e+96|0)){c=j[b+4>>2];j[e+256>>2]=j[b>>2];j[e+260>>2]=c;c=Zb(e+248|0,39232);d=j[e+260>>2];j[e+88>>2]=j[e+256>>2];j[e+92>>2]=d;d=j[c+4>>2];j[e+80>>2]=j[c>>2];j[e+84>>2]=d;if(!nc(e+88|0,e+80|0)){break w}}h[a+61|0]=k[e+415|0];break c}c=j[b+4>>2];j[e+240>>2]=j[b>>2];j[e+244>>2]=c;c=Zb(e+232|0,38954);d=j[e+244>>2];j[e+72>>2]=j[e+240>>2];j[e+76>>2]=d;d=j[c+4>>2];j[e+64>>2]=j[c>>2];j[e+68>>2]=d;if(nc(e+72|0,e- -64|0)){h[a+62|0]=k[e+415|0];break c}c=j[b+4>>2];j[e+224>>2]=j[b>>2];j[e+228>>2]=c;c=Zb(e+216|0,38972);d=j[e+228>>2];j[e+56>>2]=j[e+224>>2];j[e+60>>2]=d;d=j[c+4>>2];j[e+48>>2]=j[c>>2];j[e+52>>2]=d;if(nc(e+56|0,e+48|0)){h[a+63|0]=k[e+415|0];break c}c=j[b+4>>2];j[e+208>>2]=j[b>>2];j[e+212>>2]=c;c=Zb(e+200|0,38996);d=j[e+212>>2];j[e+40>>2]=j[e+208>>2];j[e+44>>2]=d;d=j[c+4>>2];j[e+32>>2]=j[c>>2];j[e+36>>2]=d;if(nc(e+40|0,e+32|0)){h[a+64|0]=k[e+415|0];break c}c=j[b+4>>2];j[e+192>>2]=j[b>>2];j[e+196>>2]=c;b=Zb(e+184|0,39070);c=j[e+196>>2];j[e+24>>2]=j[e+192>>2];j[e+28>>2]=c;c=j[b+4>>2];j[e+16>>2]=j[b>>2];j[e+20>>2]=c;if(!nc(e+24|0,e+16|0)){break c}c=a+24|0;b=j[c>>2];d=b+24664|0;f=j[d+4>>2];j[e+176>>2]=j[d>>2];j[e+180>>2]=f;d=b+24656|0;f=j[d+4>>2];j[e+168>>2]=j[d>>2];j[e+172>>2]=f;d=j[b+24652>>2];j[e+160>>2]=j[b+24648>>2];j[e+164>>2]=d;b=e;if(k[e+415|0]){a=SF(j[a+56>>2])}else{a=0}j[b+180>>2]=a;if(!cw(e+160|0,j[c>>2]+24648|0)){break c}$w(j[c>>2],e+160|0)}Za=e+416|0}function x9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Za-48|0;Za=d;e=Eb(d+32|0,38719);f=Ze(c,e);gb(e);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(f){Ni(a,0,j[b+24>>2]+1304448|0);break k}e=Eb(d+32|0,38724);f=Ze(c,e);gb(e);if(f){Ni(a,0,j[b+24>>2]+1304436|0);break k}e=Eb(d+32|0,38734);f=Ze(c,e);gb(e);if(f){Ni(a,0,j[b+24>>2]+1304484|0);break k}e=Eb(d+32|0,38747);f=Ze(c,e);gb(e);if(f){Ni(a,0,j[b+24>>2]+1304472|0);break k}e=Eb(d+32|0,38765);f=Ze(c,e);gb(e);if(f){Xla(d+32|0,j[j[b+24>>2]+480184>>2]);j[114626]=0;I(9,a|0,0,d+32|0);a=j[114626];j[114626]=0;if((a|0)==1){break j}gb(d+32|0);break k}e=Eb(d+32|0,38775);f=Ze(c,e);gb(e);if(f){Wla(d+32|0,j[j[b+24>>2]+480184>>2]);j[114626]=0;I(9,a|0,0,d+32|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(d+32|0);break k}c=D()|0;C()|0;gb(d+32|0);break a}e=Eb(d+32|0,38790);f=Ze(c,e);gb(e);if(f){Ni(a,0,j[b+24>>2]+1304460|0);break k}e=Eb(d+32|0,38798);f=Ze(c,e);gb(e);if(f){Ni(a,0,j[b+24>>2]+1304412|0);break k}e=Eb(d+32|0,38805);f=Ze(c,e);gb(e);if(f){Mf(d+32|0,j[b+24>>2]+1304400|0);j[114626]=0;I(2177,a|0,b|0,d+32|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(d+32|0);break k}c=D()|0;C()|0;gb(d+32|0);break a}e=Eb(d+32|0,38811);f=Ze(c,e);gb(e);if(f){l:{b=b+24|0;if(!ad(Wv(j[b>>2]))){if(j[YF(Wv(j[b>>2]))+12>>2]){break l}}Db(a);break k}$na(d+32|0,YF(Wv(j[b>>2])));j[114626]=0;I(9,a|0,0,d+32|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(d+32|0);break k}c=D()|0;C()|0;gb(d+32|0);break a}e=Eb(d+32|0,38816);f=Ze(c,e);gb(e);if(f){c=b+24|0;wM(d+32|0,j[c>>2]+1304424|0);m:{n:{o:{if(!Ec(d+32|0)){break o}c=j[c>>2];j[114626]=0;c=H(2178,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break m}p:{switch(c|0){case 0:j[114626]=0;F(2179,d+16|0,b|0);c=j[114626];j[114626]=0;if((c|0)!=1){ob(d+32|0,d+16|0);gb(d+16|0);break o}c=D()|0;C()|0;break b;case 1:j[114626]=0;F(2180,d+16|0,b|0);c=j[114626];j[114626]=0;if((c|0)!=1){ob(d+32|0,d+16|0);gb(d+16|0);break o}c=D()|0;C()|0;break b;case 2:if(Ec(d+32|0)){j[114626]=0;F(2179,d+16|0,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break i}ob(d+32|0,d+16|0);gb(d+16|0)}if(!Ec(d+32|0)){break o}j[114626]=0;F(2180,d+16|0,b|0);c=j[114626];j[114626]=0;if((c|0)!=1){ob(d+32|0,d+16|0);gb(d+16|0);break o}c=D()|0;C()|0;break b;case 3:if(Ec(d+32|0)){j[114626]=0;F(2180,d+16|0,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break h}ob(d+32|0,d+16|0);gb(d+16|0)}if(!Ec(d+32|0)){break o}j[114626]=0;F(2179,d+16|0,b|0);c=j[114626];j[114626]=0;if((c|0)!=1){ob(d+32|0,d+16|0);gb(d+16|0);break o}c=D()|0;C()|0;break b;case 4:j[114626]=0;F(2179,d+16|0,b|0);c=j[114626];j[114626]=0;q:{r:{if((c|0)!=1){j[114626]=0;F(2180,d|0,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break q}if(Ec(d+16|0)){break r}j[114626]=0;E(1245,d+32|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break r}break d}c=D()|0;C()|0;break b}if(!Ec(d)){j[114626]=0;E(1245,d+32|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break d}}gb(d);gb(d+16|0);break o}c=D()|0;C()|0;break c;case 5:break p;default:break o}}j[114626]=0;F(2179,d+16|0,b|0);c=j[114626];j[114626]=0;s:{if((c|0)!=1){j[114626]=0;F(2180,d|0,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break n}if(Ec(d)){break s}j[114626]=0;E(1245,d+32|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break s}break f}c=D()|0;C()|0;break b}if(!Ec(d+16|0)){j[114626]=0;E(1245,d+32|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break f}}gb(d);gb(d+16|0)}j[114626]=0;I(2177,a|0,b|0,d+32|0);a=j[114626];j[114626]=0;if((a|0)==1){break m}gb(d+32|0);break k}c=D()|0;C()|0;break e}c=D()|0;C()|0;break b}e=Eb(d+32|0,38824);f=Ze(c,e);gb(e);if(f){wM(d+32|0,j[b+24>>2]+1304424|0);j[114626]=0;I(2177,a|0,b|0,d+32|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(d+32|0);break k}c=D()|0;C()|0;gb(d+32|0);break a}e=c;c=Eb(d+32|0,38836);e=Ze(e,c);gb(c);if(e){a=Db(a);b=b+68|0;g=d,h=Lb(b),j[g+32>>2]=h;g=d,h=Mb(b),j[g+16>>2]=h;if(!rb(d+32|0,d+16|0)){break k}c=1;while(1){b=j[d+32>>2];if(!(c&1)){j[114626]=0;E(1988,a|0,38845)|0;c=j[114626];j[114626]=0;if((c|0)==1){break g}}j[114626]=0;E(1245,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}_m(d+32|0);c=0;if(rb(d+32|0,d+16|0)){continue}break}break k}Eb(a,38235)}Za=d+48|0;return}c=D()|0;C()|0;gb(d+32|0);break a}c=D()|0;C()|0;break b}c=D()|0;C()|0;break b}c=D()|0;C()|0;gb(a);break a}c=D()|0;C()|0;gb(d)}gb(d+16|0);break b}c=D()|0;C()|0;gb(d)}gb(d+16|0)}gb(d+32|0)}G(c|0);z()}function I2(a,b,c,d,e,f){var g=0,h=0,i=0,l=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=Za-432|0;Za=g;h=j[b+4>>2];a:{if(h>>>0<m[b+104>>2]){j[b+4>>2]=h+1;i=k[h|0];break a}i=Lc(b)}b:{c:{while(1){if((i|0)!=48){d:{if((i|0)!=46){break b}h=j[b+4>>2];if(h>>>0>=m[b+104>>2]){break d}j[b+4>>2]=h+1;i=k[h|0];break c}}else{h=j[b+4>>2];if(h>>>0<m[b+104>>2]){z=1;j[b+4>>2]=h+1;i=k[h|0]}else{z=1;i=Lc(b)}continue}break}i=Lc(b)}y=1;if((i|0)!=48){break b}while(1){h=u;u=h-1|0;v=v-(h>>>0<1)|0;h=j[b+4>>2];e:{if(h>>>0<m[b+104>>2]){j[b+4>>2]=h+1;i=k[h|0];break e}i=Lc(b)}if((i|0)==48){continue}break}z=1}h=1073676288;while(1){f:{A=i|32;g:{h:{B=i-48|0;if(B>>>0<10){break h}if(A-97>>>0>5?(i|0)!=46:0){break f}if((i|0)!=46){break h}if(y){break f}y=1;u=p;v=l;break g}i=(i|0)>57?A-87|0:B;i:{if((l|0)<0?1:(l|0)<=0?p>>>0<=7:0){r=i+(r<<4)|0;break i}if((l|0)<0?1:(l|0)<=0?p>>>0<=28:0){Vf(g+48|0,i);$c(g+32|0,w,x,q,h,0,0,0,1073414144);w=j[g+32>>2];x=j[g+36>>2];q=j[g+40>>2];h=j[g+44>>2];$c(g+16|0,w,x,q,h,j[g+48>>2],j[g+52>>2],j[g+56>>2],j[g+60>>2]);Gf(g,n,o,s,t,j[g+16>>2],j[g+20>>2],j[g+24>>2],j[g+28>>2]);s=j[g+8>>2];t=j[g+12>>2];n=j[g>>2];o=j[g+4>>2];break i}if(!i|E){break i}$c(g+80|0,w,x,q,h,0,0,0,1073610752);Gf(g- -64|0,n,o,s,t,j[g+80>>2],j[g+84>>2],j[g+88>>2],j[g+92>>2]);s=j[g+72>>2];t=j[g+76>>2];E=1;n=j[g+64>>2];o=j[g+68>>2]}p=p+1|0;l=p>>>0<1?l+1|0:l;z=1}i=j[b+4>>2];if(i>>>0<m[b+104>>2]){j[b+4>>2]=i+1;i=k[i|0]}else{i=Lc(b)}continue}break}j:{k:{l:{if(!z){if(!j[b+104>>2]){if(f){break k}break l}c=j[b+4>>2];j[b+4>>2]=c-1;if(!f){break l}j[b+4>>2]=c-2;if(!y){break k}j[b+4>>2]=c-3;break k}if((l|0)<0?1:(l|0)<=0?p>>>0<=7:0){q=p;h=l;while(1){r=r<<4;q=q+1|0;h=q>>>0<1?h+1|0:h;if((q|0)!=8|h){continue}break}}m:{if((i&-33)==80){q=CD(b,f);i=ab;h=i;if(q|(h|0)!=-2147483648){break m}if(f){q=0;h=0;if(!j[b+104>>2]){break m}j[b+4>>2]=j[b+4>>2]-1;break m}n=0;o=0;Hg(b,0,0);c=0;b=0;break j}q=0;h=0;if(!j[b+104>>2]){break m}j[b+4>>2]=j[b+4>>2]-1}if(!r){Ih(g+112|0,+(e|0)*0);n=j[g+112>>2];o=j[g+116>>2];c=j[g+120>>2];b=j[g+124>>2];break j}f=y?u:p;b=(y?v:l)<<2|f>>>30;f=q+(f<<2)|0;l=b+h|0;b=f;p=b-32|0;l=(b>>>0<q>>>0?l+1|0:l)-(b>>>0<32)|0;b=l;if((b|0)>0?1:(b|0)>=0?p>>>0>0-d>>>0:0){j[114600]=68;Vf(g+160|0,e);$c(g+144|0,j[g+160>>2],j[g+164>>2],j[g+168>>2],j[g+172>>2],-1,-1,-1,2147418111);$c(g+128|0,j[g+144>>2],j[g+148>>2],j[g+152>>2],j[g+156>>2],-1,-1,-1,2147418111);n=j[g+128>>2];o=j[g+132>>2];c=j[g+136>>2];b=j[g+140>>2];break j}b=d-226|0;f=p>>>0>=b>>>0;b=b>>31;if((b|0)<(l|0)?1:(l|0)>=(b|0)?f:0){if((r|0)>-1){while(1){Gf(g+416|0,n,o,s,t,0,0,0,-1073807360);h=nE(n,o,s,t,1073610752);f=(h|0)<0;b=f;Gf(g+400|0,n,o,s,t,b?n:j[g+416>>2],b?o:j[g+420>>2],b?s:j[g+424>>2],b?t:j[g+428>>2]);b=p;p=b-1|0;l=l-(b>>>0<1)|0;s=j[g+408>>2];t=j[g+412>>2];n=j[g+400>>2];o=j[g+404>>2];r=r<<1|(h|0)>-1;if((r|0)>-1){continue}break}}b=d;h=(p-b|0)+32|0;l=l-((b>>31)+(b>>>0>p>>>0)|0)|0;b=h;l=b>>>0<32?l+1|0:l;c=((l|0)<0?1:(l|0)<=0?c>>>0>b>>>0:0)?(b|0)>0?b:0:c;n:{if((c|0)>=113){Vf(g+384|0,e);u=j[g+392>>2];v=j[g+396>>2];w=j[g+384>>2];x=j[g+388>>2];d=0;b=0;break n}Ih(g+352|0,Bh(1,144-c|0));Vf(g+336|0,e);w=j[g+336>>2];x=j[g+340>>2];u=j[g+344>>2];v=j[g+348>>2];HD(g+368|0,j[g+352>>2],j[g+356>>2],j[g+360>>2],j[g+364>>2],w,x,u,v);C=j[g+376>>2];D=j[g+380>>2];d=j[g+372>>2];b=j[g+368>>2]}c=!(r&1)&((Kk(n,o,s,t,0,0,0,0)|0)!=0&(c|0)<32);_l(g+320|0,c+r|0);$c(g+304|0,w,x,u,v,j[g+320>>2],j[g+324>>2],j[g+328>>2],j[g+332>>2]);Gf(g+272|0,j[g+304>>2],j[g+308>>2],j[g+312>>2],j[g+316>>2],b,d,C,D);$c(g+288|0,c?0:n,c?0:o,c?0:s,c?0:t,w,x,u,v);Gf(g+256|0,j[g+288>>2],j[g+292>>2],j[g+296>>2],j[g+300>>2],j[g+272>>2],j[g+276>>2],j[g+280>>2],j[g+284>>2]);fv(g+240|0,j[g+256>>2],j[g+260>>2],j[g+264>>2],j[g+268>>2],b,d,C,D);e=j[g+240>>2];d=j[g+244>>2];c=j[g+248>>2];b=j[g+252>>2];if(!Kk(e,d,c,b,0,0,0,0)){j[114600]=68}FD(g+224|0,e,d,c,b,p);n=j[g+224>>2];o=j[g+228>>2];c=j[g+232>>2];b=j[g+236>>2];break j}j[114600]=68;Vf(g+208|0,e);$c(g+192|0,j[g+208>>2],j[g+212>>2],j[g+216>>2],j[g+220>>2],0,0,0,65536);$c(g+176|0,j[g+192>>2],j[g+196>>2],j[g+200>>2],j[g+204>>2],0,0,0,65536);n=j[g+176>>2];o=j[g+180>>2];c=j[g+184>>2];b=j[g+188>>2];break j}Hg(b,0,0)}Ih(g+96|0,+(e|0)*0);n=j[g+96>>2];o=j[g+100>>2];c=j[g+104>>2];b=j[g+108>>2]}j[a>>2]=n;j[a+4>>2]=o;j[a+8>>2]=c;j[a+12>>2]=b;Za=g+432|0}function oIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=Za-336|0;Za=d;rc(b);a:{if(!ct(b,d+320|0)){break a}if(!VQ(d+320|0)){break a}if(j[d+320>>2]==1179472708){Jb(b,4)}if(!kf(b,d+312|0)|j[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}n=d+312|4;g=n;bS(b,d+120|0,k[g|0]|k[g+1|0]<<8|(k[g+2|0]<<16|k[g+3|0]<<24));if((k[d+156|0]|k[d+157|0]<<8)>>>0>128|(k[d+162|0]|k[d+163|0]<<8)>>>0>16|((k[d+160|0]|k[d+161|0]<<8)>>>0>256|(k[d+154|0]|k[d+155|0]<<8)>>>0>128)){break a}od(a,8192);e=Eb(d+40|0,12774);ob(a+1304436|0,e);gb(e);e=Eb(d+40|0,12786);ob(a+1304448|0,e);gb(e);j[a+1304496>>2]=4;bt(d+104|0,2,d+120|0);qc(d+40|0,d+104|0);ob(a+1304400|0,d+40|0);gb(d+40|0);i[d+40>>1]=k[d+162|0]|k[d+163|0]<<8;i[d+104>>1]=1;v=a,w=l[ui(d+40|0,d+104|0)>>1],i[v+480188>>1]=w;j[a+480196>>2]=k[d+166|0];j[a+480204>>2]=p(k[d+167|0],1e4);h[d+40|0]=k[d+164|0];h[d+104|0]=64;e=k[Yb(d+40|0,d+104|0)|0];j[a+480200>>2]=e<<2;if(!e){j[a+480200>>2]=256}e=a;b:{if(k[d+165|0]==128){j[d+40>>2]=256/l[a+480188>>1];j[d+104>>2]=128;g=j[tb(d+40|0,d+104|0)>>2];break b}g=k[d+165|0]&127}j[e+480228>>2]=g;e=0;while(1){g=(e<<5)+a|0;vg(g+480280|0);f=d+e|0;if(k[f+168|0]<=128){i[g+480284>>1]=k[f+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}e=a+484360|0;fn(Fb(e),d+184|0,k[d+156|0]|k[d+157|0]<<8,255,254);if((k[d+154|0]|k[d+155|0]<<8)>>>0<(k[d+156|0]|k[d+157|0]<<8)>>>0){Ge(Fb(e),k[d+154|0]|k[d+155|0]<<8)}e=1;if(!kf(b,d+312|0)){break a}s=c&2;o=a+484344|0;t=c&1;u=d+76|0;while(1){c=n;cd(d+104|0,b,k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24));c:{d:{e:{if(!(!t|j[d+312>>2]!=1414807888)){j[114626]=0;r=q&65535;c=K(402,o|0,r|0,64)|0;e=j[114626];j[114626]=0;if((e|0)==1){break e}if(!c){break c}j[114626]=0;E(338,d+104|0,2)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}Ug(d+40|0);g=0;f:{while(1){j[114626]=0;c=E(258,d+104|0,1)|0;e=j[114626];j[114626]=0;g:{h:{if((e|0)!=1){if(c^1|g>>>0>63){break f}j[114626]=0;e=H(387,d+104|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break h}if(e){break g}g=g+1|0;continue}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}c=d+40|0;i:{j:{k:{f=e&15;l:{if(f>>>0<l[a+480188>>1]){c=Ib(o,r);j[114626]=0;c=K(471,c|0,g|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break l}}m:{if(!(e&128)){break m}j[114626]=0;f=H(387,d+104|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break k}if(!f){break m}h[c|0]=f>>>0<109?f+12|0:f}if(!(e&64)){break i}j[114626]=0;f=H(387,d+104|0)|0;m=j[114626];j[114626]=0;if((m|0)!=1){break j}}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}h[c+1|0]=f}n:{o:{p:{q:{r:{s:{t:{u:{if(e&32){h[c+2|0]=1;j[114626]=0;f=H(387,d+104|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break u}j[114626]=0;h[d+24|0]=f;h[d+8|0]=64;f=E(391,d+24|0,d+8|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break t}h[c+4|0]=k[f|0]}if(!(e&16)){continue}j[114626]=0;F(472,d+24|0,d+104|0);e=j[114626];j[114626]=0;if((e|0)==1){break s}m=Pc(d+24|0);f=d+24|0;e=k[f|0];switch(e-17|0){case 2:break q;case 0:case 1:break r;default:break p}}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}e=e&15;break o}h[f|0]=33;h[m|0]=145;e=k[f|0];break n}if(e>>>0<17){break n}e=(e&240)==32?9:-1}h[f|0]=e}h[c+3|0]=e;h[c+5|0]=k[m|0];j[114626]=0;N(574,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}b=D()|0;C()|0;break d}q=q+1|0;break c}if(j[d+312>>2]!=1414745673){break c}if(!bn(a)){break c}c=l[a+480190>>1]+1|0;i[a+480190>>1]=c;j[114626]=0;E(575,d+104|0,d+40|0)|0;e=j[114626];j[114626]=0;v:{w:{x:{if((e|0)==1){break x}j[114626]=0;c=(p(c&65535,104)+a|0)+484380|0;F(576,d+40|0,c|0);e=j[114626];j[114626]=0;if((e|0)==1){break x}j[114626]=0;I(577,d+8|0,2,u|0);e=j[114626];j[114626]=0;if((e|0)==1){break w}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break w}e=l[a+480190>>1];j[114626]=0;E(369,((e<<5)+a|0)+946300|0,d+24|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break v}gb(d+24|0);if(!s){break c}j[114626]=0;F(578,d+24|0,d+40|0);e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;K(400,d+24|0,c|0,d+104|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break c}}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;gb(d+24|0);break d}b=D()|0;C()|0}jb(d+104|0);G(b|0);z()}jb(d+104|0);e=1;if(kf(b,d+312|0)){continue}break}}Za=d+336|0;return e|0}function Ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0;e=Za-144|0;Za=e;d=-1;a:{b:{c:{if(!ut(j[j[b>>2]-12>>2]+b|0)){b=Ek(e+40|0,b);j[114626]=0;d=E(683,e+24|0,32412)|0;f=j[114626];j[114626]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((f|0)!=1){j[114626]=0;j[e+16>>2]=83886084;j[e+20>>2]=0;I(684,b|0,d|0,e+16|0);f=j[114626];j[114626]=0;if((f|0)==1){break F}qb(d);j[114626]=0;h[e+15|0]=0;d=E(683,e+24|0,32422)|0;f=j[114626];j[114626]=0;if((f|0)==1){break E}j[114626]=0;K(685,b|0,e+15|0,d|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break D}qb(d);j[114626]=0;f=k[e+15|0];d=E(683,e+24|0,32427)|0;g=j[114626];j[114626]=0;if((g|0)==1){break C}j[114626]=0;f=f?0:c;L(1598,b|0,a+40|0,d|0,f|0);c=j[114626];j[114626]=0;if((c|0)==1){break B}qb(d);j[114626]=0;i[e+12>>1]=65535;c=E(683,e+24|0,32429)|0;d=j[114626];j[114626]=0;if((d|0)==1){break A}j[114626]=0;K(1178,b|0,e+12|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break z}qb(c);j[114626]=0;i[e+10>>1]=0;c=E(683,e+24|0,32431)|0;d=j[114626];j[114626]=0;if((d|0)==1){break y}j[114626]=0;K(1178,b|0,e+10|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break x}qb(c);i[a>>1]=l[e+10>>1];j[114626]=0;c=E(683,e+24|0,32433)|0;d=j[114626];j[114626]=0;if((d|0)==1){break w}j[114626]=0;L(1599,b|0,a+52|0,c|0,f|0);d=j[114626];j[114626]=0;if((d|0)==1){break v}qb(c);j[114626]=0;c=E(683,e+24|0,32435)|0;d=j[114626];j[114626]=0;if((d|0)==1){break u}j[114626]=0;K(1564,b|0,a+36|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break t}qb(c);j[114626]=0;c=E(683,e+24|0,32437)|0;d=j[114626];j[114626]=0;if((d|0)==1){break s}j[114626]=0;f=a+4|0;P(1600,b|0,f|0,c|0,1601)|0;d=j[114626];j[114626]=0;if((d|0)==1){break r}qb(c);j[114626]=0;c=E(683,e+24|0,32442)|0;d=j[114626];j[114626]=0;if((d|0)==1){break q}j[114626]=0;g=a+28|0;K(1602,b|0,g|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break p}qb(c);j[114626]=0;c=E(683,e+24|0,32447)|0;d=j[114626];j[114626]=0;if((d|0)==1){break o}j[114626]=0;K(1602,b|0,a+30|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break n}qb(c);j[114626]=0;c=E(683,e+24|0,32452)|0;d=j[114626];j[114626]=0;if((d|0)==1){break m}j[114626]=0;K(1603,b|0,a+32|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break l}qb(c);j[114626]=0;i[e+8>>1]=0;c=E(683,e+24|0,32457)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}j[114626]=0;K(1178,b|0,e+8|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break k}qb(c);d=-1;if(j[b>>2]&1073741824|(l[g>>1]+300&65535)>>>0>=601){break d}c=l[a>>1];if(c>>>0>3|(c|0)==2|i[a+30>>1]<0){break d}c=j[a+36>>2];j[114626]=0;c=H(859,c|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break j}j[114626]=0;j[e+24>>2]=c;j[e+16>>2]=0;c=K(1235,e+24|0,e+16|0,32408)|0;m=j[114626];j[114626]=0;if((m|0)==1){break i}j[a+36>>2]=j[c>>2];if(sb(f)>>>0>32767){break d}switch(l[a>>1]-1|0){case 0:break g;case 2:break h;default:break f}}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(d);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(d);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(d);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(c);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(c);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(c);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(c);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(c);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(c);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(c);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(c);break a}a=D()|0;C()|0;qb(c);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}if(i[e+8>>1]<1){break d}i[e+6>>1]=l[a+30>>1];n[e+24>>2]=n[a+32>>2];c=l[a+28>>1];j[114626]=0;i[e+16>>1]=c;i[e+18>>1]=(c+l[e+8>>1]|0)-1;a=P(1604,a|0,e+6|0,e+24|0,e+16|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){if(a){break e}break d}a=D()|0;C()|0;break a}if(i[e+8>>1]<1){break d}n[e+24>>2]=n[a+32>>2];c=l[a+28>>1];j[114626]=0;i[e+16>>1]=c;i[e+18>>1]=(c+l[e+8>>1]|0)-1;a=U(1605,a|0,f|0,e+24|0,e+16|0,g|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){if(a){break e}break d}a=D()|0;C()|0;break a}j[114626]=0;N(1606,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}}d=1}ag(b)}Za=e+144|0;return d|0}a=D()|0;C()|0;break a}a=D()|0;C()|0}ag(b);G(a|0);z()}function uK(a,b,c,d,e){var f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;m=Za-16|0;Za=m;a:{if(!Ld(d&255)){break a}o=(p(b,896)+a|0)+1074984|0;b:{c:{if(e?0:!(!(j[a+480180>>2]&17825824)|!l[a+480192>>1])){break c}if(Qi(o)){break c}d=p(b,896)+a|0;e=d+1075060|0;if(!j[e>>2]|k[d+1075073|0]&4){break a}c=p(b,896)+a|0;g=c+1075004|0;f=c+1075008|0;if(!(j[g>>2]|j[f>>2])){break a}c=wK(a,b);if((c|0)==65535){break a}n=a+1074984|0;c=n+p(c,896)|0;Rr(c,o);h[c+851|0]=0;h[c+827|0]=0;i[c+808>>1]=b+1;j[c+88>>2]=j[c+88>>2]&-918529;As(c+810|0);j[c+696>>2]=0;j[c+88>>2]=j[c+88>>2]|2101248;j[e>>2]=0;j[o>>2]=0;j[o+4>>2]=0;c=n+p(b,896)|0;j[c+92>>2]=0;j[c+96>>2]=0;j[g>>2]=0;j[f>>2]=0;if(!(k[d+1075073|0]&2)){break b}a=a+1304392|0;if(!bd(a)){break b}bi(j[a>>2],b,1);break b}e=p(b,896)+a|0;q=j[e+1075088>>2];c=l[a+480192>>1]<c>>>0?0:c;g=j[(c?((c<<2)+a|0)+900380|0:e+1075640|0)>>2];d:{if(!g){break d}n=d-1|0;c=l[Oc(g+236|0,n)>>1];f=a+1074308|0;mb(m+8|0,f,104);e:{if(kb(m+8|0)){mb(m,f,34);if(kb(m)){break e}}d=k[Pb(g+108|0,n)|0]}if((c-1&65535)>>>0<=3998){q=(p(c,104)+a|0)+484380|0;break d}mb(m+8|0,f,43);if(!kb(m+8|0)){break d}if(!ci(g)){break a}}if(k[e+1075073|0]&4){break a}if(b>>>0<=255){n=a+1304392|0;t=a+1074308|0;w=b+1|0;c=b;while(1){f=(b|0)==(c|0);f:{if(l[a+480188>>1]>c>>>0?!f:0){break f}e=p(c,896)+a|0;if(l[e+1075792>>1]!=(w|0)?!f:0){break f}v=e+1075640|0;f=j[v>>2];if(!f){break f}r=e+1074984|0;g:{h:{i:{j:{k:{l:{m:{switch(k[f+17|0]-1|0){case 0:if(!d){break f}s=(f|0)==(g|0)&k[e+1075803|0]==(d|0);u=s;if(!g){break l}if(s){break i}break f;case 1:if(!q|j[e+1075088>>2]!=(q|0)){break f}if((f|0)==(g|0)){break g}mb(m+8|0,t,104);if(!kb(m+8|0)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(g){break j}u=(f|0)==(g|0)}if(u){break g}break f}if(!g){break f}s=k[g+34|0];if(!s){break f}if((s|0)==k[f+34|0]){break h}break f}if((f|0)!=(g|0)){break f}}if(!k[g+34|0]){break g}}if(!k[e+1075803|0]|k[f+18|0]>2){break g}mb(m+8|0,t,34);Mj(a,c&65535,pM(r,kb(m+8|0))+255|0,0);h[e+1075806|0]=0}n:{o:{switch(k[j[v>>2]+18|0]){case 0:Cm(a,r);j[e+1075672>>2]=0;if(!(k[e+1075073|0]&2)){break n}if(!bd(n)){break n}bi(j[n>>2],c&65535,1);break n;case 1:Cm(a,r);if(!(k[e+1075073|0]&2)){break n}if(!bd(n)){break n}Tj(j[n>>2],c&65535);break n;case 2:break o;default:break n}}r=e+1075072|0;f=j[r>>2];j[r>>2]=f|4096;if(!(f&512)){break n}if(!bd(n)){break n}mb(m+8|0,t,105);if(kb(m+8|0)){break n}Tj(j[n>>2],c&65535)}if(j[e+1075672>>2]){break f}j[e+1075680>>2]=0;e=e+1075072|0;j[e>>2]=j[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}e=0;g=0;p:{if(!Qi(o)){break p}if(!Ld(k[(p(b,896)+a|0)+1075803|0])){break p}q:{c=Zk(a,b,2,1);if(c-251>>>0<5){break q}if(!c){break p}g=j[(p(c,160)+a|0)+906140>>2];if(!g){break q}mb(m+8|0,a+1074308|0,34);e=(y=g,z=pM(o,kb(m+8|0)),A=b,x=j[j[g>>2]+96>>2],bb[x](y|0,z|0,A|0)|0);break p}g=0}if(ph(o)?0:!e){break a}d=wK(a,b);if((d|0)==65535){break a}f=p(d,896)+a|0;c=f+1075072|0;n=f+1074984|0;r:{if(!(k[f+1075073|0]&2)){break r}q=a+1304392|0;if(!bd(q)){break r}bi(j[q>>2],d,1)}Rr(n,o);j[c>>2]=j[c>>2]&-917505;h[f+1075835|0]=0;q=l[a+480188>>1];h[f+1075811|0]=0;i[f+1075792>>1]=b>>>0<q>>>0?b+1|0:0;s:{if(!g|e^1){break s}e=k[(p(b,896)+a|0)+1075804|0];if(e>>>0>3|(e|0)==1){break s}Mj(a,b,255,0);h[(p(b,896)+a|0)+1075806|0]=0}t:{u:{switch(k[(p(b,896)+a|0)+1075804|0]){case 2:Cm(a,n);if(!(k[c+1|0]&2)){break t}e=a+1304392|0;if(!bd(e)){break t}Tj(j[e>>2],b);mb(m+8|0,a+1074308|0,105);if(!kb(m+8|0)){break t}Mx(j[e>>2],b,d);break t;case 0:j[(p(d,896)+a|0)+1075680>>2]=0;e=j[c>>2];j[c>>2]=e|4096;if(!(e&512)){break t}e=a+1304392|0;if(!bd(e)){break t}bi(j[e>>2],b,1);break t;case 3:e=j[c>>2];j[c>>2]=e|4096;if(!(e&512)){break t}e=a+1304392|0;if(!bd(e)){break t}mb(m+8|0,a+1074308|0,105);g=kb(m+8|0);e=j[e>>2];if(g){Mx(e,b,d);break t}Tj(e,b);break t;case 1:break u;default:break t}}if(!(k[c+1|0]&2)){break t}e=a+1304392|0;if(!bd(e)){break t}Mx(j[e>>2],b,d)}if(!j[(p(d,896)+a|0)+1075672>>2]){j[(p(d,896)+a|0)+1075680>>2]=0;j[c>>2]=j[c>>2]|2101248}a=p(b,896)+a|0;j[a+1075060>>2]=0;j[o>>2]=0;j[o+4>>2]=0;a=a+1075076|0;j[a>>2]=0;j[a+4>>2]=0}}Za=m+16|0}function DE(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,q=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;h=Za-560|0;Za=h;g=c;c=(c-3|0)/24|0;x=(c|0)>0?c:0;m=g+p(x,-24)|0;q=j[(e<<2)+52288>>2];k=d-1|0;if((q+k|0)>=0){g=d+q|0;c=x-k|0;while(1){o[(h+320|0)+(i<<3)>>3]=(c|0)<0?0:+j[(c<<2)+52304>>2];c=c+1|0;i=i+1|0;if((g|0)!=(i|0)){continue}break}}t=m-24|0;g=0;i=(q|0)>0?q:0;n=(d|0)<1;while(1){a:{if(n){f=0;break a}l=g+k|0;c=0;f=0;while(1){f=f+o[(c<<3)+a>>3]*o[(h+320|0)+(l-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}o[(g<<3)+h>>3]=f;c=(g|0)==(i|0);g=g+1|0;if(!c){continue}break}C=47-m|0;y=48-m|0;D=m-25|0;g=q;b:{while(1){f=o[(g<<3)+h>>3];c=0;i=g;l=(g|0)<1;if(!l){while(1){n=(h+480|0)+(c<<2)|0;s=f;f=f*5.960464477539063e-8;c:{if(r(f)<2147483648){k=~~f;break c}k=-2147483648}f=+(k|0);s=s+f*-16777216;d:{if(r(s)<2147483648){k=~~s;break d}k=-2147483648}j[n>>2]=k;i=i-1|0;f=o[(i<<3)+h>>3]+f;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=Bh(f,t);f=f+v(f*.125)*-8;e:{if(r(f)<2147483648){n=~~f;break e}n=-2147483648}f=f- +(n|0);f:{g:{h:{z=(t|0)<1;i:{if(!z){i=(g<<2)+h|0;k=j[i+476>>2];c=k>>y;w=i;i=k-(c<<y)|0;j[w+476>>2]=i;n=c+n|0;k=i>>C;break i}if(t){break h}k=j[((g<<2)+h|0)+476>>2]>>23}if((k|0)<1){break f}break g}k=2;if(!(f>=.5^1)){break g}k=0;break f}c=0;i=0;if(!l){while(1){w=(h+480|0)+(c<<2)|0;A=j[w>>2];l=16777215;j:{k:{if(i){break k}l=16777216;if(A){break k}i=0;break j}j[w>>2]=l-A;i=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(z){break l}m:{switch(D|0){case 0:c=(g<<2)+h|0;j[c+476>>2]=j[c+476>>2]&8388607;break l;case 1:break m;default:break l}}c=(g<<2)+h|0;j[c+476>>2]=j[c+476>>2]&4194303}n=n+1|0;if((k|0)!=2){break f}f=1-f;k=2;if(!i){break f}f=f-Bh(1,t)}if(f==0){i=0;n:{c=g;if((q|0)>=(c|0)){break n}while(1){c=c-1|0;i=j[(h+480|0)+(c<<2)>>2]|i;if((c|0)>(q|0)){continue}break}if(!i){break n}m=t;while(1){m=m-24|0;g=g-1|0;if(!j[(h+480|0)+(g<<2)>>2]){continue}break}break b}c=1;while(1){i=c;c=c+1|0;if(!j[(h+480|0)+(q-i<<2)>>2]){continue}break}i=g+i|0;while(1){k=d+g|0;g=g+1|0;o[(h+320|0)+(k<<3)>>3]=j[(x+g<<2)+52304>>2];c=0;f=0;if((d|0)>=1){while(1){f=f+o[(c<<3)+a>>3]*o[(h+320|0)+(k-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}o[(g<<3)+h>>3]=f;if((g|0)<(i|0)){continue}break}g=i;continue}break}f=Bh(f,24-m|0);o:{if(!(f>=16777216^1)){d=(h+480|0)+(g<<2)|0;s=f;f=f*5.960464477539063e-8;p:{if(r(f)<2147483648){c=~~f;break p}c=-2147483648}f=s+ +(c|0)*-16777216;q:{if(r(f)<2147483648){a=~~f;break q}a=-2147483648}j[d>>2]=a;g=g+1|0;break o}if(r(f)<2147483648){c=~~f}else{c=-2147483648}m=t}j[(h+480|0)+(g<<2)>>2]=c}f=Bh(1,m);r:{if((g|0)<=-1){break r}c=g;while(1){o[(c<<3)+h>>3]=f*+j[(h+480|0)+(c<<2)>>2];f=f*5.960464477539063e-8;a=(c|0)>0;c=c-1|0;if(a){continue}break}l=0;if((g|0)<0){break r}a=(q|0)>0?q:0;i=g;while(1){d=a>>>0<l>>>0?a:l;m=g-i|0;c=0;f=0;while(1){f=f+o[(c<<3)+55072>>3]*o[(c+i<<3)+h>>3];t=(c|0)!=(d|0);c=c+1|0;if(t){continue}break}o[(h+160|0)+(m<<3)>>3]=f;i=i-1|0;c=(g|0)!=(l|0);l=l+1|0;if(c){continue}break}}s:{t:{u:{switch(e|0){case 3:v:{if((g|0)<1){break v}f=o[(h+160|0)+(g<<3)>>3];c=g;while(1){s=f;a=c-1|0;d=(h+160|0)+(a<<3)|0;B=o[d>>3];f=B+f;o[(h+160|0)+(c<<3)>>3]=s+(B-f);o[d>>3]=f;d=(c|0)>1;c=a;if(d){continue}break}if((g|0)<2){break v}f=o[(h+160|0)+(g<<3)>>3];c=g;while(1){s=f;a=c-1|0;d=(h+160|0)+(a<<3)|0;u=o[d>>3];f=u+f;o[(h+160|0)+(c<<3)>>3]=s+(u-f);o[d>>3]=f;d=(c|0)>2;c=a;if(d){continue}break}u=0;if((g|0)<=1){break v}while(1){u=u+o[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=o[h+160>>3];if(k){break t}o[b>>3]=f;f=o[h+168>>3];o[b+16>>3]=u;o[b+8>>3]=f;break s;case 0:f=0;if((g|0)>=0){while(1){f=f+o[(h+160|0)+(g<<3)>>3];a=(g|0)>0;g=g-1|0;if(a){continue}break}}o[b>>3]=k?-f:f;break s;case 1:case 2:break u;default:break s}}f=0;if((g|0)>=0){c=g;while(1){f=f+o[(h+160|0)+(c<<3)>>3];a=(c|0)>0;c=c-1|0;if(a){continue}break}}o[b>>3]=k?-f:f;f=o[h+160>>3]-f;c=1;if((g|0)>=1){while(1){f=f+o[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}o[b+8>>3]=k?-f:f;break s}o[b>>3]=-f;f=o[h+168>>3];o[b+16>>3]=-u;o[b+8>>3]=-f}Za=h+560|0;return n&7}function UF(a,b,c,d,e,f){var g=0,i=0,m=0,n=0;g=Za-48|0;Za=g;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(er(c)){i=b+24|0;if(tg(j[i>>2]+484344|0,c&65535)){break j}}c=a;a=Db(g+32|0);b=Db(g+16|0);jh(c,a,b);gb(b);gb(a);break i}b=Ib(j[i>>2]+484344|0,c);if(!(j[b+12>>2]>(d|0)?(d|0)>=0:0)){c=a;a=Db(g+32|0);b=Db(g+16|0);jh(c,a,b);gb(b);gb(a);break i}if(!(l[j[i>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){c=a;a=Db(g+32|0);b=Db(g+16|0);jh(c,a,b);gb(b);gb(a);break i}if(f>>>0>=6){c=a;a=Db(g+32|0);b=Db(g+16|0);jh(c,a,b);gb(b);gb(a);break i}b=Se(b,d,e&65535);k:{switch(f|0){case 0:l:{m:{n:{if(!Lf(b)){if(!Er(b)){break n}}uJ(g+16|0,j[i>>2],k[b|0],k[b+1|0]);j[114626]=0;I(9,g+32|0,0,g+16|0);c=j[114626];j[114626]=0;d=1;if((c|0)!=1){break m}c=D()|0;C()|0;break b}d=0;j[114626]=0;E(85,g+32|0,38869)|0;c=j[114626];j[114626]=0;if((c|0)==1){break l}}j[114626]=0;c=H(553,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}o:{if(c){j[114626]=0;E(85,g|0,38873)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}break o}if(Er(b)){j[114626]=0;E(85,g|0,38877)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break o}break c}j[114626]=0;E(85,g|0,38869)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}}jh(a,g+32|0,g);gb(g);gb(g+32|0);if(!d){break i}gb(g+16|0);break i}c=D()|0;C()|0;break a;case 1:c=b+1|0;p:{if(k[b+1|0]){Is(g+32|0,c);break p}Eb(g+32|0,38881)}q:{if(k[c|0]){j[114626]=0;E(85,g+16|0,38884)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break q}break d}j[114626]=0;E(85,g+16|0,38881)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}}jh(a,g+32|0,g+16|0);gb(g+16|0);gb(g+32|0);break i;case 2:r:{if(Em(b)){Eb(g+32|0,38887);break r}if(k[b+2|0]){gj(g+32|0,1,AI(j[j[i>>2]+8>>2],k[b+2|0]));break r}Eb(g+32|0,38887)}j[114626]=0;c=H(1336,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}s:{if(c){j[114626]=0;E(85,g+16|0,38887)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}break s}if(k[b+2|0]){j[114626]=0;E(85,g+16|0,38889)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break s}break e}j[114626]=0;E(85,g+16|0,38887)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}}jh(a,g+32|0,g+16|0);gb(g+16|0);gb(g+32|0);break i;case 4:t:{if(Em(b)){m=g,n=yx(b)&255,j[m>>2]=n;Gy(g+32|0,g);break t}if(k[b+2|0]){Is(g+32|0,b+4|0);break t}Eb(g+32|0,38881)}j[114626]=0;c=H(1336,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}u:{if(c){j[114626]=0;E(85,g+16|0,38891)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}break u}if(k[b+2|0]){j[114626]=0;E(85,g+16|0,38891)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break u}break f}j[114626]=0;E(85,g+16|0,38881)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}}jh(a,g+32|0,g+16|0);gb(g+16|0);gb(g+32|0);break i;case 3:v:{if(Em(b)){m=g,n=(Wr(b)&3840)!=0,h[m|0]=n;Y8(g+32|0,g);break v}if(k[b+3|0]){gj(g+32|0,1,zI(j[j[i>>2]+8>>2],k[b+3|0]));break v}Eb(g+32|0,38894)}j[114626]=0;c=H(1336,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}w:{if(c){j[114626]=0;E(85,g+16|0,38896)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}break w}if(k[b+3|0]){j[114626]=0;E(85,g+16|0,38896)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break w}break g}j[114626]=0;E(85,g+16|0,38894)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}}jh(a,g+32|0,g+16|0);gb(g+16|0);gb(g+32|0);break i;case 5:x:{if(Em(b)){m=g,n=Wr(b)&255,j[m>>2]=n;Gy(g+32|0,g);break x}if(k[b+3|0]){Is(g+32|0,b+5|0);break x}Eb(g+32|0,38881)}j[114626]=0;c=H(1336,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break h}y:{if(c){j[114626]=0;E(85,g+16|0,38898)|0;b=j[114626];j[114626]=0;if((b|0)==1){break h}break y}if(k[b+3|0]){j[114626]=0;E(85,g+16|0,38898)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break y}break h}j[114626]=0;E(85,g+16|0,38881)|0;b=j[114626];j[114626]=0;if((b|0)==1){break h}}jh(a,g+32|0,g+16|0);gb(g+16|0);gb(g+32|0);break i;default:break k}}c=a;a=Db(g+32|0);b=Db(g+16|0);jh(c,a,b);gb(b);gb(a)}Za=g+48|0;return}c=D()|0;C()|0;gb(g+32|0);break a}c=D()|0;C()|0;gb(g+32|0);break a}c=D()|0;C()|0;gb(g+32|0);break a}c=D()|0;C()|0;gb(g+32|0);break a}c=D()|0;C()|0;gb(g+32|0);break a}c=D()|0;C()|0;gb(g+32|0);if(!d){break a}}gb(g+16|0)}G(c|0);z()}function Jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,m=0,o=0,p=q(0),r=0,s=0;d=Za-128|0;Za=d;h=-1;a:{b:{c:{d:{if(!mf(j[j[b>>2]-12>>2]+b|0)){break d}Ve(d+112|0,b);e=j[d+120>>2];f=j[d+124>>2];Bl(d+104|0);Aj(b,d+104|0,8);if((k[d+104|0]|k[d+105|0]<<8|(k[d+106|0]<<16|k[d+107|0]<<24))!=1414681667|(k[d+108|0]|k[d+109|0]<<8|(k[d+110|0]<<16|k[d+111|0]<<24))!=776101705){a=sg(d+88|0,e,f);c=j[a+12>>2];j[d+16>>2]=j[a+8>>2];j[d+20>>2]=c;c=j[a+4>>2];j[d+8>>2]=j[a>>2];j[d+12>>2]=c;Gi(b,d+8|0);break d}i[d+86>>1]=0;cf(b,d+86|0);if((l[d+86>>1]&65534)!=2){break d}Bl(d+78|0);Aj(b,d+78|0,8);if((k[d+78|0]|k[d+79|0]<<8|(k[d+80|0]<<16|k[d+81|0]<<24))!=1933333571|(k[d+82|0]|k[d+83|0]<<8|(k[d+84|0]<<16|k[d+85|0]<<24))!=1111389030){break d}i[d+76>>1]=0;cf(b,d+76|0);e=i[d+76>>1];if((e-3&65535)>>>0>1){break d}e:{f:{g:{h:{i:{j:{k:{if((e|0)<=3){e=Db(d+112|0);j[114626]=0;f=K(721,b|0,e|0,65535)|0;m=j[114626];j[114626]=0;if((m|0)==1){break b}if(!f){break j}j[114626]=0;I(13,d- -64|0,c|0,e|0);f=j[114626];j[114626]=0;if((f|0)!=1){break k}break b}e=Db(d+112|0);j[114626]=0;f=K(723,b|0,e|0,255)|0;m=j[114626];j[114626]=0;if((m|0)==1){break c}if(!f){break i}j[114626]=0;I(13,d- -64|0,c|0,e|0);f=j[114626];j[114626]=0;if((f|0)==1){break c}}ob(a+40|0,d- -64|0);gb(d- -64|0);gb(e);i[d+62>>1]=0;cf(b,d+62|0);i[d+60>>1]=0;cf(b,d+60|0);i[a>>1]=l[d+60>>1];i[d+58>>1]=0;l:{if(i[d+76>>1]<=3){j[d+112>>2]=0;ii(b,d+112|0);e=j[d+112>>2];if(e>>>0>65535){break d}e=wz(e);i[d+58>>1]=e;break l}cf(b,d+58|0);e=l[d+58>>1]}m:{n:{o:{p:{if(e&65535){m=a+52|0;f=0;while(1){e=Db(d+112|0);j[114626]=0;i[d+40>>1]=0;E(1609,b|0,d+40|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break g}q:{if(i[d+76>>1]<=3){j[114626]=0;g=K(721,b|0,e|0,65535)|0;o=j[114626];j[114626]=0;if((o|0)==1){break g}if(g){break q}break e}j[114626]=0;g=K(723,b|0,e|0,255)|0;o=j[114626];j[114626]=0;if((o|0)==1){break g}if(!g){break e}}j[114626]=0;I(13,d- -64|0,c|0,e|0);g=j[114626];j[114626]=0;if((g|0)==1){break p}j[114626]=0;g=E(1610,m|0,d+40|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break o}ob(g,d- -64|0);gb(d- -64|0);gb(e);f=f+1|0;if(l[d+58>>1]>(f&65535)>>>0){continue}break}}Bl(d- -64|0);Aj(b,d- -64|0,8);if((k[d+64|0]|k[d+65|0]<<8|(k[d+66|0]<<16|k[d+67|0]<<24))!=1933333571|(k[d+68|0]|k[d+69|0]<<8|(k[d+70|0]<<16|k[d+71|0]<<24))!=1161720678){break d}c=l[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(i[d+86>>1]>2){break n}if(_H(b,c)){break m}break d}b=D()|0;C()|0;break f}b=D()|0;C()|0;gb(d- -64|0);break f}if(!ZH(b,c)){break d}}c=a+16|0;r:{if(i[d+86>>1]<=2){if(_H(b,c)){break r}break d}if(!ZH(b,c)){break d}}r=a,s=sb(a+16|0),j[r+36>>2]=s;i[d+56>>1]=0;cf(b,d+56|0);c=l[d+56>>1];i[a+28>>1]=c;if((c+200&65535)>>>0>400){break d}i[d+54>>1]=0;cf(b,d+54|0);c=i[d+54>>1];i[a+30>>1]=c;if((c|0)<0){break d}j[d+48>>2]=0;ho(b,d+48|0);p=n[d+48>>2];n[a+32>>2]=p;if(p<q(0)){break d}Bl(d+40|0);Aj(b,d+40|0,8);if((k[d+40|0]|k[d+41|0]<<8|(k[d+42|0]<<16|k[d+43|0]<<24))!=1414681667|(k[d+44|0]|k[d+45|0]<<8|(k[d+46|0]<<16|k[d+47|0]<<24))!=776298313){break d}c=a+4|0;if(sb(c)>>>0>32767){break d}f=a+32|0;s:{if(!(n[f>>2]>q(0)?i[a+30>>1]>=1:0)){if(!l[a>>1]){break s}break d}t:{switch(l[a>>1]-1|0){case 0:case 2:break t;default:break s}}if(sb(c)>>>0<i[a+30>>1]>>>0){break d}}b=0;e=j[a+36>>2];if(e){b=e-1|0;j[a+36>>2]=b}r=d,s=Hs(b),j[r+112>>2]=s;j[d+32>>2]=0;r=a,s=j[cs(d+112|0,d+32|0,32408)>>2],j[r+36>>2]=s;io(a);h=1;if(l[a>>1]!=3){break d}if((dI(sb(c))|0)<(i[a+30>>1]-i[a+28>>1]|0)){break d}e=Ij(d+112|0);h=0;if(i[a+30>>1]>0){while(1){b=xb(c,h-i[a+28>>1]|0);j[114626]=0;F(1611,e|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break h}h=h+1|0;if((h|0)<i[a+30>>1]){continue}break}}b=l[a+28>>1];i[d+32>>1]=b;c=sb(c);j[114626]=0;i[d+34>>1]=(b+c|0)-1;i[d+30>>1]=0;U(1605,a|0,e|0,f|0,d+32|0,d+30|0)|0;a=j[114626];j[114626]=0;h=1;if((a|0)!=1){xf(e);break d}break h}gb(e);break d}gb(e);break d}b=D()|0;C()|0;xf(e);break a}b=D()|0;C()|0}gb(e);break a}gb(e)}Za=d+128|0;return h|0}b=D()|0;C()|0;gb(e);break a}b=D()|0;C()|0;gb(e)}G(b|0);z()}function cya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=Za-192|0;Za=d;rc(b);a:{if(!lz(b,d+144|0)){break a}if(!_M(d+144|0)){break a}if(!yb(b,Wc(ZM(d+144|0),ab))){break a}b:{if(!c){break b}od(a,256);en(d+16|0,2,d+144|0);qc(d+48|0,d+16|0);ob(a+1304400|0,d+48|0);gb(d+48|0);e=Eb(d+48|0,17295);ob(a+1304436|0,e);gb(e);e=Eb(d+48|0,17312);ob(a+1304448|0,e);gb(e);g=Eb(d+128|0,17316);j[114626]=0;F(219,d+16|0,g|0);e=j[114626];j[114626]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){j[114626]=0;F(450,d+112|0,d+175|0);e=j[114626];j[114626]=0;if((e|0)==1){break i}j[114626]=0;L(451,d+48|0,d+16|0,d+174|0,d+112|0);e=j[114626];j[114626]=0;if((e|0)==1){break h}ob(a+1304460|0,d+48|0);gb(d+48|0);gb(d+112|0);qb(d+16|0);gb(g);j[a+1304496>>2]=4;j[a+480260>>2]=64;j[a+480264>>2]=32767;j[a+480188>>2]=2031620;f=k[d+176|0];if(k[d+175|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-p(e,10)}g=(f&255?f:96)&255;e=zK(g);j[a+480196>>2]=g>>>4;j[a+480204>>2]=e;if(k[d+175|0]>10){break e}break d}f=D()|0;C()|0;break f}f=D()|0;C()|0;break g}f=D()|0;C()|0;gb(d+112|0)}qb(d+16|0)}gb(g);break c}h[d+48|0]=64;v=a,w=k[Yb(d+178|0,d+48|0)|0]<<2,j[v+480200>>2]=w}f=0;while(1){e=(f<<5)+a|0;vg(e+480280|0);i[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;j:{k:{while(1){Ds(b,d+16|0);if(k[d+28|0]!=46?k[d+28|0]:0){break k}bya(d+16|0,(p(f,104)+a|0)+484380|0);dk(d,2,d+16|0);qc(d+112|0,d);j[114626]=0;E(369,((f<<5)+a|0)+946300|0,d+112|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break j}gb(d+112|0);i[((f<<1)+d|0)+46>>1]=k[d+30|0]|k[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;lp(Fb(e),b,k[d+175|0]?128:64,65535,65535);e=Fb(e);v=d,w=Lb(e),j[v+16>>2]=w;v=d,w=Mb(e),j[v+112>>2]=w;if(rb(d+16|0,d+112|0)){while(1){e=j[d+16>>2];g=l[e>>1];l:{if(!((g|0)!=99?(g|0)!=255:0)){i[e>>1]=65535;break l}if(g>>>0>63){break k}}je(d+16|0);if(rb(d+16|0,d+112|0)){continue}break}}t=c&1;if(t){If(a+484344|0,k[d+177|0])}if(k[d+177|0]){r=a+484344|0;while(1){m:{n:{if(t){if(Wf(r,o&65535,64)){break n}}f=0;while(1){if((dd(b)+5&255)>>>0>=3){Jb(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break m}v=d,w=Lb(Ib(r,o)),j[v+112>>2]=w;j[d>>2]=63;n=65535;q=0;while(1){f=0;while(1){g=f;m=0;f=0;s=0;u=0;o:{p:{q:{r:{s:{t:{e=dd(b);switch(e-251|0){case 1:break o;case 0:break r;case 2:break t;default:break s}}h[j[d+112>>2]]=254;break o}Ft(d+16|0,b);f=k[Pb(d+16|0,0)|0];s=k[Pb(d+16|0,1)|0];u=k[Pb(d+16|0,2)|0];m=254;if((e|0)==254){break q}m=e;if(e>>>0>95){break p}}m=(p(m>>>4|0,12)+(m&15)|0)+37|0}e=m;h[j[d+112>>2]]=e}h[j[d+112>>2]+1|0]=(f&248)>>>3;if(k[j[d+112>>2]+1|0]>=32){h[j[d+112>>2]+1|0]=0}e=s>>>1&120|f&7;if(e>>>0<=64){h[j[d+112>>2]+2|0]=1;h[j[d+112>>2]+4|0]=e}h[j[d+112>>2]+3|0]=k[(s&15)+17344|0];h[j[d+112>>2]+5|0]=u;u:{switch(k[j[d+112>>2]+3|0]-11|0){case 0:m=j[d+112>>2];e=k[m+5|0];if(k[j[d+112>>2]+5|0]&15){h[m+5|0]=e&15;break o}h[m+5|0]=e&240;break o;case 3:h[j[d+112>>2]+5|0]=p(k[j[d+112>>2]+5|0]&240,10)|k[j[d+112>>2]+5|0]&15;v:{if((n|0)!=65535){if(k[j[d+112>>2]+5|0]){break v}h[j[d+112>>2]+3|0]=12;h[j[d+112>>2]+5|0]=n}n=65535}kc(d,q);break o;case 1:n=k[j[d+112>>2]+5|0];j[d>>2]=63;h[j[d+112>>2]+3|0]=0;break o;case 5:if(k[d+175|0]<=20){h[j[d+112>>2]+5|0]=k[j[d+112>>2]+5|0]%10|k[j[d+112>>2]+5|0]/10<<4}if(k[j[d+112>>2]+5|0]){break o}h[j[d+112>>2]+3|0]=0;break o;case 7:break o;default:break u}}if(k[j[d+112>>2]+5|0]){break o}h[j[d+112>>2]+3|0]=0}kk(d+112|0);f=g+1|0;if((g&65535)>>>0<3){continue}break}q=q+1|0;if((q|0)!=64){continue}break}if((n|0)==65535){break m}Uk(Ib(r,o),dn(Fe(Cp(d+16|0,12,n&255),j[d>>2])))}o=o+1|0;if(o>>>0<k[d+177|0]){continue}break}}f=1;if(!(c&2)){break a}g=Mc(d+16|0,8,1,0,0);while(1){c=p(f,104)+a|0;e=c+484380|0;w:{if(!j[e>>2]|!l[c+484410>>1]){break w}c=l[((f<<1)+d|0)+46>>1];if(c>>>0<4){break w}if(!xc(b,c<<4)){break w}$f(g,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=D()|0;C()|0;gb(d+112|0)}G(f|0);z()}f=1}Za=d+192|0;return f|0}function p$(){var a=0,b=0,c=0,d=0,e=0;td(463456);j[115864]=62464;j[114626]=0;b=E(2507,463472,28)|0;a=j[114626];j[114626]=0;a:{b:{c:{d:{if((a|0)!=1){j[114626]=0;c=E(85,463632,62453)|0;a=j[114626];j[114626]=0;if((a|0)==1){break d}sb(b);EC(b);DC(b);td(463136);j[115784]=64080;j[114626]=0;F(2508,463456,463136);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463144);j[115786]=64112;j[114626]=0;F(2509,463456,463144);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463152);h[463164]=0;j[115790]=0;j[115788]=62484;d=463160,e=Mn(),j[d>>2]=e;j[114626]=0;F(2510,463456,463152);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463168);j[115792]=63068;j[114626]=0;F(2511,463456,463168);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463176);j[115794]=63216;j[114626]=0;F(2512,463456,463176);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;M(2513);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;F(2514,463456,463184);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463200);j[115800]=63364;j[114626]=0;F(2515,463456,463200);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;oq(463208);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;F(2517,463456,463208);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463216);i[231612]=11310;j[115804]=62584;Db(463228);j[114626]=0;F(2518,463456,463216);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463248);j[115814]=46;j[115815]=44;j[115812]=62624;Db(463264);j[114626]=0;F(2519,463456,463248);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463280);j[115820]=64144;j[114626]=0;F(2520,463456,463280);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463288);j[115822]=64388;j[114626]=0;F(2521,463456,463288);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463296);j[115824]=64600;j[114626]=0;F(2522,463456,463296);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463304);j[115826]=64832;j[114626]=0;F(2523,463456,463304);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;CC();a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;F(2525,463456,463312);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463320);j[115830]=65964;j[114626]=0;F(2526,463456,463320);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463328);j[115832]=66080;j[114626]=0;F(2527,463456,463328);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463336);j[115834]=66196;j[114626]=0;F(2528,463456,463336);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;BC();a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;F(2530,463456,463344);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;AC();a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;F(2532,463456,463352);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;zC();a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;F(2534,463456,463360);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;yC();a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;F(2536,463456,463368);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463376);j[115846]=68356;j[115844]=65032;j[115846]=65080;j[114626]=0;F(2537,463456,463376);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463392);j[115850]=68392;j[115848]=65296;j[115850]=65344;j[114626]=0;F(2538,463456,463392);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;M(2539);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;F(2540,463456,463408);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;M(2541);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;F(2542,463456,463424);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;xC();a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;F(2544,463456,463440);a=j[114626];j[114626]=0;if((a|0)==1){break c}td(463448);j[115862]=67088;j[114626]=0;F(2545,463456,463448);a=j[114626];j[114626]=0;if((a|0)==1){break c}return}a=D()|0;C()|0;break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;gb(c)}HC(b)}G(a|0);z()}function xU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,l=0,m=0;d=Za-160|0;Za=d;rc(b);aq(a);a:{if(!_t(b,d+120|0)){break a}if(!MI(d+120|0)){break a}if(!Ala(b,d+120|0)){break a}if(!c){f=1;break a}wla(d+104|0,b,d+120|0);c=d+152|0;c=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[114626]=0;c=E(256,b|0,c|0)|0;g=j[114626];j[114626]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((g|0)!=1){if(!c){break b}g=d+88|0;rU(g);c=d+148|0;f=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[114626]=0;F(332,g|0,f|0);f=j[114626];j[114626]=0;if((f|0)==1){break h}if(!(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))){break i}f=d+120|4;while(1){j:{j[114626]=0;e=E(258,b|0,4)|0;m=j[114626];j[114626]=0;if((m|0)==1){break j}if(!e){break i}e=k[f|0]|k[f+1|0]<<8;j[114626]=0;e=E(333,b|0,e|0)|0;m=j[114626];j[114626]=0;k:{if((m|0)!=1){j[d+24>>2]=e;if(cc(d+104|0)>>>0<=e>>>0){break k}j[114626]=0;F(334,g|0,d+24|0);e=j[114626];j[114626]=0;if((e|0)!=1){break k}}b=D()|0;C()|0;break f}i=i+1|0;if(i>>>0<(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))>>>0){continue}break i}break}b=D()|0;C()|0;break f}b=D()|0;C()|0;break e}c=d+144|0;c=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);f=0;j[114626]=0;c=E(256,b|0,c|0)|0;i=j[114626];j[114626]=0;if((i|0)!=1){break g}}b=D()|0;C()|0;break f}if(!c){break c}f=d+140|0;if(!(k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24))){break d}m=d+36|0;c=d+120|4;i=0;l:{m:{n:{o:{p:{q:{while(1){j[114626]=0;e=E(258,b|0,4)|0;h=j[114626];j[114626]=0;r:{if((h|0)!=1){if(e){break r}break d}b=D()|0;C()|0;break f}e=k[c|0]|k[c+1|0]<<8;j[114626]=0;aa(335,b|0,d+84|0,d+80|0,d+76|0,d+72|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break o}s:{t:{if(j[d+76>>2]<1){break t}e=j[d+84>>2];if((e|0)>-1){break t}e=e^-1;j[d+84>>2]=e;if(sb(g)>>>0<=e>>>0){break t}if(!Dd(Zc(d+104|0,j[xb(g,j[d+84>>2])>>2]),11555)){break t}j[114626]=0;L(336,d+56|0,b|0,j[d+80>>2],j[d+76>>2]);e=j[114626];j[114626]=0;if((e|0)==1){break n}j[114626]=0;e=H(337,d+56|0)|0;h=j[114626];j[114626]=0;if((h|0)==1){break m}if(e){if((k[c|0]|k[c+1|0]<<8)>>>0<=39){j[114626]=0;E(338,d+56|0,8)|0;e=j[114626];j[114626]=0;if((e|0)==1){break m}}if((k[c|0]|k[c+1|0]<<8)>>>0<=59){j[114626]=0;E(338,d+56|0,16)|0;e=j[114626];j[114626]=0;if((e|0)==1){break m}}j[114626]=0;H(339,d+56|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break m}u:{if((k[c|0]|k[c+1|0]<<8)>>>0>=120){j[114626]=0;H(339,d+56|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break m}j[114626]=0;E(338,d+56|0,8)|0;break u}if((k[c|0]|k[c+1|0]<<8)>>>0>=100){j[114626]=0;E(338,d+56|0,4)|0;e=j[114626];j[114626]=0;if((e|0)==1){break m}j[114626]=0;H(339,d+56|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break m}j[114626]=0;E(338,d+56|0,4)|0;break u}if((k[c|0]|k[c+1|0]<<8)>>>0>=62){j[114626]=0;H(339,d+56|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break m}j[114626]=0;E(338,d+56|0,4)|0;break u}j[114626]=0;H(339,d+56|0)|0}e=j[114626];j[114626]=0;if((e|0)==1){break m}j[114626]=0;h=H(339,d+56|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break p}j[114626]=0;e=H(340,d+24|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break s}l=j[d+72>>2];v:{if((l|0)<0){break v}if(cc(d+104|0)>>>0<=l>>>0){break v}l=Zc(d+104|0,j[d+72>>2]);j[114626]=0;I(13,d+8|0,2,l|0);l=j[114626];j[114626]=0;if((l|0)==1){break q}ob(d+24|0,d+8|0);gb(d+8|0)}j[114626]=0;I(341,d+8|0,d+56|0,h|0);h=j[114626];j[114626]=0;if((h|0)==1){break q}Ed(m,d+8|0);jb(d+8|0);j[114626]=0;F(342,a|0,e|0);h=j[114626];j[114626]=0;if((h|0)==1){break q}hu(e)}jb(d+56|0)}i=i+1|0;if(i>>>0<(k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24))>>>0){continue}break d}break}b=D()|0;C()|0;break l}b=D()|0;C()|0;hu(e);break l}b=D()|0;C()|0;break l}b=D()|0;C()|0;break f}b=D()|0;C()|0;break f}b=D()|0;C()|0}jb(d+56|0)}JA(g)}Uc(d+104|0);G(b|0);z()}f=ad(a)^1}JA(g)}Uc(d+104|0)}Za=d+160|0;return f|0}function P4(a,b){var c=q(0),d=0,e=0,f=0,g=q(0),h=0,i=0,j=q(0),k=q(0),l=q(0),m=0,o=q(0),p=0,s=q(0),t=q(0),u=q(0),v=q(0);g=q(1);a:{b:{h=(ZMa(a),VMa(2));c:{if((h|0)==1065353216){break c}i=(ZMa(b),VMa(2));d=i&2147483647;if(!d){break c}e=h&2147483647;if(!(d>>>0<2139095041?e>>>0<=2139095040:0)){return q(a+b)}d:{e:{if((h|0)>-1){break e}m=2;if(d>>>0>1266679807){break d}if(d>>>0<1065353216){break e}f=150-(d>>>23|0)|0;p=d>>>f|0;m=0;if((d|0)!=p<<f){break d}m=2-(p&1)|0;break d}m=0}f=m;f:{if((d|0)!=1065353216){if((d|0)!=2139095040){break f}if((e|0)==1065353216){break c}if(e>>>0>=1065353217){return(i|0)>-1?b:q(0)}return(i|0)>-1?q(0):q(-b)}return(i|0)>-1?a:q(q(1)/a)}if((i|0)==1073741824){return q(a*a)}if(!((i|0)!=1056964608|(h|0)<0)){return q(y(a))}c=q(r(a));if(!(e?(h&1073741823)!=1065353216:0)){g=(i|0)<0?q(q(1)/c):c;if((h|0)>-1){break c}if(!(f|e-1065353216)){a=q(g-g);return q(a/a)}return(f|0)==1?q(-g):g}g:{if((h|0)>-1){break g}h:{switch(f|0){case 0:a=q(a-a);return q(a/a);case 1:break h;default:break g}}g=q(-1)}i:{if(d>>>0>=1291845633){if(e>>>0<=1065353207){return(i|0)<0?q(q(g*q(1.0000000150474662e+30))*q(1.0000000150474662e+30)):q(q(g*q(1.0000000031710769e-30))*q(1.0000000031710769e-30))}if(e>>>0>=1065353224){return(i|0)>0?q(q(g*q(1.0000000150474662e+30))*q(1.0000000150474662e+30)):q(q(g*q(1.0000000031710769e-30))*q(1.0000000031710769e-30))}a=q(c+q(-1));c=q(a*q(1.44268798828125));j=q(q(a*q(7052607543300837e-21))+q(q(q(a*a)*q(q(.5)-q(a*q(q(a*q(-.25))+q(.3333333432674408)))))*q(-1.4426950216293335)));a=(WMa(2,(ZMa(q(c+j)),VMa(2))&-4096),_Ma());o=q(a-c);break i}d=e>>>0<8388608;e=d?(ZMa(q(c*q(16777216))),VMa(2)):e;h=e&8388607;f=h|1065353216;d=(e>>23)+(d?-151:-127)|0;e=0;j:{if(h>>>0<1885298){break j}if(h>>>0<6140887){e=1;break j}f=f-8388608|0;d=d+1|0}h=e<<2;o=n[h+52240>>2];j=(WMa(2,f),_Ma());k=n[h+52224>>2];l=q(j-k);s=q(q(1)/q(k+j));c=q(l*s);a=(WMa(2,(ZMa(c),VMa(2))&-4096),_Ma());t=q(a*a);u=a;v=l;l=(WMa(2,((f>>1&-536875008)+(e<<21)|0)+541065216|0),_Ma());j=q(s*q(q(v-q(a*l))-q(a*q(j-q(l-k)))));l=q(q(c+a)*j);a=q(c*c);k=q(l+q(q(a*a)*q(q(a*q(q(a*q(q(a*q(q(a*q(q(a*q(.20697501301765442))+q(.23066075146198273)))+q(.2727281153202057)))+q(.3333333432674408)))+q(.4285714328289032)))+q(.6000000238418579))));a=(WMa(2,(ZMa(q(q(t+q(3))+k)),VMa(2))&-4096),_Ma());l=q(u*a);c=q(q(j*a)+q(c*q(k-q(q(a+q(-3))-t))));a=(WMa(2,(ZMa(q(l+c)),VMa(2))&-4096),_Ma());k=q(a*q(.9619140625));j=q(n[h+52232>>2]+q(q(q(c-q(a-l))*q(.9617967009544373))+q(a*q(-.00011736857413779944))));c=q(d|0);a=(WMa(2,(ZMa(q(q(o+q(k+j))+c)),VMa(2))&-4096),_Ma());o=q(q(q(a-c)-o)-k)}k=(WMa(2,i&-4096),_Ma());c=q(a*k);a=q(q(q(j-o)*b)+q(q(b-k)*a));b=q(c+a);f=(ZMa(b),VMa(2));if((f|0)>=1124073473){break b}e=1124073472;k:{l:{if((f|0)==1124073472){if(q(a+q(4.299566569443414e-8))>q(b-c)^1){break l}break b}e=f&2147483647;if(!(a<=q(b-c)^1|(f|0)!=-1021968384)|e>>>0>=1125515265){break a}d=0;if(e>>>0<1056964609){break k}}i=(8388608>>>(e>>>23|0)-126|0)+f|0;e=i>>>23&255;d=(i&8388607|8388608)>>>150-e|0;d=(f|0)<0?0-d|0:d;c=q(c-(WMa(2,i&-8388608>>e-127),_Ma()));f=(ZMa(q(a+c)),VMa(2))}b=(WMa(2,f&-32768),_Ma());j=q(b*q(.693145751953125));c=q(q(b*q(14286065379565116e-22))+q(q(a-q(b-c))*q(.6931471824645996)));a=q(j+c);b=q(a*a);b=q(a-q(b*q(q(b*q(q(b*q(q(b*q(q(b*q(4.138136944220605e-8))+q(-16533901998627698e-22)))+q(661375597701408e-19)))+q(-.0027777778450399637)))+q(.1666666716337204))));l=q(q(a*b)/q(b+q(-2)));b=q(c-q(a-j));a=q(q(a-q(l-q(b+q(a*b))))+q(1));f=(ZMa(a),VMa(2))+(d<<23)|0;m:{if((f|0)<=8388607){a=FE(a,d);break m}a=(WMa(2,f),_Ma())}g=q(g*a)}return g}return q(q(g*q(1.0000000150474662e+30))*q(1.0000000150474662e+30))}return q(q(g*q(1.0000000031710769e-30))*q(1.0000000031710769e-30))}function lG(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=Za-256|0;Za=e;o[e+248>>3]=c;a:{if(Pi(b)){break a}g=k[Fj(b)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;Pj(e+216|0,b,j[b+4>>2]-1|0);f=j[e+220>>2];j[b>>2]=j[e+216>>2];j[b+4>>2]=f}ld(e+216|0);f=j[e+216>>2];ld(e+200|0);h=Ej(f,j[e+204>>2],b);ld(e+216|0);f=j[b>>2];g=j[b+4>>2];c:{d:{e:{f:{if((h|0)==j[e+220>>2]){j[e+240>>2]=f;j[e+244>>2]=g;a=Zb(e+232|0,38235);f=j[e+244>>2];j[e+16>>2]=j[e+240>>2];j[e+20>>2]=f;f=j[a+4>>2];j[e+8>>2]=j[a>>2];j[e+12>>2]=f;if(nc(e+16|0,e+8|0)){d=R(8)|0;j[114626]=0;F(2136,e+200|0,e+248|0);a=j[114626];j[114626]=0;g:{h:{i:{if((a|0)!=1){j[114626]=0;I(2111,e+216|0,39300,e+200|0);a=j[114626];j[114626]=0;if((a|0)==1){break i}Wb(d,e+216|0);a=0;j[114626]=0;I(2002,d|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break c}b=D()|0;C()|0;gb(e+216|0);break h}b=D()|0;C()|0;break g}b=D()|0;a=1;C()|0}gb(e+200|0);if(!a){break d}}S(d|0);break d}if(!d){break f}d=R(8)|0;j[114626]=0;f=E(2134,e+168|0,b|0)|0;b=j[114626];j[114626]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){j[114626]=0;I(2111,e+184|0,39179,f|0);a=j[114626];j[114626]=0;if((a|0)==1){break r}j[114626]=0;I(2129,e+200|0,e+184|0,39315);b=j[114626];j[114626]=0;a=1;if((b|0)==1){break q}j[114626]=0;F(2136,e+152|0,e+248|0);a=j[114626];j[114626]=0;if((a|0)==1){break p}j[114626]=0;I(138,e+216|0,e+200|0,e+152|0);b=j[114626];j[114626]=0;a=1;if((b|0)==1){break o}Wb(d,e+216|0);j[114626]=0;I(2002,d|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(e+216|0);a=0;break n}b=D()|0;C()|0;break j}b=D()|0;a=1;C()|0;break k}b=D()|0;C()|0;break l}b=D()|0;a=1;C()|0;break m}b=D()|0;C()|0}gb(e+152|0)}gb(e+200|0)}gb(e+184|0)}gb(f)}if(!a){break d}S(d|0);break d}j[e+144>>2]=f;j[e+148>>2]=g;d=Zb(e+136|0,38235);f=j[e+148>>2];j[e+80>>2]=j[e+144>>2];j[e+84>>2]=f;f=j[d+4>>2];j[e+72>>2]=j[d>>2];j[e+76>>2]=f;if(nc(e+80|0,e+72|0)){d=R(8)|0;j[114626]=0;F(2136,e+200|0,e+248|0);a=j[114626];j[114626]=0;s:{t:{u:{if((a|0)!=1){j[114626]=0;I(2111,e+216|0,39300,e+200|0);a=j[114626];j[114626]=0;if((a|0)==1){break u}Wb(d,e+216|0);a=0;j[114626]=0;I(2002,d|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break c}b=D()|0;C()|0;gb(e+216|0);break t}b=D()|0;C()|0;break s}b=D()|0;a=1;C()|0}gb(e+200|0);if(!a){break d}}S(d|0);break d}d=j[b+4>>2];j[e+128>>2]=j[b>>2];j[e+132>>2]=d;d=Zb(e+120|0,39022);f=j[e+132>>2];j[e+64>>2]=j[e+128>>2];j[e+68>>2]=f;f=j[d+4>>2];j[e+56>>2]=j[d>>2];j[e+60>>2]=f;if(nc(e- -64|0,e+56|0)){if(!k[a+28|0]){break f}c=o[e+248>>3];if(!(c<=4?!(c<=0):0)){a=R(8)|0;j[114626]=0;d=E(85,e+216|0,39320)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}Wb(a,d);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(d);break d}b=Yj(65536/c);a=a+24|0;j[j[a>>2]+480244>>2]=b;qo(j[a>>2]);break f}d=j[b+4>>2];j[e+112>>2]=j[b>>2];j[e+116>>2]=d;d=Zb(e+104|0,39040);f=j[e+116>>2];j[e+48>>2]=j[e+112>>2];j[e+52>>2]=f;f=j[d+4>>2];j[e+40>>2]=j[d>>2];j[e+44>>2]=f;if(nc(e+48|0,e+40|0)){if(!k[a+28|0]){break f}c=o[e+248>>3];if(!(c<=4?!(c<=0):0)){a=R(8)|0;j[114626]=0;d=E(85,e+216|0,39341)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Wb(a,d);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(d);break d}b=D()|0;C()|0;S(a|0);break d}b=Yj(c*65536);a=a+24|0;j[j[a>>2]+480240>>2]=b;qo(j[a>>2]);break f}d=j[b+4>>2];j[e+96>>2]=j[b>>2];j[e+100>>2]=d;b=Zb(e+88|0,39137);d=j[e+100>>2];j[e+32>>2]=j[e+96>>2];j[e+36>>2]=d;d=j[b+4>>2];j[e+24>>2]=j[b>>2];j[e+28>>2]=d;if(!nc(e+32|0,e+24|0)){break f}a=a+24|0;a;b=Mm(o[e+248>>3]*65536);j[j[a>>2]+480236>>2]=b}Za=e+256|0;return}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function f5(a,b,c,d,e,f){var g=0,h=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;s=Za-16|0;Za=s;o=j[a+4>>2];h=j[a+396>>2];r=h+p(e,24)|0;q=j[r+4>>2];x=l[((e<<1)+a|0)+268>>1];g=d<<((x|0)==2);n=g>>>0>q>>>0?q:g;q=j[r>>2];q=(n-(g>>>0>q>>>0?q:g)>>>0)/m[r+8>>2]|0;t=q<<2;g=p(o,t+4|0);y=j[j[a+124>>2]+p(k[r+13|0],2096)>>2];C=j[a+92>>2];a:{if(j[a+80>>2]){g=im(a,g);o=j[a+4>>2];break a}g=_c(g)}t=b5(g,o,t);b:{c:{d:{if((c|0)>=1){o=d<<2;g=0;while(1){if(!k[f+g|0]){Ab(j[(g<<2)+b>>2],0,o)}g=g+1|0;if((g|0)!=(c|0)){continue}break}if((c|0)==1|(x|0)!=2){break d}g=0;if((c|0)<1){break c}while(1){if(!k[f+g|0]){break c}g=g+1|0;if((g|0)!=(c|0)){continue}break}break b}g=0;if((x|0)==2){break c}}z=h+p(e,24)|0;A=z;B=(q|0)<1;d=0;while(1){if(!B){v=0;w=(c|0)<1;D=w|(d|0)!=0;o=0;while(1){g=0;if(!D){while(1){if(!k[f+g|0]){h=j[a+124>>2]+p(k[r+13|0],2096)|0;if(j[a+1396>>2]<=9){Dj(a)}n=j[a+1392>>2];e=i[(h+((n&1023)<<1)|0)+36>>1];e:{if((e|0)>=0){u=n;n=k[e+j[h+8>>2]|0];j[a+1392>>2]=u>>>n;u=j[a+1396>>2]-n|0;n=(u|0)<0;j[a+1396>>2]=n?0:u;e=n?-1:e;break e}e=Mk(a,h)}e=k[h+23|0]?j[j[h+2088>>2]+(e<<2)>>2]:e;if((e|0)==-1){break b}j[j[t+(g<<2)>>2]+(v<<2)>>2]=j[j[z+16>>2]+(e<<2)>>2]}g=g+1|0;if((g|0)!=(c|0)){continue}break}}f:{if((o|0)>=(q|0)){break f}e=0;if((y|0)<1){break f}while(1){g=0;if(!w){while(1){g:{if(k[f+g|0]){break g}h=g<<2;n=i[(j[A+20>>2]+(k[j[j[h+t>>2]+(v<<2)>>2]+e|0]<<4)|0)+(d<<1)>>1];if((n|0)<0){break g}u=j[b+h>>2];h=j[r+8>>2];if(!a5(a,j[a+124>>2]+p(n&65535,2096)|0,u,j[r>>2]+p(h,o)|0,h,x)){break b}}g=g+1|0;if((g|0)!=(c|0)){continue}break}}o=o+1|0;if((q|0)<=(o|0)){break f}e=e+1|0;if((y|0)>(e|0)){continue}break}}v=v+1|0;if((o|0)<(q|0)){continue}break}}d=d+1|0;if((d|0)!=8){continue}break}break b}if((c|0)==(g|0)){break b}z=(q|0)<1;A=z|(c|0)<3;v=h+p(e,24)|0;x=v;B=(c|0)!=2;e=0;while(1){h:{if(!B){if(z){break h}f=0;o=0;while(1){g=j[r>>2]+p(j[r+8>>2],f)|0;j[s+12>>2]=g&1;j[s+8>>2]=g>>1;if(!e){h=j[a+124>>2]+p(k[r+13|0],2096)|0;if(j[a+1396>>2]<=9){Dj(a)}n=j[a+1392>>2];g=i[(h+((n&1023)<<1)|0)+36>>1];i:{if((g|0)>=0){u=n;n=k[g+j[h+8>>2]|0];j[a+1392>>2]=u>>>n;w=j[a+1396>>2]-n|0;n=(w|0)<0;j[a+1396>>2]=n?0:w;g=n?-1:g;break i}g=Mk(a,h)}g=k[h+23|0]?j[j[h+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break b}j[j[t>>2]+(o<<2)>>2]=j[j[v+16>>2]+(g<<2)>>2]}j:{if((f|0)>=(q|0)){break j}g=0;if((y|0)<1){break j}while(1){h=j[r+8>>2];n=i[(j[x+20>>2]+(k[j[j[t>>2]+(o<<2)>>2]+g|0]<<4)|0)+(e<<1)>>1];k:{if((n|0)>=0){if(LE(a,j[a+124>>2]+p(n&65535,2096)|0,b,2,s+12|0,s+8|0,d,h)){break k}break b}h=j[r>>2]+(h+p(f,h)|0)|0;j[s+8>>2]=h>>1;j[s+12>>2]=h&1}f=f+1|0;if((q|0)<=(f|0)){break j}g=g+1|0;if((y|0)>(g|0)){continue}break}}o=o+1|0;if((f|0)<(q|0)){continue}break}break h}if(A){break h}f=0;o=0;while(1){h=j[r>>2]+p(j[r+8>>2],f)|0;g=(h|0)/(c|0)|0;j[s+12>>2]=h-p(c,g);j[s+8>>2]=g;if(!e){h=j[a+124>>2]+p(k[r+13|0],2096)|0;if(j[a+1396>>2]<=9){Dj(a)}n=j[a+1392>>2];g=i[(h+((n&1023)<<1)|0)+36>>1];l:{if((g|0)>=0){u=n;n=k[g+j[h+8>>2]|0];j[a+1392>>2]=u>>>n;w=j[a+1396>>2]-n|0;n=(w|0)<0;j[a+1396>>2]=n?0:w;g=n?-1:g;break l}g=Mk(a,h)}g=k[h+23|0]?j[j[h+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break b}j[j[t>>2]+(o<<2)>>2]=j[j[v+16>>2]+(g<<2)>>2]}m:{if((f|0)>=(q|0)){break m}g=0;if((y|0)<1){break m}while(1){h=j[r+8>>2];n=i[(j[x+20>>2]+(k[j[j[t>>2]+(o<<2)>>2]+g|0]<<4)|0)+(e<<1)>>1];n:{if((n|0)>=0){if(LE(a,j[a+124>>2]+p(n&65535,2096)|0,b,c,s+12|0,s+8|0,d,h)){break n}break b}h=j[r>>2]+(h+p(f,h)|0)|0;n=(h|0)/(c|0)|0;j[s+8>>2]=n;j[s+12>>2]=h-p(c,n)}f=f+1|0;if((q|0)<=(f|0)){break m}g=g+1|0;if((y|0)>(g|0)){continue}break}}o=o+1|0;if((f|0)<(q|0)){continue}break}}e=e+1|0;if((e|0)!=8){continue}break}}if(!j[a+80>>2]){Cb(t)}j[a+92>>2]=C;Za=s+16|0}function d5(a,b,c,d){var e=0,f=0,g=0,h=q(0),i=0,k=q(0),m=0,o=q(0),r=q(0),s=0,t=q(0),u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=q(0),C=q(0),D=q(0),E=q(0),F=0,G=0,H=0,I=0,J=0,K=0;v=b>>1;f=v<<2;J=j[c+92>>2];a:{if(j[c+80>>2]){u=im(c,f);break a}u=_c(f)}f=v<<2;w=f+a|0;f=(f+u|0)-8|0;i=j[((d<<2)+c|0)+1068>>2];b:{if(!v){e=i;break b}g=a;e=i;while(1){n[f+4>>2]=q(n[e>>2]*n[g>>2])-q(n[e+4>>2]*n[g+8>>2]);n[f>>2]=q(n[e>>2]*n[g+8>>2])+q(n[e+4>>2]*n[g>>2]);e=e+8|0;f=f-8|0;g=g+16|0;if((w|0)!=(g|0)){continue}break}}if(f>>>0>=u>>>0){g=((v<<2)+a|0)-12|0;while(1){n[f+4>>2]=q(n[e+4>>2]*n[g>>2])-q(n[e>>2]*n[g+8>>2]);n[f>>2]=q(n[e>>2]*q(-n[g>>2]))-q(n[e+4>>2]*n[g+8>>2]);g=g-16|0;e=e+8|0;f=f-8|0;if(u>>>0<=f>>>0){continue}break}}H=b>>2;if((b|0)>=16){g=H<<2;f=g+u|0;m=a+g|0;e=(i+(v<<2)|0)-32|0;s=a;g=u;while(1){r=n[g>>2];o=n[f>>2];k=n[g+4>>2];h=n[f+4>>2];n[m+4>>2]=k+h;n[m>>2]=n[g>>2]+n[f>>2];k=q(h-k);h=q(o-r);n[s+4>>2]=q(n[e+16>>2]*k)-q(n[e+20>>2]*h);n[s>>2]=q(n[e+20>>2]*k)+q(n[e+16>>2]*h);r=n[g+8>>2];o=n[f+8>>2];k=n[g+12>>2];h=n[f+12>>2];n[m+12>>2]=k+h;n[m+8>>2]=n[g+8>>2]+n[f+8>>2];k=q(h-k);h=q(o-r);n[s+12>>2]=q(n[e>>2]*k)-q(n[e+4>>2]*h);n[s+8>>2]=q(n[e+4>>2]*k)+q(n[e>>2]*h);g=g+16|0;f=f+16|0;s=s+16|0;m=m+16|0;e=e-32|0;if(i>>>0<=e>>>0){continue}break}}y=Nk(b);g=b>>4;m=v-1|0;e=b>>3;f=0-e|0;KE(g,a,m,f,i);KE(g,a,m-H|0,f,i);A=b>>5;f=0-g|0;$n(A,a,m,f,i,16);$n(A,a,m-e|0,f,i,16);$n(A,a,m-(e<<1)|0,f,i,16);$n(A,a,m+p(e,-3)|0,f,i,16);s=2;if((y|0)>=10){f=y-4>>1;s=(f|0)>3?f:3;f=2;while(1){g=f;f=f+1|0;F=2<<g;if((F|0)>=1){G=8<<g;e=0;x=b>>g+2;z=0-(x>>1)|0;g=b>>g+4;while(1){$n(g,a,m-p(e,x)|0,z,i,G);e=e+1|0;if((F|0)!=(e|0)){continue}break}}if((f|0)!=(s|0)){continue}break}}I=y-7|0;if((I|0)>(s|0)){while(1){f=s;s=f+1|0;e=b>>f+6;if((e|0)>=1){K=2<<f;y=8<<f;F=y<<2;G=b>>f+2;x=0-(G>>1)|0;f=i;g=m;while(1){_4(K,a,g,x,f,y,G);g=g-8|0;f=(F<<2)+f|0;z=(e|0)>1;e=e-1|0;if(z){continue}break}}if((s|0)!=(I|0)){continue}break}}Z4(A,a,m,i,b);x=v-4|0;e=((H<<2)+u|0)-16|0;if(u>>>0<=e>>>0){f=(x<<2)+u|0;g=j[((d<<2)+c|0)+1100>>2];while(1){i=(l[g>>1]<<2)+a|0;n[f+12>>2]=n[i>>2];n[f+8>>2]=n[i+4>>2];n[e+12>>2]=n[i+8>>2];n[e+8>>2]=n[i+12>>2];i=(l[g+2>>1]<<2)+a|0;n[f+4>>2]=n[i>>2];n[f>>2]=n[i+4>>2];n[e+4>>2]=n[i+8>>2];n[e>>2]=n[i+12>>2];g=g+4|0;f=f-16|0;e=e-16|0;if(u>>>0<=e>>>0){continue}break}}f=(v<<2)+u|0;i=f-16|0;if(u>>>0<i>>>0){g=j[((d<<2)+c|0)+1084>>2];m=f;e=u;while(1){B=n[g+4>>2];z=m-4|0;C=n[z>>2];o=n[e+4>>2];D=q(C+o);k=n[g>>2];E=n[e>>2];s=m-8|0;t=n[s>>2];h=q(E-t);r=q(q(B*D)-q(k*h));o=q(o-C);n[e+4>>2]=r+o;k=q(q(k*D)+q(B*h));h=q(t+E);n[e>>2]=k+h;n[z>>2]=r-o;n[s>>2]=h-k;B=n[g+12>>2];s=m-12|0;C=n[s>>2];o=n[e+12>>2];D=q(C+o);k=n[g+8>>2];E=n[e+8>>2];t=n[i>>2];h=q(E-t);r=q(q(B*D)-q(k*h));o=q(o-C);n[e+12>>2]=r+o;k=q(q(k*D)+q(B*h));h=q(t+E);n[e+8>>2]=k+h;n[i>>2]=h-k;n[s>>2]=r-o;g=g+16|0;e=e+16|0;m=i;i=i-16|0;if(e>>>0<i>>>0){continue}break}}i=f-32|0;if(u>>>0<=i>>>0){e=j[((d<<2)+c|0)+1076>>2]+(v<<2)|0;g=(x<<2)+a|0;m=((b<<2)+a|0)-16|0;while(1){t=n[e-4>>2];r=n[f-8>>2];o=n[e-8>>2];k=n[f-4>>2];h=q(q(t*r)-q(o*k));n[a>>2]=h;n[g+12>>2]=-h;h=q(q(o*q(-r))-q(k*t));n[w>>2]=h;n[m+12>>2]=h;t=n[e-12>>2];r=n[f-16>>2];o=n[e-16>>2];k=n[f-12>>2];h=q(q(t*r)-q(o*k));n[a+4>>2]=h;n[g+8>>2]=-h;h=q(q(o*q(-r))-q(k*t));n[w+4>>2]=h;n[m+8>>2]=h;t=n[e-20>>2];r=n[f-24>>2];o=n[e-24>>2];k=n[f-20>>2];h=q(q(t*r)-q(o*k));n[a+8>>2]=h;n[g+4>>2]=-h;h=q(q(o*q(-r))-q(k*t));n[w+8>>2]=h;n[m+4>>2]=h;t=n[e-28>>2];r=n[i>>2];e=e-32|0;o=n[e>>2];k=n[f-28>>2];h=q(q(t*r)-q(o*k));n[a+12>>2]=h;n[g>>2]=-h;h=q(q(o*q(-r))-q(k*t));n[w+12>>2]=h;n[m>>2]=h;m=m-16|0;g=g-16|0;w=w+16|0;a=a+16|0;f=i;i=f-32|0;if(u>>>0<=i>>>0){continue}break}}if(!j[c+80>>2]){Cb(u)}j[c+92>>2]=J}function Zqa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;f=Za-11360|0;Za=f;rc(c);a:{b:{if(!yb(c,4)){break b}c:{while(1){d:{NS(c,f+16|0);e:{if(!Yc(f+16|0,20249,3)){Xqa(c,f+4648|0);h=3;d=0;while(1){g=k[(f+4648|0)+h|0];if(g&128){break c}d=g|d<<7;h=h+1|0;if((h|0)!=7){continue}break}Jb(c,d);break e}f:{if(Yc(f+16|0,20253,3)){break f}if(!AO(c,20257)){break f}Jb(c,hf(c)+16|0);break e}if(!Yc(f+16|0,20263,3)){break e}if(!Yc(f+16|0,20267,3)){break e}if(k[f+16|0]){break d}cg(c,2)}if(yb(c,4)){continue}break b}break}if(yM(f+16|0)){break b}}h=0;break a}rc(c);$y(f+11336|0,c);h=j[f+11336>>2];j[114626]=0;c=H(412,f+11336|0)|0;d=j[114626];j[114626]=0;g:{h:{if((d|0)!=1){j[114626]=0;c=H(854,c|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break h}}h=D()|0;C()|0;break g}n=f+11320|0;VT(n);Ab(f+4648|0,0,6668);j[114626]=0;N(1233,f+4648|0);d=j[114626];j[114626]=0;i:{j:{k:{if((d|0)!=1){d=f+4640|0;j[d>>2]=0;j[d+4>>2]=0;d=f+4632|0;j[d>>2]=0;j[d+4>>2]=0;j[f+4624>>2]=0;j[f+4628>>2]=0;g=0;d=0;l:{m:{n:{while(1){j[114626]=0;m=ig(458,h,q);o=j[114626];j[114626]=0;if((o|0)==1){break l}j[114626]=0;r=U(1234,f+4648|0,c|0,m|0,f+16|0,f+4624|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break l}if((r|0)<0){break j}m=j[f+4624>>2];if((m|0)<0|!m&(r|0)>0|!(m|r)){break j}o:{if((m|0)>=1){o=j[f+4636>>2];if((o|0)!=(g|0)?g:0){break j}m=j[f+4632>>2];if((m|0)!=(d|0)?d:0){break j}if((o|0)<1|m-1>>>0>1){break k}j[114626]=0;j[f+8>>2]=0;d=ig(458,h,q);g=j[114626];j[114626]=0;if((g|0)==1){break o}j[114626]=0;j[f+4>>2]=d;d=K(1235,f+4624|0,f+8|0,f+4|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break o}d=j[d>>2];j[114626]=0;j[f+8>>2]=0;g=ig(458,h,q);s=j[114626];j[114626]=0;if((s|0)==1){break n}j[114626]=0;j[f+4>>2]=g;g=K(1235,f+4624|0,f+8|0,f+4|0)|0;s=j[114626];j[114626]=0;if((s|0)==1){break n}c=c+d|0;d=h;g=j[g>>2];h=d-g|0;q=q-((g>>31)+(d>>>0<g>>>0)|0)|0;if((r|0)>=1){t=f,u=Mb(n),j[t+8>>2]=u;Cd(f,f+8|0);j[114626]=0;P(1236,n|0,j[f>>2],f+16|0,(f+16|0)+(p(m,r)<<1)|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break m}}g=o;d=m}m=bc(n);if((q|0)<0?1:(q|0)<=0?h>>>0<1:0){break j}if((m>>>0)/(d>>>0)>>>0<268435457){continue}break j}break}h=D()|0;C()|0;break i}h=D()|0;C()|0;break i}h=J(71396)|0;if((C()|0)!=(W(71396)|0)){break i}O(h|0)|0;j[114626]=0;M(20);c=j[114626];j[114626]=0;g=o;d=m;if((c|0)!=1){break j}h=D()|0;C()|0;break i}h=D()|0;C()|0;break i}h=D()|0;C()|0;break i}g=o;d=m}h=0;p:{q:{r:{s:{t:{if(!d|!g){break t}if(ad(n)){break t}if((bc(n)>>>0)/(d>>>0)>>>0>268435456){break t}j[114626]=0;E(1237,a|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break p}if(!e){j[114626]=0;c=E(85,f+16|0,20271)|0;m=j[114626];j[114626]=0;if((m|0)==1){break s}j[114626]=0;E(369,((b<<5)+a|0)+946300|0,c|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break r}gb(c);j[114626]=0;c=p(b,104)+a|0;F(386,c+484380|0,0);m=j[114626];j[114626]=0;if((m|0)==1){break p}j[c+484404>>2]=g}g=p(b,104)+a|0;c=g+484380|0;t=c,u=(bc(n)>>>0)/(d>>>0)|0,j[t>>2]=u;m=g+484414|0;g=l[m>>1];i[m>>1]=(d|0)==2?g|65:g&65470|1;j[114626]=0;H(465,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break p}if(ke(c)){d=Lb(n);g=Mb(n);b=j[(p(b,104)+a|0)+484400>>2];j[114626]=0;K(1238,d|0,g|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break p}}if(!e){b=j[a+480180>>2];j[114626]=0;I(1239,c|0,32,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break q}j[114626]=0;I(1240,c|0,a|0,0);a=j[114626];j[114626]=0;if((a|0)==1){break p}}h=ke(c)}CA(n);lc(f+11336|0);break a}h=D()|0;C()|0;break i}h=D()|0;C()|0;gb(c);break i}h=D()|0;C()|0;break i}h=D()|0;C()|0}CA(n)}lc(f+11336|0);G(h|0);z()}Za=f+11360|0;return h|0}function N8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-352|0;Za=d;a:{if(Pi(b)){break a}e=k[Fj(b)|0];f=1;b:{if((e|0)==33){break b}if((e|0)!=63){break a}f=0}c=f;Pj(d+320|0,b,j[b+4>>2]-1|0);e=j[d+324>>2];j[b>>2]=j[d+320>>2];j[b+4>>2]=e}ld(d+320|0);e=j[d+320>>2];ld(d+304|0);e=Ej(e,j[d+308>>2],b);ld(d+320|0);c:{d:{e:{f:{if((e|0)==j[d+324>>2]){a=j[b+4>>2];j[d+344>>2]=j[b>>2];j[d+348>>2]=a;a=Zb(d+336|0,38235);e=j[d+348>>2];j[d+8>>2]=j[d+344>>2];j[d+12>>2]=e;e=j[a+4>>2];j[d>>2]=j[a>>2];j[d+4>>2]=e;if(nc(d+8|0,d)){a=R(8)|0;j[114626]=0;c=E(85,d+320|0,39169)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(c);break d}e=0;if(!c){break f}a=R(8)|0;j[114626]=0;c=E(2134,d+304|0,b|0)|0;b=j[114626];j[114626]=0;g:{h:{i:{if((b|0)!=1){j[114626]=0;I(2111,d+320|0,39179,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break i}Wb(a,d+320|0);e=0;j[114626]=0;I(2002,a|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break c}b=D()|0;C()|0;gb(d+320|0);break h}b=D()|0;C()|0;break g}b=D()|0;e=1;C()|0}gb(c);if(!e){break d}}S(a|0);break d}if(j[e+4>>2]){a=R(8)|0;j[114626]=0;c=E(85,d+320|0,39193)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(c);break d}b=D()|0;C()|0;S(a|0);break d}c=j[b+4>>2];j[d+296>>2]=j[b>>2];j[d+300>>2]=c;c=Zb(d+288|0,38235);e=j[d+300>>2];j[d+152>>2]=j[d+296>>2];j[d+156>>2]=e;e=j[c+4>>2];j[d+144>>2]=j[c>>2];j[d+148>>2]=e;if(nc(d+152|0,d+144|0)){a=R(8)|0;j[114626]=0;c=E(85,d+320|0,39169)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(c);break d}b=D()|0;C()|0;S(a|0);break d}c=j[b+4>>2];j[d+280>>2]=j[b>>2];j[d+284>>2]=c;c=Zb(d+272|0,38917);e=j[d+284>>2];j[d+136>>2]=j[d+280>>2];j[d+140>>2]=e;e=j[c+4>>2];j[d+128>>2]=j[c>>2];j[d+132>>2]=e;j:{if(!nc(d+136|0,d+128|0)){c=j[b+4>>2];j[d+264>>2]=j[b>>2];j[d+268>>2]=c;c=Zb(d+256|0,39214);e=j[d+268>>2];j[d+120>>2]=j[d+264>>2];j[d+124>>2]=e;e=j[c+4>>2];j[d+112>>2]=j[c>>2];j[d+116>>2]=e;if(!nc(d+120|0,d+112|0)){break j}}e=k[a+60|0]!=0;break f}c=j[b+4>>2];j[d+248>>2]=j[b>>2];j[d+252>>2]=c;c=Zb(d+240|0,38935);e=j[d+252>>2];j[d+104>>2]=j[d+248>>2];j[d+108>>2]=e;e=j[c+4>>2];j[d+96>>2]=j[c>>2];j[d+100>>2]=e;k:{if(!nc(d+104|0,d+96|0)){c=j[b+4>>2];j[d+232>>2]=j[b>>2];j[d+236>>2]=c;c=Zb(d+224|0,39232);e=j[d+236>>2];j[d+88>>2]=j[d+232>>2];j[d+92>>2]=e;e=j[c+4>>2];j[d+80>>2]=j[c>>2];j[d+84>>2]=e;if(!nc(d+88|0,d+80|0)){break k}}e=k[a+61|0]!=0;break f}c=j[b+4>>2];j[d+216>>2]=j[b>>2];j[d+220>>2]=c;c=Zb(d+208|0,38954);e=j[d+220>>2];j[d+72>>2]=j[d+216>>2];j[d+76>>2]=e;e=j[c+4>>2];j[d+64>>2]=j[c>>2];j[d+68>>2]=e;if(nc(d+72|0,d- -64|0)){e=k[a+62|0]!=0;break f}c=j[b+4>>2];j[d+200>>2]=j[b>>2];j[d+204>>2]=c;c=Zb(d+192|0,38972);e=j[d+204>>2];j[d+56>>2]=j[d+200>>2];j[d+60>>2]=e;e=j[c+4>>2];j[d+48>>2]=j[c>>2];j[d+52>>2]=e;if(nc(d+56|0,d+48|0)){e=k[a+63|0]!=0;break f}c=j[b+4>>2];j[d+184>>2]=j[b>>2];j[d+188>>2]=c;c=Zb(d+176|0,38996);e=j[d+188>>2];j[d+40>>2]=j[d+184>>2];j[d+44>>2]=e;e=j[c+4>>2];j[d+32>>2]=j[c>>2];j[d+36>>2]=e;if(nc(d+40|0,d+32|0)){e=k[a+64|0]!=0;break f}c=j[b+4>>2];j[d+168>>2]=j[b>>2];j[d+172>>2]=c;b=Zb(d+160|0,39070);c=j[d+172>>2];j[d+24>>2]=j[d+168>>2];j[d+28>>2]=c;c=j[b+4>>2];j[d+16>>2]=j[b>>2];j[d+20>>2]=c;e=0;if(!nc(d+24|0,d+16|0)){break f}e=j[j[a+24>>2]+24668>>2]!=0}Za=d+352|0;return e|0}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function D6(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-112|0;Za=c;f=Qc(c+96|0);j[114626]=0;g=E(2,c+80|0,6848)|0;d=j[114626];j[114626]=0;a:{b:{c:{if((d|0)!=1){d=j[b+20>>2];if(d){break c}Nc(a,f);break a}a=D()|0;C()|0;break b}j[114626]=0;j[c+48>>2]=d+1900;F(191,c- -64|0,c+48|0);d=j[114626];j[114626]=0;d:{e:{if((d|0)!=1){j[114626]=0;E(192,f|0,c- -64|0)|0;d=j[114626];j[114626]=0;f:{if((d|0)!=1){gb(c- -64|0);if(m[b+16>>2]<12){break f}Nc(a,f);break a}a=D()|0;C()|0;gb(c- -64|0);break d}j[114626]=0;d=E(2,c+48|0,6850)|0;e=j[114626];j[114626]=0;g:{h:{i:{j:{k:{l:{if((e|0)!=1){e=j[b+16>>2];j[114626]=0;j[c+16>>2]=e+1;F(193,c+32|0,c+16|0);e=j[114626];j[114626]=0;if((e|0)==1){break l}j[114626]=0;I(3,c- -64|0,d|0,c+32|0);e=j[114626];j[114626]=0;if((e|0)==1){break k}j[114626]=0;E(192,f|0,c- -64|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break j}gb(c- -64|0);gb(c+32|0);gb(d);if(j[b+12>>2]-1>>>0<31){break g}Nc(a,f);break a}a=D()|0;C()|0;break d}a=D()|0;C()|0;break h}a=D()|0;C()|0;break i}a=D()|0;C()|0;gb(c- -64|0)}gb(c+32|0)}gb(d);break d}j[114626]=0;d=E(2,c+48|0,6850)|0;e=j[114626];j[114626]=0;m:{n:{o:{p:{q:{r:{s:{if((e|0)!=1){j[114626]=0;F(193,c+32|0,b+12|0);e=j[114626];j[114626]=0;if((e|0)==1){break s}j[114626]=0;I(3,c- -64|0,d|0,c+32|0);e=j[114626];j[114626]=0;if((e|0)==1){break r}j[114626]=0;E(192,f|0,c- -64|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break q}gb(c- -64|0);gb(c+32|0);gb(d);d=j[b+8>>2];if(d){break n}if(j[b+4>>2]|j[b>>2]){break m}Nc(a,f);break a}a=D()|0;C()|0;break d}a=D()|0;C()|0;break o}a=D()|0;C()|0;break p}a=D()|0;C()|0;gb(c- -64|0)}gb(c+32|0)}gb(d);break d}if(d>>>0<24){break m}Nc(a,f);break a}if(m[b+4>>2]>=60){Nc(a,f);break a}j[114626]=0;d=E(2,c- -64|0,6852)|0;e=j[114626];j[114626]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((e|0)!=1){j[114626]=0;E(192,f|0,d|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break F}gb(d);if(j[b+32>>2]>=1){j[114626]=0;d=E(2,c- -64|0,6854)|0;e=j[114626];j[114626]=0;if((e|0)==1){break E}ob(g,d);gb(d)}j[114626]=0;F(193,c+32|0,b+8|0);d=j[114626];j[114626]=0;if((d|0)==1){break D}j[114626]=0;d=E(2,c+16|0,6861)|0;e=j[114626];j[114626]=0;if((e|0)==1){break C}j[114626]=0;I(3,c+48|0,c+32|0,d|0);e=j[114626];j[114626]=0;if((e|0)==1){break B}j[114626]=0;F(193,c|0,b+4|0);e=j[114626];j[114626]=0;if((e|0)==1){break A}j[114626]=0;I(3,c- -64|0,c+48|0,c|0);e=j[114626];j[114626]=0;if((e|0)==1){break z}j[114626]=0;E(192,f|0,c- -64|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break y}gb(c- -64|0);gb(c);gb(c+48|0);gb(d);gb(c+32|0);if(m[b>>2]<62){break t}j[114626]=0;I(194,a|0,f|0,g|0);a=j[114626];j[114626]=0;if((a|0)!=1){break a}break e}a=D()|0;C()|0;break d}a=D()|0;C()|0;gb(d);break d}a=D()|0;C()|0;break d}a=D()|0;C()|0;break d}a=D()|0;C()|0;break u}a=D()|0;C()|0;break v}a=D()|0;C()|0;break w}a=D()|0;C()|0;break x}a=D()|0;C()|0;gb(c- -64|0)}gb(c)}gb(c+48|0)}gb(d)}gb(c+32|0);break d}j[114626]=0;d=E(2,c+48|0,6861)|0;e=j[114626];j[114626]=0;G:{H:{I:{J:{K:{if((e|0)!=1){j[114626]=0;F(193,c+32|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break K}j[114626]=0;I(3,c- -64|0,d|0,c+32|0);b=j[114626];j[114626]=0;if((b|0)==1){break J}j[114626]=0;E(192,f|0,c- -64|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break I}gb(c- -64|0);gb(c+32|0);gb(d);j[114626]=0;E(192,f|0,g|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}Nc(a,f);break a}a=D()|0;C()|0;break d}a=D()|0;C()|0;break G}a=D()|0;C()|0;break H}a=D()|0;C()|0;gb(c- -64|0)}gb(c+32|0)}gb(d);break d}a=D()|0;C()|0;break d}a=D()|0;C()|0}gb(g)}gb(f);G(a|0);z()}gb(g);gb(f);Za=c+112|0}function Gf(a,b,c,d,e,f,g,h,i){var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,t=0,u=0;l=Za-112|0;Za=l;m=h;p=i&2147483647;n=c-(b>>>0<1)|0;k=b-1|0;r=(k|0)==-1&(n|0)==-1;t=d;q=(c|0)==(n|0)&b>>>0>k>>>0|c>>>0>n>>>0;o=d+q|0;n=e&2147483647;k=n;k=o>>>0<q>>>0?k+1|0:k;q=o-1|0;a:{b:{k=k-(o>>>0<1)|0;if(!((q|0)==-1&(k|0)==2147418111?r:k>>>0>2147418111)){k=f;o=g-(k>>>0<1)|0;k=k-1|0;r=(k|0)!=-1|(o|0)!=-1;q=(g|0)==(o|0)&f>>>0>k>>>0|g>>>0>o>>>0;o=q+m|0;k=p;k=o>>>0<q>>>0?k+1|0:k;q=o;o=o-1|0;k=k-(q>>>0<1)|0;if((o|0)==-1&(k|0)==2147418111?r:(k|0)==2147418111&(o|0)!=-1|k>>>0<2147418111){break b}}if(!(!t&(n|0)==2147418112?!(b|c):n>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!m&(p|0)==2147418112?!(f|g):p>>>0<2147418112)){i=i|32768;break a}if(!(b|t|(n^2147418112|c))){k=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:k;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|m|(p^2147418112|g))){break a}if(!(b|t|(c|n))){if(f|m|(g|p)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|m|(g|p)){break b}f=b;g=c;h=d;i=e;break a}r=(m|0)==(t|0)&(n|0)==(p|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:(n|0)==(p|0)&m>>>0>t>>>0|n>>>0<p>>>0;k=r;o=k?f:b;p=k?g:c;m=k?i:e;t=m;n=k?h:d;k=m&65535;i=r?e:i;e=i;h=r?d:h;q=i>>>16&32767;m=m>>>16&32767;if(!m){d=!(k|n);i=d<<6;m=s(d?o:n)+32|0;d=s(d?p:k);d=i+((d|0)==32?m:d)|0;We(l+96|0,o,p,n,k,d-15|0);n=j[l+104>>2];o=j[l+96>>2];p=j[l+100>>2];m=16-d|0;k=j[l+108>>2]}f=r?b:f;g=r?c:g;i=e&65535;if(!q){b=!(h|i);c=b<<6;d=s(b?f:h)+32|0;b=s(b?g:i);b=c+((b|0)==32?d:b)|0;We(l+80|0,f,g,h,i,b-15|0);q=16-b|0;h=j[l+88>>2];i=j[l+92>>2];g=j[l+84>>2];f=j[l+80>>2]}b=h;c=i<<3|b>>>29;h=b<<3|g>>>29;i=c|524288;b=n;d=k<<3|b>>>29;n=b<<3|p>>>29;u=d;r=e^t;b=f;k=g<<3|b>>>29;b=b<<3;c=k;d=m-q|0;e=b;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;k=0;e=1;break c}We(l- -64|0,b,c,h,i,128-d|0);fm(l+48|0,b,c,h,i,d);h=j[l+56>>2];i=j[l+60>>2];k=j[l+52>>2];e=j[l+48>>2]|((j[l+64>>2]|j[l+72>>2])!=0|(j[l+68>>2]|j[l+76>>2])!=0)}f=k;d=n;q=u|524288;b=o;k=p<<3|b>>>29;c=b<<3;d:{if((r|0)<-1?1:(r|0)<=-1){p=e;b=c-e|0;n=h;o=d-h|0;e=(f|0)==(k|0)&c>>>0<e>>>0|f>>>0>k>>>0;h=o-e|0;c=k-((c>>>0<p>>>0)+f|0)|0;i=(q-((d>>>0<n>>>0)+i|0)|0)-(e>>>0>o>>>0)|0;if(!(b|h|(c|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}f=b;d=!(h|i);e=d<<6;g=s(d?b:h)+32|0;b=s(d?c:i);b=e+((b|0)==32?g:b)|0;b=b-12|0;We(l+32|0,f,c,h,i,b);m=m-b|0;h=j[l+40>>2];i=j[l+44>>2];b=j[l+32>>2];c=j[l+36>>2];break d}b=c;g=b+e|0;c=f+k|0;c=b>>>0>g>>>0?c+1|0:c;b=g;g=(c|0)==(f|0)&e>>>0>b>>>0|c>>>0<f>>>0;e=d;f=d+h|0;d=i+q|0;d=e>>>0>f>>>0?d+1|0:d;e=g+f|0;h=e;i=h>>>0<f>>>0?d+1|0:d;if(!(i&1048576)){break d}b=b&1|((c&1)<<31|b>>>1);c=h<<31|c>>>1;m=m+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}k=0;p=t&-2147483648;if((m|0)>=32767){h=k;i=p|2147418112;f=0;g=0;break a}e=0;e:{if((m|0)>0){e=m;break e}We(l+16|0,b,c,h,i,m+127|0);fm(l,b,c,h,i,1-m|0);b=j[l>>2]|((j[l+16>>2]|j[l+24>>2])!=0|(j[l+20>>2]|j[l+28>>2])!=0);c=j[l+4>>2];h=j[l+8>>2];i=j[l+12>>2]}t=(c&7)<<29|b>>>3;g=t;m=b&7;b=g+(m>>>0>4)|0;d=h<<29|c>>>3;c=b>>>0<g>>>0?d+1|0:d;f=b;g=c;b=(d|0)==(c|0)&b>>>0<t>>>0|c>>>0<d>>>0;d=(i&7)<<29|h>>>3|k;b=b+d|0;k=p|i>>>3&65535|e<<16;h=b;i=b>>>0<d>>>0?k+1|0:k;f:{if((m|0)==4){k=i;c=0;d=g+c|0;e=f&1;b=f+e|0;d=b>>>0<f>>>0?d+1|0:d;f=b;g=d;c=(c|0)==(d|0)&b>>>0<e>>>0|c>>>0>d>>>0;b=c+h|0;h=b;i=b>>>0<c>>>0?k+1|0:k;break f}if(!m){break a}}}j[a>>2]=f;j[a+4>>2]=g;j[a+8>>2]=h;j[a+12>>2]=i;Za=l+112|0}function fAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=Za-256|0;Za=d;rc(b);a:{if(!zz(b,d+184|0)){break a}if(!XN(d+184|0)){break a}if(!yb(b,Wc(WN(d+184|0),ab))){break a}b:{if(!c){break b}od(a,16);en(d,2,d+184|4);qc(d+16|0,d);ob(a+1304400|0,d+16|0);gb(d+16|0);i[a+480190>>1]=k[d+214|0];i[a+480188>>1]=k[d+217|0];e=Eb(d+16|0,16588);ob(a+1304436|0,e);gb(e);e=Eb(d+16|0,16601);ob(a+1304448|0,e);gb(e);f=Eb(d+168|0,16605);j[114626]=0;F(219,d|0,f|0);e=j[114626];j[114626]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=d+184|3;j[d+152>>2]=k[e|0]>>>4;e=k[e|0];j[114626]=0;j[d+164>>2]=e&15;L(533,d+16|0,d|0,d+152|0,d+164|0);e=j[114626];j[114626]=0;if((e|0)==1){break i}ob(a+1304460|0,d+16|0);gb(d+16|0);qb(d);gb(f);j[a+1304496>>2]=4;if(l[a+480190>>1]){e=1;g=1;while(1){TS(b,d+16|0);eAa(d+16|0,(p(e,104)+a|0)+484380|0);on(d+152|0,2,d+16|0);qc(d,d+152|0);j[114626]=0;E(369,((e<<5)+a|0)+946300|0,d|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break e}gb(d);g=g+1|0;e=g&65535;if(e>>>0<=l[a+480190>>1]){continue}break}}if(l[a+480188>>1]){e=0;while(1){f=(e<<5)+a|0;vg(f+480280|0);i[f+480284>>1]=(k[(d+e|0)+218|0]<<4|8)&248;e=e+1|0;if(e>>>0<l[a+480188>>1]){continue}break}}dAa(b,d+16|0);cT(Fb(a+484360|0),d+16|0,k[d+211|0]+1|0);if(k[d+216|0]){break g}o=64;break f}e=D()|0;C()|0;break h}e=D()|0;C()|0;qb(d)}gb(f);break c}o=k[d+216|0]}cd(d,b,p(k[d+208|0]|k[d+209|0]<<8,192));j:{k:{if(!(c&1)){break k}e=k[d+210|0];j[114626]=0;s=a+484344|0;F(401,s|0,e+1|0);e=j[114626];j[114626]=0;if((e|0)==1){break d}while(1){j[114626]=0;f=K(402,s|0,q&65535,o|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break j}e=0;if(!f){break k}while(1){j[114626]=0;f=H(357,b|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break d}t=e;l:{if(!f|f>>>0>(k[d+208|0]|k[d+209|0]<<8)>>>0){break l}e=t&65535;if(e>>>0>=l[a+480188>>1]){break l}j[114626]=0;E(256,d|0,p(f,192)-192|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}f=Ib(s,q);j[114626]=0;e=K(471,f|0,0,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}u=0;if(!o){break l}while(1){j[114626]=0;F(805,d+152|0,d|0);f=j[114626];j[114626]=0;if((f|0)==1){break d}g=Pc(d+152|0);r=Bf(d+152|0);m=e;n=d+152|0;f=k[n|0];if(f>>>0>=4){h[e|0]=(f>>>2|0)+37;f=k[n|0]}h[m+1|0]=f<<4&48|k[g|0]>>>4;f=k[r|0];m=0;r=0;m:{n:{o:{p:{q:{r:{g=k[g|0]&15;switch(g-8|0){case 0:break o;case 6:break q;case 2:break r;default:break p}}f=f&240?f&-16:f&15;g=10;break n}g=14;n=(f+16&240)>>>4|0;if(n>>>0>8){break n}if(1<<n&435){break o}break n}m=g;r=f}f=r;g=m;if(!((f|g)&255)){break m}}h[e+5|0]=f;h[e+3|0]=g;j[114626]=0;N(574,e|0);f=j[114626];j[114626]=0;if((f|0)!=1){break m}break d}e=p(l[a+480188>>1],6)+e|0;u=u+1|0;if((u|0)!=(o|0)){continue}break}}e=t+1|0;if((t&65535)>>>0<31){continue}break}e=k[d+210|0]>q>>>0;q=q+1|0;if(e){continue}break}}if(k[d+212|0]|k[d+213|0]<<8){e=k[d+212|0]|k[d+213|0]<<8;j[114626]=0;U(547,a+1304424|0,b|0,e|0,39,1)|0;e=j[114626];j[114626]=0;if((e|0)==1){break d}}if(!(!(c&2)|!l[a+480190>>1])){f=1;while(1){c=p(f&65535,104)+a|0;e=Mc(d+152|0,i[c+484414>>1]&1?16:8,1,0,1);j[114626]=0;K(400,e|0,c+484380|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break d}f=f+1|0;if(l[a+480190>>1]>=(f&65535)>>>0){continue}break}}j[a+480260>>2]=64;j[a+480264>>2]=32767;jb(d);break b}break d}e=D()|0;C()|0;gb(d);break c}e=D()|0;C()|0;jb(d)}G(e|0);z()}e=1}Za=d+256|0;return e|0}function mK(a,b,c){var d=0,e=0,f=0,g=0,i=0,m=0,n=0,o=0,q=0;f=Za-16|0;Za=f;d=c&15;g=p(b,896)+a|0;e=g+1074984|0;a:{b:{switch((c&240)-16>>>4|0){case 0:a=g+1075072|0;j[a>>2]=j[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(k[a+480209|0]&16)){break a}if(j[a+480180>>2]!=64){b=p(b,896)+a|0;c=d<<28>>24;j[b+1075752>>2]=c;d=l[(d<<1)+21456>>1];j[b+1075688>>2]=d;e=b+1075684|0;if(!j[e>>2]){break a}o=e,q=Zf(a,k[b+1075803|0],c,d),j[o>>2]=q;break a}a=p(b,896)+a|0;b=j[a+1075088>>2];if(!b){break a}j[a+1075688>>2]=j[b+24>>2]+p(d,80);break a;case 2:if(j[a+480180>>2]==2){h[(p(b,896)+a|0)+1075826|0]=c&3;break a}mb(f+8|0,a+1074308|0,21);if(kb(f+8|0)){h[(p(b,896)+a|0)+1075826|0]=d>>>0<4?d:0;break a}h[(p(b,896)+a|0)+1075826|0]=c&7;break a;case 3:if(j[a+480180>>2]==2){h[(p(b,896)+a|0)+1075829|0]=c&3;break a}mb(f+8|0,a+1074308|0,21);if(kb(f+8|0)){h[(p(b,896)+a|0)+1075829|0]=d>>>0<4?d:0;break a}h[(p(b,896)+a|0)+1075829|0]=c&7;break a;case 4:mb(f+8|0,a+1074308|0,21);if(kb(f+8|0)){a=p(b,896)+a|0;h[a+1075825|0]=0;h[a+1075832|0]=d>>>0<4?d:0;break a}h[(p(b,896)+a|0)+1075832|0]=c&7;break a;case 5:if(j[a+1074392>>2]|!(k[a+480209|0]&16)){break a}a=a+1074400|0;j[a>>2]=j[a>>2]+d;break a;case 6:if(!(k[a+480209|0]&16)){break a}c:{switch(d|0){case 0:case 1:case 2:d=l[a+480188>>1];if(d>>>0>255){break a}e=a+1304392|0;m=b+1|0;n=(c&15)-1|0;while(1){c=p(d,896)+a|0;d:{if(l[c+1075792>>1]!=(m|0)){break d}e:{f:{switch(n|0){case 0:Cm(a,c+1074984|0);if(!(k[c+1075073|0]&2)){break e}if(!bd(e)){break e}Tj(j[e>>2],d&65535);break e;case 1:i=c+1075072|0;g=j[i>>2];j[i>>2]=g|4096;if(!(g&512)){break e}if(!bd(e)){break e}Tj(j[e>>2],d&65535);break e;default:break f}}j[c+1075680>>2]=0;i=c+1075072|0;g=j[i>>2];j[i>>2]=g|4096;if(!(g&512)){break e}if(!bd(e)){break e}bi(j[e>>2],d&65535,1)}g=j[c+1075640>>2];if(!g){break d}i=k[g+34|0];if(!i){break d}i=j[(p(i,160)+a|0)+906140>>2];if(!i){break d}bb[j[j[i>>2]+88>>2]](i,g,k[c+1075803|0]+255|0,0,b)}d=d+1|0;if((d&65535)!=256){continue}break}break a;case 3:h[(p(b,896)+a|0)+1075804|0]=0;break a;case 4:h[(p(b,896)+a|0)+1075804|0]=1;break a;case 5:h[(p(b,896)+a|0)+1075804|0]=2;break a;case 6:h[(p(b,896)+a|0)+1075804|0]=3;break a;case 7:a=(p(b,896)+a|0)+1075708|0;h[a|0]=k[a|0]&254;break a;case 8:a=(p(b,896)+a|0)+1075708|0;h[a|0]=k[a|0]|1;break a;case 9:a=(p(b,896)+a|0)+1075720|0;h[a|0]=k[a|0]&254;break a;case 10:a=(p(b,896)+a|0)+1075720|0;h[a|0]=k[a|0]|1;break a;case 11:a=(p(b,896)+a|0)+1075732|0;h[a|0]=k[a|0]&254;break a;case 12:a=(p(b,896)+a|0)+1075732|0;h[a|0]=k[a|0]|1;break a;case 13:case 14:break c;default:break a}}if(j[a+480180>>2]!=16777216){break a}b=(p(b,896)+a|0)+1075732|0;a=k[b|0];h[b|0]=(d|0)==13?a&238|1:a|17;break a;case 7:if(!(k[a+480209|0]&16)){break a}$k(a,e,d,4);break a;case 8:Hoa(a,e,d);break a;case 9:if(!(k[a+480209|0]&16)){break a}c=p(b,896)+a|0;h[c+1075840|0]=d;mb(f+8|0,a+1074308|0,35);if(kb(f+8|0)){break a}if(!Lf(c+1075794|0)){break a}b=j[(p(b,896)+a|0)+1075060>>2];a=d<<16;if(b>>>0<=a>>>0){break a}j[e+4>>2]=a;break a;case 11:g:{if(d){break g}d=1;if(j[a+480180>>2]&16777248){break g}d=0;if(j[a+480180>>2]==2){break a}}mb(f+8|0,a+1074308|0,30);c=a;if(kb(f+8|0)){a=1}else{a=j[a+480180>>2]==2}ux(c,b,d,a);break a;case 14:break b;default:break a}}if(j[a+480180>>2]==2){break a}h[(p(b,896)+a|0)+1075848|0]=d}Za=f+16|0}function lma(a,b,c,d){var e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;n=Za-16|0;Za=n;q=p(b,896)+a|0;e=j[q+1075640>>2];a:{if(!e){break a}f=k[e+34|0];if(!f|k[e+15|0]&2|(!j[(p(f,160)+a|0)+906140>>2]|j[(p(b,896)+a|0)+1075072>>2]&134218752)){break a}f=p(b,896)+a|0;r=f+1075797|0;s=k[r|0];o=f+1075805|0;if(Ld(k[o|0])){g=k[Pb(e+108|0,k[o|0]-1|0)|0]}o=f+1075794|0;b:{c:{if((s|0)==1){e=0;d:{e:{switch((m[a+1074392>>2]%3|0)-1|0){case 0:e=k[(p(b,896)+a|0)+1075812|0]>>>4|0;break d;case 1:break e;default:break d}}e=k[(p(b,896)+a|0)+1075812|0]&15}f=p(b,896)+a|0;h[f+1075807|0]=g;if(k[f+1075806|0]==(e+g|0)){break b}if(!(k[a+480209|0]&16)){break c}if(!Lf(o)){break c}break b}e=0;if(k[o|0]|!k[(p(b,896)+a|0)+1075806|0]){break b}}f=p(b,896)+a|0;Mj(a,b,k[f+1075807|0]+e|0,l[f+1075672>>1])}f=(p(b,896)+a|0)+1075806|0;t=k[f|0];f:{if(t){Mj(a,b,t+255|0,0);break f}if(!(k[a+480209|0]&16)|(s|0)!=1){break f}if(Lf(o)){break f}if(!Ld(g)){break f}Mj(a,b,g+255|0,0)}h[f|0]=k[r|0]==1?k[(p(b,896)+a|0)+1075807|0]+e|0:0}g:{if(k[q+1075811|0]!=1){break g}if(Wi(q+1074984|0)){g=0;h:{i:{j:{switch(m[a+1074392>>2]%3|0){case 1:g=k[(p(b,896)+a|0)+1075812|0]>>>4|0;break i;case 0:break i;case 2:break j;default:break h}}g=k[(p(b,896)+a|0)+1075812|0]&15}i[d>>1]=g}a=(p(b,896)+a|0)+1075856|0;h[a|0]=k[a|0]|12;break g}if(!(!(k[a+480209|0]&16)|j[a+480180>>2]!=1048576)){d=p(b,896)+a|0;e=Zf(a,k[d+1075803|0],j[d+1075752>>2],j[d+1075688>>2]);j[c>>2]=e;j[d+1075684>>2]=e}g=a+1074308|0;mb(n+8|0,g,13);if(kb(n+8|0)){g=k[(p(b,896)+a|0)+1075812|0];if(!g){break g}b=65536;k:{switch(((m[a+1074392>>2]%(j[a+1074400>>2]+j[a+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:g=g<<4;case 0:b=j[((g&240)<<2)+25312>>2];break;default:break k}}e=zo(a);a=j[c>>2];d=a;a=a>>31;if(e){b=OMa(d,a,b,b>>31)+32768|0;a=ab;a=PMa(b,b>>>0<32768?a+1|0:a,65536,0)}else{a=a<<16|d>>>16;e=(b|0)/2|0;f=d<<16;d=e+f|0;a=a+(e>>31)|0;a=PMa(d,d>>>0<f>>>0?a+1|0:a,b,b>>31)}b=ab;u=c,v=ic(a,b),j[u>>2]=v;break g}mb(n+8|0,g,51);if(kb(n+8|0)){if(k[a+480209|0]&16){break g}l:{m:{d=j[a+1074416>>2];d=d-(m[a+1074392>>2]%(d>>>0)|0)|0;if((d|0)>16){break m}if((d|0)==16){break g}e=0;n:{switch((d|0)%3|0){case 0:break g;case 2:break m;case 1:break n;default:break l}}e=k[(p(b,896)+a|0)+1075812|0]>>>4|0;break l}e=k[(p(b,896)+a|0)+1075812|0]&15}b=p(b,896)+a|0;d=b+1075752|0;b=b+1075688|0;e=Qr(a,j[c>>2],j[d>>2],j[b>>2])+e|0;d=Zf(a,e,j[d>>2],j[b>>2]);j[c>>2]=d;if(e>>>0<109){break g}j[n+8>>2]=d;u=n,v=Zf(a,109,0,j[b>>2]),j[u+4>>2]=v;u=c,v=j[Gc(n+8|0,n+4|0)>>2],j[u>>2]=v;break g}d=j[a+1074392>>2];if(j[a+480180>>2]!=1){e=k[(p(b,896)+a|0)+1075803|0]}else{e=p(b,896)+a|0;e=Qr(a,j[c>>2],j[e+1075752>>2],j[e+1075688>>2])}o:{p:{switch((((j[a+480180>>2]&67633152?d+2|0:d)>>>0)%3|0)-1|0){case 0:e=(k[(p(b,896)+a|0)+1075812|0]>>>4|0)+e|0;break o;case 1:break p;default:break o}}e=(k[(p(b,896)+a|0)+1075812|0]&15)+e|0}if(!(j[a+480180>>2]&67633408|k[(p(b,896)+a|0)+1075803|0]!=(e&255))){mb(n+8|0,g,82);if(!kb(n+8|0)){break g}}f=c;q=a;if(k[a+480210|0]&32){o=e&255;if((o|0)==85){j[c>>2]=2147483647;break g}e=o>>>0>85?e-37|0:e}d=p(b,896)+a|0;u=f,v=Zf(q,e&255,j[d+1075752>>2],j[d+1075688>>2]),j[u>>2]=v;if(j[a+480180>>2]&71827712){j[d+1075684>>2]=j[c>>2];break g}mb(n+8|0,g,82);if(!kb(n+8|0)){break g}h[(p(b,896)+a|0)+1075806|0]=e}Za=n+16|0}function BD(a,b,c,d,e){var f=0,g=0,i=0,l=0,n=0,o=0,q=0,r=0,s=0;q=Za-16|0;Za=q;a:{b:{c:{d:{e:{f:{if(b>>>0<=36){while(1){f=j[a+4>>2];g:{if(f>>>0<m[a+104>>2]){j[a+4>>2]=f+1;f=k[f|0];break g}f=Lc(a)}if($l(f)){continue}break}h:{i:{switch(f-43|0){case 0:case 2:break i;default:break h}}r=(f|0)==45?-1:0;f=j[a+4>>2];if(f>>>0<m[a+104>>2]){j[a+4>>2]=f+1;f=k[f|0];break h}f=Lc(a)}j:{if(!(b&-17|(f|0)!=48)){f=j[a+4>>2];k:{if(f>>>0<m[a+104>>2]){j[a+4>>2]=f+1;f=k[f|0];break k}f=Lc(a)}if((f&-33)==88){b=16;f=j[a+4>>2];l:{if(f>>>0<m[a+104>>2]){j[a+4>>2]=f+1;f=k[f|0];break l}f=Lc(a)}if(k[f+57441|0]<16){break e}if(!j[a+104>>2]){d=0;e=0;if(c){break a}break b}b=j[a+4>>2];j[a+4>>2]=b-1;if(!c){break b}j[a+4>>2]=b-2;d=0;e=0;break a}if(b){break j}b=8;break e}b=b?b:10;if(b>>>0>k[f+57441|0]){break j}if(j[a+104>>2]){j[a+4>>2]=j[a+4>>2]-1}d=0;e=0;Hg(a,0,0);j[114600]=28;break a}if((b|0)!=10){break e}c=f-48|0;if(c>>>0<=9){b=0;while(1){b=p(b,10)+c|0;c=j[a+4>>2];m:{if(c>>>0<m[a+104>>2]){j[a+4>>2]=c+1;f=k[c|0];break m}f=Lc(a)}c=f-48|0;if(b>>>0<429496729?c>>>0<=9:0){continue}break}g=b}if(c>>>0>9){break f}n=OMa(g,0,10,0);l=ab;b=c;while(1){c=j[a+4>>2];n:{if(c>>>0<m[a+104>>2]){j[a+4>>2]=c+1;f=k[c|0];break n}f=Lc(a)}c=f-48|0;o=c>>>0>9;i=l;g=b+n|0;i=g>>>0<b>>>0?i+1|0:i;if((i|0)==429496729&g>>>0>=2576980378|i>>>0>429496729|o){break f}n=OMa(g,i,10,0);l=ab;b=c;if((l|0)==-1&n>>>0<=(c^-1)>>>0|(l|0)!=-1){continue}break}b=10;break d}j[114600]=28;d=0;e=0;break a}b=10;if(c>>>0<=9){break d}break c}if(b-1&b){c=k[f+57441|0];if(c>>>0<b>>>0){while(1){l=p(b,l)+c|0;g=l>>>0<=119304646;c=j[a+4>>2];o:{if(c>>>0<m[a+104>>2]){j[a+4>>2]=c+1;f=k[c|0];break o}f=Lc(a)}c=k[f+57441|0];if(c>>>0<b>>>0?g:0){continue}break}g=l}if(b>>>0<=c>>>0){break d}l=b;while(1){o=OMa(g,i,l,0);n=ab;c=c&255;if((n|0)==-1&(c^-1)>>>0<o>>>0){break d}i=n;f=c+o|0;i=f>>>0<c>>>0?i+1|0:i;g=f;n=b;c=j[a+4>>2];p:{if(c>>>0<m[a+104>>2]){j[a+4>>2]=c+1;f=k[c|0];break p}f=Lc(a)}c=k[f+57441|0];if(n>>>0<=c>>>0){break d}eh(q,l,0,g,i);if(!(j[q+8>>2]|j[q+12>>2])){continue}break}break d}n=h[(p(b,23)>>>5&7)+57697|0];c=k[f+57441|0];if(c>>>0<b>>>0){while(1){l=l<<n|c;g=l>>>0<=134217727;c=j[a+4>>2];q:{if(c>>>0<m[a+104>>2]){j[a+4>>2]=c+1;f=k[c|0];break q}f=Lc(a)}c=k[f+57441|0];if(c>>>0<b>>>0?g:0){continue}break}g=l}s=b>>>0<=c>>>0;l=n;o=l&31;if((l&63)>>>0>=32){n=0;o=-1>>>o|0}else{n=-1>>>o|0;o=(1<<o)-1<<32-o|-1>>>o}if(!n&g>>>0>o>>>0|s){break d}while(1){s=c&255;c=l;f=c&31;if((c&63)>>>0>=32){i=g<<f;c=0}else{i=(1<<f)-1&g>>>32-f|i<<f;c=g<<f}g=s|c;c=j[a+4>>2];r:{if(c>>>0<m[a+104>>2]){j[a+4>>2]=c+1;f=k[c|0];break r}f=Lc(a)}if((i|0)==(n|0)&g>>>0>o>>>0|i>>>0>n>>>0){break d}c=k[f+57441|0];if(c>>>0<b>>>0){continue}break}}if(k[f+57441|0]>=b>>>0){break c}while(1){f=j[a+4>>2];s:{if(f>>>0<m[a+104>>2]){j[a+4>>2]=f+1;c=k[f|0];break s}c=Lc(a)}if(k[c+57441|0]<b>>>0){continue}break}j[114600]=68;r=d&1?0:r;g=d;i=e}if(j[a+104>>2]){j[a+4>>2]=j[a+4>>2]-1}t:{if((e|0)==(i|0)&d>>>0>g>>>0|e>>>0>i>>>0){break t}if(!(d&1|r)){j[114600]=68;a=d;d=a-1|0;e=e-(a>>>0<1)|0;break a}if((e|0)==(i|0)&d>>>0>=g>>>0|e>>>0>i>>>0){break t}j[114600]=68;break a}a=r;b=a^g;d=b-a|0;c=a>>31;e=(c^i)-((a>>>0>b>>>0)+c|0)|0;break a}d=0;e=0;Hg(a,0,0)}Za=q+16|0;ab=e;return d}function Cb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;a:{if(!a){break a}d=a-8|0;b=j[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=j[d>>2];d=d-b|0;if(d>>>0<m[115940]){break a}a=a+b|0;if(j[115941]!=(d|0)){if(b>>>0<=255){e=j[d+8>>2];b=b>>>3|0;c=j[d+12>>2];if((c|0)==(e|0)){i=463744,k=j[115936]&TMa(-2,b),j[i>>2]=k;break b}j[e+12>>2]=c;j[c+8>>2]=e;break b}h=j[d+24>>2];b=j[d+12>>2];c:{if((d|0)!=(b|0)){c=j[d+8>>2];j[c+12>>2]=b;j[b+8>>2]=c;break c}d:{e=d+20|0;c=j[e>>2];if(c){break d}e=d+16|0;c=j[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=j[e>>2];if(c){continue}e=b+16|0;c=j[b+16>>2];if(c){continue}break}j[g>>2]=0}if(!h){break b}e=j[d+28>>2];c=(e<<2)+464048|0;e:{if(j[c>>2]==(d|0)){j[c>>2]=b;if(b){break e}i=463748,k=j[115937]&TMa(-2,e),j[i>>2]=k;break b}j[h+(j[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}j[b+24>>2]=h;c=j[d+16>>2];if(c){j[b+16>>2]=c;j[c+24>>2]=b}c=j[d+20>>2];if(!c){break b}j[b+20>>2]=c;j[c+24>>2]=b;break b}b=j[f+4>>2];if((b&3)!=3){break b}j[115938]=a;j[f+4>>2]=b&-2;j[d+4>>2]=a|1;j[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=j[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(j[115942]==(f|0)){j[115942]=d;a=j[115939]+a|0;j[115939]=a;j[d+4>>2]=a|1;if(j[115941]!=(d|0)){break a}j[115938]=0;j[115941]=0;return}if(j[115941]==(f|0)){j[115941]=d;a=j[115938]+a|0;j[115938]=a;j[d+4>>2]=a|1;j[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){c=j[f+8>>2];b=b>>>3|0;e=j[f+12>>2];if((c|0)==(e|0)){i=463744,k=j[115936]&TMa(-2,b),j[i>>2]=k;break g}j[c+12>>2]=e;j[e+8>>2]=c;break g}h=j[f+24>>2];b=j[f+12>>2];h:{if((f|0)!=(b|0)){c=j[f+8>>2];j[c+12>>2]=b;j[b+8>>2]=c;break h}i:{e=f+20|0;c=j[e>>2];if(c){break i}e=f+16|0;c=j[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=j[e>>2];if(c){continue}e=b+16|0;c=j[b+16>>2];if(c){continue}break}j[g>>2]=0}if(!h){break g}e=j[f+28>>2];c=(e<<2)+464048|0;j:{if(j[c>>2]==(f|0)){j[c>>2]=b;if(b){break j}i=463748,k=j[115937]&TMa(-2,e),j[i>>2]=k;break g}j[h+(j[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}j[b+24>>2]=h;c=j[f+16>>2];if(c){j[b+16>>2]=c;j[c+24>>2]=b}c=j[f+20>>2];if(!c){break g}j[b+20>>2]=c;j[c+24>>2]=b}j[d+4>>2]=a|1;j[a+d>>2]=a;if(j[115941]!=(d|0)){break f}j[115938]=a;return}j[f+4>>2]=b&-2;j[d+4>>2]=a|1;j[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+463784|0;c=j[115936];a=1<<a;k:{if(!(c&a)){j[115936]=a|c;a=b;break k}a=j[b+8>>2]}j[b+8>>2]=d;j[a+12>>2]=d;j[d+12>>2]=b;j[d+8>>2]=a;return}e=31;j[d+16>>2]=0;j[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}j[d+28>>2]=e;g=(e<<2)+464048|0;l:{m:{c=j[115937];b=1<<e;n:{if(!(c&b)){j[115937]=b|c;j[g>>2]=d;j[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=j[g>>2];while(1){c=b;if((j[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=j[g+16>>2];if(b){continue}break}j[g+16>>2]=d;j[d+24>>2]=c}j[d+12>>2]=d;j[d+8>>2]=d;break l}a=j[c+8>>2];j[a+12>>2]=d;j[c+8>>2]=d;j[d+24>>2]=0;j[d+12>>2]=c;j[d+8>>2]=a}a=j[115944]-1|0;j[115944]=a;if(a){break a}d=464200;while(1){a=j[d>>2];d=a+8|0;if(a){continue}break}j[115944]=-1}}function vGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0;e=Za-272|0;Za=e;gGa(e+24|0,b);j[114626]=0;g=K(674,e+128|0,e+24|0,8)|0;b=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){gb(e+24|0);if(c>>>0<2189){break g}j[114626]=0;b=E(682,e+24|0,g|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break c}j[114626]=0;c=E(683,e+8|0,14349)|0;d=j[114626];j[114626]=0;if((d|0)==1){break z}j[114626]=0;j[e>>2]=19465728;j[e+4>>2]=0;I(684,b|0,c|0,e|0);d=j[114626];j[114626]=0;if((d|0)==1){break y}qb(c);j[114626]=0;h[e|0]=0;c=E(683,e+8|0,14357)|0;d=j[114626];j[114626]=0;if((d|0)==1){break i}d=0;j[114626]=0;K(685,b|0,e|0,c|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break x}qb(c);if(!k[e|0]){j[114626]=0;d=H(686,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break w}}f=j[a+4>>2];j[114626]=0;c=E(683,e+8|0,14368)|0;i=j[114626];j[114626]=0;if((i|0)==1){break v}j[114626]=0;L(687,b|0,f|0,c|0,d|0);f=j[114626];j[114626]=0;if((f|0)==1){break u}qb(c);j[114626]=0;c=E(683,e+8|0,14370)|0;f=j[114626];j[114626]=0;if((f|0)==1){break t}j[114626]=0;L(688,b|0,a|0,c|0,d|0);d=j[114626];j[114626]=0;if((d|0)==1){break s}qb(c);j[114626]=0;c=E(683,e+8|0,14372)|0;d=j[114626];j[114626]=0;if((d|0)==1){break r}j[114626]=0;d=a+484360|0;P(689,b|0,d|0,c|0,690)|0;f=j[114626];j[114626]=0;if((f|0)==1){break q}qb(c);j[114626]=0;c=E(683,e+8|0,14374)|0;f=j[114626];j[114626]=0;if((f|0)==1){break p}j[114626]=0;P(691,b|0,a+484344|0,c|0,692)|0;f=j[114626];j[114626]=0;if((f|0)==1){break o}qb(c);j[114626]=0;f=H(686,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break n}j[114626]=0;c=E(683,e+8|0,14380)|0;i=j[114626];j[114626]=0;if((i|0)==1){break m}j[114626]=0;L(693,b|0,d|0,c|0,f|0);d=j[114626];j[114626]=0;if((d|0)==1){break l}qb(c);if(j[b>>2]&1073741824){j[114626]=0;c=E(2,e+8|0,14388)|0;d=j[114626];j[114626]=0;if((d|0)==1){break k}j[114626]=0;I(647,a|0,1,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break j}gb(c)}ag(b);break f}a=D()|0;C()|0;gb(e+24|0);break a}a=D()|0;C()|0;break h}a=D()|0;C()|0;qb(c);break h}a=D()|0;C()|0;qb(c);break h}a=D()|0;C()|0;break h}a=D()|0;C()|0;break h}a=D()|0;C()|0;qb(c);break h}a=D()|0;C()|0;break h}a=D()|0;C()|0;qb(c);break h}a=D()|0;C()|0;break h}a=D()|0;C()|0;qb(c);break h}a=D()|0;C()|0;break h}a=D()|0;C()|0;qb(c);break h}a=D()|0;C()|0;break h}a=D()|0;C()|0;break h}a=D()|0;C()|0;qb(c);break h}a=D()|0;C()|0;break h}a=D()|0;C()|0;gb(c);break h}a=D()|0;C()|0}ag(b);break b}b=Qc(e+24|0);d=j[a+4>>2];j[114626]=0;f=H(686,a|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break e}j[114626]=0;d=P(694,d|0,g|0,b|0,f|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}A:{if((d|0)!=1){j[114626]=0;c=E(2,e+8|0,14437)|0;d=j[114626];j[114626]=0;B:{if((d|0)!=1){j[114626]=0;I(647,a|0,1,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break B}gb(c);break A}a=D()|0;C()|0;break d}a=D()|0;C()|0;gb(c);break d}j[114626]=0;d=H(686,a|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}j[114626]=0;L(695,g|0,a|0,d|0,c>>>0<2188|0);a=j[114626];j[114626]=0;if((a|0)==1){break e}}gb(b)}Xe(g);Za=e+272|0;return}a=D()|0;C()|0}gb(b);break b}a=D()|0;C()|0}Xe(g)}G(a|0);z()}function tJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;e=Za-720|0;Za=e;rc(b);f=e+104|0;g=mJa(b,f);if(!g){sR(f)}a:{if(!g){break a}if(!tR(e+104|0)){break a}b:{if(!c){break b}od(a,67108864);_h(a);d=k[e+129|0];i[a+480190>>1]=31;i[a+480188>>1]=d;j[a+480228>>2]=256/(d>>>0);d=Eb(e,12631);ob(a+1304436|0,d);gb(d);d=Eb(e,12643);ob(a+1304448|0,d);gb(d);f=Eb(e+88|0,12648);j[114626]=0;F(219,e- -64|0,f|0);d=j[114626];j[114626]=0;c:{d:{if((d|0)!=1){j[e+84>>2]=k[e+128|0]>>>4;d=k[e+128|0];j[114626]=0;j[e+80>>2]=d&15;L(533,e|0,e- -64|0,e+84|0,e+80|0);d=j[114626];j[114626]=0;if((d|0)!=1){ob(a+1304460|0,e);gb(e);qb(e- -64|0);gb(f);j[a+1304496>>2]=2;fn(Fb(a+484360|0),e+152|0,k[e+151|0]+1|0,65535,65535);f=0;while(1){d=f+1|0;n=p(d,104)+a|0;o=n+484380|0;md(o,1);g=(e+104|0)+(f<<2)|0;m=k[g+176|0]|k[g+177|0]<<8|(k[g+178|0]<<16|k[g+179|0]<<24);j[o>>2]=m<<24|m<<8&16711680|(m>>>8&65280|m>>>24);m=k[g+300|0]|k[g+301|0]<<8|(k[g+302|0]<<16|k[g+303|0]<<24);q=m<<24|m<<8&16711680|(m>>>8&65280|m>>>24);j[n+484384>>2]=q;m=k[g+424|0]|k[g+425|0]<<8|(k[g+426|0]<<16|k[g+427|0]<<24);j[n+484388>>2]=q+(m<<24|m<<8&16711680|(m>>>8&65280|m>>>24));if(k[g+424|0]|k[g+425|0]<<8|(k[g+426|0]<<16|k[g+427|0]<<24)){g=n+484414|0;i[g>>1]=l[g>>1]|2}Nm(o);f=(e+104|0)+f|0;h[e|0]=k[f+548|0];h[e+64|0]=64;u=n+484410|0,v=k[Yb(e,e- -64|0)|0]<<2,i[u>>1]=v;h[n+484417|0]=k[f+579|0]<<4;f=d;if((d|0)!=31){continue}break}Iz(b,a+1304400|0,32);d=1;while(1){OS(b,((d<<5)+a|0)+946300|0,30);d=d+1|0;if((d|0)!=32){continue}break}q=c&1;if(q){If(a+484344|0,k[e+150|0]+1|0)}o=a+484344|0;d=0;e:{while(1){n=zh(e- -64|0);f:{if(k[e+130|0]){j[114626]=0;f=H(484,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break e}j[114626]=0;I(341,e|0,b|0,f|0);break f}f=l[a+480188>>1];j[114626]=0;I(341,e|0,b|0,f<<8)}f=j[114626];j[114626]=0;if((f|0)==1){break e}g=d;Ed(n,e);jb(e);g:{if(!q){break g}j[114626]=0;d=K(402,o|0,g&65535,64)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}if(!d){break g}if(!k[e+130|0]){d=0;if(!l[a+480188>>1]){break g}while(1){f=0;while(1){m=Ib(o,g);j[114626]=0;m=K(471,m|0,f|0,d&65535)|0;r=j[114626];j[114626]=0;if((r|0)==1){break e}j[114626]=0;F(534,n|0,m|0);m=j[114626];j[114626]=0;if((m|0)==1){break e}f=f+1|0;if((f|0)!=64){continue}break}d=d+1|0;if(l[a+480188>>1]>(d&65535)>>>0){continue}break}break g}m=0;j[114626]=0;E(535,n|0,e|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}while(1){d=Ib(o,g);j[114626]=0;r=E(496,d|0,m|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}if(l[a+480188>>1]){s=e+m|0;d=128;f=0;while(1){h:{if(!(k[s|0]&d)){break h}j[114626]=0;F(534,n|0,r+p(f,6)|0);t=j[114626];j[114626]=0;if((t|0)!=1){break h}break e}d=d>>>1|0;f=f+1|0;if(f>>>0<l[a+480188>>1]){continue}break}}m=m+1|0;if((m|0)!=64){continue}break}}jb(n);d=g+1|0;if(g>>>0<k[e+150|0]){continue}break}d=1;if(!(c&2)){break a}c=Mc(e,8,1,1,0);while(1){$f(c,(p(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}d=D()|0;C()|0;jb(n);break c}d=D()|0;C()|0;qb(e- -64|0);break d}d=D()|0;C()|0}gb(f)}G(d|0);z()}d=1}Za=e+720|0;return d|0}function wHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,A=0;e=Za-976|0;Za=e;rc(b);g=e+872|0;f=sHa(b,g);if(!f){JQ(g)}a:{if(!f){break a}if(!MQ(e+872|0)){break a}if(!yb(b,Wc(LQ(e+872|0),ab))){break a}b:{if(!c){break b}od(a,512);j[a+480228>>2]=32;i[a+480188>>1]=16;j[a+480196>>2]=k[e+947|0];j[a+480200>>2]=256;j[a+480204>>2]=8e5;d=Eb(e+96|0,12920);ob(a+1304436|0,d);gb(d);d=Eb(e+96|0,12939);ob(a+1304448|0,d);gb(d);j[a+1304496>>2]=4;KQ(e+24|0,2,e+872|4);qc(e+96|0,e+24|0);ob(a+1304400|0,e+96|0);gb(e+96|0);d=0;while(1){g=(d<<5)+a|0;f=g+480280|0;vg(f);m=f;f=(e+872|0)+d|0;j[m>>2]=!k[f+50|0]<<10;i[g+480284>>1]=(k[f+76|0]<<4|8)&248;d=d+1|0;if((d|0)!=16){continue}break}if(k[e+968|0]|k[e+969|0]<<8){Xx(a+1304424|0,b,k[e+968|0]|k[e+969|0]<<8,132,0)}d=0;if(!uHa(b,e+96|0)){break a}d=a+484360|0;mz(Fb(d),e+96|0,k[e+353|0],255,254);Ge(Fb(d),k[e+354|0]);xc(b,k[e+919|0]|k[e+920|0]<<8);s=a+484344|0;u=c&1;g=0;c:{d:{while(1){d=(g<<1)+e|0;f=d+355|0;if(k[f|0]|k[f+1|0]<<8){cd(e+24|0,b,k[d+355|0]|k[d+356|0]<<8);d=k[d+355|0]|k[d+356|0]<<8;q=(d-2|0)/64|0;e:{if(!u){break e}j[114626]=0;f=K(402,s|0,g&65535,q|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break d}if(!f){break e}j[114626]=0;o=H(387,e+24|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}j[114626]=0;E(338,e+24|0,1)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}if(d>>>0>=66){v=q>>>0>1?q:1;m=0;while(1){d=Ib(s,g);j[114626]=0;w=E(496,d|0,m|0)|0;d=j[114626];j[114626]=0;r=0;if((d|0)==1){break d}while(1){j[114626]=0;F(595,e+80|0,e+24|0);d=j[114626];j[114626]=0;f:{g:{if((d|0)!=1){d=p(r,6)+w|0;x=Pc(e+80|0);f=Bf(e+80|0);t=pi(e+80|0);n=k[e+80|0];if((n-1&255)>>>0<72){break g}n=k[d|0];break f}break d}n=n+36|0;h[d|0]=n;h[d+1|0]=k[x|0]+1}if(k[f|0]|n&255){h[d+2|0]=1;y=d,A=(kd(k[f|0],1,16)<<2)-4|0,h[y+4|0]=A}f=k[t|0]&15;h[d+5|0]=f;h:{i:{switch((k[t|0]>>>4|0)-3|0){case 0:h[d+5|0]=f<<2;break h;case 1:h[d+5|0]=(6/(f+1>>>0)|0)+1;break h;case 3:case 4:h[d+5|0]=f<<3;break h;case 7:h[d+4|0]=(f<<2)+4;h[d+2|0]=1;break h;case 8:h[d+5|0]=f|128;break h;case 9:break i;default:break h}}h[d+5|0]=(6/(f+1>>>0)|0)+1|13}h[d+3|0]=k[(k[t|0]>>>4|0)+12944|0];r=r+1|0;if((r|0)!=16){continue}break}m=m+1|0;if((v|0)!=(m|0)){continue}break}}d=Ib(s,g);j[114626]=0;f=K(497,e+80|0,14,0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break d}f=qi(Fe(f,o?o>>>0<q-2>>>0?o+1|0:-1:-1));j[114626]=0;E(498,d|0,f|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break d}}jb(e+24|0)}g=g+1|0;if((g|0)!=256){continue}break}d=1;if(!(c&2)){break a}ER(b,e+72|0);d=0;while(1){j:{k:{if(!(k[e+72+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;break k}if(!lz(b,e+24|0)){break b}d=d+1|0;i[a+480190>>1]=d;ug(e+8|0,1,e+24|0);qc(e+80|0,e+8|0);c=l[a+480190>>1];j[114626]=0;E(369,((c<<5)+a|0)+946300|0,e+80|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break j}gb(e+80|0);c=(p(d,104)+a|0)+484380|0;vHa(e+24|0,c);Mc(e+80|0,h[e+70|0]&1?16:8,1,0,0);$f(e+80|0,c,b)}if((d|0)!=64){continue}break b}break}d=D()|0;C()|0;gb(e+80|0);break c}d=D()|0;C()|0;jb(e+24|0)}G(d|0);z()}d=1}Za=e+976|0;return d|0}function qba(a){var b=0,c=0,d=0,e=0;b=Za-96|0;Za=b;e=Db(a);j[114626]=0;N(236,b- -64|0);a=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((a|0)!=1){j[114626]=0;j[b+32>>2]=0;F(2110,b+48|0,b+32|0);a=j[114626];j[114626]=0;if((a|0)==1){break k}j[114626]=0;E(1245,e|0,b+48|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break j}gb(b+48|0);j[114626]=0;E(1988,e|0,38894)|0;a=j[114626];j[114626]=0;l:{if((a|0)==1){break l}j[114626]=0;j[b+32>>2]=5;F(2110,b+48|0,b+32|0);a=j[114626];j[114626]=0;if((a|0)==1){break i}j[114626]=0;E(1245,e|0,b+48|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break h}gb(b+48|0);j[114626]=0;E(1988,e|0,38894)|0;a=j[114626];j[114626]=0;if((a|0)==1){break l}j[114626]=0;j[b+32>>2]=4;F(2110,b+48|0,b+32|0);a=j[114626];j[114626]=0;if((a|0)==1){break g}j[114626]=0;E(1245,e|0,b+48|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break f}gb(b+48|0);j[114626]=0;a=E(85,b+48|0,38235)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}d=nb(a);gb(a);if(!d){break d}j[114626]=0;E(1988,e|0,38235)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break d}}a=D()|0;C()|0;break c}a=D()|0;C()|0;break b}a=D()|0;C()|0;break c}a=D()|0;C()|0;gb(b+48|0);break c}a=D()|0;C()|0;break c}a=D()|0;C()|0;gb(b+48|0);break c}a=D()|0;C()|0;break c}a=D()|0;C()|0;gb(b+48|0);break c}a=D()|0;C()|0;break c}d=Mg(b+48|0);m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if(j[(b- -64|0)+12>>2]){a=j[(b- -64|0)+12>>2];j[114626]=0;j[b+12>>2]=a;F(2110,b+16|0,b+12|0);a=j[114626];j[114626]=0;if((a|0)==1){break y}j[114626]=0;I(2111,b+32|0,39478,b+16|0);a=j[114626];j[114626]=0;if((a|0)==1){break x}j[114626]=0;F(1527,d|0,b+32|0);a=j[114626];j[114626]=0;if((a|0)==1){break w}gb(b+32|0);gb(b+16|0)}if(!k[(b- -64|0)+16|0]){break s}j[114626]=0;c=E(85,b+32|0,39480)|0;a=j[114626];j[114626]=0;if((a|0)==1){break u}j[114626]=0;F(1527,d|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break t}gb(c);break r}a=D()|0;C()|0;break m}a=D()|0;C()|0;break v}a=D()|0;C()|0;gb(b+32|0)}gb(b+16|0);break m}a=D()|0;C()|0;break m}a=D()|0;C()|0;gb(c);break m}if(!k[(b- -64|0)+17|0]){break r}j[114626]=0;c=E(85,b+32|0,39489)|0;a=j[114626];j[114626]=0;if((a|0)==1){break q}j[114626]=0;F(1527,d|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break p}gb(c)}if(k[(b- -64|0)+18|0]){break o}break n}a=D()|0;C()|0;break m}a=D()|0;C()|0;gb(c);break m}j[114626]=0;c=E(85,b+32|0,39495)|0;a=j[114626];j[114626]=0;z:{if((a|0)!=1){j[114626]=0;F(1527,d|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break z}gb(c);break n}a=D()|0;C()|0;break m}a=D()|0;C()|0;gb(c);break m}if(ad(d)){break a}j[114626]=0;E(1988,e|0,39499)|0;a=j[114626];j[114626]=0;if((a|0)!=1){j[114626]=0;c=E(85,b+16|0,38894)|0;a=j[114626];j[114626]=0;A:{B:{C:{if((a|0)!=1){j[114626]=0;I(2112,b+32|0,d|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break C}j[114626]=0;E(1245,e|0,b+32|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break B}gb(b+32|0);gb(c);break a}a=D()|0;C()|0;break m}a=D()|0;C()|0;break A}a=D()|0;C()|0;gb(b+32|0)}gb(c);break m}a=D()|0;C()|0}Uc(d)}Je(b- -64|0)}gb(e);G(a|0);z()}Uc(d);Je(b- -64|0);Za=b+96|0}function aK(a,b,c,d,e){var f=0,g=0,m=0,n=0,o=0,r=0,s=0,t=0,u=0,v=0,w=q(0),x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=q(0),K=q(0),L=0,M=0;g=Za-48|0;Za=g;s=l[a+480192>>1]?j[(p(b,896)+a|0)+1075640>>2]:s;x=a+1074308|0;f=p(b,896)+a|0;y=f+1075805|0;B=f+1075672|0;C=f+1075772|0;z=f+1075748|0;A=f+1075744|0;D=f+1075704|0;E=f+1075676|0;F=f+1075668|0;G=f+1075648|0;H=f+1075792|0;I=f+1075072|0;o=e&127;J=q(o>>>0);u=f+1075855|0;K=q(k[u|0]);m=1;while(1){e=k[d+n|0];if(e){f=e-48|0;a:{b:{c:{if((f&255)>>>0<10){break c}if((e-65&255)>>>0<=5){f=e-55|0;break c}f=r;d:{e:{f:{switch(e-97|0){case 2:g:{e=Zk(a,b,3,0);if(!e|e-251>>>0<5){break g}e=j[(p(e,160)+a|0)+906140>>2];if(!e){break g}e=Du(e,80056,80064);if(!e){break g}f=bb[j[j[e>>2]+184>>2]](e,b)|0;e=(f|0)!=255;f=e?f:0;if(e|!s){break c}break d}if(s){break d}f=0;break c;case 13:f=0;if(!Ld(k[y|0])){break e}f=k[y|0]-1|0;break e;case 21:mb(g+8|0,x,28);h:{if(!kb(g+8|0)){mb(g,x,1);e=0;if(!kb(g)){break h}}e=i[C>>1]}f=p(j[z>>2],j[A>>2]);e=p(j[a+1074444>>2],e+j[B>>2]|0);f=Gb((ic(PMa(OMa(f,f>>31,e,e>>31),ab,1048576,0),ab)|0)/2|0,1,127);break e;case 23:j[g+8>>2]=j[E>>2]/2;j[g>>2]=127;f=j[Pd(g+8|0,g)>>2];break e;case 24:j[g+8>>2]=j[F>>2]/2;j[g>>2]=127;f=j[Pd(g+8|0,g)>>2];break e;case 0:f=0;if(!s){break e}e=l[s+28>>1];if(!e){break e}f=e-1>>>7&127;break e;case 1:f=0;if(!s){break e}e=l[s+28>>1];if(!e){break e}f=e-1&127;break e;case 14:f=j[G>>2]>>>8|0;break e;case 7:e=b;if(e>>>0>=l[a+480188>>1]){e=k[H|0]-1|0}f=e&127;break e;case 12:f=j[I>>2]>>>7&1;break e;case 15:f=0;if(!s){break e}e=k[s+30|0];if(!e){break e}f=e-1&127;break e;case 25:v=u;e=o;i:{if(!c){break i}e=o;if(h[u|0]<0){break i}j:{if(r>>>0<3){break j}t=(g+16|0)+r|0;if(k[t-3|0]!=240){break j}e=o;if(k[t-2|0]>239){break i}}w=yo(a,K,J);if(w<q(4294967296)&w>=q(0)){e=~~w>>>0;break i}e=0}f=e;h[v|0]=f;break e;case 18:while(1){k:{if(!f){f=0;break k}f=f-1|0;if(k[f+(g+16|0)|0]!=240){continue}}break}if(k[(g+16|0)+f|0]!=240|r-f>>>0<5){break a}t=0;e=f+5|0;if((r|0)!=(e|0)){while(1){t=k[(g+16|0)+e|0]+t|0;e=e+1|0;if((r|0)!=(e|0)){continue}break}}f=0-t&127;break e;case 20:break f;default:break a}}e=p(j[z>>2],j[A>>2]);f=e;v=e>>31;e=p(j[a+1074444>>2],j[D>>2]);f=Gb((ic(PMa(OMa(f,v,e,e>>31),ab,67108864,0),ab)|0)/2|0,1,127)}e=((m^-1)&1)+r|0;h[e+(g+16|0)|0]=f;r=e+1|0;m=1;break b}f=Rta(s,a,b)}e=(g+16|0)+r|0;l:{if(m&1){h[e|0]=f;break l}h[e|0]=k[e|0]<<4|f;r=r+1|0}m=(m^-1)&1}}n=n+1|0;if((n|0)!=31){continue}}break}e=((m^-1)&1)+r|0;m:{if(!e){break m}f=0;m=0;while(1){d=(g+16|0)+m|0;o=h[d|0];n:{o:{p:{if((o|0)==-16){if(e-m>>>0>=4){n=4;if((k[(g+m|0)+17|0]&254)==240){break o}}n=m;q:{while(1){n=n+1|0;if(n>>>0>=e>>>0){break q}if(k[(g+16|0)+n|0]!=247){continue}break}o=n-m|0;n=o+1|0;if(n>>>0>=o>>>0){break o}}h[(g+16|0)+e|0]=247;e=e+1|0;n=e-m|0;break p}if((o|0)>=0){if(f&255){m=m-1|0;h[m+(g+16|0)|0]=f;break n}m=m+1|0;f=0;break n}L=g,M=CM(o&255),j[L+8>>2]=M;j[g>>2]=e-m;n=j[tb(g+8|0,g)>>2]}if(!n){break m}o=k[d|0];f=o>>>0<240?o:f}d=Goa(a,b,c,d,n);m=(d?d:n)+m|0}if(e>>>0>m>>>0){continue}break}}Za=g+48|0}function sx(a,b,c,d){var e=0,f=0,g=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=Za-16|0;Za=g;o=p(b,896)+a|0;t=o+1075782|0;n=l[t>>1];s=a+1074308|0;mb(g+8|0,s,23);e=c&15;a:{b:{if(kb(g+8|0)){if(!(j[a+1074392>>2]|!k[(p(b,896)+a|0)+1075794|0])){i[t>>1]=e;break b}f=l[t>>1];if(f){q=f-1|0;i[t>>1]=q;f=0;if(q&65535){break b}}i[t>>1]=e;f=1;break b}mb(g+8|0,s,52);q=c&256;if(!(!q|!kb(g+8|0))){c:{if(!(k[a+480209|0]&16)){break c}f=p(b,896)+a|0;if(k[f+1075795|0]){n=zQ(f+1075794|0)?1:n}if(!k[(p(b,896)+a|0)+1075798|0]|k[f+1075796|0]!=1){break c}i[t>>1]=n;break a}f=0;if(n<<16>>16<(e|0)){break b}if(k[a+480209|0]&16){if(Lf((p(b,896)+a|0)+1075794|0)){break b}}n=0;f=1;break b}if(j[a+480180>>2]&16777250){f=n&65535?!((n<<16>>16)%((e?e:1)|0)&65535):0;n=n+1|0;break b}if(j[a+480180>>2]==16){f=j[a+1074392>>2]==(e|0)&(e|0)!=0;break b}d:{e:{f:{g:{h:{if(q){f=p(b,896)+a|0;if(k[f+1075796|0]==1){e=(k[f+1075799|0]>15)+e|0}e=e?e:1;break h}if(j[a+480208>>2]&4096?!q:0){break e}e=e?e:1;if(j[a+1074416>>2]){break g}}f=0;break f}f=!(m[a+1074392>>2]%(e>>>0)|0)}n=n+1|0;break d}n=j[a+480180>>2]&1048580?0:n}if(!(n<<16>>16<(e|0)|(k[(p(b,896)+a|0)+1075794|0]|!q?!j[a+1074392>>2]:0))){f=1}mb(g+8|0,s,52);if(!kb(g+8|0)|c){break b}f=!j[a+1074392>>2]}q=o+1074984|0;r=(p(b,896)+a|0)+1075060|0;i:{if(j[r>>2]){break i}mb(g+8|0,s,38);if(!kb(g+8|0)){break i}if(!Qi(q)){break a}}mb(g+8|0,s,106);if(A=0,B=kb(g+8|0),C=j[(p(b,896)+a|0)+1075680>>2],C?A:B){break a}if(f){e=p(b,896)+a|0;v=e+1075672|0;j[g+4>>2]=j[v>>2];f=c>>>4&15;j:{if(!f){e=j[e+1075072>>2];break j}mb(g+8|0,s,52);k:{if(A=kb(g+8|0),B=0,C=k[(p(b,896)+a|0)+1075796|0]==1,C?A:B){break k}e=h[f+21872|0];if(e){j[g+4>>2]=p(e,j[g+4>>2])>>4;break k}j[g+4>>2]=j[g+4>>2]+(h[f+21888|0]<<2)}Md(g+4|0,0,256);f=(p(b,896)+a|0)+1075072|0;e=j[f>>2]|2097152;j[f>>2]=e}u=p(b,896)+a|0;w=u+1075684|0;x=j[w>>2];f=k[u+1075808|0];o=0;if(e&512){mb(g+8|0,s,108);o=kb(g+8|0)}if(!(!j[r>>2]|o^1|(f-1&255)>>>0>119)){uK(a,b,0,f,1)}l:{if(!(j[a+480180>>2]&1048580)){e=0;break l}e=(c|0)<256;if((c|0)>255){break l}r=k[(p(b,896)+a|0)+1075795|0];if(!r){break l}e=1;Fo(a,q,r,0,0,1)}u=u+1075072|0;m:{if(!o){break m}r=(p(b,896)+a|0)+1075088|0;if(!j[r>>2]){break m}o=a+1304392|0;if(!bd(o)){break m}bi(j[o>>2],b,1);Lx(j[o>>2],b,j[r>>2]+68|0)}o=p(b,896)+a|0;r=o+1075644|0;y=j[r>>2];z=j[u>>2];j[r>>2]=0;mb(g+8|0,s,23);Vr(a,q,f,kb(g+8|0),e,0,b);if(!k[o+1075795|0]){j[r>>2]=y}if(!(!(z&4096)|j[a+480180>>2]!=4)){j[u>>2]=j[u>>2]|4096}e=o+1075794|0;j[v>>2]=j[g+4>>2];if(l[a+480192>>1]){h[e|0]=f;$I(a,b)}if(!(k[e|0]|(!(j[a+480180>>2]&16777248)|!x))){j[w>>2]=x}f=j[a+480180>>2];mb(g+8|0,s,23);if(kb(g+8|0)){j[q>>2]=0;j[q+4>>2]=0}f=f&16777250;n:{if(d-1>>>0>9){break n}e=j[(p(b,896)+a|0)+1075088>>2];if(!e){break n}o:{if((d|0)==1){b=j[(p(b,896)+a|0)+1075648>>2];break o}o=(p(b,896)+a|0)+1075648|0;b=j[(e+(d<<2)|0)+60>>2];j[o>>2]=b}Eo(a,q,b)}n=f?n:0}mb(g+8|0,s,52);a=kb(g+8|0);mb(g+8|0,s,23);if(kb(g+8|0)){break a}i[t>>1]=(a&c>>>8)+n}Za=g+16|0}function N5(a,b,c,d){var e=0,f=0,g=0,h=0,j=q(0),k=q(0),l=q(0),m=q(0),o=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=Za-32|0;Za=h;n[d+4080>>2]=n[a+1152>>2];u=c-1|0;v=p(u,2304)+a|0;n[d+4084>>2]=n[v+1152>>2];n[d+4088>>2]=n[a>>2];n[d+4092>>2]=n[v>>2];n[d+4336>>2]=n[a+1156>>2];n[d+4340>>2]=n[v+1156>>2];n[d+4344>>2]=n[a+4>>2];n[d+4348>>2]=n[v+4>>2];w=(u<<1)+b|0;Yq(w,c,d+244|0);u=c<<6;Yq(u+w|0,c,d+500|0);Yq(b,c,d+240|0);Yq(b+u|0,c,d+496|0);s=49136;x=d+3840|0;f=14;while(1){o=f<<4;g=o+x|0;u=f;e=p(31-f|0,72);j=n[e+a>>2];n[g>>2]=j;n[(o|4)+x>>2]=n[e+v>>2];e=e|4;n[(o|8)+x>>2]=n[e+a>>2];n[(o|12)+x>>2]=n[e+v>>2];r=p(f,72);e=r+76|0;n[g+256>>2]=n[e+a>>2];n[g+260>>2]=n[e+v>>2];e=r+72|0;n[g-248>>2]=n[e+a>>2];n[g-244>>2]=n[e+v>>2];l=n[s>>2];r=d+o|0;k=n[r>>2];m=n[s+4>>2];n[h+16>>2]=q(j*l)-q(k*m);n[h>>2]=q(k*l)+q(j*m);e=f<<2;f=1;while(1){o=f<<2;j=n[o+g>>2];k=n[o+r>>2];n[o+(h+16|0)>>2]=q(j*l)-q(k*m);n[h+o>>2]=q(k*l)+q(j*m);f=f+1|0;if((f|0)!=4){continue}break}t=(e<<2)+x|0;o=t-3584|0;r=t-256|0;l=n[s+12>>2];m=n[s+8>>2];f=0;while(1){g=f<<2;e=g+h|0;j=n[g+o>>2];k=n[g+r>>2];n[e>>2]=q(q(j*m)+q(k*l))+n[e>>2];e=g+(h+16|0)|0;n[e>>2]=q(q(j*l)-q(k*m))+n[e>>2];f=f+1|0;if((f|0)!=4){continue}break}o=t-3328|0;r=t-512|0;l=n[s+20>>2];m=n[s+16>>2];f=0;while(1){g=f<<2;e=g+h|0;j=n[g+o>>2];k=n[g+r>>2];n[e>>2]=q(q(j*m)+q(k*l))+n[e>>2];e=g+(h+16|0)|0;n[e>>2]=q(q(k*m)-q(j*l))+n[e>>2];f=f+1|0;if((f|0)!=4){continue}break}o=t-3072|0;r=t-768|0;l=n[s+28>>2];m=n[s+24>>2];f=0;while(1){g=f<<2;e=g+h|0;j=n[g+o>>2];k=n[g+r>>2];n[e>>2]=q(q(j*m)+q(k*l))+n[e>>2];e=g+(h+16|0)|0;n[e>>2]=q(q(j*l)-q(k*m))+n[e>>2];f=f+1|0;if((f|0)!=4){continue}break}o=t-2816|0;r=t-1024|0;l=n[s+36>>2];m=n[s+32>>2];f=0;while(1){g=f<<2;e=g+h|0;j=n[g+o>>2];k=n[g+r>>2];n[e>>2]=q(q(j*m)+q(k*l))+n[e>>2];e=g+(h+16|0)|0;n[e>>2]=q(q(k*m)-q(j*l))+n[e>>2];f=f+1|0;if((f|0)!=4){continue}break}o=t-2560|0;r=t-1280|0;l=n[s+44>>2];m=n[s+40>>2];f=0;while(1){g=f<<2;e=g+h|0;j=n[g+o>>2];k=n[g+r>>2];n[e>>2]=q(q(j*m)+q(k*l))+n[e>>2];e=g+(h+16|0)|0;n[e>>2]=q(q(j*l)-q(k*m))+n[e>>2];f=f+1|0;if((f|0)!=4){continue}break}o=t-2304|0;r=t-1536|0;l=n[s+52>>2];m=n[s+48>>2];f=0;while(1){g=f<<2;e=g+h|0;j=n[g+o>>2];k=n[g+r>>2];n[e>>2]=q(q(j*m)+q(k*l))+n[e>>2];e=g+(h+16|0)|0;n[e>>2]=q(q(k*m)-q(j*l))+n[e>>2];f=f+1|0;if((f|0)!=4){continue}break}o=t-2048|0;r=t-1792|0;l=n[s+60>>2];m=n[s+56>>2];f=0;while(1){g=f<<2;e=g+h|0;j=n[g+o>>2];k=n[g+r>>2];n[e>>2]=q(q(j*m)+q(k*l))+n[e>>2];e=g+(h+16|0)|0;n[e>>2]=q(q(j*l)-q(k*m))+n[e>>2];f=f+1|0;if((f|0)!=4){continue}break}e=p(15-u|0,c)<<1;y=e+w|0,z=Ph(n[h+20>>2]),i[y>>1]=z;f=p(u+17|0,c)<<1;y=f+w|0,z=Ph(n[h+4>>2]),i[y>>1]=z;y=b+e|0,z=Ph(n[h+16>>2]),i[y>>1]=z;y=b+f|0,z=Ph(n[h>>2]),i[y>>1]=z;e=p(47-u|0,c)<<1;y=e+w|0,z=Ph(n[h+28>>2]),i[y>>1]=z;f=p(u+49|0,c)<<1;y=f+w|0,z=Ph(n[h+12>>2]),i[y>>1]=z;y=b+e|0,z=Ph(n[h+24>>2]),i[y>>1]=z;y=b+f|0,z=Ph(n[h+8>>2]),i[y>>1]=z;f=u-1|0;s=s- -64|0;if(u){continue}break}Za=h+32|0}function fq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;f=a+b|0;a:{b:{c=j[a+4>>2];if(c&1){break b}if(!(c&3)){break a}c=j[a>>2];b=c+b|0;a=a-c|0;if((a|0)!=j[115941]){if(c>>>0<=255){e=c>>>3|0;c=j[a+8>>2];d=j[a+12>>2];if((d|0)==(c|0)){i=463744,k=j[115936]&TMa(-2,e),j[i>>2]=k;break b}j[c+12>>2]=d;j[d+8>>2]=c;break b}h=j[a+24>>2];c=j[a+12>>2];c:{if((c|0)!=(a|0)){d=j[a+8>>2];j[d+12>>2]=c;j[c+8>>2]=d;break c}d:{d=a+20|0;e=j[d>>2];if(e){break d}d=a+16|0;e=j[d>>2];if(e){break d}c=0;break c}while(1){g=d;c=e;d=c+20|0;e=j[d>>2];if(e){continue}d=c+16|0;e=j[c+16>>2];if(e){continue}break}j[g>>2]=0}if(!h){break b}d=j[a+28>>2];e=(d<<2)+464048|0;e:{if(j[e>>2]==(a|0)){j[e>>2]=c;if(c){break e}i=463748,k=j[115937]&TMa(-2,d),j[i>>2]=k;break b}j[h+(j[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}j[c+24>>2]=h;d=j[a+16>>2];if(d){j[c+16>>2]=d;j[d+24>>2]=c}d=j[a+20>>2];if(!d){break b}j[c+20>>2]=d;j[d+24>>2]=c;break b}c=j[f+4>>2];if((c&3)!=3){break b}j[115938]=b;j[f+4>>2]=c&-2;j[a+4>>2]=b|1;j[f>>2]=b;return}c=j[f+4>>2];f:{if(!(c&2)){if(j[115942]==(f|0)){j[115942]=a;b=j[115939]+b|0;j[115939]=b;j[a+4>>2]=b|1;if(j[115941]!=(a|0)){break a}j[115938]=0;j[115941]=0;return}if(j[115941]==(f|0)){j[115941]=a;b=j[115938]+b|0;j[115938]=b;j[a+4>>2]=b|1;j[a+b>>2]=b;return}b=(c&-8)+b|0;g:{if(c>>>0<=255){e=c>>>3|0;c=j[f+8>>2];d=j[f+12>>2];if((d|0)==(c|0)){i=463744,k=j[115936]&TMa(-2,e),j[i>>2]=k;break g}j[c+12>>2]=d;j[d+8>>2]=c;break g}h=j[f+24>>2];c=j[f+12>>2];h:{if((f|0)!=(c|0)){d=j[f+8>>2];j[d+12>>2]=c;j[c+8>>2]=d;break h}i:{d=f+20|0;e=j[d>>2];if(e){break i}d=f+16|0;e=j[d>>2];if(e){break i}c=0;break h}while(1){g=d;c=e;d=c+20|0;e=j[d>>2];if(e){continue}d=c+16|0;e=j[c+16>>2];if(e){continue}break}j[g>>2]=0}if(!h){break g}d=j[f+28>>2];e=(d<<2)+464048|0;j:{if(j[e>>2]==(f|0)){j[e>>2]=c;if(c){break j}i=463748,k=j[115937]&TMa(-2,d),j[i>>2]=k;break g}j[h+(j[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break g}}j[c+24>>2]=h;d=j[f+16>>2];if(d){j[c+16>>2]=d;j[d+24>>2]=c}d=j[f+20>>2];if(!d){break g}j[c+20>>2]=d;j[d+24>>2]=c}j[a+4>>2]=b|1;j[a+b>>2]=b;if(j[115941]!=(a|0)){break f}j[115938]=b;return}j[f+4>>2]=c&-2;j[a+4>>2]=b|1;j[a+b>>2]=b}if(b>>>0<=255){c=b>>>3|0;b=(c<<3)+463784|0;d=j[115936];c=1<<c;k:{if(!(d&c)){j[115936]=c|d;c=b;break k}c=j[b+8>>2]}j[b+8>>2]=a;j[c+12>>2]=a;j[a+12>>2]=b;j[a+8>>2]=c;return}d=31;j[a+16>>2]=0;j[a+20>>2]=0;if(b>>>0<=16777215){d=b>>>8|0;c=d+1048320>>>16&8;e=d<<c;d=e+520192>>>16&4;g=e<<d;e=g+245760>>>16&2;c=(g<<e>>>15|0)-(e|(c|d))|0;d=(c<<1|b>>>c+21&1)+28|0}j[a+28>>2]=d;c=(d<<2)+464048|0;l:{e=j[115937];g=1<<d;m:{if(!(e&g)){j[115937]=e|g;j[c>>2]=a;j[a+24>>2]=c;break m}d=b<<((d|0)==31?0:25-(d>>>1|0)|0);c=j[c>>2];while(1){e=c;if((j[c+4>>2]&-8)==(b|0)){break l}c=d>>>29|0;d=d<<1;g=e+(c&4)|0;c=j[g+16>>2];if(c){continue}break}j[g+16>>2]=a;j[a+24>>2]=e}j[a+12>>2]=a;j[a+8>>2]=a;return}b=j[e+8>>2];j[b+12>>2]=a;j[e+8>>2]=a;j[a+24>>2]=0;j[a+12>>2]=e;j[a+8>>2]=b}}function vB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=Za-144|0;Za=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if(j[19104]>=(c|0)){iu(a+96|0,c);j[114626]=0;c=E(2,a+80|0,1024)|0;d=j[114626];j[114626]=0;if((d|0)==1){break E}j[114626]=0;I(3,a+112|0,a+96|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break D}j[114626]=0;d=E(4,a+48|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break C}j[114626]=0;e=E(2,a+32|0,1027)|0;f=j[114626];j[114626]=0;if((f|0)==1){break B}j[114626]=0;I(5,a- -64|0,d|0,e|0);f=j[114626];j[114626]=0;if((f|0)==1){break A}j[114626]=0;I(3,a+128|0,a+112|0,a- -64|0);f=j[114626];j[114626]=0;if((f|0)==1){break z}gb(a- -64|0);gb(e);gb(d);gb(a+112|0);gb(c);gb(a+96|0);if(j[b>>2]){c=j[b>>2]}else{c=1030}j[114626]=0;I(6,a+112|0,1,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break t}if(j[b+4>>2]){c=j[b+4>>2]}else{c=1030}j[114626]=0;I(6,a+96|0,1,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break s}b=j[b+8>>2];j[114626]=0;j[a+64>>2]=b;F(7,a+80|0,a- -64|0);b=j[114626];j[114626]=0;if((b|0)==1){break r}j[114626]=0;b=E(8,461112,1031)|0;c=j[114626];j[114626]=0;if((c|0)==1){break q}j[114626]=0;I(9,a- -64|0,0,a+112|0);c=j[114626];j[114626]=0;if((c|0)==1){break p}j[114626]=0;b=E(10,b|0,a- -64|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break o}j[114626]=0;b=E(8,b|0,1044)|0;c=j[114626];j[114626]=0;if((c|0)==1){break o}j[114626]=0;I(9,a+32|0,0,a+80|0);c=j[114626];j[114626]=0;if((c|0)==1){break n}j[114626]=0;b=E(10,b|0,a+32|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break m}j[114626]=0;b=E(8,b|0,1046)|0;c=j[114626];j[114626]=0;if((c|0)==1){break m}j[114626]=0;b=E(8,b|0,1024)|0;c=j[114626];j[114626]=0;if((c|0)==1){break m}j[114626]=0;I(9,a+16|0,0,a+128|0);c=j[114626];j[114626]=0;if((c|0)==1){break l}j[114626]=0;b=E(10,b|0,a+16|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break k}j[114626]=0;b=E(8,b|0,1048)|0;c=j[114626];j[114626]=0;if((c|0)==1){break k}j[114626]=0;I(9,a|0,0,a+96|0);c=j[114626];j[114626]=0;if((c|0)==1){break j}j[114626]=0;b=E(10,b|0,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break i}j[114626]=0;b=E(8,b|0,1051)|0;c=j[114626];j[114626]=0;if((c|0)==1){break i}j[114626]=0;E(11,b|0,12)|0;b=j[114626];j[114626]=0;if((b|0)==1){break i}gb(a);gb(a+16|0);gb(a+32|0);gb(a- -64|0);gb(a+80|0);gb(a+96|0);gb(a+112|0);gb(a+128|0)}Za=a+144|0;return}b=D()|0;C()|0;break u}b=D()|0;C()|0;break v}b=D()|0;C()|0;break w}b=D()|0;C()|0;break x}b=D()|0;C()|0;break y}b=D()|0;C()|0;gb(a- -64|0)}gb(e)}gb(d)}gb(a+112|0)}gb(c)}gb(a+96|0);break a}b=D()|0;C()|0;break b}b=D()|0;C()|0;break c}b=D()|0;C()|0;break d}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}b=D()|0;C()|0;break f}b=D()|0;C()|0;break f}b=D()|0;C()|0;break g}b=D()|0;C()|0;break g}b=D()|0;C()|0;break h}b=D()|0;C()|0;break h}b=D()|0;C()|0;gb(a)}gb(a+16|0)}gb(a+32|0)}gb(a- -64|0)}gb(a+80|0)}gb(a+96|0)}gb(a+112|0)}gb(a+128|0)}G(b|0);z()}function hQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,m=0,n=0,o=0,p=0;e=Za-144|0;Za=e;m=$Fa(e+128|0);a:{b:{c:{if(d){j[114626]=0;I(710,a|0,m|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){break c}break b}j[114626]=0;I(711,a|0,m|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}}d=Av(e+112|0);d:{e:{if(l[b+480192>>1]){c=1;n=1;while(1){j[114626]=0;i[e+110>>1]=0;E(712,a|0,e+110|0)|0;k=j[114626];j[114626]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((k|0)!=1){j[114626]=0;k=E(713,m|0,e+110|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}j[e+104>>2]=k;k=((c<<2)+b|0)+900380|0;if(!j[k>>2]){break f}c=ki(m);j[114626]=0;j[e+88>>2]=c;c=E(714,e+104|0,e+88|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break u}if(!c){break g}j[114626]=0;c=H(715,e+104|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break t}j[114626]=0;c=E(4,e+88|0,c+4|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break t}j[114626]=0;f=E(2,e+72|0,14549)|0;g=j[114626];j[114626]=0;if((g|0)==1){break i}g=ip(c,f);gb(f);if(!g){break s}j[j[k>>2]+44>>2]=0;break r}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}f=j[b+4>>2];j[114626]=0;f=E(716,f|0,c|0)|0;g=j[114626];j[114626]=0;v:{w:{x:{y:{z:{A:{if((g|0)!=1){j[j[k>>2]+44>>2]=f;if(j[j[k>>2]+44>>2]){break r}j[114626]=0;f=E(2,e+72|0,14569)|0;g=j[114626];j[114626]=0;if((g|0)==1){break A}B:{C:{if(ip(c,f)){gb(f);break C}j[114626]=0;g=E(2,e+56|0,14595)|0;h=j[114626];j[114626]=0;if((h|0)==1){break z}h=ip(c,g);gb(g);gb(f);if(!h){break B}}j[114626]=0;F(717,e+72|0,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break y}g=j[b+4>>2];f=hp(e+48|0,e+72|0);j[114626]=0;g=E(718,g|0,f|0)|0;h=j[114626];j[114626]=0;if((h|0)==1){break x}Jf(f);Jf(e+72|0);if(g){break r}}o=e,p=WFa(Lb(d),Mb(d),c),j[o+72>>2]=p;o=e,p=Mb(d),j[o+56>>2]=p;if(!al(e+72|0,e+56|0)){break v}j[114626]=0;F(719,d|0,c|0);f=j[114626];j[114626]=0;if((f|0)!=1){break w}}b=D()|0;C()|0;break h}b=D()|0;C()|0;break h}b=D()|0;C()|0;gb(f);break h}b=D()|0;C()|0;break h}b=D()|0;C()|0;Jf(f);Jf(e+72|0);break h}j[114626]=0;f=E(2,e+16|0,14601)|0;g=j[114626];j[114626]=0;if((g|0)==1){break q}j[114626]=0;I(720,e+32|0,f|0,c|0);g=j[114626];j[114626]=0;if((g|0)==1){break p}j[114626]=0;g=E(2,e|0,14610)|0;h=j[114626];j[114626]=0;if((h|0)==1){break o}j[114626]=0;I(3,e+56|0,e+32|0,g|0);h=j[114626];j[114626]=0;if((h|0)==1){break n}h=vy(e+72|0,e+56|0);j[114626]=0;F(624,b|0,h|0);h=j[114626];j[114626]=0;if((h|0)==1){break m}gb(e+72|0);gb(e+56|0);gb(g);gb(e+32|0);gb(f)}j[j[k>>2]+44>>2]=0}gb(c);break f}b=D()|0;C()|0;break h}b=D()|0;C()|0;break j}b=D()|0;C()|0;break k}b=D()|0;C()|0;break l}b=D()|0;C()|0;gb(e+72|0);gb(e+56|0)}gb(g)}gb(e+32|0)}gb(f);break h}b=D()|0;C()|0}gb(c);break d}if(!j[k>>2]){break f}j[j[k>>2]+44>>2]=0}n=n+1|0;c=n&65535;if(c>>>0<=l[b+480192>>1]){continue}break}}Ok(d);cQ(m);Za=e+144|0;return}b=D()|0;C()|0}Ok(d);break a}b=D()|0;C()|0}cQ(m);G(b|0);z()}function bja(a,b,c){var d=0,e=0,f=0,g=0,h=0,m=0;d=Za-80|0;Za=d;g=i[b+28>>1];e=i[c>>1];f=b+4|0;sb(f);a:{b:{if((e|0)>=(g|0)){if((e|0)<=(l[b+28>>1]+sb(f)<<16)-65536>>16){break b}}Qc(a);break a}c:{e=i[b+30>>1];if(!e){b=b+52|0;h=d,m=zw(b,c),j[h+56>>2]=m;h=d,m=ki(b),j[h+40>>2]=m;if(!ji(d+56|0,d+40|0)){break c}Mf(a,Rg(d+56|0)+4|0);break a}f=d;g=i[c>>1];d:{if((g|0)>=0){g=(g|0)%(e|0)|0;break d}g=e+((g^-1)%(e|0)^-1)|0}i[f+78>>1]=g;e=Qc(a);j[114626]=0;g=b+52|0;f=E(1592,g|0,d+78|0)|0;a=j[114626];j[114626]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((a|0)==1){break u}j[d+72>>2]=f;a=ki(g);j[114626]=0;j[d+56>>2]=a;f=E(1593,d+72|0,d+56|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break f}if(f){j[114626]=0;f=H(1594,d+72|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break u}j[114626]=0;E(237,e|0,f+4|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break u}b=i[b+30>>1];a=i[c>>1];v:{if((a|0)>=0){a=(a|0)/(b|0)|0;break v}a=((a+1|0)/(b|0)|0)-1|0}j[114626]=0;j[d+40>>2]=a+5;F(234,d+56|0,d+40|0);a=j[114626];j[114626]=0;w:{if((a|0)!=1){j[114626]=0;E(192,e|0,d+56|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break w}gb(d+56|0);break a}b=D()|0;C()|0;break e}b=D()|0;C()|0;gb(d+56|0);break e}if(i[b+30>>1]>26){break r}j[114626]=0;f=K(798,d+40|0,1,(k[d+78|0]<<24)+1090519040>>24)|0;a=j[114626];j[114626]=0;if((a|0)==1){break t}j[114626]=0;I(13,d+56|0,0,f|0);a=j[114626];j[114626]=0;if((a|0)==1){break s}ob(e,d+56|0);gb(d+56|0);gb(f);j[114626]=0;E(235,e|0,32403)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break q}}b=D()|0;C()|0;break e}b=D()|0;C()|0;break e}b=D()|0;C()|0;gb(f);break e}j[114626]=0;j[d+36>>2]=i[d+78>>1]%16<<16>>16;F(1595,d+40|0,d+36|0);a=j[114626];j[114626]=0;if((a|0)==1){break p}j[114626]=0;j[d+20>>2]=(i[d+78>>1]/16<<16>>16)%16<<16>>16;F(1595,d+24|0,d+20|0);a=j[114626];j[114626]=0;if((a|0)==1){break o}j[114626]=0;I(3,d+56|0,d+40|0,d+24|0);a=j[114626];j[114626]=0;if((a|0)==1){break n}ob(e,d+56|0);gb(d+56|0);gb(d+24|0);gb(d+40|0);if(i[d+78>>1]<256){break q}j[114626]=0;I(9,d+8|0,0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break l}j[114626]=0;F(1596,d+40|0,d+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break k}j[114626]=0;I(13,d+56|0,0,d+40|0);a=j[114626];j[114626]=0;if((a|0)==1){break j}ob(e,d+56|0);gb(d+56|0);gb(d+40|0);gb(d+8|0)}b=i[b+30>>1];a=i[c>>1];if((a|0)<0){break h}a=(a|0)/(b|0)|0;break g}b=D()|0;C()|0;break e}b=D()|0;C()|0;break m}b=D()|0;C()|0;gb(d+24|0)}gb(d+40|0);break e}b=D()|0;C()|0;break e}b=D()|0;C()|0;break i}b=D()|0;C()|0;gb(d+40|0)}gb(d+8|0);break e}a=((a+1|0)/(b|0)|0)-1|0}j[114626]=0;j[d+40>>2]=a+5;F(234,d+56|0,d+40|0);a=j[114626];j[114626]=0;x:{if((a|0)!=1){j[114626]=0;E(192,e|0,d+56|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break x}gb(d+56|0);break a}b=D()|0;C()|0;break e}b=D()|0;C()|0;gb(d+56|0);break e}b=D()|0;C()|0}gb(e);G(b|0);z()}b=Za-16|0;Za=b;Eha(a,c);Za=b+16|0}Za=d+80|0}function mG(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=Za-224|0;Za=f;j[f+216>>2]=c;j[f+220>>2]=d;a:{if(Pi(b)){break a}d=k[Fj(b)|0];c=1;b:{if((d|0)==33){break b}if((d|0)!=63){break a}c=0}e=c;Pj(f+184|0,b,j[b+4>>2]-1|0);c=j[f+188>>2];j[b>>2]=j[f+184>>2];j[b+4>>2]=c}ld(f+184|0);c=j[f+184>>2];ld(f+168|0);g=Ej(c,j[f+172>>2],b);ld(f+184|0);c=j[b>>2];d=j[b+4>>2];c:{d:{e:{f:{if((g|0)==j[f+188>>2]){j[f+208>>2]=c;j[f+212>>2]=d;a=Zb(f+200|0,38235);c=j[f+212>>2];j[f+16>>2]=j[f+208>>2];j[f+20>>2]=c;c=j[a+4>>2];j[f+8>>2]=j[a>>2];j[f+12>>2]=c;if(nc(f+16|0,f+8|0)){a=R(8)|0;j[114626]=0;F(2135,f+168|0,f+216|0);b=j[114626];j[114626]=0;g:{h:{i:{if((b|0)!=1){j[114626]=0;I(2111,f+184|0,39300,f+168|0);b=j[114626];j[114626]=0;if((b|0)==1){break i}Wb(a,f+184|0);e=0;j[114626]=0;I(2002,a|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break e}b=D()|0;C()|0;gb(f+184|0);break h}b=D()|0;C()|0;break g}b=D()|0;e=1;C()|0}gb(f+168|0);if(!e){break f}}S(a|0);break f}if(!e){break c}c=R(8)|0;j[114626]=0;d=E(2134,f+136|0,b|0)|0;b=j[114626];j[114626]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){j[114626]=0;I(2111,f+152|0,39179,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break r}j[114626]=0;I(2129,f+168|0,f+152|0,39315);b=j[114626];j[114626]=0;a=1;if((b|0)==1){break q}j[114626]=0;F(2135,f+120|0,f+216|0);a=j[114626];j[114626]=0;if((a|0)==1){break p}j[114626]=0;I(138,f+184|0,f+168|0,f+120|0);b=j[114626];j[114626]=0;a=1;if((b|0)==1){break o}Wb(c,f+184|0);j[114626]=0;I(2002,c|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break e}b=D()|0;C()|0;gb(f+184|0);a=0;break n}b=D()|0;C()|0;break j}b=D()|0;a=1;C()|0;break k}b=D()|0;C()|0;break l}b=D()|0;a=1;C()|0;break m}b=D()|0;C()|0}gb(f+120|0)}gb(f+168|0)}gb(f+152|0)}gb(d)}if(!a){break f}S(c|0);break f}j[f+112>>2]=c;j[f+116>>2]=d;c=Zb(f+104|0,38235);d=j[f+116>>2];j[f+64>>2]=j[f+112>>2];j[f+68>>2]=d;d=j[c+4>>2];j[f+56>>2]=j[c>>2];j[f+60>>2]=d;if(!nc(f- -64|0,f+56|0)){break d}a=R(8)|0;j[114626]=0;F(2135,f+168|0,f+216|0);b=j[114626];j[114626]=0;s:{t:{u:{if((b|0)!=1){j[114626]=0;I(2111,f+184|0,39300,f+168|0);b=j[114626];j[114626]=0;if((b|0)==1){break u}Wb(a,f+184|0);e=0;j[114626]=0;I(2002,a|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break e}b=D()|0;C()|0;gb(f+184|0);break t}b=D()|0;C()|0;break s}b=D()|0;e=1;C()|0}gb(f+168|0);if(!e){break f}}S(a|0)}G(b|0)}z()}c=j[b+4>>2];j[f+96>>2]=j[b>>2];j[f+100>>2]=c;c=Zb(f+88|0,39014);d=j[f+100>>2];j[f+48>>2]=j[f+96>>2];j[f+52>>2]=d;d=j[c+4>>2];j[f+40>>2]=j[c>>2];j[f+44>>2]=d;if(nc(f+48|0,f+40|0)){_F(a,ic(j[f+216>>2],j[f+220>>2]));break c}c=j[b+4>>2];j[f+80>>2]=j[b>>2];j[f+84>>2]=c;b=Zb(f+72|0,39162);c=j[f+84>>2];j[f+32>>2]=j[f+80>>2];j[f+36>>2]=c;c=j[b+4>>2];j[f+24>>2]=j[b>>2];j[f+28>>2]=c;if(!nc(f+32|0,f+24|0)){break c}b=ic(j[f+216>>2],j[f+220>>2]);j[j[a+32>>2]+40>>2]=b>>>0>3?1:b}Za=f+224|0}function vma(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;m=Za-16|0;Za=m;a:{b:{c:{if(!j[a+1074376>>2]){n=a+1074448|0;c=n;j[c>>2]=0;j[c+4>>2]=0;j[a+1074456>>2]=j[a+1074444>>2];break c}h=j[a+1074456>>2];c=j[a+1074444>>2];d:{if((h|0)==(c|0)){c=j[a+1074448>>2];break d}j[a+1074456>>2]=c;e=a+24604|0;d=a+1074448|0;e:{if((c|0)>(h|0)){c=sM(e);break e}c=rM(e)}j[d>>2]=c;j[a+1074452>>2]=c}n=a+1074448|0;if((c|0)>=1){break b}}break a}h=(j[a+1074456>>2]<<12)-j[a+1074460>>2]|0;l=(h|0)/(c|0)|0;if(j[a+1074368>>2]!=2){break a}j[m+12>>2]=50;j[m+8>>2]=1e4/(j[a+1074452>>2]+1|0);g=j[zf(m+12|0,m+8|0)>>2];c=l>>31;if((g|0)>=(c+l^c)){break a}c=j[a+1074448>>2];f=j[a+1074452>>2];while(1){c=c+f|0;l=(h|0)/(c|0)|0;e=l>>31;if((g|0)<(e^e+l)){continue}break}j[n>>2]=c}f:{g:{switch(j[a+24624>>2]-1|0){case 0:if((b|0)<1){break f}e=j[a+1074444>>2];f=e<<12;c=a+12|0;h=e;d=e>>31;g=0;while(1){h:{if(j[n>>2]>=1){e=j[a+1074460>>2]+l|0;j[a+1074460>>2]=e;k=j[c>>2];p=c,q=ic(PMa(OMa(k,k>>31,e,e>>31),ab,1048576,0),ab),j[p>>2]=q;j[a+1074448>>2]=j[a+1074448>>2]-1;break h}e=j[c>>2];p=c,q=ic(PMa(OMa(e,e>>31,h,d),ab,256,0),ab),j[p>>2]=q;j[a+1074460>>2]=f}c=c+4|0;g=g+1|0;if((g|0)!=(b|0)){continue}break}break f;case 1:if((b|0)<1){break f}e=j[a+1074444>>2];d=e<<12;c=a+12|0;h=e;e=e>>31;g=0;while(1){i:{if(j[n>>2]>=1){f=j[a+1074460>>2]+l|0;j[a+1074460>>2]=f;k=j[c>>2];p=c,q=ic(PMa(OMa(k,k>>31,f,f>>31),ab,1048576,0),ab),j[p>>2]=q;f=j[a+1074460>>2];i=f;k=f>>31;f=j[c+4>>2];p=c,q=ic(PMa(OMa(i,k,f,f>>31),ab,1048576,0),ab),j[p+4>>2]=q;j[a+1074448>>2]=j[a+1074448>>2]-1;break i}f=j[c>>2];p=c,q=ic(PMa(OMa(f,f>>31,h,e),ab,256,0),ab),j[p>>2]=q;f=j[c+4>>2];p=c,q=ic(PMa(OMa(f,f>>31,h,e),ab,256,0),ab),j[p+4>>2]=q;j[a+1074460>>2]=d}c=c+8|0;g=g+1|0;if((g|0)!=(b|0)){continue}break}break f;case 3:break g;default:break f}}if((b|0)<1){break f}h=j[a+1074444>>2];k=h<<12;c=a+12|0;g=a+8204|0;e=h;h=e>>31;f=0;while(1){j:{if(j[n>>2]>=1){d=j[a+1074460>>2]+l|0;j[a+1074460>>2]=d;i=j[c>>2];p=c,q=ic(PMa(OMa(i,i>>31,d,d>>31),ab,1048576,0),ab),j[p>>2]=q;d=j[a+1074460>>2];i=d;o=d>>31;d=j[c+4>>2];p=c,q=ic(PMa(OMa(i,o,d,d>>31),ab,1048576,0),ab),j[p+4>>2]=q;d=j[a+1074460>>2];i=d;o=d>>31;d=j[g>>2];p=g,q=ic(PMa(OMa(i,o,d,d>>31),ab,1048576,0),ab),j[p>>2]=q;d=j[a+1074460>>2];i=d;o=d>>31;d=j[g+4>>2];p=g,q=ic(PMa(OMa(i,o,d,d>>31),ab,1048576,0),ab),j[p+4>>2]=q;j[a+1074448>>2]=j[a+1074448>>2]-1;break j}d=j[c>>2];p=c,q=ic(PMa(OMa(d,d>>31,e,h),ab,256,0),ab),j[p>>2]=q;d=j[c+4>>2];p=c,q=ic(PMa(OMa(d,d>>31,e,h),ab,256,0),ab),j[p+4>>2]=q;d=j[g>>2];p=g,q=ic(PMa(OMa(d,d>>31,e,h),ab,256,0),ab),j[p>>2]=q;d=j[g+4>>2];p=g,q=ic(PMa(OMa(d,d>>31,e,h),ab,256,0),ab),j[p+4>>2]=q;j[a+1074460>>2]=k}g=g+8|0;c=c+8|0;f=f+1|0;if((f|0)!=(b|0)){continue}break}}Za=m+16|0}function XT(a,b){var c=0,d=0,e=0,f=0,g=0,i=0,o=0,r=0,s=q(0),t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=q(0),E=0,F=0;i=b<<2;z=l[a+480214>>1]!=0;d=a+1074328|0;s=n[d>>2];D=n[d+4>>2];while(1){f=(p(e,160)+a|0)+906300|0;d=j[f>>2];a:{if(!d|!j[d+24>>2]){break a}if(!Yg(d+44|0)){break a}g=j[f>>2];if(!(bb[j[j[g>>2]+108>>2]](g)|0)){bb[j[j[g>>2]+104>>2]](g,1);bb[j[j[g>>2]+116>>2]](g)}d=g+44|0;w=wd(d,0);r=wd(d,1);b:{if(h[g+28|0]&1){Vx(j[g+24>>2],w,r,b,s);break b}d=g+40|0;if(!(j[g+36>>2]?0:!j[d>>2])){Rm(j[g+24>>2],b,d,g+36|0);Vx(j[g+24>>2],w,r,b,s);break b}Ab(w,0,i);Ab(r,0,i)}j[g+28>>2]=j[g+28>>2]&-2;if(Yt(f)){break a}z=!(k[g+28|0]&4)|z}e=e+1|0;if((e|0)!=250){continue}break}B=a+12|0;g=a+12300|0;w=a+14348|0;Vx(B,g,w,b,s);d=a+1074464|0;E=k[d|0];h[d|0]=0;i=g;d=w;while(1){o=(p(v,160)+a|0)+906300|0;f=j[o>>2];c:{if(!f|!j[f+24>>2]){break c}if(!Yg(f+44|0)){break c}x=j[o>>2];d:{if(Yt(o)){break d}f=j[o>>2];if(bb[j[j[f>>2]+140>>2]](f)|k[j[o>>2]+28|0]&2){break d}e=0;if(!v){break c}while(1){if((fj((p(e,160)+a|0)+906300|0)|0)==(v|0)){break d}e=e+1|0;if((v|0)!=(e|0)){continue}break}break c}f=x+44|0;A=wd(f,0);C=wd(f,1);u=j[o>>2];t=(i|0)==(A|0);i=t?g:i;r=i;d=t?w:d;c=o+28|0;f=d;e:{if(!(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))){break e}r=i;c=fj(o);f=d;if(c>>>0<=v>>>0){break e}f=d;if((c|0)==255){break e}c=j[(p(c,160)+a|0)+906300>>2];f=d;if(!c){break e}if(!(k[u+28|0]&4)){bb[j[j[c>>2]+144>>2]](c)}c=c+44|0;f=d;if(!Yg(c)){break e}r=wd(c,0);f=wd(c,1)}f:{if(!Yt(o)){break f}g:{if(t){break g}e=0;if(!b){break g}while(1){y=e<<2;c=y+A|0;t=i+y|0;n[c>>2]=n[c>>2]+n[t>>2];c=y+C|0;F=c;s=n[c>>2];c=d+y|0;n[F>>2]=s+n[c>>2];j[t>>2]=0;j[c>>2]=0;e=e+1|0;if((e|0)!=(b|0)){continue}break}}d=f;i=r;if(!(z&1)){break f}i=j[o>>2];if(i){bb[j[j[i>>2]+144>>2]](i)}i=r;e=fj(o);if(e>>>0>249|e>>>0<=v>>>0){break f}while(1){i=e&255;d=(p(i,160)+a|0)+906300|0;e=fj(d);d=j[d>>2];if(d){bb[j[j[d>>2]+144>>2]](d)}if(e>>>0>i>>>0?e>>>0<=249:0){continue}break}d=f;i=r}h:{i:{if(!((k[o+24|0]&2)>>>1|0)){if(!DA(o)|!(k[u+28|0]&4)){break i}}e=0;if(!b){break h}while(1){t=e<<2;c=t+r|0;n[c>>2]=n[c>>2]+n[t+A>>2];c=f+t|0;n[c>>2]=n[c>>2]+n[t+C>>2];e=e+1|0;if((e|0)!=(b|0)){continue}break}break h}if(E){bb[j[j[x>>2]+124>>2]](x)}bb[j[j[x>>2]+60>>2]](x,r,f,b);j[u+32>>2]=j[u+32>>2]+b;if(!DA(o)){break h}if((bb[j[j[x>>2]+152>>2]](x)|0)<1|m[u+32>>2]<j[a+24620>>2]<<2>>>0){break h}e=0;j:{if(!b){break j}while(1){k:{c=e<<2;s=n[c+r>>2];if(s>=q(1.1920928955078125e-7)|s<=q(-1.1920928955078125e-7)){break k}s=n[c+f>>2];if(s>=q(1.1920928955078125e-7)|!(s>q(-1.1920928955078125e-7))){break k}e=e+1|0;if((e|0)!=(b|0)){continue}break j}break}j[u+32>>2]=0;break h}j[u+28>>2]=j[u+28>>2]|4}j[u+28>>2]=j[u+28>>2]&-3}v=v+1|0;if((v|0)!=250){continue}break}pua(i,d,B,b,D)}function k0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,k=0,l=0,m=0;h=Za+ -64|0;Za=h;j[h+56>>2]=b;j[e>>2]=0;hc(h,d);j[114626]=0;i=H(2441,h|0)|0;k=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((k|0)!=1){wb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=D()|0;C()|0;wb(h);G(a|0);z()}bD(a,f+24|0,h+56|0,c,e,i);break b}aD(a,f+16|0,h+56|0,c,e,i);break b}b=bb[j[j[a+8>>2]+12>>2]](a+8|0)|0;l=h,m=Ei(a,j[h+56>>2],c,d,e,f,zb(b),zb(b)+(nb(b)<<2)|0),j[l+56>>2]=m;break b}i0(f+12|0,h+56|0,c,e,i);break b}g=j[15567];j[h+24>>2]=j[15566];j[h+28>>2]=g;g=j[15565];j[h+16>>2]=j[15564];j[h+20>>2]=g;g=j[15563];j[h+8>>2]=j[15562];j[h+12>>2]=g;g=j[15561];j[h>>2]=j[15560];j[h+4>>2]=g;l=h,m=Ei(a,b,c,d,e,f,h,h+32|0),j[l+56>>2]=m;break b}g=j[15575];j[h+24>>2]=j[15574];j[h+28>>2]=g;g=j[15573];j[h+16>>2]=j[15572];j[h+20>>2]=g;g=j[15571];j[h+8>>2]=j[15570];j[h+12>>2]=g;g=j[15569];j[h>>2]=j[15568];j[h+4>>2]=g;l=h,m=Ei(a,b,c,d,e,f,h,h+32|0),j[l+56>>2]=m;break b}h0(f+8|0,h+56|0,c,e,i);break b}g0(f+8|0,h+56|0,c,e,i);break b}f0(f+28|0,h+56|0,c,e,i);break b}e0(f+16|0,h+56|0,c,e,i);break b}d0(f+4|0,h+56|0,c,e,i);break b}c0(h+56|0,c,e,i);break b}b0(a,f+8|0,h+56|0,c,e,i);break b}g=Vb(h,62304,44);l=g,m=Ei(a,b,c,d,e,f,g,g+44|0),j[l+56>>2]=m;break b}j[h+16>>2]=j[15592];g=j[15591];j[h+8>>2]=j[15590];j[h+12>>2]=g;g=j[15589];j[h>>2]=j[15588];j[h+4>>2]=g;l=h,m=Ei(a,b,c,d,e,f,h,h+20|0),j[l+56>>2]=m;break b}a0(f,h+56|0,c,e,i);break b}g=j[15603];j[h+24>>2]=j[15602];j[h+28>>2]=g;g=j[15601];j[h+16>>2]=j[15600];j[h+20>>2]=g;g=j[15599];j[h+8>>2]=j[15598];j[h+12>>2]=g;g=j[15597];j[h>>2]=j[15596];j[h+4>>2]=g;l=h,m=Ei(a,b,c,d,e,f,h,h+32|0),j[l+56>>2]=m;break b}$$(f+24|0,h+56|0,c,e,i);break b}a=bb[j[j[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=bb[j[j[a+8>>2]+24>>2]](a+8|0)|0;l=h,m=Ei(a,j[h+56>>2],c,d,e,f,zb(b),zb(b)+(nb(b)<<2)|0),j[l+56>>2]=m;break b}$C(f+20|0,h+56|0,c,e,i);break b}_$(f+20|0,h+56|0,c,e,i);break b}if((g|0)==37){break c}}j[e>>2]=j[e>>2]|4;break b}Z$(h+56|0,c,e,i)}a=j[h+56>>2]}Za=h- -64|0;return a|0}function _na(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;j[a+24588>>2]=0;j[a+24592>>2]=0;j[a+4>>2]=0;j[a>>2]=20768;j[a+8>>2]=j[19863];b=a+24596|0;j[b>>2]=0;j[b+4>>2]=0;Uo(a+24604|0);NJ(a+24648|0,0);oea(a+393352|0);j[a+480224>>2]=0;i[a+480212>>1]=0;j[a+480204>>2]=0;j[a+480208>>2]=0;j[a+480180>>2]=0;j[a+480184>>2]=0;b=a+480186|0;i[b>>1]=0;i[b+2>>1]=0;i[b+4>>1]=0;i[b+6>>1]=0;j[a+480240>>2]=65536;j[a+480244>>2]=65536;n=nx(a+480248|0);j[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{while(1){j[114626]=0;b=H(1383,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break l}b=b+32|0;if((c|0)!=(b|0)){continue}break}e=a+484344|0;Rma(e);j[e+12>>2]=a;j[114626]=0;o=E(1384,a+484360|0,a|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break k}c=a+900380|0;b=a+484380|0;while(1){j[114626]=0;b=E(1008,b|0,0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break j}b=b+104|0;if((c|0)!=(b|0)){continue}break}j[114626]=0;H(1385,a+901404|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break i}f=a+946300|0;k=a+906300|0;c=0;while(1){j[114626]=0;d=(p(c,160)+a|0)+906300|0;H(1386,d|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break h}c=c+1|0;if((c|0)!=250){continue}break}c=a+1074300|0;d=a+946300|0;b=d;while(1){j[114626]=0;b=H(1157,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break g}b=b+32|0;if((c|0)!=(b|0)){continue}break}j[a+1074300>>2]=0;j[a+1074304>>2]=0;mx(a+1074308|0);j[114626]=0;b=T(1387)|0;c=j[114626];j[114626]=0;if((c|0)==1){break f}j[114626]=0;b=H(1388,b|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break f}j[a+1074324>>2]=b;j[114626]=0;H(1389,a+1074328|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}j[114626]=0;H(1390,a+1074376|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}j[114626]=0;c=K(1328,a+1304360|0,a|0,255)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}g=Wna(a+1304392|0);q=Una(a+1304396|0);r=Db(a+1304400|0);s=Qc(a+1304412|0);l=a+1304424|0;Db(l);t=LJ(a+1304436|0);m=a+1304500|0;Qna(m);h[a+1304512|0]=0;Tna(a+1304520|0);j[a+1304560>>2]=0;vo(a+12|0);Vo(a+8204|0);Vo(a+12300|0);b=a+1074408|0;j[b>>2]=4;j[b+4>>2]=16;j[a+480216>>2]=4;j[a+480220>>2]=16;KJ(a+900380|0);j[114626]=0;N(1391,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=H(1392,12)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}j[b>>2]=0;j[b+4>>2]=0;j[b+8>>2]=0;Pma(b);j[a+4>>2]=b;return a|0}b=D()|0;C()|0;break a}b=D()|0;C()|0;break b}b=D()|0;C()|0;break c}b=D()|0;C()|0;break c}b=D()|0;C()|0;if(!c){break c}while(1){d=ym(d-160|0);if((k|0)!=(d|0)){continue}break}break c}b=D()|0;C()|0;break d}b=D()|0;C()|0;break d}b=D()|0;C()|0;lx(m);Nr(t);gb(l);gb(s);gb(r);Mr(q);Lr(g);Bo(c)}while(1){f=ym(f-160|0);if((k|0)!=(f|0)){continue}break}}js(o)}kx(e)}Ud(n);G(b|0);z()}function J8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-192|0;Za=d;a:{if(Pi(b)){break a}e=k[Fj(b)|0];g=1;b:{if((e|0)==33){break b}if((e|0)!=63){break a}g=0}c=g;Pj(d+160|0,b,j[b+4>>2]-1|0);e=j[d+164>>2];j[b>>2]=j[d+160>>2];j[b+4>>2]=e}ld(d+160|0);e=j[d+160>>2];ld(d+144|0);e=Ej(e,j[d+148>>2],b);ld(d+160|0);c:{d:{e:{f:{if((e|0)==j[d+164>>2]){a=j[b+4>>2];j[d+184>>2]=j[b>>2];j[d+188>>2]=a;a=Zb(d+176|0,38235);e=j[d+188>>2];j[d+8>>2]=j[d+184>>2];j[d+12>>2]=e;e=j[a+4>>2];j[d>>2]=j[a>>2];j[d+4>>2]=e;if(nc(d+8|0,d)){a=R(8)|0;j[114626]=0;c=E(85,d+160|0,39169)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(c);break d}f=0;if(!c){break f}a=R(8)|0;j[114626]=0;e=E(2134,d+144|0,b|0)|0;b=j[114626];j[114626]=0;g:{h:{i:{if((b|0)!=1){j[114626]=0;I(2111,d+160|0,39179,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break i}Wb(a,d+160|0);c=0;j[114626]=0;I(2002,a|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break c}b=D()|0;C()|0;gb(d+160|0);break h}b=D()|0;C()|0;break g}b=D()|0;c=1;C()|0}gb(e);if(!c){break d}}S(a|0);break d}if(j[e+4>>2]!=2){a=R(8)|0;j[114626]=0;c=E(85,d+160|0,39193)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(c);break d}b=D()|0;C()|0;S(a|0);break d}c=j[b+4>>2];j[d+136>>2]=j[b>>2];j[d+140>>2]=c;c=Zb(d+128|0,38235);e=j[d+140>>2];j[d+72>>2]=j[d+136>>2];j[d+76>>2]=e;e=j[c+4>>2];j[d+64>>2]=j[c>>2];j[d+68>>2]=e;if(nc(d+72|0,d- -64|0)){a=R(8)|0;j[114626]=0;c=E(85,d+160|0,39169)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(c);break d}b=D()|0;C()|0;S(a|0);break d}c=j[b+4>>2];j[d+120>>2]=j[b>>2];j[d+124>>2]=c;c=Zb(d+112|0,39022);e=j[d+124>>2];j[d+56>>2]=j[d+120>>2];j[d+60>>2]=e;e=j[c+4>>2];j[d+48>>2]=j[c>>2];j[d+52>>2]=e;if(nc(d+56|0,d+48|0)){f=1;if(!k[a+28|0]){break f}f=65536/+m[j[a+24>>2]+480244>>2];break f}c=j[b+4>>2];j[d+104>>2]=j[b>>2];j[d+108>>2]=c;c=Zb(d+96|0,39040);e=j[d+108>>2];j[d+40>>2]=j[d+104>>2];j[d+44>>2]=e;e=j[c+4>>2];j[d+32>>2]=j[c>>2];j[d+36>>2]=e;if(nc(d+40|0,d+32|0)){f=1;if(!k[a+28|0]){break f}f=+m[j[a+24>>2]+480240>>2]*152587890625e-16;break f}c=j[b+4>>2];j[d+88>>2]=j[b>>2];j[d+92>>2]=c;b=Zb(d+80|0,39137);c=j[d+92>>2];j[d+24>>2]=j[d+88>>2];j[d+28>>2]=c;c=j[b+4>>2];j[d+16>>2]=j[b>>2];j[d+20>>2]=c;f=0;if(!nc(d+24|0,d+16|0)){break f}a=a+24|0;a;f=+m[j[a>>2]+480236>>2]*152587890625e-16}Za=d+192|0;return+f}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function EMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=Za-576|0;Za=e;rc(b);d=e+72|0;g=zMa(b,d);if(!g){aT(d)}a:{if(!g){break a}if(!fT(e+72|0)){break a}b:{if(!c){break b}if(!yb(b,Wc(eT(e+72|0),ab))){break a}od(a,64);j[a+480260>>2]=112;j[a+480264>>2]=13696;j[a+480204>>2]=78e4;j[a+480196>>2]=4;i[a+480188>>1]=8;d=Eb(e+40|0,11897);ob(a+1304436|0,d);gb(d);d=Eb(e+40|0,11910);ob(a+1304448|0,d);gb(d);vc(a+1304460|0,l[e+72>>1]==26217?11897:11914);j[a+1304496>>2]=4;d=k[e+182|0];i[a+480190>>1]=d;c:{d:{e:{f:{if(d){f=1;g=1;while(1){CMa(b,e+40|0);if((k[e+53|0]|k[e+54|0]<<8|(k[e+55|0]<<16|k[e+56|0]<<24))>>>0>67108863){break d}DMa(e+40|0,(p(f,104)+a|0)+484380|0);si(e+8|0,2,e+40|0);qc(e+24|0,e+8|0);j[114626]=0;E(369,((f<<5)+a|0)+946300|0,e+24|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}gb(e+24|0);g=g+1|0;f=g&65535;if(f>>>0<=l[a+480190>>1]){continue}break}}d=e+72|2;dT(e+24|0,3,d,36);qc(e+40|0,e+24|0);ob(a+1304400|0,e+40|0);gb(e+40|0);f=0;xM(a+1304424|0,lb(d),108,36,0);d=a+484360|0;cT(Fb(d),e+185|0,128);if(l[ac(Fb(d),k[e+184|0])>>1]<k[e+183|0]){break e}break c}a=D()|0;C()|0;gb(e+24|0);G(a|0);z()}Ge(Fb(d),k[e+184|0]);break c}f=0;break a}while(1){d=(f<<5)+a|0;vg(d+480280|0);i[d+480284>>1]=f&1?208:48;f=f+1|0;if((f|0)!=8){continue}break}q=a+484344|0;If(q,k[e+183|0]);if(k[e+183|0]){s=c&1;while(1){g:{h:{if(s){if(Wf(q,n&65535,64)){break h}}Jb(b,1536);break g}j[e+24>>2]=-1;j[e+28>>2]=-1;r=0;while(1){f=Dp(Ib(q,n),r);g=0;while(1){Ft(e+40|0,b);d=Pc(e+40|0);t=Bf(e+40|0);m=k[d|0];o=e+40|0;d=k[o|0];if(d>>>0<=253){h[f|0]=(d>>>2|0)+37;h[f+1|0]=(d<<4&48|m>>>4)+1;h[(e+24|0)+g|0]=255;d=k[o|0]}if((d|0)!=255){h[f+2|0]=1;h[f+4|0]=(((m&15)<<6|8)>>>0)/15}o=(e+24|0)+g|0;i:{j:{d=k[t|0];k:{if((d|0)!=255){h[o|0]=d;if(d&15|(d|0)==48){break k}break j}d=k[o|0];if((d|0)==255){break i}}m=d&15;h[f+5|0]=m;l:{if(d<<24>>24<0){break l}d=d>>>4|0;h[f+3|0]=k[d+11923|0];m:{switch(d-3|0){case 0:h[f+5|0]=m|32;break j;case 1:h[f+5|0]=m|m<<4;break i;case 2:break j;case 3:break m;default:break i}}n:{switch(m|0){case 0:h[f+5|0]=79;break i;case 1:break n;default:break l}}h[f+5|0]=244;break i}h[f+3|0]=0;break i}h[o|0]=255}f=f+6|0;g=g+1|0;if((g|0)!=8){continue}break}r=r+1|0;if((r|0)!=64){continue}break}d=(e+72|0)+n|0;f=d;if(k[d+369|0]<63){Uk(Ib(q,n),qi(Fe(Cp(e+40|0,14,0),k[f+369|0])))}Uk(Ib(q,n),qi(Cp(e+40|0,16,k[d+241|0])))}n=n+1|0;if(n>>>0<k[e+183|0]){continue}break}}f=1;if(!(c&2)){break a}c=Mc(e+40|0,8,1,0,1);if(!l[a+480190>>1]){break b}while(1){$f(c,(p(f&65535,104)+a|0)+484380|0,b);f=f+1|0;if(l[a+480190>>1]>=(f&65535)>>>0){continue}break}}f=1}Za=e+576|0;return f|0}function xaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,l=0,m=0,n=0,o=0;d=Za-160|0;Za=d;g=d+144|0;jG(g);j[g>>2]=83784;B8(g+4|0);i=a+24|0;nm(j[i>>2],g);f=k[a+62|0];e=k[a+61|0];l=k[a+60|0];m=j[i>>2];b=Ie(d+128|0,b);j[114626]=0;l=l?13:15;e=e?l&14:l;f=K(2137,m|0,b|0,(f?e&3:e)|0)|0;e=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){jb(b);if(!f){b=R(8)|0;j[114626]=0;c=E(85,d+112|0,38611)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}a=D()|0;C()|0;S(b|0);break b}r:{if(k[a+63|0]){break r}j[114626]=0;F(2138,a|0,a+36|0);b=j[114626];j[114626]=0;if((b|0)!=1){break r}a=D()|0;C()|0;break b}h[a+28|0]=1;nm(j[i>>2],j[a+4>>2]);j[114626]=0;F(2139,d+112|0,g|0);b=j[114626];j[114626]=0;if((b|0)==1){break q}n=d,o=Lb(d+112|0),j[n+104>>2]=o;n=d,o=Mb(d+112|0),j[n+96>>2]=o;if(rb(d+104|0,d+96|0)){i=a+68|0;while(1){b=j[d+104>>2];f=j[b>>2];j[114626]=0;e=f;f=b+4|0;I(2140,a|0,e|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break e}b=j[b>>2];j[114626]=0;F(2141,d+32|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break f}j[114626]=0;I(9,d+48|0,0,d+32|0);b=j[114626];j[114626]=0;if((b|0)==1){break h}j[114626]=0;b=E(85,d+16|0,38630)|0;e=j[114626];j[114626]=0;if((e|0)==1){break j}j[114626]=0;I(138,d- -64|0,d+48|0,b|0);e=j[114626];j[114626]=0;if((e|0)==1){break l}j[114626]=0;I(800,d+80|0,d- -64|0,f|0);f=j[114626];j[114626]=0;if((f|0)==1){break n}j[114626]=0;F(1527,i|0,d+80|0);f=j[114626];j[114626]=0;if((f|0)==1){break o}gb(d+80|0);gb(d- -64|0);gb(b);gb(d+48|0);gb(d+32|0);yf(d+104|0);if(rb(d+104|0,d+96|0)){continue}break}}n=d,o=Wm(c),j[n+80>>2]=o;n=d,o=ki(c),j[n+64>>2]=o;s:{while(1){j[114626]=0;b=E(2142,d+80|0,d- -64|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break d}if(!b){break p}j[114626]=0;c=H(2143,d+80|0)|0;b=j[114626];j[114626]=0;t:{if((b|0)==1){break t}j[114626]=0;b=E(120,d|0,c|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break t}j[114626]=0;L(2074,a|0,b|0,c+12|0,0);c=j[114626];j[114626]=0;if((c|0)==1){break s}gb(b);j[114626]=0;H(2144,d+80|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){continue}break d}break}a=D()|0;C()|0;break c}a=D()|0;C()|0;gb(b);break c}a=D()|0;C()|0;jb(b);break b}a=D()|0;C()|0;break b}$v(d+112|0);hr(g);Za=d+160|0;return}a=D()|0;C()|0;gb(d+80|0);break m}a=D()|0;C()|0}gb(d- -64|0);break k}a=D()|0;C()|0}gb(b);break i}a=D()|0;C()|0}gb(d+48|0);break g}a=D()|0;C()|0}gb(d+32|0);break c}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}a=D()|0;C()|0}$v(d+112|0)}hr(g);G(a|0)}z()}function jDa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0;f=Za-16|0;Za=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=k[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}h[a+3|0]=5;h[f+15|0]=k[a+5|0]>>>3;h[f+14|0]=15;b=k[Yb(f+15|0,f+14|0)|0];h[f+13|0]=k[a+5|0]<<1&30;h[f+12|0]=15;i=a,j=k[Yb(f+13|0,f+12|0)|0]|b<<4,h[i+5|0]=j;break a}h[a+3|0]=0;break a}if((k[a+5|0]-1&255)>>>0<=19){h[a+3|0]=16;break a}h[a+3|0]=0;break a}h[a+3|0]=13;b=k[a+5|0];A:{if(!e){if(b>>>0>152){break A}h[a+5|0]=p((b&240)>>>4|0,10)+(b&15);break a}h[a+5|0]=(b&127)+1>>>1;break a}h[a+3|0]=0;break a}h[a+3|0]=11;break a}h[a+3|0]=0;break a}e=k[a+5|0];if(!e){h[a+3|0]=14;break a}if(e>>>0<=240){h[a+3|0]=17;if(e>>>0<=2){h[a+5|0]=112;break a}i=a,j=Ls(+(gP(e,b,c,d)>>>0)*1e-4),h[i+5|0]=j;break a}h[a+3|0]=0;break a}h[a+3|0]=31;h[a+5|0]=k[a+5|0]|128;break a}h[a+3|0]=19;h[f+11|0]=15;i=a,j=k[Yb(a+5|0,f+11|0)|0]|16,h[i+5|0]=j;break a}h[a+3|0]=19;h[f+10|0]=15;i=a,j=k[Yb(a+5|0,f+10|0)|0]|32,h[i+5|0]=j;break a}h[a+3|0]=5;h[f+9|0]=(k[a+5|0]>>>4|0)+1;h[f+8|0]=15;b=Yb(f+9|0,f+8|0);h[a+5|0]=k[a+5|0]&15|k[b|0]<<4;break a}h[a+3|0]=19;h[a+5|0]=k[a+5|0]&15|80;break a}h[a+3|0]=19;h[f+7|0]=15;i=a,j=k[Yb(a+5|0,f+7|0)|0]|96,h[i+5|0]=j;break a}h[a+3|0]=19;h[f+6|0]=15;i=a,j=k[Yb(a+5|0,f+6|0)|0]|192,h[i+5|0]=j;break a}h[a+3|0]=10;break a}h[a+3|0]=19;h[f+5|0]=15;i=a,j=k[Yb(a+5|0,f+5|0)|0]|160,h[i+5|0]=j;break a}h[a+3|0]=19;h[f+4|0]=15;i=a,j=k[Yb(a+5|0,f+4|0)|0]|176,h[i+5|0]=j;break a}b=(k[a+5|0]<<24)-16777216>>24;if((b|0)>=0){h[a+5|0]=b;h[a+3|0]=31;break a}h[a+3|0]=0;break a}h[a+3|0]=14;break a}h[a+3|0]=19;h[f+3|0]=15;i=a,j=k[Yb(a+5|0,f+3|0)|0]|224,h[i+5|0]=j;break a}b=k[a+5|0];if(b&240){h[a+3|0]=19;h[a+5|0]=b>>>4|208;break a}if(b&15){h[a+3|0]=19;h[a+5|0]=b|144;break a}h[a+3|0]=0;break a}if(!(k[a+5|0]|k[a+4|0])){h[a+5|0]=159;h[a+3|0]=20;break a}h[a+3|0]=0;break a}b=k[a+4|0];if(b){h[a+3|0]=41;i=a,j=Vm(Wc(((k[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),h[i+5|0]=j;break a}h[a+3|0]=0;break a}b=k[a+5|0];if((b-17&255)>>>0>=223){h[a+3|0]=9;i=a,j=$i(((b^128)<<3)-896|0),h[i+5|0]=j;break a}h[a+3|0]=0;break a}if(g>>>0<=15){Yi(a);break a}h[a+3|0]=0}Za=f+16|0}function D0(a,b,c,d,e,f,g,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;var l=0,m=0,n=0,o=0;i=Za-32|0;Za=i;j[i+24>>2]=b;j[e>>2]=0;hc(i+8|0,d);j[114626]=0;l=H(21,i+8|0)|0;m=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((m|0)!=1){wb(i+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=D()|0;C()|0;wb(i+8|0);G(a|0);z()}eD(a,f+24|0,i+24|0,c,e,l);break b}dD(a,f+16|0,i+24|0,c,e,l);break b}b=bb[j[j[a+8>>2]+12>>2]](a+8|0)|0;n=i,o=Fi(a,j[i+24>>2],c,d,e,f,zb(b),zb(b)+nb(b)|0),j[n+24>>2]=o;break b}C0(f+12|0,i+24|0,c,e,l);break b}j[i+8>>2]=623865125;j[i+12>>2]=2032480100;n=i,o=Fi(a,b,c,d,e,f,i+8|0,i+16|0),j[n+24>>2]=o;break b}j[i+8>>2]=623728933;j[i+12>>2]=1680158061;n=i,o=Fi(a,b,c,d,e,f,i+8|0,i+16|0),j[n+24>>2]=o;break b}B0(f+8|0,i+24|0,c,e,l);break b}A0(f+8|0,i+24|0,c,e,l);break b}z0(f+28|0,i+24|0,c,e,l);break b}y0(f+16|0,i+24|0,c,e,l);break b}x0(f+4|0,i+24|0,c,e,l);break b}w0(i+24|0,c,e,l);break b}v0(a,f+8|0,i+24|0,c,e,l);break b}g=k[62223]|k[62224]<<8|(k[62225]<<16|k[62226]<<24);h[i+15|0]=g;h[i+16|0]=g>>>8;h[i+17|0]=g>>>16;h[i+18|0]=g>>>24;g=k[62220]|k[62221]<<8|(k[62222]<<16|k[62223]<<24);j[i+8>>2]=k[62216]|k[62217]<<8|(k[62218]<<16|k[62219]<<24);j[i+12>>2]=g;n=i,o=Fi(a,b,c,d,e,f,i+8|0,i+19|0),j[n+24>>2]=o;break b}h[i+12|0]=k[62231];j[i+8>>2]=k[62227]|k[62228]<<8|(k[62229]<<16|k[62230]<<24);n=i,o=Fi(a,b,c,d,e,f,i+8|0,i+13|0),j[n+24>>2]=o;break b}u0(f,i+24|0,c,e,l);break b}j[i+8>>2]=624576549;j[i+12>>2]=1394948685;n=i,o=Fi(a,b,c,d,e,f,i+8|0,i+16|0),j[n+24>>2]=o;break b}t0(f+24|0,i+24|0,c,e,l);break b}a=bb[j[j[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=bb[j[j[a+8>>2]+24>>2]](a+8|0)|0;n=i,o=Fi(a,j[i+24>>2],c,d,e,f,zb(b),zb(b)+nb(b)|0),j[n+24>>2]=o;break b}cD(f+20|0,i+24|0,c,e,l);break b}s0(f+20|0,i+24|0,c,e,l);break b}if((g|0)==37){break c}}j[e>>2]=j[e>>2]|4;break b}r0(i+24|0,c,e,l)}a=j[i+24>>2]}Za=i+32|0;return a|0}function jaa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=Za-96|0;Za=d;a:{b:{c:{if(!(b<.8)){j[114626]=0;N(2150,d+24|0);e=j[114626];j[114626]=0;d:{e:{f:{g:{h:{if((e|0)!=1){c=j[c>>2];j[114626]=0;F(2151,d+8|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break h}nm(j[d+24>>2],j[d+8>>2]);e=j[d+24>>2];c=Ie(d+80|0,a);j[114626]=0;a=K(2137,e|0,c|0,15)|0;e=j[114626];j[114626]=0;if((e|0)==1){break g}jb(c);if(a){a=j[d+24>>2];j[114626]=0;H(1396,a|0)|0;a=j[114626];j[114626]=0;f=1;if((a|0)==1){break f}}Hc(d+8|0);kh(d+24|0);break b}a=J(0)|0;C()|0;break c}a=J(0)|0;C()|0;break d}a=J(0)|0;C()|0;jb(c);break e}a=J(0)|0;C()|0}Hc(d+8|0)}kh(d+24|0);break c}if(!(b<.6)){j[114626]=0;N(2150,d+24|0);e=j[114626];j[114626]=0;i:{j:{k:{l:{m:{if((e|0)!=1){c=j[c>>2];j[114626]=0;F(2151,d+8|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break m}nm(j[d+24>>2],j[d+8>>2]);e=j[d+24>>2];c=Ie(d- -64|0,a);j[114626]=0;a=K(2137,e|0,c|0,2)|0;e=j[114626];j[114626]=0;if((e|0)==1){break l}jb(c);if(a){a=j[d+24>>2];j[114626]=0;H(1396,a|0)|0;a=j[114626];j[114626]=0;f=.8;if((a|0)==1){break k}}Hc(d+8|0);kh(d+24|0);break b}a=J(0)|0;C()|0;break c}a=J(0)|0;C()|0;break i}a=J(0)|0;C()|0;jb(c);break j}a=J(0)|0;C()|0}Hc(d+8|0)}kh(d+24|0);break c}f=.2;if(!(b<.2)){j[114626]=0;N(2150,d+24|0);e=j[114626];j[114626]=0;n:{o:{p:{q:{r:{if((e|0)!=1){c=j[c>>2];j[114626]=0;F(2151,d+8|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break r}nm(j[d+24>>2],j[d+8>>2]);e=j[d+24>>2];c=Ie(d+48|0,a);j[114626]=0;a=K(2137,e|0,c|0,0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break q}jb(c);f=0;if(a){a=j[d+24>>2];j[114626]=0;H(1396,a|0)|0;a=j[114626];j[114626]=0;f=.6;if((a|0)==1){break p}}Hc(d+8|0);kh(d+24|0);break b}a=J(0)|0;C()|0;break c}a=J(0)|0;C()|0;break n}a=J(0)|0;C()|0;jb(c);break o}a=J(0)|0;C()|0}Hc(d+8|0)}kh(d+24|0);break c}if(b<.1){break b}j[114626]=0;I(853,d+24|0,a|0,2048);c=j[114626];j[114626]=0;s:{t:{u:{if((c|0)!=1){j[114626]=0;c=H(412,d+24|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break t}e=j[d+24>>2];j[114626]=0;a=H(255,a|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break t}j[114626]=0;a=JB(2152,3,0,c,e,a,0);c=j[114626];j[114626]=0;if((c|0)==1){break t}a=a+1|0;if(a>>>0>=3){break u}f=o[(a<<3)+40512>>3];lc(d+24|0);break b}a=J(0)|0;C()|0;break c}c=R(8)|0;j[114626]=0;e=E(85,d+8|0,38235)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Wb(c,e);j[114626]=0;I(2002,c|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=J(0)|0;C()|0;gb(e);break s}a=J(0)|0;C()|0;S(c|0);break s}a=J(0)|0;C()|0}lc(d+24|0)}O(a|0)|0;Q();f=0}Za=d+96|0;return+f}z()}function U5(a,b,c,d,e){var f=0,g=0,h=0,m=0,o=0,p=0,r=0,s=0,t=q(0),u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=q(0),E=0,F=0;s=j[b+4>>2];h=j[b>>2]+((s|0)/8|0)|0;r=k[h|0]|k[h+1|0]<<8|(k[h+2|0]<<16|k[h+3|0]<<24);g=(r<<24|r<<8&16711680|(r>>>8&65280|r>>>24))<<(s&7);f=s|-8;u=h+4|0;s=j[c>>2];a:{v=l[c+6>>1];if(!v){v=0;break a}while(1){r=c+C|0;h=k[r+15|0];z=(i[(h<<1)+47968>>1]<<1)+43584|0;r=k[r+18|0];b:{if(h>>>0<16){p=s;w=r;while(1){x=k[p|0]>>>1|0;y=(v|0)>(x|0)?x:v;t=n[d>>2];while(1){m=i[(g>>>26&62)+z>>1];if((m|0)<=-1){o=5;while(1){f=f+o|0;g=g<<o;o=m&7;m=i[((g>>>32-o|0)-(m>>3)<<1)+z>>1];if((m|0)<0){continue}break}}h=m>>8;f=h+f|0;g=g<<h;o=1;while(1){h=m&15;n[a>>2]=n[(((h|g>>>27&16)^16)<<2)+48064>>2]*t;m=m>>4;a=a+4|0;h=(h|0)!=0;f=h+f|0;g=g<<h;h=o&1;o=0;if(h){continue}break}if((f|0)>-1){while(1){g=k[u|0]<<f|g;h=(f|0)>7;f=f-8|0;u=u+1|0;if(h){continue}break}}y=y-1|0;if(y){continue}break}d=d+4|0;p=p+1|0;v=v-x|0;if((v|0)<1){s=p;break a}h=(w|0)>0;w=w-1|0;if(h){continue}break}break b}A=k[h+48032|0];E=32-A|0;h=s;x=r;while(1){B=k[h|0]>>>1|0;w=(v|0)>(B|0)?B:v;t=n[d>>2];while(1){o=i[(g>>>26&62)+z>>1];if((o|0)<=-1){m=5;while(1){g=g<<m;f=f+m|0;p=o&7;m=p;o=i[((g>>>32-m|0)-(o>>3)<<1)+z>>1];if((o|0)<0){continue}break}}p=o>>8;f=p+f|0;g=g<<p;y=1;while(1){F=a;p=o&15;c:{if((p|0)==15){m=g<<A;p=(g>>>E|0)+15|0;f=f+A|0;if((f|0)>=0){while(1){m=k[u|0]<<f|m;g=(f|0)>7;f=f-8|0;u=u+1|0;if(g){continue}break}}D=q(q(t*q(((m|0)>-1?1:-1)|0))*J5(p));break c}m=g;D=q(n[(((g>>>27&16|p)^16)<<2)+48064>>2]*t)}n[F>>2]=D;o=o>>4;a=a+4|0;p=(p|0)!=0;f=p+f|0;g=m<<p;p=y&1;y=0;if(p){continue}break}if((f|0)>-1){while(1){g=k[u|0]<<f|g;p=(f|0)>7;f=f-8|0;u=u+1|0;if(p){continue}break}}w=w-1|0;if(w){continue}break}d=d+4|0;h=h+1|0;v=v-B|0;if((v|0)<1){s=h;break a}p=(x|0)>0;x=x-1|0;if(p){continue}break}}C=C+1|0;s=(r+s|0)+1|0;continue}}o=1-v|0;while(1){d:{r=k[c+26|0]?47952:47920;m=k[r+(g>>>28|0)|0];if(!(m&8)){m=k[r+((g<<4>>>32-(m&3))+(m>>>3)|0)|0]}h=m&7;f=h+f|0;if(((f+(u-j[b>>2]<<3)|0)-24|0)>(e|0)){break d}o=o-1|0;r=d;e:{if(o){break e}o=k[s|0]>>>1|0;if(!o){break d}s=s+1|0;t=n[d>>2];r=d+4|0}g=g<<h;if(m&128){n[a>>2]=(g|0)<0?q(-t):t;f=f+1|0;g=g<<1}if(m&64){n[a+4>>2]=(g|0)<0?q(-t):t;f=f+1|0;g=g<<1}o=o-1|0;d=r;f:{if(o){break f}o=k[s|0]>>>1|0;if(!o){break d}s=s+1|0;t=n[r>>2];d=r+4|0}if(m&32){n[a+8>>2]=(g|0)<0?q(-t):t;f=f+1|0;g=g<<1}if(m&16){n[a+12>>2]=(g|0)<0?q(-t):t;f=f+1|0;g=g<<1}if((f|0)>=0){while(1){g=k[u|0]<<f|g;r=(f|0)>7;f=f-8|0;u=u+1|0;if(r){continue}break}}a=a+16|0;continue}break}j[b+4>>2]=e}function lla(a,b){var c=0,d=0,e=0,f=0,g=0,m=0,n=0,o=0;m=l[a+4>>1];c=m+1|0;i[a+4>>1]=c;if(l[j[a>>2]+480188>>1]<=(c&65535)>>>0){i[a+4>>1]=0}a:{if(Em(b)){break a}g=j[a>>2];c=j[g+1074304>>2];g=j[g+480180>>2];b:{if((g|0)==2){if(k[b+3|0]!=23|c>>>0>=18415616){break b}Ae(b+5|0,64);break b}if(g&16777248){c:{if(k[a+6|0]|c>>>0>=18874368?c>>>0>=18285314:0){break c}d:{switch(k[b+3|0]-20|0){case 3:Ae(b+5|0,128);break c;case 0:break d;default:break c}}e=k[b+5|0];if((e|0)!=208){if((e|0)!=192){break c}h[b|0]=254;h[b+3|0]=0;break c}h[b+3|0]=0}e:{if(c>>>0>=18350080){d=0;if(k[a+6|0]|c>>>0>=18874368){break e}}f=k[b+3|0]-6&255;d=0;if(f>>>0>23){break e}d=8388643>>>f&1}e=k[b+3|0];f:{if(((e|0)==24|(e|0)==22)&c>>>0<18874368?0:!d){break f}d=k[b+5|0];f=d&15;if(!f|(f|0)==15){break f}d=d&240;if(!d|(d|0)==240){break f}if((e|0)==24){h[b+5|0]=d;break f}h[b+5|0]=f}if(!l[j[a>>2]+480192>>1]|((c|0)==19005440|c>>>0>=19005700)|(k[a+6|0]|l[j[a>>2]+480192>>1]>=k[b+1|0])){break b}h[b+4|0]=0;h[b+2|0]=1;break b}if((g|0)!=4){break b}g:{if(k[b+3|0]!=23|c>>>0>=19137026|(c>>>0<18874368?!(k[a+6|0]?c>>>0>=18285314:0):0)){break g}if(k[b+5|0]<65){break g}h[b+3|0]=0}if(!(k[b+3|0]!=10|(k[a+6|0]|c>>>0>=18874368?c>>>0>=18415616:0)|k[b+2|0]!=11)){h[b+3|0]=0}h:{if(k[b+2|0]!=11|c>>>0>=18874640|k[b+3|0]!=4){break h}e=k[b+4|0];if(k[a+6|0]?0:!e){break h}f=k[b+5|0];if(!f){break h}h[b+2|0]=0;n=b,o=eP(f+(e<<4)|0),h[n+5|0]=o}if(k[b+5|0]|(k[b+3|0]!=16|c>>>0>=19007241)){break b}h[b+3|0]=0}i:{if(c>>>0>=18874368){break i}e=0;j:{k:{l:{f=k[b+3|0];d=k[b+5|0]&240;if(!((f|0)!=28|(d|0)!=96)){if(!k[a+6|0]|(g|0)!=4){break l}e=c>>>0<18350080}if(!m){break j}if((f|0)==20&(d|0)==96|e){break k}break j}if(!m){break j}}a=p(0-m|0,6)+b|0;while(1){if(!((k[a+3|0]|8)!=28|(k[a+5|0]&240)!=96)){h[a+3|0]=0}a=a+6|0;if(b>>>0>a>>>0){continue}break}}if(!m|(k[b+5|0]&240)!=224|k[b+3|0]!=20){break i}a=p(0-m|0,6)+b|0;while(1){if(!(k[a+3|0]!=20|(k[a+5|0]&240)!=224)){h[a+3|0]=0}a=a+6|0;if(b>>>0>a>>>0){continue}break}}m:{if(k[b+2|0]!=8|c>>>0>=19333175|(c|0)==19333120){break m}n:{o:{p:{q:{a=k[b+3|0];switch(a-5|0){case 1:break m;case 0:break o;case 2:break q;default:break p}}if(!k[b+4|0]){break n}h[b+3|0]=11;break m}if((a|0)!=26){break m}}c=k[b+5|0];if(!(c&15)){h[b+2|0]=0;h[b+3|0]=5;h[b+5|0]=c|k[b+4|0]&15;break m}r:{switch(a-5|0){case 1:break m;case 0:case 2:break n;default:break r}}if((a|0)!=26){break m}}h[b+2|0]=0}if(k[b+3|0]|((g|0)==16777216|k[b+2|0]!=15)){break a}h[b+2|0]=0;h[b+3|0]=10;h[b+5|0]=k[b+4|0]<<3}}function $ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,l=0,m=0,n=0,o=0,p=0;c=Za-48|0;Za=c;if(th(b)){g=Jj(b);m=j[b+12>>2];f=bka(c+32|0,g);a:{if(!m){break a}while(1){e=j[j[a>>2]-12>>2];j[114626]=0;e=H(1568,a+e|0)|0;d=j[114626];j[114626]=0;b:{if((d|0)!=1){c:{if(!e){break a}j[114626]=0;h[c+31|0]=0;E(1569,a|0,c+31|0)|0;e=j[114626];j[114626]=0;d:{if((e|0)!=1){e=h[c+31|0];if(e){break d}l=l+1|0;break b}break c}h[c+30|0]=0;e:{if((e|0)>-1){break e}j[114626]=0;E(1569,a|0,c+30|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break e}break c}h[c+29|0]=0;Ug(c+16|0);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{e=e&127;e=(e?e-1|0:0)&65535;n=e>>>0>=g>>>0;A:{B:{if(!n){j[114626]=0;i=K(471,b|0,l|0,e|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}if(h[c+30|0]&1){break B}break y}i=c+16|0;d=k[c+30|0];if(!(d&1)){break A}}j[114626]=0;E(1569,a|0,c+29|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}if(e>>>0<g>>>0){break z}d=k[c+30|0]}if(d&2){break x}break w}d=k[c+29|0];o=wc(f,e),p=d,h[o|0]=p}o=i,p=k[wc(f,e)|0],h[o|0]=p;if(!(k[c+30|0]&2)){break u}}j[114626]=0;E(1569,a|0,c+29|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}if(e>>>0<g>>>0){break v}d=k[c+30|0]}if(d&4){break t}break s}d=k[c+29|0];o=wc(f,e),p=d,h[o+1|0]=p}o=i,p=k[wc(f,e)+1|0],h[o+1|0]=p;if(!(k[c+30|0]&4)){break q}}j[114626]=0;E(1569,a|0,c+29|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}if(e>>>0<g>>>0){break r}d=k[c+30|0]}if(d&8){break p}break o}d=k[c+29|0];o=wc(f,e),p=d,h[o+2|0]=p}o=i,p=k[wc(f,e)+2|0],h[o+2|0]=p;if(!(k[c+30|0]&8)){break m}}j[114626]=0;E(1569,a|0,c+29|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}if(e>>>0<g>>>0){break n}d=k[c+30|0]}if(d&16){break l}break k}d=k[c+29|0];o=wc(f,e),p=d,h[o+4|0]=p}o=i,p=k[wc(f,e)+4|0],h[o+4|0]=p;if(!(k[c+30|0]&16)){break i}}j[114626]=0;E(1569,a|0,c+29|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}if(e>>>0<g>>>0){break j}d=k[c+30|0]}if(d&32){break h}break f}d=k[c+29|0];o=wc(f,e),p=d,h[o+3|0]=p}o=i,p=k[wc(f,e)+3|0],h[o+3|0]=p;if(!(k[c+30|0]&32)){break g}}j[114626]=0;E(1569,a|0,c+29|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}if(n){break f}d=k[c+29|0];o=wc(f,e),p=d,h[o+5|0]=p}o=i,p=k[wc(f,e)+5|0],h[o+5|0]=p}if(!(k[c+30|0]&64)){break b}j[114626]=0;E(1569,a|0,c+15|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){e=k[c+15|0];j[114626]=0;K(1570,a|0,e|0,-1)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break b}}}}a=D()|0;C()|0;kl(f);G(a|0);z()}if(l>>>0<m>>>0){continue}break}}kl(f)}Za=c+48|0}function rBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=Za-560|0;Za=e;a:{if(!xc(b,1464)){break a}if(!$m(b,e+556|0)){break a}od(a,1);d=a+1074308|0;rg(d,83);vb(d,84,1);vb(d,85,1);b:{if(Jd(e+556|0,16026)){d=Eb(e+32|0,16036);ob(a+1304436|0,d);gb(d);d=Eb(e+32|0,16059);ob(a+1304448|0,d);gb(d);d=Eb(e+32|0,16064);ob(a+1304460|0,d);break b}if(!Jd(e+556|0,16031)){break a}d=Eb(e+32|0,16081);ob(a+1304436|0,d);gb(d);d=Eb(e+32|0,16093);ob(a+1304448|0,d);gb(d);d=Eb(e+32|0,16097);ob(a+1304460|0,d)}gb(d);j[a+1304496>>2]=2;d=0;xc(b,0);Pz(b,a+1304400|0,20);i[a+480190>>1]=31;f=1;while(1){d=Cy(b,e+32|0,(p(f,104)+a|0)+484380|0,((f<<5)+a|0)+946300|0,1)+d|0;f=f+1|0;if((f|0)!=32){continue}break}if(d>>>0>40){break a}zt(e+552|0,b);r=Pc(e+552|0);m=e+552|0;if(k[m|0]>128){break a}qBa(b,e+32|0);d=e+544|0;f=e+32|0;g=k[r|0];c:{while(1){if(g>>>0>=k[f|0]){f=f+1|0;if((d|0)!=(f|0)){continue}break c}break}break a}t=1;if(!c){break a}j[a+480260>>2]=56;j[a+480264>>2]=13696;j[a+480204>>2]=125e4;j[a+480196>>2]=6;i[a+480192>>1]=0;i[a+480188>>1]=4;j[a+480228>>2]=64;j[a+480208>>2]=j[a+480208>>2]|2097152;Oi(a,0);s=a+484360|0;bg(Fb(s),k[m|0]);i[e+30>>1]=0;n=a+484344|0;If(n,k[m|0]);if(k[m|0]){g=0;while(1){x=ac(Fb(s),g),y=g,i[x>>1]=y;if(Wf(n,g&65535,64)){u=g<<2;l=0;while(1){xc(b,(k[e+32+(l+u)|0]<<8)+1468|0);f=Se(Ib(n,g),0,l&65535);d=0;while(1){Gs(b,f);d:{e:{q=k[f+3|0];f:{if((q|0)!=14){if(!q){if(k[f+5|0]){break e}break f}if((q-5&255)>>>0<5){break f}break e}if(k[f+5|0]<=15){break e}}h[f+3|0]=0;break d}Yi(f)}f=f+24|0;d=d+1|0;if((d|0)!=64){continue}break}l=l+1|0;if((l|0)!=4){continue}break}x=e,y=Lb(Ib(n,g)),j[x+24>>2]=y;l=0;while(1){d=0;while(1){f=d;g:{if(k[j[e+24>>2]+3|0]!=17?k[j[e+24>>2]+3|0]!=16:0){break g}h[j[e+24>>2]+3|0]=16;o=0;if(k[j[e+24>>2]+5|0]<16){break g}if(!(!(k[j[e+24>>2]+5|0]&15)|(k[j[e+24>>2]+5|0]&15)==(k[j[e+24>>2]+5|0]>>>4|0))){v=k[j[e+24>>2]+5|0]>>>4|0;w=k[j[e+24>>2]+5|0]&15;o=1}d=j[e+24>>2];h[d+5|0]=k[d+5|0]>>>4}kk(e+24|0);d=f+1|0;if((f&65535)>>>0<3){continue}break}h[e+31|0]=w;h[e+30|0]=v;d=o&255;f=0;h:{if(!d){break h}Uk(Ib(n,g),Fe(Cp(e+8|0,16,k[(e+d|0)+29|0]),l));d=o+1|0;f=(d&255)==3?1:d}o=f;l=l+1|0;if((l|0)!=64){continue}break}}g=g+1|0;if(g>>>0<k[m|0]){continue}break}}if(!(c&2)){break a}xc(b,(k[r|0]<<8)+1468|0);f=1;while(1){c=(p(f,104)+a|0)+484380|0;if(j[c>>2]){$f(Mc(e+8|0,8,1,0,0),c,b)}f=f+1|0;if((f|0)!=32){continue}break}}Za=e+560|0;return t|0}function Swa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,n=0,o=0,q=0,r=0;e=Za+ -64|0;Za=e;a:{if(!yb(c,8)){break a}Jb(c,4);while(1){f=Rs(c);if(f){break a}if(csa(c)){continue}break}}h[d|0]=k[d|0]!=0|f;rc(c);b:{c:{d:{e:{if(f){d=hf(c);cd(e+48|0,c,ef(c));i[a+34>>1]=l[a+34>>1]&65534|k[b|0]>15;b=l[a+34>>1]&-65|(k[b+1|0]!=1)<<6;i[a+34>>1]=b;j[a>>2]=d>>>(b&1)>>>(b>>>6&1);j[114626]=0;j[e+44>>2]=0;j[e+40>>2]=0;F(857,e+16|0,e+48|0);b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;c=H(412,e+16|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){d=j[e+16>>2];j[114626]=0;b=H(854,c|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;f=H(855,d|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break c}j[114626]=0;b=U(856,b|0,f|0,e+44|0,e+40|0,0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;E(338,e+48|0,j[e+44>>2])|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}f:{if(!b){break f}n=j[e+44>>2];j[114626]=0;H(465,a|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}f=d-n|0;n=c+n|0;c=j[e+40>>2];d=0;while(1){g:{if(m[a>>2]<=d>>>0|(!f|(c|0)!=1?c:0)){break g}if(!ke(a)){break g}j[114626]=0;j[e+12>>2]=0;j[e+8>>2]=0;c=H(854,n|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break c}j[114626]=0;o=H(855,f|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=_(858,b|0,c|0,o|0,e+12|0,e+4|0,e+8|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break c}j[114626]=0;j[e+44>>2]=c;E(338,e+48|0,c|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break c}c=j[a>>2];j[114626]=0;o=j[e+44>>2];c=H(859,c-d|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}Zj(e+8|0,c);h:{if(j[e+8>>2]<1){break h}if(j[e+12>>2]!=(be(a)|0)){break h}c=0;if(j[e+12>>2]<=0){break h}while(1){i:{if(h[a+34|0]&1){g=j[a+20>>2];q=be(a);r=j[j[e+4>>2]+(c<<2)>>2];j[114626]=0;V(860,g+(p(d,q)<<1)|0,r|0,j[e+12>>2],j[e+8>>2],c|0);g=j[114626];j[114626]=0;if((g|0)!=1){break i}break c}g=j[a+20>>2];q=be(a);r=j[j[e+4>>2]+(c<<2)>>2];j[114626]=0;V(861,g+p(d,q)|0,r|0,j[e+12>>2],j[e+8>>2],c|0);g=j[114626];j[114626]=0;if((g|0)==1){break c}}c=c+1|0;if((c|0)<j[e+12>>2]){continue}break}}j[114626]=0;g=j[e+8>>2];c=H(862,b|0)|0;q=j[114626];j[114626]=0;if((q|0)==1){break c}f=f-o|0;n=n+o|0;j[e+40>>2]=c;d=d+g|0;continue}break}j[114626]=0;N(863,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){break f}break c}lc(e+16|0);jb(e+48|0);a=(b|0)!=0;break e}break c}$f(b,a,c);a=1}Za=e- -64|0;return a|0}c=D()|0;C()|0;break b}c=D()|0;C()|0;lc(e+16|0)}jb(e+48|0);G(c|0);z()}function hxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=Za-208|0;Za=d;rc(b);a:{if(!lz(b,d+160|0)){break a}if(!OM(d+160|0)){break a}if(!c){f=1;break a}if(!yb(b,Wc(NM(d+160|0),ab))){break a}od(a,128);ug(d+144|0,2,d+175|0);qc(d+72|0,d+144|0);ob(a+1304400|0,d+72|0);gb(d+72|0);f=Eb(d+72|0,17473);ob(a+1304436|0,f);gb(f);f=Eb(d+72|0,17486);ob(a+1304448|0,f);gb(f);e=Eb(d+144|0,17490);j[114626]=0;I(1022,d+72|0,e|0,j[(k[d+174|0]<<2)+77340>>2]);f=j[114626];j[114626]=0;b:{if((f|0)!=1){ob(a+1304460|0,d+72|0);gb(d+72|0);gb(e);j[a+480208>>2]=12;j[a+1304496>>2]=4;Xx(a+1304424|0,b,k[d+207|0]<<5,32,0);t=a,u=dd(b),i[t+480190>>1]=u;c:{if(l[a+480190>>1]){m=d+136|0;g=d+134|0;f=1;e=1;while(1){d:{if(k[d+174|0]>=52){zz(b,d+72|0);break d}cxa(b,d+72|0);n=k[g|0]|k[g+1|0]<<8;h[m|0]=n;h[m+1|0]=n>>>8;h[g|0]=171;h[g+1|0]=32}gxa(d+72|0,(p(f,104)+a|0)+484380|0);ug(d+56|0,2,d+72|0);qc(d+144|0,d+56|0);j[114626]=0;E(369,((f<<5)+a|0)+946300|0,d+144|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}gb(d+144|0);e=e+1|0;f=e&65535;if(f>>>0<=l[a+480190>>1]){continue}break}}lp(Fb(a+484360|0),b,256,255,254);f=0;e=dd(b);if(e>>>0>=127){break a}i[a+480188>>1]=e+1;m=dd(b);r=m+1|0;if(l[a+480188>>1]){while(1){e=(f<<5)+a|0;vg(e+480280|0);e=e+480284|0;e:{if(k[d+174|0]>=51){q=(dd(b)<<4|8)&248;break e}q=f&1?192:64}i[e>>1]=q;f=f+1|0;if(f>>>0<l[a+480188>>1]){continue}break}}g=a+484344|0;If(g,r);f=0;e=0;while(1){n=e&65535;if(!Wf(g,n,64)){break a}e=e+1|0;if(m>>>0>n>>>0){continue}break}if(l[a+480188>>1]){m=0;while(1){s=bj(d+72|0);n=0;while(1){if(yb(b,5)){e=0;f=Se(Ib(g,n),0,m&65535);while(1){o=fxa(s,b,k[d+174|0]);q=o+e|0;e=q>>>0>64?64-e|0:o;if(e){while(1){o=j[d+72>>2];h[f|0]=o;h[f+1|0]=o>>>8;h[f+2|0]=o>>>16;h[f+3|0]=o>>>24;o=l[d+76>>1];h[f+4|0]=o;h[f+5|0]=o>>>8;f=p(l[a+480188>>1],6)+f|0;e=e-1|0;if(e){continue}break}e=q;q=q>>>0<64;e=q?e:64;if(q){continue}}break}n=n+1|0;if((r|0)!=(n|0)){continue}}break}m=m+1|0;if(l[a+480188>>1]>(m&65535)>>>0){continue}break}}e=exa(d+8|0,l[a+480188>>1]);j[114626]=0;I(1023,d+32|0,g|0,e|0);g=j[114626];j[114626]=0;f=1;if((g|0)!=1){Vd(d+32|0);Vd(e);if(!(c&2)|!l[a+480190>>1]){break a}e=1;while(1){c=p(e&65535,104)+a|0;$f(Mc(d+72|0,i[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);e=e+1|0;if(l[a+480190>>1]>=(e&65535)>>>0){continue}break}break a}f=D()|0;C()|0;Vd(e);break b}f=D()|0;C()|0;gb(d+144|0);break b}f=D()|0;C()|0;gb(e)}G(f|0);z()}Za=d+208|0;return f|0}function CE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=Za-48|0;Za=g;YMa(+a);d=VMa(1)|0;f=VMa(0)|0;a:{b:{e=d;d=e;h=e&2147483647;c:{if(h>>>0<=1074752122){if((d&1048575)==598523){break c}if(h>>>0<=1073928572){if((e|0)>0?1:(e|0)>=0){a=a+ -1.5707963267341256;c=a+ -6.077100506506192e-11;o[b>>3]=c;o[b+8>>3]=a-c+ -6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;o[b>>3]=c;o[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0?1:(e|0)>=0){a=a+ -3.1415926534682512;c=a+ -1.2154201013012384e-10;o[b>>3]=c;o[b+8>>3]=a-c+ -1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;o[b>>3]=c;o[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(h>>>0<=1075594811){if(h>>>0<=1075183036){if((h|0)==1074977148){break c}if((e|0)>0?1:(e|0)>=0){a=a+ -4.712388980202377;c=a+ -1.8231301519518578e-10;o[b>>3]=c;o[b+8>>3]=a-c+ -1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;o[b>>3]=c;o[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((h|0)==1075388923){break c}if((e|0)>0?1:(e|0)>=0){a=a+ -6.2831853069365025;c=a+ -2.430840202602477e-10;o[b>>3]=c;o[b+8>>3]=a-c+ -2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;o[b>>3]=c;o[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(h>>>0>1094263290){break b}}j=a*.6366197723675814+6755399441055744+ -6755399441055744;c=a+j*-1.5707963267341256;i=j*6.077100506506192e-11;a=c-i;o[b>>3]=a;YMa(+a);d=VMa(1)|0;VMa(0)|0;e=h>>>20|0;f=(e-(d>>>20&2047)|0)<17;if(r(j)<2147483648){d=~~j}else{d=-2147483648}d:{if(f){break d}i=c;a=j*6.077100506303966e-11;c=c-a;i=j*2.0222662487959506e-21-(i-c-a);a=c-i;o[b>>3]=a;f=e;YMa(+a);e=VMa(1)|0;VMa(0)|0;if((f-(e>>>20&2047)|0)<50){break d}i=c;a=j*2.0222662487111665e-21;c=c-a;i=j*8.4784276603689e-32-(i-c-a);a=c-i;o[b>>3]=a}o[b+8>>3]=c-a-i;break a}if(h>>>0>=2146435072){a=a-a;o[b>>3]=a;o[b+8>>3]=a;d=0;break a}WMa(0,f|0);WMa(1,e&1048575|1096810496);a=+XMa();d=0;f=1;while(1){k=(g+16|0)+(d<<3)|0;if(r(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);o[k>>3]=c;a=(a-c)*16777216;d=1;k=f&1;f=0;if(k){continue}break}o[g+32>>3]=a;e:{if(a!=0){d=2;break e}f=1;while(1){d=f;f=d-1|0;if(o[(g+16|0)+(d<<3)>>3]==0){continue}break}}d=DE(g+16|0,g,(h>>>20|0)-1046|0,d+1|0,1);a=o[g>>3];if((e|0)<-1?1:(e|0)<=-1){o[b>>3]=-a;o[b+8>>3]=-o[g+8>>3];d=0-d|0;break a}o[b>>3]=a;o[b+8>>3]=o[g+8>>3]}Za=g+48|0;return d}



function ipa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,m=0,n=0,o=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=Za-32|0;Za=f;v=a+4|0;u=j[v>>2];t=a+20|0;y=j[yc(t,b)+16>>2];a:{if(y+1>>>0<2){break a}i=(p(b,896)+u|0)+608|0;if(!ph(i)){if(!k[yc(t,b)+20|0]){break a}}m=p(b,896)+u|0;if(!j[m+712>>2]){break a}D=j[(j[m+696>>2]&2?m+692|0:m+684|0)>>2];g=j[m+688>>2];n=j[m+692>>2];mb(f+24|0,j[a>>2]+1074308|0,31);z=kb(f+24|0);A=m+1356|0;r=k[A|0];B=m+616|0;e=Zt(B,c);o=ab;s=o;j[f+24>>2]=e;j[f+28>>2]=o;if(k[m+696|0]&128){j[f+24>>2]=0-e;j[f+28>>2]=0-(((e|0)!=0)+s|0)}o=n-g|0;E=o<<1;e=p(b,896)+u|0;C=e;F=e+1308|0;s=e+1480|0;G=(r&17)!=1;b:{while(1){c:{if(d>>>0>w>>>0){g=(k[A|0]&17)==1;break c}h[s|0]=k[s|0]&254;e=Se(Ib(j[a>>2]+484344|0,l[j[v>>2]+60>>1]),j[j[v>>2]+48>>2],b);n=k[e+3|0];if(k[e+2|0]==11){xx(f+16|0,j[a>>2],e,0);r=Rb(f+16|0);Am(j[a>>2],i,j[f+16>>2]);g=1;if(k[r|0]){break c}}g=1;d:{switch(n-4|0){case 0:Am(j[a>>2],i,k[e+5|0]);break c;case 2:break d;default:break c}}Am(j[a>>2],i,0)}j[f+12>>2]=j[F>>2];if(z){Hr(j[a>>2],i)}if(!G){fJ(j[a>>2],i,f+12|0);g=1}if(!z){Hr(j[a>>2],i)}j[f+8>>2]=0;hJ(i,f+8|0);e:{if(!g){if(!k[yc(t,b)+20|0]){break e}}if(k[s|0]&12){oM(i,q(1),0,j[a>>2]);e=k[s|0];h[s|0]=(e&8?-9:-5)&e}H=C,I=_w(j[a>>2],i,j[f+12>>2],0),j[H+616>>2]=I;j[C+620>>2]=ab;H=yc(t,b),I=0,h[H+20|0]=I;e=Zt(B,c);g=ab;n=g;j[f+24>>2]=e;j[f+28>>2]=g;if(!(k[m+696|0]&128)){break e}j[f+24>>2]=0-e;j[f+28>>2]=0-(((e|0)!=0)+n|0)}Bb(i,f+24|0);g=j[i+4>>2];n=g;r=j[i>>2];f:{g:{if(D>>>0>g>>>0){break g}e=j[m+696>>2];if(!(e&2)){break f}if(e&4){x=j[m+688>>2];r=x;e=r;if((e|0)>(n|0)?1:0){j[f+16>>2]=0;j[f+20>>2]=r<<1;H=i,I=Qf(f+16|0,i),j[H>>2]=I;j[i+4>>2]=ab;j[m+696>>2]=j[m+696>>2]^128;e=j[f+24>>2];g=0-(j[f+28>>2]+((e|0)!=0)|0)|0;j[f+24>>2]=0-e;j[f+28>>2]=g;x=j[m+688>>2];g=j[i+4>>2]}mb(f+16|0,j[a>>2]+1074308|0,33);e=(g-x>>>0)%(E-kb(f+16|0)>>>0)|0;n=e>>>0<o>>>0;h:{if(!n){j[i+4>>2]=j[m+692>>2]+(o-e|0);g=j[m+696>>2];if(!(n^(g&128)>>>7)){break h}break g}j[i+4>>2]=e+j[m+688>>2];g=j[m+696>>2];if(n^(g&128)>>>7){break g}}j[m+696>>2]=g^128;e=j[f+24>>2];g=0-(j[f+28>>2]+((e|0)!=0)|0)|0;j[f+24>>2]=0-e;j[f+28>>2]=g;break g}n=j[m+692>>2];if(n+o>>>0<=g>>>0){g=n+((g-n>>>0)%(o>>>0)|0)|0}while(1){e=g;g=e-o|0;if(e>>>0>=n>>>0){continue}break}j[i>>2]=r;j[i+4>>2]=e}w=w+1|0;if((y|0)!=(w|0)){continue}break b}break}qM(i);j[(p(b,896)+u|0)+1316>>2]=0}H=yc(t,b),I=0,j[H+16>>2]=I}Za=f+32|0}function kma(a,b,c,d,e){var f=0,g=0,i=0,l=0,m=0,o=0,r=0,s=0;o=Za-16|0;Za=o;g=j[b+104>>2];a:{if(!g|!k[g+40|0]){break a}s=Wi(b);f=zo(a);mb(o+8|0,a+1074308|0,21);m=f?26336:25312;r=f?25312:26336;if(!(!kb(o+8|0)|s|j[a+480180>>2]==1048576)){if(!k[g+41|0]){break a}l=k[b+838|0];j[o+4>>2]=j[b+780>>2]+k[g+39|0];Zj(o+4|0,k[g+40|0]<<8);d=j[o+4>>2];j[b+780>>2]=d;d=(d|0)/256|0;j[o+4>>2]=d;h[b+838|0]=k[b+838|0]+k[g+41|0];b:{c:{switch(k[g+38|0]-1|0){case 3:b=bJ(Bm(a))+ -64|0;d=j[o+4>>2];break b;case 2:b=64-(l+1>>>1|0)|0;break b;case 1:b=(l+1>>>1|0)+ -64|0;break b;case 0:b=(l>>>1^-1)&64;break b;default:break c}}b=h[l+21616|0]}Zj(c,8388607);a=j[c>>2]<<8;j[c>>2]=a;l=p(b,d);d=(l|0)/64|0;b=d>>31;g=b^b+d;d=g>>>2|0;b=c;d:{if((l|0)<=-64){d=j[(d<<2)+m>>2];d=ic(PMa(OMa(d,d>>31,a,a>>31),ab,65536,0),ab);a=j[c>>2];m=d-a|0;d=m;r=g&3;if(!r){break d}d=j[(r<<2)+(f?25248:25184)>>2];d=ic(PMa(OMa(d,d>>31,a,a>>31),ab,65536,0),ab)+m|0;a=j[c>>2];d=d-a|0;break d}d=j[(d<<2)+r>>2];d=ic(PMa(OMa(d,d>>31,a,a>>31),ab,65536,0),ab);a=j[c>>2];m=d-a|0;d=m;r=g&3;if(!r){break d}d=j[(r<<2)+(f?25184:25248)>>2];d=ic(PMa(OMa(d,d>>31,a,a>>31),ab,65536,0),ab)+m|0;a=j[c>>2];d=d-a|0}j[b>>2]=(a+d|0)/256;j[e>>2]=d&255;break a}e:{if(!(k[g+39|0]|j[a+480180>>2]&16777248)){j[b+780>>2]=k[g+40|0]<<8;break e}f:{g:{if(j[a+480180>>2]&16777248){l=j[b+780>>2];i=b+780|0;f=k[g+39|0]<<1;break g}if(k[b+89|0]&8){break f}l=((k[g+40|0]<<8&65280)>>>0)/k[g+39|0]|0;i=b+780|0;f=j[b+780>>2]}j[i>>2]=f+l}Zj(b+780|0,k[g+40|0]<<8)}f=k[b+838|0]+k[g+41|0]|0;h[b+838|0]=f;f=f<<24>>24;h:{i:{switch(k[g+38|0]-1|0){case 3:h[b+838|0]=f+1;i=h[(f&63)+21552|0];break h;case 2:i=(64-(f>>>1|0)&127)+ -64|0;break h;case 1:i=((f>>>1|0)- -64&127)+ -64|0;break h;case 0:i=(f|0)>-1?-64:64;break h;default:break i}}f=k[b+838|0];i=0-h[f+21616|0]|0;if(j[a+480180>>2]!=1048576){break h}i=(64-h[(f+ -64&255)+21616|0]|0)/2<<16>>16}f=i;i=p(f,j[b+780>>2]);l=(i|0)/256|0;if(s){n[d>>2]=q(q(q(f|0)*q(1220703143189894e-20))*q(k[g+40|0]))+n[d>>2];h[b+872|0]=k[b+872|0]|8;break a}if(j[a+480180>>2]!=4){j:{if((i|0)<=-256){l=0-l|0;b=0-i>>>16|0;a=(b<<2)+m|0;break j}m=r;b=(i|0)/65536|0;a=m+(b<<2)|0}d=j[c>>2];a=j[a>>2];a=((p(j[((b<<2)+m|0)+4>>2]-a|0,(l|0)/4&63)|0)/64|0)+a|0;a=ic(PMa(OMa(d,d>>31,a,a>>31),ab,256,0),ab);j[c>>2]=a;j[e>>2]=a&255;j[c>>2]=j[c>>2]/256;break a}j[c>>2]=j[c>>2]+((i|0)/16384|0)}Za=o+16|0}function O0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;n=Za-16|0;Za=n;p=nv(g);r=Vu(g);Uf(n,r);j[f>>2]=d;a:{b:{c:{l=a;g=k[l|0];switch(g-43|0){case 0:case 2:break c;default:break b}}j[114626]=0;g=E(2467,p|0,g<<24>>24)|0;l=j[114626];j[114626]=0;if((l|0)==1){break a}l=j[f>>2];j[f>>2]=l+4;j[l>>2]=g;l=a+1|0}d:{g=l;if(!((c-g|0)<=1|k[g|0]!=48|(k[g+1|0]|32)!=120)){j[114626]=0;g=E(2467,p|0,48)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}i=j[f>>2];j[f>>2]=i+4;j[i>>2]=g;g=h[l+1|0];j[114626]=0;g=E(2467,p|0,g|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}i=j[f>>2];j[f>>2]=i+4;j[i>>2]=g;l=l+2|0;g=l;while(1){if(c>>>0<=g>>>0){break d}i=h[g|0];j[114626]=0;m=T(2437)|0;o=j[114626];j[114626]=0;e:{if((o|0)==1){break e}j[114626]=0;i=dv(i,m);m=j[114626];j[114626]=0;if((m|0)==1){break e}if(!i){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}i=h[g|0];j[114626]=0;T(2437)|0;m=j[114626];j[114626]=0;if((m|0)==1){break a}j[114626]=0;i=Ig(i);m=j[114626];j[114626]=0;if((m|0)==1){break a}if(!i){break d}g=g+1|0;continue}}f:{if(Ec(n)){i=j[f>>2];j[114626]=0;P(2455,p|0,l|0,g|0,i|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}j[f>>2]=j[f>>2]+(g-l<<2);break f}o=0;j[114626]=0;uj(l,g);i=j[114626];j[114626]=0;if((i|0)==1){break a}j[114626]=0;t=H(2452,r|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}m=0;i=l;while(1){if(g>>>0<=i>>>0){i=j[f>>2];j[114626]=0;On((l-a<<2)+d|0,i);l=j[114626];j[114626]=0;if((l|0)!=1){break f}break a}g:{if(h[Ub(n,m)|0]<1){break g}if(h[Ub(n,m)|0]!=(o|0)){break g}o=j[f>>2];j[f>>2]=o+4;j[o>>2]=t;m=(nb(n)-1>>>0>m>>>0)+m|0;o=0}s=h[i|0];j[114626]=0;s=E(2467,p|0,s|0)|0;q=j[114626];j[114626]=0;if((q|0)!=1){q=j[f>>2];j[f>>2]=q+4;j[q>>2]=s;i=i+1|0;o=o+1|0;continue}break}break a}h:{while(1){if(c>>>0>g>>>0){l=k[g|0];if((l|0)==46){j[114626]=0;l=H(2456,r|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}m=j[f>>2];i=m+4|0;j[f>>2]=i;j[m>>2]=l;g=g+1|0;break h}j[114626]=0;l=E(2467,p|0,l<<24>>24)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}i=j[f>>2];j[f>>2]=i+4;j[i>>2]=l;g=g+1|0;continue}break}i=j[f>>2]}j[114626]=0;P(2455,p|0,g|0,c|0,i|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break a}l=f;f=j[f>>2]+(c-g<<2)|0;j[l>>2]=f;j[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;gb(n);Za=n+16|0;return}a=D()|0;C()|0;gb(n);G(a|0);z()}function Z0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;n=Za-16|0;Za=n;p=Xt(g);r=Yu(g);Uf(n,r);j[f>>2]=d;a:{b:{c:{l=a;g=k[l|0];switch(g-43|0){case 0:case 2:break c;default:break b}}j[114626]=0;g=E(22,p|0,g<<24>>24)|0;l=j[114626];j[114626]=0;if((l|0)==1){break a}l=j[f>>2];j[f>>2]=l+1;h[l|0]=g;l=a+1|0}d:{g=l;if(!((c-g|0)<=1|k[g|0]!=48|(k[g+1|0]|32)!=120)){j[114626]=0;g=E(22,p|0,48)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}i=j[f>>2];j[f>>2]=i+1;h[i|0]=g;g=h[l+1|0];j[114626]=0;g=E(22,p|0,g|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}i=j[f>>2];j[f>>2]=i+1;h[i|0]=g;l=l+2|0;g=l;while(1){if(c>>>0<=g>>>0){break d}i=h[g|0];j[114626]=0;m=T(2437)|0;o=j[114626];j[114626]=0;e:{if((o|0)==1){break e}j[114626]=0;i=dv(i,m);m=j[114626];j[114626]=0;if((m|0)==1){break e}if(!i){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}i=h[g|0];j[114626]=0;T(2437)|0;m=j[114626];j[114626]=0;if((m|0)==1){break a}j[114626]=0;i=Ig(i);m=j[114626];j[114626]=0;if((m|0)==1){break a}if(!i){break d}g=g+1|0;continue}}f:{if(Ec(n)){i=j[f>>2];j[114626]=0;P(2432,p|0,l|0,g|0,i|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}j[f>>2]=j[f>>2]+(g-l|0);break f}o=0;j[114626]=0;uj(l,g);i=j[114626];j[114626]=0;if((i|0)==1){break a}j[114626]=0;t=H(2423,r|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}m=0;i=l;while(1){if(g>>>0<=i>>>0){i=j[f>>2];j[114626]=0;uj((l-a|0)+d|0,i);l=j[114626];j[114626]=0;if((l|0)!=1){break f}break a}g:{if(h[Ub(n,m)|0]<1){break g}if(h[Ub(n,m)|0]!=(o|0)){break g}o=j[f>>2];j[f>>2]=o+1;h[o|0]=t;m=(nb(n)-1>>>0>m>>>0)+m|0;o=0}s=h[i|0];j[114626]=0;s=E(22,p|0,s|0)|0;q=j[114626];j[114626]=0;if((q|0)!=1){q=j[f>>2];j[f>>2]=q+1;h[q|0]=s;i=i+1|0;o=o+1|0;continue}break}break a}while(1){h:{if(c>>>0>g>>>0){l=k[g|0];if((l|0)!=46){break h}j[114626]=0;l=H(2433,r|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}i=j[f>>2];j[f>>2]=i+1;h[i|0]=l;g=g+1|0}l=j[f>>2];j[114626]=0;P(2432,p|0,g|0,c|0,l|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break a}l=f;f=j[f>>2]+(c-g|0)|0;j[l>>2]=f;j[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;gb(n);Za=n+16|0;return}j[114626]=0;l=E(22,p|0,l<<24>>24)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}i=j[f>>2];j[f>>2]=i+1;h[i|0]=l;g=g+1|0;continue}}a=D()|0;C()|0;gb(n);G(a|0);z()}function L8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-160|0;Za=d;a:{if(Pi(b)){break a}f=k[Fj(b)|0];e=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}e=0}c=e;Pj(d+128|0,b,j[b+4>>2]-1|0);e=j[d+132>>2];j[b>>2]=j[d+128>>2];j[b+4>>2]=e}ld(d+128|0);e=j[d+128>>2];ld(d+112|0);e=Ej(e,j[d+116>>2],b);ld(d+128|0);c:{d:{e:{f:{if((e|0)==j[d+132>>2]){a=j[b+4>>2];j[d+152>>2]=j[b>>2];j[d+156>>2]=a;a=Zb(d+144|0,38235);e=j[d+156>>2];j[d+8>>2]=j[d+152>>2];j[d+12>>2]=e;e=j[a+4>>2];j[d>>2]=j[a>>2];j[d+4>>2]=e;if(nc(d+8|0,d)){a=R(8)|0;j[114626]=0;c=E(85,d+128|0,39169)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(c);break d}e=0;f=0;if(!c){break f}a=R(8)|0;j[114626]=0;e=E(2134,d+112|0,b|0)|0;b=j[114626];j[114626]=0;g:{h:{i:{if((b|0)!=1){j[114626]=0;I(2111,d+128|0,39179,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break i}Wb(a,d+128|0);c=0;j[114626]=0;I(2002,a|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break c}b=D()|0;C()|0;gb(d+128|0);break h}b=D()|0;C()|0;break g}b=D()|0;c=1;C()|0}gb(e);if(!c){break d}}S(a|0);break d}if(j[e+4>>2]!=1){a=R(8)|0;j[114626]=0;c=E(85,d+128|0,39193)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(c);break d}b=D()|0;C()|0;S(a|0);break d}c=j[b+4>>2];j[d+104>>2]=j[b>>2];j[d+108>>2]=c;c=Zb(d+96|0,38235);e=j[d+108>>2];j[d+56>>2]=j[d+104>>2];j[d+60>>2]=e;e=j[c+4>>2];j[d+48>>2]=j[c>>2];j[d+52>>2]=e;if(nc(d+56|0,d+48|0)){a=R(8)|0;j[114626]=0;c=E(85,d+128|0,39169)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(c);break d}b=D()|0;C()|0;S(a|0);break d}c=j[b+4>>2];j[d+88>>2]=j[b>>2];j[d+92>>2]=c;c=Zb(d+80|0,39014);e=j[d+92>>2];j[d+40>>2]=j[d+88>>2];j[d+44>>2]=e;e=j[c+4>>2];j[d+32>>2]=j[c>>2];j[d+36>>2]=e;if(nc(d+40|0,d+32|0)){a=j[a+8>>2];e=a;f=a>>31;break f}c=j[b+4>>2];j[d+72>>2]=j[b>>2];j[d+76>>2]=c;b=Zb(d- -64|0,39162);c=j[d+76>>2];j[d+24>>2]=j[d+72>>2];j[d+28>>2]=c;c=j[b+4>>2];j[d+16>>2]=j[b>>2];j[d+20>>2]=c;e=0;f=0;if(!nc(d+24|0,d+16|0)){break f}a=j[j[a+32>>2]+40>>2];e=a;f=a>>31}Za=d+160|0;ab=f;return e|0}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function Jba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Db(a);j[114626]=0;M(81);c=j[114626];j[114626]=0;a:{b:{if((c|0)==1){c=Pa(83632,71396,71372,0)|0;d=C()|0;c:{d:{e:{if((W(83632)|0)==(d|0)){c=O(c|0)|0;j[114626]=0;E(1988,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;E(1988,a|0,37654)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;E(1988,a|0,37713)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}b=bb[j[j[c>>2]+8>>2]](c)|0;j[114626]=0;E(1988,a|0,(b?b:34181)|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){break b}b=D()|0;C()|0;break a}f:{if((W(71396)|0)==(d|0)){c=O(c|0)|0;j[114626]=0;E(1988,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}j[114626]=0;E(1988,a|0,37654)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}j[114626]=0;E(1988,a|0,37697)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}b=bb[j[j[c>>2]+8>>2]](c)|0;j[114626]=0;E(1988,a|0,(b?b:34181)|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){break b}b=D()|0;C()|0;break a}e=W(71372)|0;c=O(c|0)|0;g:{if((d|0)==(e|0)){j[114626]=0;E(1988,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;E(1988,a|0,37654)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;E(1988,a|0,37680)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}b=bb[j[j[c>>2]+8>>2]](c)|0;j[114626]=0;E(1988,a|0,(b?b:34181)|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){break b}b=D()|0;C()|0;break a}j[114626]=0;E(1988,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;E(1988,a|0,37654)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;E(1988,a|0,37657)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){break b}b=D()|0;C()|0;break a}b=D()|0;C()|0;j[114626]=0;M(20);c=j[114626];j[114626]=0;if((c|0)!=1){break a}break c}b=D()|0;C()|0;j[114626]=0;M(20);c=j[114626];j[114626]=0;if((c|0)!=1){break a}break c}b=D()|0;C()|0;j[114626]=0;M(20);c=j[114626];j[114626]=0;if((c|0)==1){break c}break a}b=D()|0;C()|0;j[114626]=0;M(20);c=j[114626];j[114626]=0;if((c|0)!=1){break a}}a=J(0)|0;C()|0;ib(a)}z()}return}gb(a);G(b|0);z()}function G8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Za-160|0;Za=e;a:{if(Pi(c)){break a}g=k[Fj(c)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;Pj(e+128|0,c,j[c+4>>2]-1|0);f=j[e+132>>2];j[c>>2]=j[e+128>>2];j[c+4>>2]=f}ld(e+128|0);f=j[e+128>>2];ld(e+112|0);h=Ej(f,j[e+116>>2],c);ld(e+128|0);f=j[c>>2];g=j[c+4>>2];c:{d:{e:{f:{if((h|0)==j[e+132>>2]){j[e+152>>2]=f;j[e+156>>2]=g;b=Zb(e+144|0,38235);f=j[e+156>>2];j[e+8>>2]=j[e+152>>2];j[e+12>>2]=f;f=j[b+4>>2];j[e>>2]=j[b>>2];j[e+4>>2]=f;if(nc(e+8|0,e)){a=R(8)|0;j[114626]=0;b=E(85,e+128|0,39169)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}Wb(a,b);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}c=D()|0;C()|0;gb(b);break d}if(d){b=R(8)|0;j[114626]=0;d=E(2134,e+112|0,c|0)|0;a=j[114626];j[114626]=0;g:{h:{i:{if((a|0)!=1){j[114626]=0;I(2111,e+128|0,39179,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break i}Wb(b,e+128|0);a=0;j[114626]=0;I(2002,b|0,83632,2010);c=j[114626];j[114626]=0;if((c|0)!=1){break c}c=D()|0;C()|0;gb(e+128|0);break h}c=D()|0;C()|0;break g}c=D()|0;a=1;C()|0}gb(d);if(!a){break d}}S(b|0);break d}Db(a);break f}j[e+104>>2]=f;j[e+108>>2]=g;d=Zb(e+96|0,38235);f=j[e+108>>2];j[e+56>>2]=j[e+104>>2];j[e+60>>2]=f;f=j[d+4>>2];j[e+48>>2]=j[d>>2];j[e+52>>2]=f;if(nc(e+56|0,e+48|0)){a=R(8)|0;j[114626]=0;b=E(85,e+128|0,39169)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Wb(a,b);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}c=D()|0;C()|0;gb(b);break d}c=D()|0;C()|0;S(a|0);break d}d=j[c+4>>2];j[e+88>>2]=j[c>>2];j[e+92>>2]=d;d=Zb(e+80|0,39058);f=j[e+92>>2];j[e+40>>2]=j[e+88>>2];j[e+44>>2]=f;f=j[d+4>>2];j[e+32>>2]=j[d>>2];j[e+36>>2]=f;if(nc(e+40|0,e+32|0)){j:{switch(j[b+52>>2]){case 0:Eb(a,39251);break f;case 1:Eb(a,39259);break f;case 2:Eb(a,39268);break f;default:break j}}Db(a);break f}d=j[c+4>>2];j[e+72>>2]=j[c>>2];j[e+76>>2]=d;c=Zb(e- -64|0,39101);d=j[e+76>>2];j[e+24>>2]=j[e+72>>2];j[e+28>>2]=d;d=j[c+4>>2];j[e+16>>2]=j[c>>2];j[e+20>>2]=d;if(nc(e+24|0,e+16|0)){k:{switch(j[b+56>>2]){case 0:Eb(a,39273);break f;case 1:Eb(a,39278);break f;case 2:Eb(a,39284);break f;case 3:Eb(a,39295);break f;default:break k}}Db(a);break f}Db(a)}Za=e+160|0;return}c=D()|0;C()|0;S(a|0)}G(c|0)}z()}function dLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,l=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=Za-32|0;Za=e;o=bj(e+24|0);if(j[a+12>>2]){v=o+3|0;w=o+5|0;x=o+4|0;y=o+2|0;z=o+1|0;A=b^1;B=e+16|5;C=e+16|3;while(1){D=Dp(a,s);while(1){a:{if(!yb(c,1)){break a}q=dd(c);if((q|0)==255){break a}l=q&31;d=Jj(a)>>>0>l>>>0;l=p(l,6)+D|0;b:{if(!(q&64)){f=dd(c);g=f<<24>>24;c:{d:{e:{f=f&127;switch(f|0){case 0:break c;case 1:break e;default:break d}}h[(d?l:e+24|0)|0]=255;break c}if(!(f>>>0>121|A)){h[(d?l:e+24|0)|0]=f-1;break c}if((f-12&255)>>>0>96|b){break c}h[(d?l:e+24|0)|0]=f+13}F=d?l+1|0:z,G=dd(c),h[F|0]=G;if((g|0)>-1){break b}}u=d?l:o;g=d?l+3|0:v;f=d?l+5|0:w;t=d?l+4|0:x;r=d?l+2|0:y;l=d?l:e+24|0;while(1){d=l;j[e+16>>2]=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);i[e+20>>1]=k[d+4|0]|k[d+5|0]<<8;d=dd(c);E=d&128;n=d&63;f:{if(d&64){h[r|0]=1;h[t|0]=n;break f}d=dd(c);h[f|0]=d;g:{h:{if(n>>>0<=15){h[g|0]=n;Yi(u);i:{j:{k:{d=k[g|0];switch(d-9|0){case 1:case 2:case 3:break g;case 4:break j;case 0:break k;default:break i}}h[g|0]=9;h[f|0]=p(k[f|0]&15,17);break g}h[g|0]=0;h[r|0]=1;j[e+12>>2]=k[f|0]+1>>>1;j[e+8>>2]=64;F=t,G=j[Pd(e+12|0,e+8|0)>>2],h[F|0]=G;break g}if((d|0)!=19){break g}if(k[f|0]==128){break h}Lw(u);break g}if(n>>>0>44){break g}n=n-16|0;h[g|0]=k[n+12272|0];l:{switch(n|0){case 0:if(d>>>0>1){break h}h[f|0]=d|158;break g;case 1:case 2:h[e+12|0]=15;F=f,G=k[Yb(e+12|0,f)|0]|224,h[F|0]=G;break g;case 5:case 6:j[e+12>>2]=16;j[e+8>>2]=d+1;F=f,G=j[Pd(e+12|0,e+8|0)>>2]/2|240,h[F|0]=G;break g;case 14:m:{n:{o:{p:{q:{n=d>>>4|0;switch(n-1|0){case 1:break o;case 0:break p;default:break q}}switch(n-10|0){case 1:break m;case 0:break n;default:break h}}h[g|0]=2;h[f|0]=d|240;break g}h[g|0]=3;h[f|0]=d|240;break g}h[g|0]=11;h[f|0]=(d<<3&120)+8|15;break g}h[g|0]=11;h[f|0]=(d&15)+1>>>1|240;break g;case 12:break l;default:break g}}j[e+12>>2]=d+1>>>1;j[e+8>>2]=64;F=f,G=j[Pd(e+12|0,e+8|0)>>2],h[F|0]=G;break g}h[g|0]=0}Jw(g,f,C,B);if(wm(k[e+19|0])>>>0<=wm(k[g|0])>>>0){break f}r:{if(k[r|0]){break r}if(!Kw(g,f,1)){break r}h[r|0]=k[g|0];h[t|0]=k[f|0]}h[g|0]=k[e+19|0];h[f|0]=k[e+21|0]}if(E){continue}break}}if(!(q&128)){continue}}break}s=s+1|0;if(s>>>0<m[a+12>>2]){continue}break}}Za=e+32|0}function gca(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var k=0,l=0,m=0;l=Za-80|0;Za=l;a:{b:{c:{k=In(1,32);d:{e:{if(!k){a=R(4)|0;zk(a);j[114626]=0;I(2002,a|0,71396,2001);a=j[114626];j[114626]=0;if((a|0)!=1){break a}i=J(0)|0;C()|0;break e}j[k+16>>2]=0;j[k+20>>2]=0;j[k+12>>2]=f;j[k+8>>2]=e;j[k+4>>2]=d;j[k+24>>2]=0;j[k+28>>2]=0;j[k>>2]=c?c:1990;d=bs(l- -64|0);f:{g:{if(!i){break g}c=j[i>>2];if(!c){break g}while(1){h:{e=j[i+4>>2];if(e){j[114626]=0;c=E(85,l+48|0,c|0)|0;f=j[114626];j[114626]=0;i:{if((f|0)!=1){j[114626]=0;f=E(2003,d|0,c|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break i}j[114626]=0;E(483,f|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break i}break h}i=J(0)|0;C()|0;break f}i=J(0)|0;C()|0;gb(c);break f}j[114626]=0;c=E(85,l+48|0,c|0)|0;e=j[114626];j[114626]=0;j:{if((e|0)!=1){j[114626]=0;E(2004,d|0,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break j}break h}i=J(0)|0;C()|0;break f}i=J(0)|0;C()|0;gb(c);break f}gb(c);c=j[i+8>>2];i=i+8|0;if(c){continue}break}}c=j[a+8>>2];e=j[a+4>>2];f=j[a>>2];j[114626]=0;a=H(1392,96)|0;i=j[114626];j[114626]=0;k:{l:{m:{if((i|0)!=1){j[114626]=0;j[l+44>>2]=c;j[l+40>>2]=e;j[l+36>>2]=f;j[l+32>>2]=b;I(2005,l+48|0,k|0,k+4|0);b=j[114626];j[114626]=0;if((b|0)==1){break m}b=go(l+24|0,l+48|0);j[114626]=0;c=j[l+44>>2];j[l+16>>2]=j[l+40>>2];j[l+20>>2]=c;c=j[l+36>>2];j[l+8>>2]=j[l+32>>2];j[l+12>>2]=c;P(2079,a|0,l+8|0,b|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break l}j[k+28>>2]=a;Hc(b);Hc(l+48|0);a=j[k+28>>2];j[k+24>>2]=a?a+8|0:0;Rj(d);break d}i=J(0)|0;C()|0;break f}i=J(0)|0;C()|0;break k}i=J(0)|0;C()|0;Hc(b);Hc(l+48|0)}Cb(a)}Rj(d);O(i|0)|0;j[114626]=0;L(1982,37229,k|0,g|0,h|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)!=1){a=j[k+28>>2];if(a){bb[j[j[a>>2]+4>>2]](a)}j[k+24>>2]=0;j[k+28>>2]=0;a=j[k+20>>2];if(a){Cb(a);j[k+20>>2]=0}Cb(k);k=0;break d}i=J(0)|0;C()|0;break e}i=J(0)|0;C()|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)==1){break b}}O(i|0)|0;k=0;j[114626]=0;L(1982,37229,0,g|0,h|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Q()}Za=l+80|0;return k|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}a=J(0)|0;C()|0;ib(a)}z()}function lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,l=0,m=0;e=Za-176|0;Za=e;Ve(e+160|0,b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{g=kia(a,b,c,d);if(!g){jn(j[j[b>>2]-12>>2]+b|0,0);g=j[e+172>>2];j[e+8>>2]=j[e+168>>2];j[e+12>>2]=g;g=j[e+164>>2];j[e>>2]=j[e+160>>2];j[e+4>>2]=g;Gi(b,e);b=Ek(e+56|0,b);j[114626]=0;g=E(683,e+40|0,32531)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}j[114626]=0;j[e+32>>2]=3;j[e+36>>2]=0;I(684,b|0,g|0,e+32|0);f=j[114626];j[114626]=0;if((f|0)==1){break c}qb(g);j[114626]=0;h[e+31|0]=0;g=E(683,e+40|0,32534)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}j[114626]=0;K(685,b|0,e+31|0,g|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}qb(g);j[114626]=0;g=k[e+31|0];f=H(1617,b|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break f}j[114626]=0;l=H(1618,b|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break g}j[e+32>>2]=l;j[e+24>>2]=f;if(rb(e+24|0,e+32|0)){g=g?0:d;while(1){j[114626]=0;i[e+22>>1]=65535;d=E(683,e+40|0,32539)|0;f=j[114626];j[114626]=0;if((f|0)==1){break j}j[114626]=0;f=K(1619,b|0,e+24|0,d|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break i}qb(d);m:{if(!f){j[114626]=0;L(1620,b|0,e+24|0,c|0,g|0);d=j[114626];j[114626]=0;if((d|0)==1){break h}break m}j[114626]=0;d=E(683,e+40|0,32541)|0;f=j[114626];j[114626]=0;n:{o:{if((f|0)!=1){j[114626]=0;f=K(1619,b|0,e+24|0,d|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break o}qb(d);if(f){break n}j[114626]=0;K(1621,b|0,e+24|0,e+22|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break m}break h}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(d);break a}j[114626]=0;d=E(683,e+40|0,32543)|0;f=j[114626];j[114626]=0;if((f|0)==1){break l}j[114626]=0;f=K(1619,b|0,e+24|0,d|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break k}qb(d);if(f){break m}j[114626]=0;L(1622,b|0,e+24|0,a|0,g|0);d=j[114626];j[114626]=0;if((d|0)==1){break h}}d=e+24|0;d;yf(d);if(rb(e+24|0,e+32|0)){continue}break}}a=j[b>>2];ag(b);g=a&1073741824?-1:1}Za=e+176|0;return g|0}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(d);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(d);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(g);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(g);break a}a=D()|0;C()|0}ag(b);G(a|0);z()}function A_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-336|0;Za=d;V0(a);e=j[a+28>>2];a:{if(!mf(j[j[e>>2]-12>>2]+e|0)){mg(a,1073741825);break a}Ve(d- -64|0,j[a+28>>2]);e=d- -64|0;f=j[e+12>>2];j[a+8>>2]=j[e+8>>2];j[a+12>>2]=f;y_(zc(d- -64|0,3),j[a+28>>2],d+24|0);if(Yc(d+24|0,6931,3)){mg(a,1073741827);break a}h[d+335|0]=0;dh(j[a+28>>2],d+335|0);uC(d- -64|0);g=b;f=d+24|0;b=d- -64|0;e=k[d+335|0];if(e){Aj(j[a+28>>2],d- -64|0,e);e=k[d+335|0]}else{e=0}b=Rl(f,b,e);e=Ru(g,b);qb(b);if(!e){mg(a,1073741830)}if(k[a+3|0]&64){break a}dh(j[a+28>>2],d+63|0);e=k[d+63|0];b=e&3;i[a+16>>1]=(b|0)==3?4:b;if(Ch(e,6)){mj(a,9,1)}j[d+56>>2]=0;pC(j[a+28>>2],d+56|0);b=j[d+56>>2];h[d+55|0]=0;if(b>>>0>=2){dh(j[a+28>>2],d+63|0);f=k[d+63|0];if(!f){dh(j[a+28>>2],d+55|0);f=k[d+63|0]}Hk(j[a+28>>2],b+(f?-1:-2)|0,-1)}j[d+40>>2]=0;j[d+44>>2]=0;b:{if(!Ch(e,4)){break b}lj(j[a+28>>2],d+40|0);b=j[d+44>>2];f=j[d+40>>2];j[a+56>>2]=f;j[a+60>>2]=b;g=j[c+4>>2];if((g|0)==(b|0)&m[c>>2]>=f>>>0|b>>>0<g>>>0){break b}mg(a,536871424)}if(Ch(e,5)){dh(j[a+28>>2],d+63|0);Hk(j[a+28>>2],k[d+63|0],-1)}c:{if(!Ch(k[d+55|0],0)){break c}dh(j[a+28>>2],d+63|0);b=k[d+63|0];b=b&1?-1:b>>>1|0;i[a+16>>1]=b;if(b){break c}mg(a,536871168)}j[a+4>>2]=0;b=1;if(Ch(k[d+55|0],1)){pC(j[a+28>>2],a+4|0)}mj(a,6,Ch(e,2));mj(a,7,Ch(e,3));mj(a,5,l[a+16>>1]!=0);mj(a,8,Ch(e,7));d:{if(gd(a,5)){break d}if(gd(a,6)){break d}if(gd(a,7)){break d}b=gd(a,8)}mj(a,11,b);gd(a,11);b=k[d+55|0];if(Ch(b,2)){i[d+24>>1]=0;Ou(j[a+28>>2],d+24|0);Hk(j[a+28>>2],p(l[d+24>>1],gd(a,9)?2:1),-1);b=k[d+55|0]}if(Ch(b&255,3)){Hk(j[a+28>>2],5,-1)}lj(j[a+28>>2],d+40|0);c=j[d+44>>2];b=j[d+40>>2];if(!c&b>>>0>=16001|c){mg(a,1073741831);break a}j[a+92>>2]=b;if(!b){mg(a,536871040)}e:{if(!gd(a,11)){break e}lj(j[a+28>>2],d+40|0);b=j[d+44>>2];if((b|0)==2147483647|b>>>0<2147483647){break e}mg(a,1073741829);break a}Ve(d+8|0,j[a+28>>2]);PC(d+24|0,d+8|0,j[a+8>>2],j[a+12>>2]);b=j[d+36>>2];e=j[d+32>>2];if(!(b?0:(b|0)>0?1:(b|0)>=0)){mg(a,1073741832);break a}j[a+88>>2]=e;b=a;f:{if(gd(a,11)){c=j[d+40>>2];break f}c=j[a+88>>2]}j[b+64>>2]=c;if(!gd(a,11)){c=j[a+12>>2];e=j[a+88>>2];f=e+j[a+8>>2]|0;c=f>>>0<e>>>0?c+1|0:c;j[a+72>>2]=f;j[a+76>>2]=c}mj(a,10,1)}Za=d+336|0}function sua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=Za-80|0;Za=e;w=j[a+16>>2];h=wf(e+48|0);j[h+8>>2]=a+112;j[h+16>>2]=j[a+128>>2];y=h,z=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[y+12>>2]=z;b=j[h+16>>2];if(b){y=h,z=vf(a+8|0,b),j[y>>2]=z;j[h+4>>2]=ab}f=j[a+44>>2];j[e+32>>2]=f;o=j[a+48>>2];j[e+36>>2]=o;m=j[a+52>>2];j[e+40>>2]=m;n=j[a+56>>2];j[e+44>>2]=n;q=j[a+40>>2];r=j[a+36>>2];k=j[a+4>>2];g=j[a>>2];j[e+24>>2]=g;j[e+28>>2]=k;b=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=b;a:{if(!d){b=q>>12;l=r>>12;break a}while(1){b=0;f=b;l=g;j[e+72>>2]=g;j[e+76>>2]=b;k=((((k&2147483647)<<1|g>>>31)&2147483646)<<1)+w|0;b:{b=j[h+16>>2];if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|l>>>31;id(j[h+8>>2],(i[(g<<1|2)+k>>1]+i[k+((g&2147483646)<<1)>>1]|0)/8<<16>>16);hd(j[h+8>>2],4);Bb(e+72|0,h);if((b|0)<2){break b}b=b-1|0;l=j[e+72>>2];f=j[e+76>>2];continue}}b=j[h+8>>2];Bb(b,b+8|0);b=j[h+8>>2];g=j[b+4>>2];if(g){f=b;b=(j[e+76>>2]&2147483647)<<1|j[e+72>>2]>>>31;id(f,(i[(b<<1|2)+k>>1]+i[k+((b&2147483646)<<1)>>1]|0)/8<<16>>16);hd(j[h+8>>2],g);b=j[h+8>>2];g=j[b>>2];j[b>>2]=g;j[b+4>>2]=0}d=d-1|0;f=qf(b,j[h+12>>2]);j[e+12>>2]=f;j[e+8>>2]=f;l=0;o=1;while(1){m=j[a+60>>2];n=m;k=(e+32|0)+(l<<3)|0;s=j[k>>2];b=Gb(s,-16777216,16776704);v=j[a+64>>2];g=Gb(j[k+4>>2],-16777216,16776704);t=j[a+68>>2];x=t;t=t>>31;j[k+4>>2]=s;s=j[a+72>>2];u=m>>31;m=f<<8;f=m;f=OMa(n,u,f,f>>31);n=ab;u=(e+8|0)+(l<<2)|0;l=OMa(v,v>>31,b,b>>31);f=l+f|0;b=ab+n|0;b=f>>>0<l>>>0?b+1|0:b;n=f;f=OMa(x,t,g,g>>31);g=n+f|0;b=ab+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;j[u>>2]=(b|0)/256;j[k>>2]=b-(m&s);if(o){l=1;o=0;f=j[e+12>>2];continue}break}b=j[a+32>>2];r=j[a+28>>2]+r|0;l=r>>12;j[c>>2]=j[c>>2]+p(l,j[e+8>>2]);q=b+q|0;b=q>>12;j[c+4>>2]=j[c+4>>2]+p(b,j[e+12>>2]);Bb(e+24|0,e+16|0);if(d){c=c+8|0;g=j[e+24>>2];k=j[e+28>>2];continue}break}g=j[e+24>>2];k=j[e+28>>2];n=j[e+44>>2];m=j[e+40>>2];o=j[e+36>>2];f=j[e+32>>2]}j[a+40>>2]=q;j[a+20>>2]=l;j[a+36>>2]=r;j[a+56>>2]=n;j[a+52>>2]=m;j[a+48>>2]=o;j[a+44>>2]=f;j[a+24>>2]=b;j[a>>2]=g;j[a+4>>2]=k;Za=e+80|0}function Goa(a,b,c,d,e){var f=0,g=0,i=0,m=q(0),o=0,r=0,s=0,t=q(0),u=0,v=0;g=Za-32|0;Za=g;j[g+28>>2]=e;a:{if(!e){break a}f=k[d|0];i=f-250|0;if(!(i>>>0>5|!(1<<i&37))){if(l[a+480188>>1]){f=0;while(1){i=(p(f,896)+a|0)+1075841|0;h[i|0]=127;h[i+1|0]=0;f=f+1|0;if(f>>>0<l[a+480188>>1]){continue}break}}f=k[d|0]}b:{if((f&255)!=240){break b}f=k[d+1|0];if((f&254)!=240){break b}if(e>>>0<4){break a}i=(p(b,896)+a|0)+1074984|0;e=h[d+3|0];r=(e|0)<0;d=k[d+2|0];if(!(r|(f|0)==241|d)){d=p(b,896)+a|0;f=d+1075841|0;o=f;if(c){e=$J(yo(a,q(k[f|0]),q((e&255)>>>0)))}h[o|0]=e;h[d+1075802|0]=0;o=4;c=d+1075072|0;d=Ho(a,i,!(j[c>>2]&32768),256);if((d|0)<0|!(k[c+1|0]&2)){break a}a=a+1304392|0;if(!bd(a)){break a}No(j[a>>2],b,d>>>2&255,1);break a}if(!(r|(f|0)==241|(d|0)!=1)){b=p(b,896)+a|0;d=b+1075842|0;c:{if(!c){break c}m=yo(a,q(k[d|0]),q((e&255)>>>0));if(m<q(4294967296)&m>=q(0)){e=~~m>>>0;break c}e=0}h[d|0]=e;h[b+1075801|0]=0;Ho(a,i,!(j[b+1075072>>2]&32768),256);o=4;break a}r=(f|0)==241;if(!(r|(d|0)!=2)){o=4;if((e&255)>>>0>31){break a}b=p(b,896)+a|0;h[b+1075849|0]=(e&240)>>>4;Ho(a,i,!(j[b+1075072>>2]&32768),256);break a}if(!(r|(d|0)!=3)){o=4;b=Zk(a,b,3,0);if((e|0)<0|(b+5&255)>>>0<6){break a}b=(p(b,160)+a|0)+906284|0;m=q(q(((e^127)&255)>>>0)*q(.007874015718698502));if(!c){n[b>>2]=m;break a}s=b,t=yo(a,n[b>>2],m),n[s>>2]=t;break a}if(d&128?0:(f|0)!=241){break a}o=4;b=Zk(a,b,3,0);if((e|0)<0|(b+5&255)>>>0<6){break a}b=j[(p(b,160)+a|0)+906140>>2];if(!b){break a}d=(f|0)==241?d+128|0:d&127;m=q(q((e&255)>>>0)*q(.007874015718698502));if(!c){bb[j[j[b>>2]+44>>2]](b,d,m);break a}u=b,v=d,t=yo(a,q(bb[j[j[b>>2]+48>>2]](b,d)),m),s=j[j[b>>2]+44>>2],bb[s](u|0,v|0,q(t));break a}d:{e:{if(l[a+480188>>1]>b>>>0){f=b+1|0;break e}f=l[(p(b,896)+a|0)+1075792>>1];if(!f){break d}}if(k[(p(b,896)+a|0)+1075075|0]&4|l[a+480188>>1]<(f&65535)>>>0){break d}b=Zk(a,b,3,0);if(!b|b-251>>>0<5){break d}a=j[(p(b,160)+a|0)+906140>>2];if(!a){break d}b=k[d|0];if((b|0)==240){Qb(g+16|0,lb(d),e);bb[j[j[a>>2]+72>>2]](a,g+16|0)|0;break d}s=g,v=CM(b),j[s+12>>2]=v;b=j[tb(g+12|0,g+28|0)>>2];j[g+12>>2]=0;Vb(g+12|0,d,b);bb[j[j[a>>2]+68>>2]](a,j[g+12>>2])|0}o=j[g+28>>2]}Za=g+32|0;return o}function jw(a){a=a|0;var b=0,c=0,d=q(0),e=0;Ab(a+4960|0,0,76);h[a+5044|0]=0;j[a+5036>>2]=0;j[a+5040>>2]=0;b=j[a+4292>>2];d=n[a+4268>>2];j[114626]=0;e=a+4504|0;if(d<q(4294967296)&d>=q(0)){c=~~d>>>0}else{c=0}V(1909,e|0,67,5,c|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}b=j[a+4296>>2];j[114626]=0;V(1909,a+4528|0,62,5,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[a+4300>>2];j[114626]=0;V(1909,a+4552|0,53,5,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[a+4304>>2];j[114626]=0;V(1909,a+4576|0,43,5,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[a+4308>>2];j[114626]=0;V(1909,a+4600|0,32,5,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[a+4312>>2];j[114626]=0;V(1909,a+4624|0,22,5,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[a+4316>>2];j[114626]=0;V(1909,a+4648|0,75,5,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[a+4320>>2];j[114626]=0;V(1909,a+4672|0,69,5,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[a+4324>>2];j[114626]=0;V(1909,a+4696|0,60,5,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[a+4328>>2];j[114626]=0;V(1909,a+4720|0,48,5,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[a+4332>>2];j[114626]=0;V(1909,a+4744|0,36,5,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[a+4336>>2];j[114626]=0;V(1909,a+4768|0,25,5,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;V(1909,a+4792|0,0,0,0,0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[a+4344>>2];j[114626]=0;V(1909,a+4816|0,3,0,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[a+4348>>2];j[114626]=0;V(1909,a+4840|0,3,0,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;V(1909,a+4864|0,407,1,c|0,0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;V(1909,a+4888|0,400,1,c|0,0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;V(1909,a+4912|0,10,0,c|0,-1);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;V(1909,a+4936|0,10,0,c|0,-1);c=j[114626];j[114626]=0;if((c|0)==1){break a}h[a+5045|0]=1;return}c=J(71396)|0;if((C()|0)==(W(71396)|0)){O(c|0)|0;h[a+5045|0]=0;Q();return}G(c|0);z()}function BG(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var k=0,l=0,m=0;k=Za-80|0;Za=k;a:{b:{c:{d:{e:{f:{l=In(1,28);if(!l){a=R(4)|0;zk(a);j[114626]=0;I(2002,a|0,71396,2001);a=j[114626];j[114626]=0;if((a|0)!=1){break a}break f}j[l+16>>2]=0;j[l+20>>2]=0;j[l+12>>2]=f;j[l+8>>2]=e;j[l+4>>2]=d;j[l>>2]=c?c:1990;d=bs(k- -64|0);g:{h:{if(!i){break h}c=j[i>>2];if(!c){break h}while(1){i:{e=j[i+4>>2];if(e){j[114626]=0;c=E(85,k+48|0,c|0)|0;f=j[114626];j[114626]=0;j:{if((f|0)!=1){j[114626]=0;f=E(2003,d|0,c|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break j}j[114626]=0;E(483,f|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break j}break i}i=J(0)|0;C()|0;break g}i=J(0)|0;C()|0;gb(c);break g}j[114626]=0;c=E(85,k+48|0,c|0)|0;e=j[114626];j[114626]=0;k:{if((e|0)!=1){j[114626]=0;E(2004,d|0,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break k}break i}i=J(0)|0;C()|0;break g}i=J(0)|0;C()|0;gb(c);break g}gb(c);c=j[i+8>>2];i=i+8|0;if(c){continue}break}}c=j[a+8>>2];e=j[a+4>>2];f=j[a>>2];j[114626]=0;a=H(1392,80)|0;i=j[114626];j[114626]=0;l:{m:{n:{if((i|0)!=1){j[114626]=0;j[k+44>>2]=c;j[k+40>>2]=e;j[k+36>>2]=f;j[k+32>>2]=b;I(2005,k+48|0,l|0,l+4|0);b=j[114626];j[114626]=0;if((b|0)==1){break n}b=go(k+24|0,k+48|0);j[114626]=0;c=j[k+44>>2];j[k+16>>2]=j[k+40>>2];j[k+20>>2]=c;c=j[k+36>>2];j[k+8>>2]=j[k+32>>2];j[k+12>>2]=c;P(2006,a|0,k+8|0,b|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break m}j[l+24>>2]=a;Hc(b);Hc(k+48|0);Rj(d);c=l;break d}i=J(0)|0;C()|0;break g}i=J(0)|0;C()|0;break l}i=J(0)|0;C()|0;Hc(b);Hc(k+48|0)}Cb(a)}Rj(d);O(i|0)|0;j[114626]=0;L(1982,34722,l|0,g|0,h|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)==1){break f}a=j[l+24>>2];if(a){Cb(gr(a))}c=0;j[l+24>>2]=0;a=j[l+20>>2];if(a){Cb(a);j[l+20>>2]=0}Cb(l);break d}i=J(0)|0;C()|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)!=1){break e}break b}i=J(0)|0;C()|0}O(i|0)|0;c=0;j[114626]=0;L(1982,34722,0,g|0,h|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Q()}Za=k+80|0;return c|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}a=J(0)|0;C()|0;ib(a)}z()}function DD(a,b,c,d){var e=0,f=0,g=0,i=0,l=0,n=0,o=0;f=Za-48|0;Za=f;a:{if(c>>>0<=2){c=c<<2;i=j[c+57420>>2];o=j[c+57408>>2];while(1){c=j[b+4>>2];b:{if(c>>>0<m[b+104>>2]){j[b+4>>2]=c+1;c=k[c|0];break b}c=Lc(b)}if($l(c)){continue}break}g=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}g=(c|0)==45?-1:1;c=j[b+4>>2];if(c>>>0<m[b+104>>2]){j[b+4>>2]=c+1;c=k[c|0];break c}c=Lc(b)}e:{f:{while(1){if(h[e+57344|0]==(c|32)){g:{if(e>>>0>6){break g}c=j[b+4>>2];if(c>>>0<m[b+104>>2]){j[b+4>>2]=c+1;c=k[c|0];break g}c=Lc(b)}e=e+1|0;if((e|0)!=8){continue}break f}break}if((e|0)!=3){if((e|0)==8){break f}if(!d|e>>>0<4){break e}if((e|0)==8){break f}}c=j[b+104>>2];if(c){j[b+4>>2]=j[b+4>>2]-1}if(!d|e>>>0<4){break f}while(1){if(c){j[b+4>>2]=j[b+4>>2]-1}e=e-1|0;if(e>>>0>3){continue}break}}J2(f,q(q(g|0)*q(B)));g=j[f+8>>2];i=j[f+12>>2];l=j[f>>2];n=j[f+4>>2];break a}h:{i:{j:{if(e){break j}e=0;while(1){if(h[e+57353|0]!=(c|32)){break j}k:{if(e>>>0>1){break k}c=j[b+4>>2];if(c>>>0<m[b+104>>2]){j[b+4>>2]=c+1;c=k[c|0];break k}c=Lc(b)}e=e+1|0;if((e|0)!=3){continue}break}break i}l:{switch(e|0){case 0:m:{if((c|0)!=48){break m}e=j[b+4>>2];n:{if(e>>>0<m[b+104>>2]){j[b+4>>2]=e+1;e=k[e|0];break n}e=Lc(b)}if((e&-33)==88){I2(f+16|0,b,o,i,g,d);g=j[f+24>>2];i=j[f+28>>2];l=j[f+16>>2];n=j[f+20>>2];break a}if(!j[b+104>>2]){break m}j[b+4>>2]=j[b+4>>2]-1}H2(f+32|0,b,c,o,i,g,d);g=j[f+40>>2];i=j[f+44>>2];l=j[f+32>>2];n=j[f+36>>2];break a;case 3:break i;default:break l}}if(j[b+104>>2]){j[b+4>>2]=j[b+4>>2]-1}break h}o:{c=j[b+4>>2];p:{if(c>>>0<m[b+104>>2]){j[b+4>>2]=c+1;c=k[c|0];break p}c=Lc(b)}if((c|0)==40){e=1;break o}g=0;i=2147450880;if(!j[b+104>>2]){break a}j[b+4>>2]=j[b+4>>2]-1;break a}while(1){c=j[b+4>>2];q:{if(c>>>0<m[b+104>>2]){j[b+4>>2]=c+1;c=k[c|0];break q}c=Lc(b)}if(!(c-97>>>0>=26?!(c-48>>>0<10|c-65>>>0<26|(c|0)==95):0)){e=e+1|0;continue}break}g=0;i=2147450880;if((c|0)==41){break a}c=j[b+104>>2];if(c){j[b+4>>2]=j[b+4>>2]-1}if(d){if(!e){break a}while(1){e=e-1|0;if(c){j[b+4>>2]=j[b+4>>2]-1}if(e){continue}break}break a}}j[114600]=28;Hg(b,0,0)}g=0;i=0}j[a>>2]=l;j[a+4>>2]=n;j[a+8>>2]=g;j[a+12>>2]=i;Za=f+48|0}function Am(a,b,c){var d=0,e=0,f=0,g=0,i=0,l=0,n=0,o=0,q=0;f=Za-16|0;Za=f;j[b+88>>2]=j[b+88>>2]|524288;a:{b:{if(!(j[a+480208>>2]&8)){mb(f+8|0,a+1074308|0,15);if(kb(f+8|0)){break b}}if(j[a+480180>>2]!=268435456){break a}}c=c?c:k[b+831|0];h[b+832|0]=c;h[b+831|0]=c}c:{if(Wi(b)){e=j[a+1074392>>2];l=j[b+880>>2];d:{if(c){j[b+776>>2]=c;break d}c=j[b+776>>2];if(!c){break c}}d=j[b+708>>2];e:{f:{if((d|0)>=1){if((c|0)<0){break f}break e}if(!d|(c|0)<1){break e}}c=0-c|0;j[b+776>>2]=c}g=b;i=(+(e>>>0)+1)*+(c|0)/+m[a+1074416>>2];g:{if(r(i)<2147483648){c=~~i;break g}c=-2147483648}j[g+880>>2]=c;if(k[b+90|0]&16){c=p(j[j[j[b+656>>2]+44>>2]+36>>2]+1|0,c);j[b+880>>2]=c}a=c-(e?l:0)|0;c=a>>31;e=d>>31;if((e+d^e)<=(c^a+c)){if(!d){break c}j[b+708>>2]=0;j[b+876>>2]=d+j[b+876>>2];h[b+872|0]=k[b+872|0]|8;break c}j[b+708>>2]=d-a;j[b+876>>2]=a+j[b+876>>2];h[b+872|0]=k[b+872|0]|8;break c}d=1;h:{if(!(h[b+872|0]&1)|j[a+480180>>2]&524352){break h}if(j[a+1074416>>2]==1){mb(f+8|0,a+1074308|0,6);if(kb(f+8|0)){break h}}d=0;if(j[a+480180>>2]!=8){break h}d=(k[a+480208|0]&2)>>>1|0}if(!(j[a+480180>>2]!=268435456|c>>>0<240)){d=h[b+872|0]&1;c=c-240|0}if(c){j[b+776>>2]=(j[a+480180>>2]==64?p(c,10):c)<<2}e=j[b+708>>2];c=j[b+700>>2];i:{if(!c){c=0;break i}if(!e|d^1){break i}g=b;j:{if((c|0)<(e|0)){d=j[b+776>>2];k:{if(!(k[a+480208|0]&16)){break k}if(j[a+480180>>2]==4){c=j[b+700>>2];break k}c=j[b+776>>2]/4|0;c=j[((c>>>0<255?c:255)<<2)+25312>>2];d=c;e=c>>31;c=j[b+700>>2];d=OMa(d,e,c,c>>31)+32768|0;c=ab;d=ic(PMa(d,d>>>0<32768?c+1|0:c,65536,0),ab);c=j[b+700>>2];d=d-c|0;d=(d|0)>1?d:1}e=j[b+708>>2];c=c+d|0;c=(c|0)>(e|0)?e:c;break j}if((c|0)<=(e|0)){break i}d=0-j[b+776>>2]|0;l:{if(!(k[a+480208|0]&16)){break l}if(j[a+480180>>2]==4){c=j[b+700>>2];break l}c=j[b+776>>2]/4|0;c=j[((c>>>0<255?c:255)<<2)+26336>>2];d=c;e=c>>31;c=j[b+700>>2];d=OMa(d,e,c,c>>31)+32768|0;c=ab;d=ic(PMa(d,d>>>0<32768?c+1|0:c,65536,0),ab);c=j[b+700>>2];d=d-c|0;d=(d|0)<-1?d:-1}e=j[b+708>>2];c=c+d|0;c=(c|0)<(e|0)?e:c}j[g+700>>2]=c}if((c|0)!=(e|0)){break c}mb(f+8|0,a+1074308|0,25);if(n=!kb(f+8|0),o=0,q=j[a+480180>>2]!=1,q?n:o){break c}j[b+708>>2]=0}Za=f+16|0}function Zua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=Za-48|0;Za=g;a:{b:{c:{k=j[a+8>>2];f=j[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?k>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?k>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?k>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?k>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}w=b;x=j[a+16>>2];h=j[a+44>>2];j[g+32>>2]=h;o=j[a+48>>2];j[g+36>>2]=o;m=j[a+52>>2];j[g+40>>2]=m;n=j[a+56>>2];j[g+44>>2]=n;r=j[a+40>>2];s=j[a+36>>2];e=j[a+4>>2];l=j[a>>2];j[g+24>>2]=l;j[g+28>>2]=e;j[g+16>>2]=k;j[g+20>>2]=f;e:{if(!d){b=r>>12;f=s>>12;break e}while(1){o=1;b=((((e&2147483647)<<1|l>>>31)&2147483646)<<1)+x|0;e=(l>>>16&65520)+w|0;l=i[e+14>>1];k=i[e+12>>1];n=i[e+10>>1];t=i[e+8>>1];y=i[e+6>>1];q=i[e+4>>1];u=i[e+2>>1];v=i[e>>1];h=0;m=1;f=0;while(1){e=f<<1;j[(g+8|0)+(f<<2)>>2]=(((((((p(i[b+(e|-8)>>1],u)+p(i[b+(e|-12)>>1],v)|0)+p(i[b+(e|-4)>>1],q)|0)+p(i[b+e>>1],y)|0)+p(i[b+(e|4)>>1],t)|0)+p(i[b+(e|8)>>1],n)|0)+p(k,i[b+(e|12)>>1])|0)+p(l,i[b+(e|16)>>1])|0)/32768;e=m&1;m=0;f=1;if(e){continue}break}while(1){m=(g+8|0)+(h<<2)|0;l=j[m>>2];k=j[a+60>>2];e=(g+32|0)+(h<<3)|0;h=j[e>>2];b=Gb(h,-16777216,16776704);t=j[a+64>>2];f=Gb(j[e+4>>2],-16777216,16776704);q=j[a+68>>2];u=q;q=q>>31;j[e+4>>2]=h;v=j[a+72>>2];l=l<<8;h=l;h=OMa(k,k>>31,h,h>>31);k=ab;n=m;m=OMa(t,t>>31,b,b>>31);h=m+h|0;b=ab+k|0;b=h>>>0<m>>>0?b+1|0:b;k=h;h=OMa(u,q,f,f>>31);f=k+h|0;b=ab+b|0;b=f>>>0<h>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;j[n>>2]=(b|0)/256;j[e>>2]=b-(l&v);h=1;b=o&1;o=0;if(b){continue}break}b=j[a+32>>2];s=j[a+28>>2]+s|0;f=s>>12;j[c>>2]=j[c>>2]+p(f,j[g+8>>2]);r=b+r|0;b=r>>12;j[c+4>>2]=j[c+4>>2]+p(b,j[g+12>>2]);Bb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;l=j[g+24>>2];e=j[g+28>>2];continue}break}l=j[g+24>>2];e=j[g+28>>2];n=j[g+44>>2];m=j[g+40>>2];o=j[g+36>>2];h=j[g+32>>2]}j[a+40>>2]=r;j[a+20>>2]=f;j[a+36>>2]=s;j[a+56>>2]=n;j[a+52>>2]=m;j[a+48>>2]=o;j[a+44>>2]=h;j[a+24>>2]=b;j[a>>2]=l;j[a+4>>2]=e;Za=g+48|0}function tua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=Za-80|0;Za=e;w=j[a+16>>2];i=wf(e+48|0);j[i+8>>2]=a+112;j[i+16>>2]=j[a+128>>2];y=i,z=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[y+12>>2]=z;b=j[i+16>>2];if(b){y=i,z=vf(a+8|0,b),j[y>>2]=z;j[i+4>>2]=ab}f=j[a+44>>2];j[e+32>>2]=f;o=j[a+48>>2];j[e+36>>2]=o;m=j[a+52>>2];j[e+40>>2]=m;n=j[a+56>>2];j[e+44>>2]=n;q=j[a+40>>2];r=j[a+36>>2];k=j[a+4>>2];g=j[a>>2];j[e+24>>2]=g;j[e+28>>2]=k;b=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=b;a:{if(!d){b=q>>12;l=r>>12;break a}while(1){b=0;f=b;l=g;j[e+72>>2]=g;j[e+76>>2]=b;k=(((k&2147483647)<<1|g>>>31)&-2)+w|0;b:{b=j[i+16>>2];if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|l>>>31;id(j[i+8>>2],h[(g|1)+k|0]+h[k+(g&-2)|0]<<5);hd(j[i+8>>2],4);Bb(e+72|0,i);if((b|0)<2){break b}b=b-1|0;l=j[e+72>>2];f=j[e+76>>2];continue}}b=j[i+8>>2];Bb(b,b+8|0);b=j[i+8>>2];g=j[b+4>>2];if(g){f=b;b=(j[e+76>>2]&2147483647)<<1|j[e+72>>2]>>>31;id(f,h[(b|1)+k|0]+h[k+(b&-2)|0]<<5);hd(j[i+8>>2],g);b=j[i+8>>2];g=j[b>>2];j[b>>2]=g;j[b+4>>2]=0}d=d-1|0;f=qf(b,j[i+12>>2]);j[e+12>>2]=f;j[e+8>>2]=f;l=0;o=1;while(1){m=j[a+60>>2];n=m;k=(e+32|0)+(l<<3)|0;s=j[k>>2];b=Gb(s,-16777216,16776704);v=j[a+64>>2];g=Gb(j[k+4>>2],-16777216,16776704);t=j[a+68>>2];x=t;t=t>>31;j[k+4>>2]=s;s=j[a+72>>2];u=m>>31;m=f<<8;f=m;f=OMa(n,u,f,f>>31);n=ab;u=(e+8|0)+(l<<2)|0;l=OMa(v,v>>31,b,b>>31);f=l+f|0;b=ab+n|0;b=f>>>0<l>>>0?b+1|0:b;n=f;f=OMa(x,t,g,g>>31);g=n+f|0;b=ab+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;j[u>>2]=(b|0)/256;j[k>>2]=b-(m&s);if(o){l=1;o=0;f=j[e+12>>2];continue}break}b=j[a+32>>2];r=j[a+28>>2]+r|0;l=r>>12;j[c>>2]=j[c>>2]+p(l,j[e+8>>2]);q=b+q|0;b=q>>12;j[c+4>>2]=j[c+4>>2]+p(b,j[e+12>>2]);Bb(e+24|0,e+16|0);if(d){c=c+8|0;g=j[e+24>>2];k=j[e+28>>2];continue}break}g=j[e+24>>2];k=j[e+28>>2];n=j[e+44>>2];m=j[e+40>>2];o=j[e+36>>2];f=j[e+32>>2]}j[a+40>>2]=q;j[a+20>>2]=l;j[a+36>>2]=r;j[a+56>>2]=n;j[a+52>>2]=m;j[a+48>>2]=o;j[a+44>>2]=f;j[a+24>>2]=b;j[a>>2]=g;j[a+4>>2]=k;Za=e+80|0}function eJ(a,b,c,d){var e=0,f=0,g=0,i=0,l=0,m=0,o=0;i=Za-16|0;Za=i;e=p(b,896)+a|0;a:{if(k[e+1075074|0]&2){m=1;b:{if(!(k[a+480209|0]&16)){break b}m=0;if(!(j[a+480180>>2]&16777248)){break b}m=!(k[a+480208|0]&4)}if(j[a+480180>>2]==64){a=p(b,896)+a|0;b=a+1075823|0;d=k[b|0];if(d&1){j[c>>2]=j[c>>2]+p(k[a+1075828|0],167)}h[b|0]=d+1;break a}g=e+1074984|0;c:{if(!m){break c}mb(i+8|0,a+1074308|0,21);if(!kb(i+8|0)){break c}e=p(b,896)+a|0;f=e+1075823|0;h[f|0]=k[f|0]+(k[e+1075827|0]<<2)}f=p(b,896)+a|0;l=f+1075826|0;o=f+1075823|0;e=Zw(a,k[l|0],k[o|0]);d:{if(Wi(g)){n[d>>2]=q(q(p(k[f+1075828|0],e)|0)*q(6510417279059766e-21))+n[d>>2];c=f+1075856|0;d=k[c|0];h[c|0]=d&243|8;if(j[a+1074416>>2]!=(j[a+1074392>>2]+1|0)){break d}h[c|0]=d|12;break d}if((j[a+480208>>2]&2101248)==2101248|(k[a+480209|0]&16?j[a+480180>>2]&67633152:0)){break a}e=j[a+480180>>2]&5?(k[l|0]&3)==1?0-e|0:e:e;g=a+1074308|0;mb(i+8|0,g,21);d=kb(i+8|0);f=j[a+480208>>2];e:{if(d){d=f&4;e=d?e:0-e|0;d=d?5:6;break e}d=5;f:{if(f&131072){break f}d=8;if(j[a+480180>>2]==1024){break f}d=7;if(j[a+480180>>2]&524304|(k[a+480208|0]&4?0:j[a+480180>>2]&16777248)){break f}d=6}mb(i+8|0,g,80);if(!kb(i+8|0)){break e}d=k[(p(b,896)+a|0)+1075797|0]==26?d+2|0:d}d=(p(k[(p(b,896)+a|0)+1075828|0],e)|0)/(1<<d)|0;f=0-d|0;g:{if(!(k[a+480208|0]&16)|j[a+480180>>2]==4){break g}e=j[c>>2];if((d|0)<=-1){d=qx(a,f>>>2|0);d=ic(PMa(OMa(d,d>>31,e,e>>31),ab,65536,0),ab);e=j[c>>2];d=d-e|0;g=f&3;if(!g){break g}l=d;d=cK(a,g);d=(l+ic(PMa(OMa(d,d>>31,e,e>>31),ab,65536,0),ab)|0)-j[c>>2]|0;break g}g=d&3;d=px(a,d>>>2|0);d=ic(PMa(OMa(d,d>>31,e,e>>31),ab,65536,0),ab);e=j[c>>2];d=d-e|0;if(!g){break g}l=d;d=bK(a,g);d=(l+ic(PMa(OMa(d,d>>31,e,e>>31),ab,65536,0),ab)|0)-j[c>>2]|0}j[c>>2]=j[c>>2]+d;c=rx(a,b);if(!c){break d}d=c;e=f<<16>>16;g=j[(p(b,896)+a|0)+1075640>>2];l=2;h:{if(!g){break h}l=k[g+33|0]}bb[j[j[c>>2]+84>>2]](d,e,l<<24>>24,b)}if(!m){break a}mb(i+8|0,a+1074308|0,21);if(kb(i+8|0)){break a}h[o|0]=k[o|0]+k[(p(b,896)+a|0)+1075827|0];break a}if(!(k[e+1075654|0]&2)){break a}a=rx(a,b);if(!a){break a}bb[j[j[a>>2]+84>>2]](a,0,0,b)}Za=i+16|0}function Uk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,i=0,n=0,o=0,q=0,r=0;i=Za-16|0;Za=i;a:{b:{if(ad(a)|m[a+12>>2]<=m[b+4>>2]){break b}c=l[b+8>>1]>=Jj(a)>>>0;g=l[b+8>>1];if((g|0)!=65535?c:0){break b}f=g;if((f&65535)==65535){g=Jj(a)-1|0;f=0}d=Se(a,j[b+4>>2],f&65535);c:{n=k[b+12|0];d:{if(n&2){break d}q=g&65535;if(q>>>0<(f&65535)>>>0){break d}r=n&4;o=k[b+10|0];e=f;c=d;while(1){e:{if(!r){if((o|0)!=k[c+3|0]){break e}break c}if((o|0)==k[c+2|0]){break c}}c=c+6|0;e=e+1|0;if(q>>>0>=(e&65535)>>>0){continue}break}}o=g&65535;if(o>>>0>=(f&65535)>>>0){q=n&4;e=f;c=d;while(1){f:{if(!q){if(k[c+3|0]){break f}h[c+3|0]=k[b+10|0];h[c+5|0]=k[b+11|0];break c}if(k[c+2|0]){break f}h[c+2|0]=k[b+10|0];h[c+4|0]=k[b+11|0];break c}c=c+6|0;e=e+1|0;if(o>>>0>=(e&65535)>>>0){continue}break}}g:{if(!(n&1)){break g}n=j[vm(a)+480180>>2]&2;e=k[b+12|0];h:{if(e&4){break h}g=g&65535;if(g>>>0<(f&65535)>>>0){break h}while(1){i:{j:{switch(k[d+3|0]-9|0){case 4:if(!BI(j[vm(a)+8>>2],1)){break i}c=1;h[d+2|0]=1;h[d+4|0]=k[d+5|0];h[d+3|0]=k[b+10|0];h[d+5|0]=k[b+11|0];break a;case 0:break j;default:break i}}c=d;k:{if(n){e=k[d+5|0];if(e>>>0>128){break i}h[d+2|0]=2;h[d+3|0]=k[b+10|0];a=1;break k}h[d+2|0]=2;h[d+3|0]=k[b+10|0];e=k[d+5|0];a=2}h[c+4|0]=a+e>>>a;h[d+5|0]=k[b+11|0];break c}d=d+6|0;f=f+1|0;if(g>>>0>=(f&65535)>>>0){continue}break}e=k[b+12|0]}l:{if(e&4){c=k[b+11|0];d=13;m:{switch(k[b+10|0]-1|0){case 1:c=Vm(p(n?2:4,c));e=k[b+12|0];d=9;break;case 0:break m;default:break l}}h[b+11|0]=c;h[b+10|0]=d;e=e&254;h[b+12|0]=e;break l}f=k[b+11|0];h[i+14|0]=f;d=b;c=k[b+10|0];n:{o:{if(!(!n|(c|0)!=9)){if(f>>>0>128){break n}c=2;f=(f&254)>>>1|0;break o}h[i+15|0]=c;if(!Kw(i+15|0,i+14|0,1)){break n}c=k[i+15|0];if(!c){break n}e=k[b+12|0];f=k[i+14|0]}h[d+11|0]=f;h[b+10|0]=c;h[b+12|0]=e&254}e=k[b+12|0]}c=1;if(e&1){break g}h[b+12|0]=e^4;if(Uk(a,b)){break a}}d=j[b>>2];p:{if((d|0)==1){if(m[a+12>>2]>j[b+4>>2]+1>>>0){j[b+4>>2]=j[b+4>>2]+1;break p}d=j[b>>2]}if((d|0)!=2){break b}c=0;d=j[b+4>>2];if(!d){break a}j[b+4>>2]=d-1}h[b+12|0]=k[b+12|0]|1;c=Uk(a,b);break a}c=1;break a}c=0}Za=i+16|0;return c|0}function Nu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,k=0,n=0,o=0,p=0;c=Za-96|0;Za=c;h=a;k=a;a:{b:{c:{d:{e:{if(!(n=0,o=!gd(a,11),p=j[a+4>>2],p?n:o)){g=j[a+28>>2];e=j[a+12>>2];d=j[a+64>>2];f=d+j[a+8>>2]|0;f=sg(c+80|0,f,d>>>0>f>>>0?e+1|0:e);d=j[f+12>>2];j[c+32>>2]=j[f+8>>2];j[c+36>>2]=d;b=j[f+4>>2];j[c+24>>2]=j[f>>2];j[c+28>>2]=b;Gi(g,c+24|0);b=j[a+28>>2];if(ut(j[j[b>>2]-12>>2]+b|0)){mg(a,1073741826);break a}f=a+44|0;hZ(f,j[a+92>>2]);d=a+32|0;fD(d,j[a+92>>2]<<2);if(j[a+92>>2]){e=0;while(1){b=j[a+28>>2];if(ut(j[j[b>>2]-12>>2]+b|0)){mg(a,1073741828);break a}b=l[a+16>>1];i[c+78>>1]=b;if((b|0)==65535){Ou(j[a+28>>2],c+78|0)}n=c,o=tc(d),j[n+72>>2]=o;f:{if(!l[c+78>>1]){g=0;break f}g=l[c+78>>1];b=j[c+72>>2];if(g>>>0>-1-b>>>0){break f}Ln(d,b+g|0);Aj(j[a+28>>2],fc(d,j[c+72>>2]),l[c+78>>1]);g=l[c+78>>1]}n=_b(f,e),o=g,i[n+12>>1]=o;b=j[c+72>>2];n=_b(f,e),o=b,j[n>>2]=o;if(gd(a,6)){lj(j[a+28>>2],c+56|0);if(m[c+60>>2]>2147483647){break e}b=j[c+56>>2];n=_b(f,e),o=b,j[n+4>>2]=o}b=j[a+4>>2];g:{if(b){n=_b(f,e),o=b,j[n+8>>2]=o;break g}if(!gd(a,7)){break g}lj(j[a+28>>2],c+56|0);if(m[c+60>>2]>2147483647){break d}b=j[c+56>>2];n=_b(f,e),o=b,j[n+8>>2]=o}h:{if(j[_b(f,e)+8>>2]==-1){break h}if(gd(a,6)){break h}if(e){b=e-1|0;b=j[_b(f,b)+4>>2]+j[_b(f,b)+8>>2]|0}else{b=0}n=_b(f,e),o=b,j[n+4>>2]=o}if(gd(a,8)){i[c+56>>1]=0;Ou(j[a+28>>2],c+56|0);b=gd(a,9);Hk(j[a+28>>2],l[c+56>>1]<<b,-1)}e=e+1|0;if(e>>>0<m[a+92>>2]){continue}break}}Ve(c+56|0,j[a+28>>2]);b=j[c+68>>2];j[a+72>>2]=j[c+64>>2];j[a+76>>2]=b}mj(a,4,1);b=j[a+88>>2];if((b|0)!=j[a+64>>2]){break c}d=j[a+76>>2];b=j[a+72>>2];break b}mg(a,1073741829);break a}mg(a,1073741829);break a}d=j[a+12>>2];g=b+j[a+8>>2]|0;d=g>>>0<b>>>0?d+1|0:d;b=g}j[k+80>>2]=b;j[h+84>>2]=d;h=j[a+28>>2];d=sg(c+40|0,b,d);b=j[d+12>>2];j[c+16>>2]=j[d+8>>2];j[c+20>>2]=b;b=j[d+4>>2];j[c+8>>2]=j[d>>2];j[c+12>>2]=b;Gi(h,c+8|0);if(gd(a,6)){break a}if((n=0,o=!gd(a,7),p=j[a+4>>2],p?n:o)|!j[a+92>>2]){break a}h=j[a+80>>2];b=j[a+8>>2];d=h-b|0;h=a+44|0;e=0;while(1){b=_b(h,e);j[b+4>>2]=d+j[b+4>>2];e=e+1|0;if(e>>>0<m[a+92>>2]){continue}break}}Za=c+96|0}function _ua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=Za-48|0;Za=e;a:{b:{c:{l=j[a+8>>2];f=j[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?l>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?l>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?l>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?l>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}x=b;y=j[a+16>>2];g=j[a+44>>2];j[e+32>>2]=g;q=j[a+48>>2];j[e+36>>2]=q;n=j[a+52>>2];j[e+40>>2]=n;o=j[a+56>>2];j[e+44>>2]=o;s=j[a+40>>2];t=j[a+36>>2];k=j[a+4>>2];m=j[a>>2];j[e+24>>2]=m;j[e+28>>2]=k;j[e+16>>2]=l;j[e+20>>2]=f;e:{if(!d){b=s>>12;f=t>>12;break e}while(1){k=(((k&2147483647)<<1|m>>>31)&-2)+y|0;b=(m>>>16&65520)+x|0;f=i[b+14>>1];m=i[b+12>>1];l=i[b+10>>1];o=i[b+8>>1];u=i[b+6>>1];z=i[b+4>>1];r=i[b+2>>1];v=i[b>>1];g=0;q=1;n=1;b=0;while(1){j[(e+8|0)+(b<<2)>>2]=(((((((p(h[k+(b|-4)|0],r)+p(h[k+(b|-6)|0],v)|0)+p(h[k+(b|-2)|0],z)|0)+p(h[b+k|0],u)|0)+p(h[k+(b|2)|0],o)|0)+p(h[k+(b|4)|0],l)|0)+p(m,h[k+(b|6)|0])|0)+p(f,h[k+(b|8)|0])<<8)/32768;w=n&1;n=0;b=1;if(w){continue}break}while(1){n=(e+8|0)+(g<<2)|0;m=j[n>>2];l=j[a+60>>2];k=(e+32|0)+(g<<3)|0;g=j[k>>2];b=Gb(g,-16777216,16776704);u=j[a+64>>2];f=Gb(j[k+4>>2],-16777216,16776704);r=j[a+68>>2];v=r;r=r>>31;j[k+4>>2]=g;w=j[a+72>>2];m=m<<8;g=m;g=OMa(l,l>>31,g,g>>31);l=ab;o=n;n=OMa(u,u>>31,b,b>>31);g=n+g|0;b=ab+l|0;b=g>>>0<n>>>0?b+1|0:b;l=g;g=OMa(v,r,f,f>>31);f=l+g|0;b=ab+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;j[o>>2]=(b|0)/256;j[k>>2]=b-(m&w);g=1;b=q&1;q=0;if(b){continue}break}b=j[a+32>>2];t=j[a+28>>2]+t|0;f=t>>12;j[c>>2]=j[c>>2]+p(f,j[e+8>>2]);s=b+s|0;b=s>>12;j[c+4>>2]=j[c+4>>2]+p(b,j[e+12>>2]);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;m=j[e+24>>2];k=j[e+28>>2];continue}break}m=j[e+24>>2];k=j[e+28>>2];o=j[e+44>>2];n=j[e+40>>2];q=j[e+36>>2];g=j[e+32>>2]}j[a+40>>2]=s;j[a+20>>2]=f;j[a+36>>2]=t;j[a+56>>2]=o;j[a+52>>2]=n;j[a+48>>2]=q;j[a+44>>2]=g;j[a+24>>2]=b;j[a>>2]=m;j[a+4>>2]=k;Za=e+48|0}function fca(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var k=0,l=0,m=0;l=Za-48|0;Za=l;a:{b:{c:{k=In(1,32);d:{e:{if(!k){a=R(4)|0;zk(a);j[114626]=0;I(2002,a|0,71396,2001);a=j[114626];j[114626]=0;if((a|0)!=1){break a}i=J(0)|0;C()|0;break e}j[k+16>>2]=0;j[k+20>>2]=0;j[k+12>>2]=f;j[k+8>>2]=e;j[k+4>>2]=d;j[k+24>>2]=0;j[k+28>>2]=0;j[k>>2]=c?c:1990;d=bs(l+32|0);f:{g:{if(!i){break g}c=j[i>>2];if(!c){break g}while(1){h:{e=j[i+4>>2];if(e){j[114626]=0;c=E(85,l+16|0,c|0)|0;f=j[114626];j[114626]=0;i:{if((f|0)!=1){j[114626]=0;f=E(2003,d|0,c|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break i}j[114626]=0;E(483,f|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break i}break h}i=J(0)|0;C()|0;break f}i=J(0)|0;C()|0;gb(c);break f}j[114626]=0;c=E(85,l+16|0,c|0)|0;e=j[114626];j[114626]=0;j:{if((e|0)!=1){j[114626]=0;E(2004,d|0,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break j}break h}i=J(0)|0;C()|0;break f}i=J(0)|0;C()|0;gb(c);break f}gb(c);c=j[i+8>>2];i=i+8|0;if(c){continue}break}}j[114626]=0;c=H(1392,96)|0;e=j[114626];j[114626]=0;k:{l:{m:{if((e|0)!=1){j[114626]=0;I(2005,l+16|0,k|0,k+4|0);e=j[114626];j[114626]=0;if((e|0)==1){break m}e=go(l+8|0,l+16|0);j[114626]=0;U(2080,c|0,a|0,b|0,e|0,d|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break l}j[k+28>>2]=c;Hc(e);Hc(l+16|0);a=j[k+28>>2];j[k+24>>2]=a?a+8|0:0;Rj(d);break d}i=J(0)|0;C()|0;break f}i=J(0)|0;C()|0;break k}i=J(0)|0;C()|0;Hc(e);Hc(l+16|0)}Cb(c)}Rj(d);O(i|0)|0;j[114626]=0;L(1982,37255,k|0,g|0,h|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)!=1){a=j[k+28>>2];if(a){bb[j[j[a>>2]+4>>2]](a)}j[k+24>>2]=0;j[k+28>>2]=0;a=j[k+20>>2];if(a){Cb(a);j[k+20>>2]=0}Cb(k);k=0;break d}i=J(0)|0;C()|0;break e}i=J(0)|0;C()|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)==1){break b}}O(i|0)|0;k=0;j[114626]=0;L(1982,37255,0,g|0,h|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Q()}Za=l+48|0;return k|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}a=J(0)|0;C()|0;ib(a)}z()}function Wwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,k=0,n=0,o=0;d=Za+ -64|0;Za=d;i[d+62>>1]=c;Sf(d+62|0,32);f=mn(a);j[114626]=0;F(794,f|0,l[d+62>>1]);a=j[114626];j[114626]=0;a:{if((a|0)!=1){b:{c:{if(!l[d+62>>1]){break c}while(1){a=l[b+480190>>1]+1|0;i[d+60>>1]=a;d:{e:{if((a&65535)>>>0<4e3){break e}i[d+24>>1]=1;f:{if(!l[b+480190>>1]){break f}while(1){g:{if(ke(Yo(b,l[d+24>>1]))){break g}n=d,o=yy(Lb(f),Mb(f),d+24|0),j[n+48>>2]=o;n=d,o=Mb(f),j[n+40>>2]=o;if(!al(d+48|0,d+40|0)){break g}i[d+60>>1]=l[d+24>>1];a=1;if(!l[b+480192>>1]){break f}while(1){c=j[(((a&65535)<<2)+b|0)+900380>>2];h:{if(!c){break h}c=c+236|0;e=rs(c);if((c|0)==(e|0)){break h}while(1){if(l[c>>1]==l[d+60>>1]){i[c>>1]=0}c=c+2|0;if((e|0)!=(c|0)){continue}break}}a=a+1|0;if(l[b+480192>>1]>=(a&65535)>>>0){continue}break}break f}a=l[d+24>>1]+1|0;i[d+24>>1]=a;if(l[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(l[d+60>>1]<4e3){break e}a=Bs(d+48|0);j[114626]=0;c=E(1045,b|0,a|0)|0;e=j[114626];j[114626]=0;i:{j:{if((e|0)==1){break j}k:{if(c){j[114626]=0;E(1046,b|0,a|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break j}e=1;if(!l[b+480192>>1]){break k}while(1){c=j[(((e&65535)<<2)+b|0)+900380>>2];l:{if(!c){break l}c=c+236|0;g=rs(c);if((c|0)==(g|0)){break l}while(1){m:{if(m[a+4>>2]<=l[c>>1]){break m}Nd(d+40|0,a,l[c>>1]);if(kb(d+40|0)){break m}i[c>>1]=0}c=c+2|0;if((g|0)!=(c|0)){continue}break}}e=e+1|0;if(l[b+480192>>1]>=(e&65535)>>>0){continue}break}break k}Vd(a);break c}Xi(d+24|0,a);j[114626]=0;I(1047,d+32|0,d+24|0,1);c=j[114626];j[114626]=0;if((c|0)!=1){Wj(d+16|0,a);j[114626]=0;h[d+15|0]=0;L(1048,d+40|0,d+32|0,d+16|0,d+15|0);c=j[114626];j[114626]=0;if((c|0)!=1){break i}}}c=D()|0;C()|0;Vd(a);break a}Xi(d,a);n=d,o=ei(d+40|0,d),i[n+60>>1]=o;Vd(a);if(l[d+60>>1]>=4e3){break d}}j[114626]=0;F(461,f|0,d+60|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}if(l[b+480190>>1]>=l[d+60>>1]){break d}i[b+480190>>1]=l[d+60>>1]}k=k+1|0;if(l[d+62>>1]>(k&65535)>>>0){continue}break}}Za=d- -64|0;return}c=D()|0;C()|0;break a}c=D()|0;C()|0}ff(f);G(c|0);z()}function x$(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=Za-1072|0;Za=a;j[a+16>>2]=f;j[a+20>>2]=g;j[a+24>>2]=h;j[a+28>>2]=i;j[a+956>>2]=a+960;l=cv(a+960|0,100,62447,a+16|0);j[a+48>>2]=2412;p=yd(a+536|0,0,a+48|0);j[a+48>>2]=2412;o=yd(a+528|0,0,a+48|0);n=a+544|0;a:{b:{c:{if(l>>>0>=100){j[114626]=0;l=T(2437)|0;n=j[114626];j[114626]=0;if((n|0)==1){break b}j[a>>2]=f;j[a+4>>2]=g;j[114626]=0;j[a+8>>2]=h;j[a+12>>2]=i;l=P(2459,a+956|0,l|0,62447,a|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}f=j[a+956>>2];if(!f){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)!=1){break c}break b}fe(p,f);fe(o,_c(l<<2));if(Ti(o)){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)==1){break b}break c}n=j[o>>2]}j[114626]=0;hc(a+520|0,d);f=j[114626];j[114626]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){j[114626]=0;r=H(2441,a+520|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break j}j[114626]=0;f=j[a+956>>2];P(2455,r|0,f|0,f+l|0,n|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break j}q=l?k[j[a+956>>2]]==45:q;h=Db(a+488|0);g=Me(a+472|0);f=Me(a+456|0);j[114626]=0;ba(2495,c|0,q|0,a+520|0,a+512|0,a+508|0,a+504|0,h|0,g|0,f|0,a+452|0);c=j[114626];j[114626]=0;if((c|0)==1){break i}j[a+36>>2]=2412;i=yd(a+40|0,0,a+36|0);c=j[a+452>>2];k:{if((c|0)<(l|0)){m=nb(f)+(l-c<<1|1)|0;break k}m=nb(f)+2|0}c=a+48|0;m=(nb(g)+m|0)+j[a+452>>2]|0;if(m>>>0<101){break h}fe(i,_c(m<<2));c=j[i>>2];if(c){break h}j[114626]=0;M(2413);b=j[114626];j[114626]=0;if((b|0)!=1){break c}break g}l=D()|0;C()|0;break a}l=D()|0;C()|0;break e}l=D()|0;C()|0;break f}m=j[d+4>>2];j[114626]=0;ga(2496,c|0,a+36|0,a+32|0,m|0,n|0,(l<<2)+n|0,r|0,q|0,a+512|0,j[a+508>>2],j[a+504>>2],h|0,g|0,f|0,j[a+452>>2]);l=j[114626];j[114626]=0;if((l|0)!=1){j[114626]=0;b=_(2471,b|0,c|0,j[a+36>>2],j[a+32>>2],d|0,e|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break d}}}l=D()|0;C()|0;mc(i)}pc(f);pc(g);gb(h)}wb(a+520|0);break a}mc(i);pc(f);pc(g);gb(h);wb(a+520|0);mc(o);mc(p);Za=a+1072|0;return b|0}z()}l=D()|0;C()|0}mc(o);mc(p);G(l|0);z()}function msa(a,b){var c=0,d=0,e=0,f=0,g=0,l=0,m=0;c=Za-368|0;Za=c;wL(c+80|0);l=Vb(b,c+80|0,282);b=0;if(vh(a,20108)){cg(a,4);f=Ie(c- -64|0,a);j[114626]=0;e=E(1196,f|0,l|0)|0;d=j[114626];j[114626]=0;a:{b:{c:{d:{if((d|0)==1){break d}if(!e){break a}e=l+26|0;d=k[e|0];j[114626]=0;d=E(258,f|0,d|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break d}if(!d){break a}if(!k[e|0]){d=0;break c}d=0;while(1){e:{j[114626]=0;g=H(375,f|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break e}h[(b+l|0)+27|0]=g;d=d+g|0;b=b+1|0;if(b>>>0<k[e|0]){continue}break c}break}b=D()|0;C()|0;break b}b=D()|0;C()|0;break b}b=0;j[114626]=0;g=d&65535;d=E(258,f|0,g|0)|0;m=j[114626];j[114626]=0;f:{if((m|0)==1){break f}if(!d){break a}j[114626]=0;E(338,f|0,g|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}cg(f,xL(l));j[114626]=0;d=H(1197,c+56|0)|0;b=j[114626];j[114626]=0;g:{if((b|0)!=1){vL(c+80|0);j[114626]=0;E(1198,f|0,c+80|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;i[c+102>>1]=0;i[c+104>>1]=0;K(1199,d|0,c+80|0,c+107|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}b=k[e|0];j[114626]=0;E(338,f|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}b=k[e|0];j[114626]=0;e=l+27|0;K(1199,d|0,e|0,b+e|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;I(341,c+40|0,f|0,g|0);b=j[114626];j[114626]=0;h:{i:{j:{if((b|0)!=1){j[114626]=0;F(857,c+16|0,c+40|0);b=j[114626];j[114626]=0;if((b|0)==1){break j}j[114626]=0;F(1201,c+8|0,c+16|0);b=j[114626];j[114626]=0;if((b|0)==1){break i}j[114626]=0;E(1202,d|0,c+8|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break i}lc(c+16|0);jb(c+40|0);b=0;j[114626]=0;d=H(1203,d|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break g}e=l+22|0;if((d|0)!=(k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))){break a}b=xL(l);j[114626]=0;E(338,a|0,b|0)|0;a=j[114626];j[114626]=0;b=1;if((a|0)!=1){break a}break f}b=D()|0;C()|0;break b}b=D()|0;C()|0;break h}b=D()|0;C()|0;lc(c+16|0)}jb(c+40|0);break b}b=D()|0;C()|0;break b}b=D()|0;C()|0;break b}b=D()|0;C()|0}jb(f);G(b|0);z()}jb(f)}Za=c+368|0;return b}function wua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=Za-80|0;Za=e;t=j[a+16>>2];k=wf(e+48|0);j[k+8>>2]=a+112;j[k+16>>2]=j[a+128>>2];y=k,z=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[y+12>>2]=z;b=j[k+16>>2];if(b){y=k,z=vf(a+8|0,b),j[y>>2]=z;j[k+4>>2]=ab}b=j[a+44>>2];j[e+32>>2]=b;g=j[a+48>>2];j[e+36>>2]=g;h=j[a+52>>2];j[e+40>>2]=h;n=j[a+56>>2];j[e+44>>2]=n;u=j[a+24>>2];v=j[a+20>>2];l=j[a+4>>2];f=j[a>>2];j[e+24>>2]=f;j[e+28>>2]=l;m=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=m;if(d){while(1){b=0;g=b;h=f;j[e+72>>2]=f;j[e+76>>2]=b;l=((((l&2147483647)<<1|f>>>31)&2147483646)<<1)+t|0;a:{b=j[k+16>>2];if((b|0)<=0){break a}while(1){f=(g&2147483647)<<1|h>>>31;id(j[k+8>>2],(i[(f<<1|2)+l>>1]+i[l+((f&2147483646)<<1)>>1]|0)/8<<16>>16);hd(j[k+8>>2],4);Bb(e+72|0,k);if((b|0)<2){break a}b=b-1|0;h=j[e+72>>2];g=j[e+76>>2];continue}}b=j[k+8>>2];Bb(b,b+8|0);b=j[k+8>>2];f=j[b+4>>2];if(f){m=b;b=(j[e+76>>2]&2147483647)<<1|j[e+72>>2]>>>31;id(m,(i[(b<<1|2)+l>>1]+i[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);hd(j[k+8>>2],f);b=j[k+8>>2];f=j[b>>2];j[b>>2]=f;j[b+4>>2]=0}d=d-1|0;h=qf(b,j[k+12>>2]);j[e+12>>2]=h;j[e+8>>2]=h;g=0;n=1;while(1){m=j[a+60>>2];r=m;l=(e+32|0)+(g<<3)|0;o=j[l>>2];b=Gb(o,-16777216,16776704);s=j[a+64>>2];f=Gb(j[l+4>>2],-16777216,16776704);q=j[a+68>>2];w=q;q=q>>31;j[l+4>>2]=o;o=j[a+72>>2];m=m>>31;h=h<<8;m=OMa(r,m,h,h>>31);r=ab;x=(e+8|0)+(g<<2)|0;g=m;m=OMa(s,s>>31,b,b>>31);g=g+m|0;b=ab+r|0;b=g>>>0<m>>>0?b+1|0:b;m=g;g=OMa(w,q,f,f>>31);f=m+g|0;b=ab+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;j[x>>2]=(b|0)/256;j[l>>2]=b-(h&o);if(n){g=1;n=0;h=j[e+12>>2];continue}break}j[c>>2]=j[c>>2]+p(j[e+8>>2],v);j[c+4>>2]=j[c+4>>2]+p(j[e+12>>2],u);Bb(e+24|0,e+16|0);if(d){c=c+8|0;f=j[e+24>>2];l=j[e+28>>2];continue}break}f=j[e+24>>2];l=j[e+28>>2];n=j[e+44>>2];h=j[e+40>>2];g=j[e+36>>2];b=j[e+32>>2]}j[a+56>>2]=n;j[a+52>>2]=h;j[a+48>>2]=g;j[a+44>>2]=b;j[a>>2]=f;j[a+4>>2]=l;Za=e+80|0}function B$(a,b,c,d,e,f,g,i,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=Za-464|0;Za=a;j[a+16>>2]=f;j[a+20>>2]=g;j[a+24>>2]=i;j[a+28>>2]=l;j[a+348>>2]=a+352;m=cv(a+352|0,100,62447,a+16|0);j[a+48>>2]=2412;q=yd(a+232|0,0,a+48|0);j[a+48>>2]=2412;p=yd(a+224|0,0,a+48|0);o=a+240|0;a:{b:{c:{if(m>>>0>=100){j[114626]=0;m=T(2437)|0;o=j[114626];j[114626]=0;if((o|0)==1){break b}j[a>>2]=f;j[a+4>>2]=g;j[114626]=0;j[a+8>>2]=i;j[a+12>>2]=l;m=P(2459,a+348|0,m|0,62447,a|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}f=j[a+348>>2];if(!f){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)!=1){break c}break b}fe(q,f);fe(p,_c(m));if(Ti(p)){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)==1){break b}break c}o=j[p>>2]}j[114626]=0;hc(a+216|0,d);f=j[114626];j[114626]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){j[114626]=0;s=H(21,a+216|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break j}j[114626]=0;f=j[a+348>>2];P(2432,s|0,f|0,f+m|0,o|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break j}r=m?k[j[a+348>>2]]==45:r;i=Db(a+192|0);g=Db(a+176|0);f=Db(a+160|0);j[114626]=0;ba(2493,c|0,r|0,a+216|0,a+208|0,a+207|0,a+206|0,i|0,g|0,f|0,a+156|0);c=j[114626];j[114626]=0;if((c|0)==1){break i}j[a+36>>2]=2412;l=yd(a+40|0,0,a+36|0);c=j[a+156>>2];k:{if((c|0)<(m|0)){n=nb(f)+(m-c<<1|1)|0;break k}n=nb(f)+2|0}c=a+48|0;n=(nb(g)+n|0)+j[a+156>>2]|0;if(n>>>0<101){break h}fe(l,_c(n));c=j[l>>2];if(c){break h}j[114626]=0;M(2413);b=j[114626];j[114626]=0;if((b|0)!=1){break c}break g}m=D()|0;C()|0;break a}m=D()|0;C()|0;break e}m=D()|0;C()|0;break f}n=j[d+4>>2];j[114626]=0;ga(2494,c|0,a+36|0,a+32|0,n|0,o|0,m+o|0,s|0,r|0,a+208|0,h[a+207|0],h[a+206|0],i|0,g|0,f|0,j[a+156>>2]);m=j[114626];j[114626]=0;if((m|0)!=1){j[114626]=0;b=_(17,b|0,c|0,j[a+36>>2],j[a+32>>2],d|0,e|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break d}}}m=D()|0;C()|0;mc(l)}gb(f);gb(g);gb(i)}wb(a+216|0);break a}mc(l);gb(f);gb(g);gb(i);wb(a+216|0);mc(p);mc(q);Za=a+464|0;return b|0}z()}m=D()|0;C()|0}mc(p);mc(q);G(m|0);z()}function Dla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;c=Za-208|0;Za=c;e=j[a+12>>2];l=1<<e;if(e>>>0>=2){k=l;o=2;f=1;while(1){k=k>>>2|0;if(k){r=p(f,3);s=f<<1;m=0;while(1){NI(c+192|0,_b(a,m<<1));NI(c+176|0,_b(a,m));nh(c+160|0,c+176|0,c+192|0);e=m<<o;q=f+e|0;if(e>>>0<q>>>0){while(1){d=_b(b,e);g=j[d+12>>2];j[c+152>>2]=j[d+8>>2];j[c+156>>2]=g;g=j[d+4>>2];j[c+144>>2]=j[d>>2];j[c+148>>2]=g;g=e+f|0;d=_b(b,g);h=j[d+12>>2];j[c+136>>2]=j[d+8>>2];j[c+140>>2]=h;h=j[d+4>>2];j[c+128>>2]=j[d>>2];j[c+132>>2]=h;h=e+s|0;d=_b(b,h);n=j[d+12>>2];j[c+120>>2]=j[d+8>>2];j[c+124>>2]=n;n=j[d+4>>2];j[c+112>>2]=j[d>>2];j[c+116>>2]=n;n=e+r|0;d=_b(b,n);i=j[d+12>>2];j[c+104>>2]=j[d+8>>2];j[c+108>>2]=i;i=j[d+4>>2];j[c+96>>2]=j[d>>2];j[c+100>>2]=i;Kj(c+80|0,c+144|0,c+128|0);Yh(c- -64|0,c+144|0,c+128|0);Kj(c+48|0,c+112|0,c+96|0);Yh(c+16|0,c+112|0,c+96|0);nh(c+32|0,30864,c+16|0);Kj(c+16|0,c+80|0,c+48|0);d=_b(b,e);i=j[c+28>>2];j[d+8>>2]=j[c+24>>2];j[d+12>>2]=i;i=j[c+20>>2];j[d>>2]=j[c+16>>2];j[d+4>>2]=i;Kj(c,c- -64|0,c+32|0);nh(c+16|0,c+192|0,c);d=_b(b,g);i=j[c+28>>2];j[d+8>>2]=j[c+24>>2];j[d+12>>2]=i;g=j[c+20>>2];j[d>>2]=j[c+16>>2];j[d+4>>2]=g;Yh(c,c+80|0,c+48|0);nh(c+16|0,c+176|0,c);d=_b(b,h);h=j[c+28>>2];j[d+8>>2]=j[c+24>>2];j[d+12>>2]=h;g=j[c+20>>2];j[d>>2]=j[c+16>>2];j[d+4>>2]=g;Yh(c,c- -64|0,c+32|0);nh(c+16|0,c+160|0,c);d=_b(b,n);h=j[c+28>>2];j[d+8>>2]=j[c+24>>2];j[d+12>>2]=h;g=j[c+20>>2];j[d>>2]=j[c+16>>2];j[d+4>>2]=g;e=e+1|0;if((q|0)!=(e|0)){continue}break}}m=m+1|0;if((m|0)!=(k|0)){continue}break}e=j[a+12>>2]}f=f<<2;o=o+2|0;if(o>>>0<=e>>>0){continue}break}}a:{if(!(e&1)){break a}k=l>>>1|0;if(!k){break a}e=0;while(1){l=e+k|0;a=_b(b,l);f=j[a+12>>2];j[c+200>>2]=j[a+8>>2];j[c+204>>2]=f;f=j[a+4>>2];j[c+192>>2]=j[a>>2];j[c+196>>2]=f;Yh(c+176|0,_b(b,e),c+192|0);a=_b(b,l);f=j[c+188>>2];j[a+8>>2]=j[c+184>>2];j[a+12>>2]=f;l=j[c+180>>2];j[a>>2]=j[c+176>>2];j[a+4>>2]=l;Pw(_b(b,e),c+192|0);e=e+1|0;if((k|0)!=(e|0)){continue}break}}Za=c+208|0}function av(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,l=0;e=j[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=j[d>>2];if(!g){break l}if(!a){d=c;break j}j[d>>2]=0;d=c;break k}m:{if(!j[j[21215]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=h[e|0];if(d){j[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}j[a>>2]=0;j[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return ne(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=k[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}f=e+1|0;n:{if(!(g&33554432)){break n}i=e;if((k[e+1|0]&192)!=128){break f}f=e+2|0;if(!(g&524288)){break n}if((k[i+2|0]&192)!=128){break f}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=k[e|0];o:{if(e&3|g-1>>>0>126){break o}g=j[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=j[e+4>>2];f=e+4|0;e=f;if(!((g-16843009|g)&-2139062144)){continue}break}e=f}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=j[(f<<2)+57712>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=k[e|0];i=f-1|0;q:{r:{if(i>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=j[e>>2];if((g|g-16843009)&-2139062144){break s}j[a>>2]=g&255;j[a+4>>2]=k[e+1|0];j[a+8>>2]=k[e+2|0];j[a+12>>2]=k[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=k[e|0]}f=g&255;i=f-1|0}if(i>>>0>126){break p}}j[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=j[(f<<2)+57712>>2];f=1;continue}i=k[e|0];f=i>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{f=i-128|g<<6;l=e+1|0;v:{if((f|0)>-1){break v}i=e;l=k[e+1|0]-128|0;if(l>>>0>63){break u}f=f<<6|l;l=e+2|0;if((f|0)>-1){break v}i=k[i+2|0]-128|0;if(i>>>0>63){break u}f=i|f<<6;l=e+3|0}e=l;j[a>>2]=f;d=d-1|0;a=a+4|0;break t}j[114600]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=k[e|0]}if(g&255){break d}if(a){j[a>>2]=0;j[b>>2]=0}return c-d|0}j[114600]=25;if(!a){break b}}j[b>>2]=e}return-1}j[b>>2]=e;return c|0}function KB(a,b,c,d,e,f,g,h,i){var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=Za-128|0;Za=k;a:{b:{c:{if(!Kk(f,g,h,i,0,0,0,0)){break c}m=cX(f,g,h,i);s=e>>>16|0;o=s&32767;if((o|0)==32767){break c}if(m){break b}}$c(k+16|0,b,c,d,e,f,g,h,i);e=j[k+16>>2];d=j[k+20>>2];c=j[k+24>>2];b=j[k+28>>2];ED(k,e,d,c,b,e,d,c,b);d=j[k+8>>2];e=j[k+12>>2];h=j[k>>2];i=j[k+4>>2];break a}m=o<<16;p=d;r=m|e&65535;n=r;q=h;r=i>>>16&32767;l=i&65535|r<<16;if((Kk(b,c,p,n,f,g,h,l)|0)<=0){if(Kk(b,c,p,n,f,g,q,l)){h=b;i=c;break a}$c(k+112|0,b,c,d,e,0,0,0,0);d=j[k+120>>2];e=j[k+124>>2];h=j[k+112>>2];i=j[k+116>>2];break a}if(o){i=c;h=b}else{$c(k+96|0,b,c,p,n,0,0,0,1081540608);h=j[k+108>>2];n=h;p=j[k+104>>2];o=(h>>>16|0)-120|0;i=j[k+100>>2];h=j[k+96>>2]}if(!r){$c(k+80|0,f,g,q,l,0,0,0,1081540608);f=j[k+92>>2];l=f;q=j[k+88>>2];r=(l>>>16|0)-120|0;g=j[k+84>>2];f=j[k+80>>2]}t=l&65535|65536;n=n&65535|65536;if((o|0)>(r|0)){while(1){l=p;m=q;u=l-m|0;m=n-((l>>>0<m>>>0)+t|0)|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;m=m-(l>>>0>u>>>0)|0;l=u-l|0;d:{if((m|0)>0?1:(m|0)>=0){n=h;h=h-f|0;i=i-((f>>>0>n>>>0)+g|0)|0;if(!(h|l|(i|m))){$c(k+32|0,b,c,d,e,0,0,0,0);d=j[k+40>>2];e=j[k+44>>2];h=j[k+32>>2];i=j[k+36>>2];break a}m=m<<1|l>>>31;p=l<<1|i>>>31;break d}m=n<<1|p>>>31;p=p<<1|i>>>31}n=m;m=i<<1|h>>>31;h=h<<1;i=m;o=o-1|0;if((r|0)<(o|0)){continue}break}o=r}m=p;r=m-q|0;l=n-((m>>>0<q>>>0)+t|0)|0;m=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;l=l-(m>>>0>r>>>0)|0;q=r-m|0;e:{if((l|0)<0){q=p;l=n;break e}p=h;h=h-f|0;i=i-((f>>>0>p>>>0)+g|0)|0;if(h|q|(i|l)){break e}$c(k+48|0,b,c,d,e,0,0,0,0);d=j[k+56>>2];e=j[k+60>>2];h=j[k+48>>2];i=j[k+52>>2];break a}if((l|0)==65535|l>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;n=i<<1|h>>>31;h=h<<1;i=n;c=b;b=q;l=l<<1|b>>>31;q=c|b<<1;if(l>>>0<65536){continue}break}}b=s&32768;if((o|0)<=0){$c(k- -64|0,h,i,q,l&65535|(b|o+120)<<16,0,0,0,1065811968);d=j[k+72>>2];e=j[k+76>>2];h=j[k+64>>2];i=j[k+68>>2];break a}d=q;e=l&65535|(b|o)<<16}j[a>>2]=h;j[a+4>>2]=i;j[a+8>>2]=d;j[a+12>>2]=e;Za=k+128|0}function cta(a,b,c){var d=0,e=0,f=0,g=0,m=0;d=Za-160|0;Za=d;f=Ek(d+56|0,a);j[114626]=0;e=E(683,d+40|0,18621)|0;a=j[114626];j[114626]=0;a:{b:{c:{d:{if((a|0)!=1){j[114626]=0;j[d+24>>2]=19465728;j[d+28>>2]=0;I(684,f|0,e|0,d+24|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}qb(e);if(!(j[f>>2]&1073741824)){break c}break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;qb(e);break b}j[114626]=0;h[d+39|0]=0;e=E(683,d+40|0,18628)|0;a=j[114626];j[114626]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){j[114626]=0;K(685,f|0,d+39|0,e|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break p}qb(e);e=Db(d+40|0);j[114626]=0;g=E(683,d+24|0,18630)|0;a=j[114626];j[114626]=0;if((a|0)==1){break o}j[114626]=0;K(1177,f|0,e|0,g|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break n}qb(g);j[114626]=0;I(13,d+24|0,(k[d+39|0]?0:c)|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break m}j[114626]=0;F(486,b|0,d+24|0);a=j[114626];j[114626]=0;if((a|0)==1){break l}gb(d+24|0);j[114626]=0;i[d+22>>1]=0;c=E(683,d+24|0,18632)|0;a=j[114626];j[114626]=0;if((a|0)==1){break f}j[114626]=0;K(1178,f|0,d+22|0,c|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break k}qb(c);Sf(d+22|0,l[j[19859]+12>>1]);j[114626]=0;c=E(683,d+24|0,18634)|0;a=j[114626];j[114626]=0;if((a|0)==1){break j}a=j[zc(d+16|0,l[d+22>>1])>>2];j[114626]=0;P(1179,f|0,b|0,c|0,a|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break i}qb(c);j[114626]=0;i[d+14>>1]=65535;c=E(683,d+24|0,18636)|0;a=j[114626];j[114626]=0;if((a|0)==1){break h}j[114626]=0;a=K(1178,f|0,d+14|0,c|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break g}g=l[d+22>>1];m=l[d+14>>1];qb(c);if(!((a|0)==1|g>>>0<=m>>>0)){Ge(b,l[d+14>>1])}gb(e);break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;qb(e);break b}a=D()|0;C()|0;break e}a=D()|0;C()|0;qb(g);break e}a=D()|0;C()|0;break e}a=D()|0;C()|0;gb(d+24|0);break e}a=D()|0;C()|0;qb(c);break e}a=D()|0;C()|0;break e}a=D()|0;C()|0;qb(c);break e}a=D()|0;C()|0;break e}a=D()|0;C()|0;qb(c);break e}a=D()|0;C()|0}gb(e)}ag(f);G(a|0);z()}ag(f);Za=d+160|0}function bva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=Za-48|0;Za=f;a:{b:{c:{h=j[a+8>>2];e=j[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}u=b;v=j[a+16>>2];b=j[a+44>>2];j[f+32>>2]=b;k=j[a+48>>2];j[f+36>>2]=k;m=j[a+52>>2];j[f+40>>2]=m;n=j[a+56>>2];j[f+44>>2]=n;w=j[a+24>>2];x=j[a+20>>2];g=j[a+4>>2];l=j[a>>2];j[f+24>>2]=l;j[f+28>>2]=g;j[f+16>>2]=h;j[f+20>>2]=e;if(d){while(1){n=1;e=((((g&2147483647)<<1|l>>>31)&2147483646)<<1)+v|0;b=(l>>>16&65520)+u|0;l=i[b+14>>1];h=i[b+12>>1];q=i[b+10>>1];r=i[b+8>>1];s=i[b+6>>1];o=i[b+4>>1];t=i[b+2>>1];y=i[b>>1];m=0;b=1;k=0;while(1){g=k<<1;j[(f+8|0)+(k<<2)>>2]=(((((((p(i[e+(g|-8)>>1],t)+p(i[e+(g|-12)>>1],y)|0)+p(i[e+(g|-4)>>1],o)|0)+p(i[e+g>>1],s)|0)+p(i[e+(g|4)>>1],r)|0)+p(i[e+(g|8)>>1],q)|0)+p(i[e+(g|12)>>1],h)|0)+p(l,i[e+(g|16)>>1])|0)/32768;g=b;b=0;k=1;if(g){continue}break}while(1){k=(f+8|0)+(m<<2)|0;l=j[k>>2];h=j[a+60>>2];q=h;g=(f+32|0)+(m<<3)|0;m=j[g>>2];b=Gb(m,-16777216,16776704);r=j[a+64>>2];e=Gb(j[g+4>>2],-16777216,16776704);o=j[a+68>>2];t=o;o=o>>31;j[g+4>>2]=m;m=j[a+72>>2];s=h>>31;l=l<<8;h=l;h=OMa(q,s,h,h>>31);q=ab;s=k;k=h;h=OMa(r,r>>31,b,b>>31);k=k+h|0;b=ab+q|0;b=h>>>0>k>>>0?b+1|0:b;h=k;k=OMa(t,o,e,e>>31);e=h+k|0;b=ab+b|0;b=e>>>0<k>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|e>>>24;j[s>>2]=(b|0)/256;j[g>>2]=b-(l&m);m=1;b=n&1;n=0;if(b){continue}break}j[c>>2]=j[c>>2]+p(j[f+8>>2],x);j[c+4>>2]=j[c+4>>2]+p(j[f+12>>2],w);Bb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;l=j[f+24>>2];g=j[f+28>>2];continue}break}l=j[f+24>>2];g=j[f+28>>2];n=j[f+44>>2];m=j[f+40>>2];k=j[f+36>>2];b=j[f+32>>2]}j[a+56>>2]=n;j[a+52>>2]=m;j[a+48>>2]=k;j[a+44>>2]=b;j[a>>2]=l;j[a+4>>2]=g;Za=f+48|0}function AG(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var k=0,l=0,m=0;l=Za-48|0;Za=l;a:{b:{c:{d:{e:{f:{k=In(1,28);if(!k){a=R(4)|0;zk(a);j[114626]=0;I(2002,a|0,71396,2001);a=j[114626];j[114626]=0;if((a|0)!=1){break a}break f}j[k+16>>2]=0;j[k+20>>2]=0;j[k+12>>2]=f;j[k+8>>2]=e;j[k+4>>2]=d;j[k>>2]=c?c:1990;d=bs(l+32|0);g:{h:{if(!i){break h}c=j[i>>2];if(!c){break h}while(1){i:{e=j[i+4>>2];if(e){j[114626]=0;c=E(85,l+16|0,c|0)|0;f=j[114626];j[114626]=0;j:{if((f|0)!=1){j[114626]=0;f=E(2003,d|0,c|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break j}j[114626]=0;E(483,f|0,e|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break j}break i}i=J(0)|0;C()|0;break g}i=J(0)|0;C()|0;gb(c);break g}j[114626]=0;c=E(85,l+16|0,c|0)|0;e=j[114626];j[114626]=0;k:{if((e|0)!=1){j[114626]=0;E(2004,d|0,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break k}break i}i=J(0)|0;C()|0;break g}i=J(0)|0;C()|0;gb(c);break g}gb(c);c=j[i+8>>2];i=i+8|0;if(c){continue}break}}j[114626]=0;c=H(1392,80)|0;e=j[114626];j[114626]=0;l:{m:{n:{if((e|0)!=1){j[114626]=0;I(2005,l+16|0,k|0,k+4|0);e=j[114626];j[114626]=0;if((e|0)==1){break n}e=go(l+8|0,l+16|0);j[114626]=0;U(2007,c|0,a|0,b|0,e|0,d|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break m}j[k+24>>2]=c;Hc(e);Hc(l+16|0);Rj(d);c=k;break d}i=J(0)|0;C()|0;break g}i=J(0)|0;C()|0;break l}i=J(0)|0;C()|0;Hc(e);Hc(l+16|0)}Cb(c)}Rj(d);O(i|0)|0;j[114626]=0;L(1982,34745,k|0,g|0,h|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)==1){break f}a=j[k+24>>2];if(a){Cb(gr(a))}c=0;j[k+24>>2]=0;a=j[k+20>>2];if(a){Cb(a);j[k+20>>2]=0}Cb(k);break d}i=J(0)|0;C()|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)!=1){break e}break b}i=J(0)|0;C()|0}O(i|0)|0;c=0;j[114626]=0;L(1982,34745,0,g|0,h|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Q()}Za=l+48|0;return c|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}a=J(0)|0;C()|0;ib(a)}z()}function eea(a,b,c,d){var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=j[a+4>>2];t=e&2047;if(d){u=a+8256|0;v=a- -64|0;w=a+24640|0;x=a+16448|0;while(1){q=i[(((e+754&2047)<<2)+u|0)+2>>1];s=i[((e+1206&2047)<<2)+u>>1];f=i[(((e+1602&2047)<<2)+v|0)+2>>1];m=i[((e+1750&2047)<<2)+v>>1];k=((e+22&2047)<<2)+w|0;g=i[k+2>>1];k=i[k>>1];h=((e+502&2047)<<2)+w|0;l=i[h+2>>1];n=i[b>>1];o=i[b+2>>1];h=i[h>>1];r=Ac(i[a+32>>1]-h|0);y=i[a+24>>1];z=Ac(i[a+34>>1]-l|0);A=i[a+26>>1];B=Ac(i[a+36>>1]-k|0);C=i[a+28>>1];D=Ac(i[a+38>>1]-g|0);E=i[a+30>>1];F=a,G=Dc(Ac((p(r,y)|0)/65536<<1)+h|0),i[F+32>>1]=G;F=a,G=Dc(Ac((p(z,A)|0)/65536<<1)+l|0),i[F+34>>1]=G;F=a,G=Dc(Ac((p(B,C)|0)/65536<<1)+k|0),i[F+36>>1]=G;F=a,G=Dc(Ac((p(D,E)|0)/65536<<1)+g|0),i[F+38>>1]=G;g=Ac((p(i[a+32>>1],i[a+16>>1])|0)/32768|0);l=Ac((p(i[a+38>>1],i[a+22>>1])|0)/32768|0);k=Ac(g+((n|0)/4<<16>>16)|0);l=Ac(l+((o|0)/4<<16>>16)|0);h=Ac(k+((p(m,i[a+8>>1])|0)/-65536|0)|0);g=t<<2;n=g+v|0;o=Ac(l+((p(f,i[a+10>>1])|0)/-65536|0)|0);i[n+2>>1]=o;i[n>>1]=h;m=Ac(m+((p(h,i[a+8>>1])|0)/65536|0)|0);h=g+x|0;f=Ac(f+((p(o,i[a+10>>1])|0)/65536|0)|0);i[h+2>>1]=f;i[h>>1]=m;m=Ac(k+m|0);k=Ac(f+l|0);f=((e+426&2047)<<2)+x|0;l=i[f+2>>1];h=i[f>>1];e=((e+682&2047)<<2)+x|0;n=i[e+2>>1];o=i[e>>1];e=Ac((p(n,i[a+42>>1])+p(o,i[a+40>>1])|0)/32768|0);f=Ac((p(l,i[a+46>>1])+p(h,i[a+44>>1])|0)/32768|0);o=Ac(Ac(m+o|0)-e|0);n=Ac(Ac(k+n|0)-f|0);m=Ac(Ac(h+m|0)-e|0);k=Ac(Ac(k+l|0)-f|0);e=Ac(e+((p(i[a+8>>1],s)|0)/-65536|0)|0);f=Ac(f+((p(q,i[a+10>>1])|0)/-65536|0)|0);l=i[a+8>>1];h=i[a+10>>1];r=g+u|0;i[r+2>>1]=f;i[r>>1]=e;r=s;s=(p(e,l)|0)/65536|0;e=Ac(r+s|0);g=g+w|0;f=(p(f,h)|0)/65536|0;q=Ac(f+q|0);i[g+2>>1]=q;i[g>>1]=e;e=Ac(e+o|0);g=i[a+48>>1];q=Ac(n+q|0);j[c>>2]=(j[c>>2]+p(e,g)|0)+p(q,i[a+50>>1]);e=Ac(Ac(s)+m|0);g=i[a+52>>1];f=Ac(Ac(f)+k|0);j[c+4>>2]=(j[c+4>>2]+p(e,g)|0)+p(f,i[a+54>>1]);c=c+8|0;b=b+4|0;e=t+1|0;t=e&2047;d=d-1|0;if(d){continue}break}}j[a+4>>2]=t}function xua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=Za-80|0;Za=e;t=j[a+16>>2];k=wf(e+48|0);j[k+8>>2]=a+112;j[k+16>>2]=j[a+128>>2];y=k,z=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[y+12>>2]=z;b=j[k+16>>2];if(b){y=k,z=vf(a+8|0,b),j[y>>2]=z;j[k+4>>2]=ab}b=j[a+44>>2];j[e+32>>2]=b;g=j[a+48>>2];j[e+36>>2]=g;i=j[a+52>>2];j[e+40>>2]=i;n=j[a+56>>2];j[e+44>>2]=n;u=j[a+24>>2];v=j[a+20>>2];l=j[a+4>>2];f=j[a>>2];j[e+24>>2]=f;j[e+28>>2]=l;m=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=m;if(d){while(1){b=0;g=b;i=f;j[e+72>>2]=f;j[e+76>>2]=b;l=(((l&2147483647)<<1|f>>>31)&-2)+t|0;a:{b=j[k+16>>2];if((b|0)<=0){break a}while(1){f=(g&2147483647)<<1|i>>>31;id(j[k+8>>2],h[(f|1)+l|0]+h[l+(f&-2)|0]<<5);hd(j[k+8>>2],4);Bb(e+72|0,k);if((b|0)<2){break a}b=b-1|0;i=j[e+72>>2];g=j[e+76>>2];continue}}b=j[k+8>>2];Bb(b,b+8|0);b=j[k+8>>2];f=j[b+4>>2];if(f){m=b;b=(j[e+76>>2]&2147483647)<<1|j[e+72>>2]>>>31;id(m,h[(b|1)+l|0]+h[l+(b&-2)|0]<<5);hd(j[k+8>>2],f);b=j[k+8>>2];f=j[b>>2];j[b>>2]=f;j[b+4>>2]=0}d=d-1|0;i=qf(b,j[k+12>>2]);j[e+12>>2]=i;j[e+8>>2]=i;g=0;n=1;while(1){m=j[a+60>>2];r=m;l=(e+32|0)+(g<<3)|0;o=j[l>>2];b=Gb(o,-16777216,16776704);s=j[a+64>>2];f=Gb(j[l+4>>2],-16777216,16776704);q=j[a+68>>2];w=q;q=q>>31;j[l+4>>2]=o;o=j[a+72>>2];m=m>>31;i=i<<8;m=OMa(r,m,i,i>>31);r=ab;x=(e+8|0)+(g<<2)|0;g=m;m=OMa(s,s>>31,b,b>>31);g=g+m|0;b=ab+r|0;b=g>>>0<m>>>0?b+1|0:b;m=g;g=OMa(w,q,f,f>>31);f=m+g|0;b=ab+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;j[x>>2]=(b|0)/256;j[l>>2]=b-(i&o);if(n){g=1;n=0;i=j[e+12>>2];continue}break}j[c>>2]=j[c>>2]+p(j[e+8>>2],v);j[c+4>>2]=j[c+4>>2]+p(j[e+12>>2],u);Bb(e+24|0,e+16|0);if(d){c=c+8|0;f=j[e+24>>2];l=j[e+28>>2];continue}break}f=j[e+24>>2];l=j[e+28>>2];n=j[e+44>>2];i=j[e+40>>2];g=j[e+36>>2];b=j[e+32>>2]}j[a+56>>2]=n;j[a+52>>2]=i;j[a+48>>2]=g;j[a+44>>2]=b;j[a>>2]=f;j[a+4>>2]=l;Za=e+80|0}function UAa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,i=0;e=Za-16|0;Za=e;h[a|0]=0;c=k[b|0];if(c){h[a|0]=c>>>0>96?-1:c+12|0}h[a+1|0]=k[b+1|0];c=a;d=k[b+2|0];a:{b:{if((d-16&255)>>>0<=128){h[a+2|0]=1;d=(d-16|0)/2|0;break b}c:{switch((d+96&240)>>>4|0){case 0:h[a+2|0]=4;d=d&15;break b;case 1:h[a+2|0]=3;d=d&15;break b;case 2:h[a+2|0]=6;d=d&15;break b;case 3:break c;default:break a}}h[a+2|0]=5;d=d&15}h[c+4|0]=d}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{c=k[b+4|0];if(c>>>0<=28){switch(c|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(c-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((c|0)==128){break e}if((c|0)!=157){break d}h[a+2|0]=15;c=k[b+6|0];h[a+3|0]=20;h[a+4|0]=c>>>3;h[e+15|0]=15;g=a,i=k[Yb(b+5|0,e+15|0)|0]|208,h[g+5|0]=i;break d}c=k[b+6|0];d=k[b+5|0];if(!(c|d)){break d}h[a+5|0]=d;h[a+3|0]=c;Yi(a);f=k[b+6|0]==15;break d}h[a+3|0]=2;g=a,i=$i(k[b+6|0]<<4|k[b+5|0]>>>4),h[g+5|0]=i;break d}h[a+3|0]=3;g=a,i=$i(k[b+6|0]<<4|k[b+5|0]>>>4),h[g+5|0]=i;break d}h[a+3|0]=4;g=a,i=$i(k[b+6|0]<<4|k[b+5|0]>>>4),h[g+5|0]=i;break d}h[a+3|0]=5;h[a+5|0]=k[b+6|0]&240|k[b+5|0]>>>4;break d}c=k[b+5|0];if(c){h[a+5|0]=c;h[a+3|0]=9;break d}if((k[b+6|0]-1&255)>>>0>1){break d}h[a+5|0]=145;h[a+3|0]=20;break d}h[a+3|0]=13;h[a+5|0]=k[b+6|0]>>>1;break d}c=k[b+6|0];if(c){h[a+5|0]=c;h[a+3|0]=17;break d}h[a+3|0]=16;h[a+5|0]=k[b+5|0]&15;break d}h[a+3|0]=k[b+6|0];h[a+5|0]=k[b+5|0];gy(a,1);f=(k[a+3|0]&254)==16;break d}h[a+3|0]=18;h[a+5|0]=k[b+5|0];break d}h[a+3|0]=31;h[a+5|0]=k[b+6|0]>>>1;break d}h[a+3|0]=31;h[a+5|0]=k[b+6|0]>>>1&120;break d}h[a+5|0]=159;h[a+3|0]=20;break d}h[a+3|0]=21;h[a+5|0]=k[b+6|0]>>>2}b=k[b+3|0];t:{if(!b){break t}if(!k[a+3|0]){h[a+5|0]=b;h[a+3|0]=9;break t}if(k[a+2|0]){break t}h[a+2|0]=2;h[a+4|0]=b>>>2}Za=e+16|0;return f|0}function eU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=Za-16|0;Za=f;if((d|0)<1){a=0}else{Ln(c,d);j[f+4>>2]=b;j[f>>2]=a;a=lb(j[c>>2]);j[f+12>>2]=d;j[f+8>>2]=a;q=d;a=0;b=0;while(1){a:{e=dg(f,b);n=dg(f,b+4|0)<<8|dg(f,b+5|0);g=dg(f,b+6|0);i=dg(f,b+7|0);t=b+8|0;b:{c:{d:{switch(e|0){case 0:b=0;if(!n){break c}while(1){Pp(f,a+b|0,dg(f,b+t|0));b=b+1|0;if((n|0)!=(b|0)){continue}break}break c;case 1:break d;default:break a}}o=dg(f,b+10|0);Pp(f,a,o);a=(a>>>0<d>>>0)+a|0;n=n+3&65532;r=i|g<<8;if(r>>>0<2){break b}k=b+11|0;b=r-1|0;g=0;l=0;m=0;p=0;while(1){i=Cf(k,g,1,f);e:{f:{g:{h:{i:{if((l|0)<=7){if(i){e=g;break f}g=g+1|0;m=8;break i}e=g+1|0;j:{if(!i){if(!Cf(k,e,1,f)){break f}e=2;k:{l:{h=g+2|0;if(!Cf(k,h,1,f)){break l}e=3;h=g+3|0;if(!Cf(k,h,1,f)){break l}e=Cf(k,h,3,f);g=g+6|0;break k}g=h+1|0}h=4;m=dU(((m<<3)+e|0)-17|0);if((m|0)!=8){break h}break j}h=4;g=e;if((m|0)!=8){break h}}m=8;h=1;if((p|0)>19){break h}}h=0;break g}p=p+8|0}e=b;m:{if((b|0)<1){break m}while(1){o=o-cU(k,g,m,f)|0;Pp(f,a,o&255);e=b-1|0;g=g+m|0;a=(a>>>0<d>>>0)+a|0;if((h|0)<1){break m}h=h-1|0;i=(b|0)>1;b=e;if(i){continue}break}}l=(l|0)==31?31:l+1|0;b=e;break e}n:{o:{p:{h=e+1|0;if(!Cf(k,h,1,f)){e=2;break p}h=e+2|0;if(!Cf(k,h,1,f)){e=4;break p}h=e+3|0;if(!Cf(k,h,1,f)){e=6;break p}i=e+5|0;if(!Cf(k,e+4|0,1,f)){g=e+8|0;h=Cf(k,i,3,f)+8|0;break n}g=e+10|0;e=16;i=Cf(k,i,5,f);break o}g=h+2|0;i=Cf(k,h+1|0,1,f)}h=e+i|0}q:{if(Cf(k,g,1,f)){i=-256;e=12;break q}g=g+1|0;e=Cf(k,g,1,f);i=e?-4352:0;e=e?14:8}g=g+1|0;s=Cf(k,g,e,f);if((h|0)>=3){l=l-((h|0)!=3)|0;l=(l|0)>0?l-1|0:0}g=e+g|0;if((h|0)<1|(b|0)<1){break e}e=(a+i|0)+(s^-1)|0;i=b;while(1){o=bU(f,e);Pp(f,a,o);b=i-1|0;a=(a>>>0<d>>>0)+a|0;if((h|0)<2){break e}e=e+1|0;h=h-1|0;s=(i|0)>1;i=b;if(s){continue}break}}p=p-(p>>3)|0;if((b|0)>0){continue}break}break b}a=a+n|0;r=n}b=n+t|0;q=q-r|0;if((q|0)>0){continue}}break}Ln(c,j[f+12>>2]-q|0);a=ad(c)^1}Za=f+16|0;return a|0}function cva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=Za-48|0;Za=f;a:{b:{c:{g=j[a+8>>2];e=j[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}v=b;w=j[a+16>>2];b=j[a+44>>2];j[f+32>>2]=b;n=j[a+48>>2];j[f+36>>2]=n;m=j[a+52>>2];j[f+40>>2]=m;o=j[a+56>>2];j[f+44>>2]=o;x=j[a+24>>2];y=j[a+20>>2];k=j[a+4>>2];l=j[a>>2];j[f+24>>2]=l;j[f+28>>2]=k;j[f+16>>2]=g;j[f+20>>2]=e;if(d){while(1){e=(((k&2147483647)<<1|l>>>31)&-2)+w|0;b=(l>>>16&65520)+v|0;l=i[b+14>>1];g=i[b+12>>1];r=i[b+10>>1];s=i[b+8>>1];t=i[b+6>>1];q=i[b+4>>1];u=i[b+2>>1];z=i[b>>1];m=0;o=1;n=1;b=0;while(1){j[(f+8|0)+(b<<2)>>2]=(((((((p(h[e+(b|-4)|0],u)+p(h[e+(b|-6)|0],z)|0)+p(h[e+(b|-2)|0],q)|0)+p(h[b+e|0],t)|0)+p(h[e+(b|2)|0],s)|0)+p(h[e+(b|4)|0],r)|0)+p(h[e+(b|6)|0],g)|0)+p(l,h[e+(b|8)|0])<<8)/32768;k=n;n=0;b=1;if(k){continue}break}while(1){e=(f+8|0)+(m<<2)|0;l=j[e>>2];g=j[a+60>>2];r=g;n=(f+32|0)+(m<<3)|0;m=j[n>>2];b=Gb(m,-16777216,16776704);s=j[a+64>>2];k=Gb(j[n+4>>2],-16777216,16776704);q=j[a+68>>2];u=q;q=q>>31;j[n+4>>2]=m;m=j[a+72>>2];t=g>>31;l=l<<8;g=l;g=OMa(r,t,g,g>>31);r=ab;t=e;e=g;g=OMa(s,s>>31,b,b>>31);e=e+g|0;b=ab+r|0;b=e>>>0<g>>>0?b+1|0:b;g=e;e=OMa(u,q,k,k>>31);k=g+e|0;b=ab+b|0;b=e>>>0>k>>>0?b+1|0:b;k=k+8388608|0;if(k>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|k>>>24;j[t>>2]=(b|0)/256;j[n>>2]=b-(l&m);m=1;b=o&1;o=0;if(b){continue}break}j[c>>2]=j[c>>2]+p(j[f+8>>2],y);j[c+4>>2]=j[c+4>>2]+p(j[f+12>>2],x);Bb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;l=j[f+24>>2];k=j[f+28>>2];continue}break}l=j[f+24>>2];k=j[f+28>>2];o=j[f+44>>2];m=j[f+40>>2];n=j[f+36>>2];b=j[f+32>>2]}j[a+56>>2]=o;j[a+52>>2]=m;j[a+48>>2]=n;j[a+44>>2]=b;j[a>>2]=l;j[a+4>>2]=k;Za=f+48|0}function Th(a,b,c,d,e,f){var g=0,h=0,i=0,l=q(0),m=q(0),o=0,p=0,r=q(0),s=q(0),t=0;if(!(bb[j[j[a>>2]+132>>2]](a)|0)){g=k[j[a+20>>2]+25|0]}l=n[j[a+20>>2]+144>>2];m=q(1);if(!(bb[j[j[a>>2]+132>>2]](a)|0)){m=n[j[a+20>>2]+144>>2]}l=q(q(1)-l);a:{if((bb[j[j[a>>2]+148>>2]](a)|0)<1){break a}if(!qH(j[a+20>>2])){break a}l=q(q(l+l)+q(-1));m=q(-l)}r=n[a+4196>>2];m=q(r*m);l=q(r*l);o=a+44|0;p=wd(o,0);o=wd(o,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;h=g+b|0;t=h;m=q(n[g+p>>2]+n[h>>2]);h=c+g|0;n[t>>2]=q(m-q(n[g+o>>2]+q(m+n[h>>2])))+q(n[d+g>>2]*l);n[h>>2]=q(n[e+g>>2]*l)-m;i=i+1|0;if((i|0)!=(f|0)){continue}break}break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;n[h>>2]=q(q(n[g+p>>2]*l)-n[d+g>>2])+n[h>>2];h=c+g|0;n[h>>2]=q(q(n[g+o>>2]*l)-n[e+g>>2])+n[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;n[h>>2]=q(n[h>>2]+n[d+g>>2])-q(n[g+p>>2]*m);h=c+g|0;n[h>>2]=q(n[h>>2]+n[e+g>>2])-q(n[g+o>>2]*m);i=i+1|0;if((i|0)!=(f|0)){continue}break}break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;n[h>>2]=q(n[h>>2]+n[g+p>>2])-q(n[d+g>>2]*l);h=c+g|0;n[h>>2]=q(n[h>>2]+n[g+o>>2])-q(n[e+g>>2]*l);i=i+1|0;if((i|0)!=(f|0)){continue}break}break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;n[h>>2]=q(q(n[g+p>>2]*m)+q(n[d+g>>2]*l))+n[h>>2];h=c+g|0;n[h>>2]=q(q(n[g+o>>2]*m)+q(n[e+g>>2]*l))+n[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}break b;case 5:break c;default:break b}}g=qH(j[a+20>>2]);if(!f){break b}l=g?q(l*q(.5)):l;m=g?q(m*q(.5)):m;while(1){g=i<<2;h=g+b|0;r=q(n[d+g>>2]-n[g+p>>2]);s=q(n[g+o>>2]-n[e+g>>2]);n[h>>2]=q(n[h>>2]+q(r*l))+q(s*m);g=c+g|0;n[g>>2]=q(q(s*l)+q(r*m))+n[g>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((k[j[a+20>>2]+24|0]&4)>>>2|0)){break d}if(bb[j[j[a>>2]+132>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;n[d>>2]=n[d>>2]+n[a+p>>2];d=a+c|0;n[d>>2]=n[d>>2]+n[a+o>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=q(0),f=q(0),g=0,h=0,i=0,k=0,l=q(0),m=0,o=0,p=0,r=0,s=q(0),t=0,u=0,v=0,w=q(0),x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=q(0),K=q(0),L=q(0),M=q(0),N=q(0),O=q(0);o=a+44|0;if(Yg(o)){B=wd(o,0);C=wd(o,1);D=Rc(o,0);E=Rc(o,1);t=j[a+4296>>2];r=j[a+4300>>2];if(d){k=a+4304|0;i=t+1|0;x=i+j[a+4272>>2]&4095;m=k+(x<<4)|0;y=i+j[a+4276>>2]&4095;g=((y<<4)+k|0)+4|0;z=i+j[a+4280>>2]&4095;p=((z<<4)+k|0)+8|0;A=i+j[a+4284>>2]&4095;h=((A<<4)+k|0)+12|0;u=j[a+4292>>2]+r|0;v=j[a+4288>>2]+r|0;G=a+69840|0;H=a+78032|0;F=d;while(1){x=x-1&4095;i=(x<<4)+k|0;e=n[i>>2];v=v&1023;I=(v<<3)+G|0;s=n[I+4>>2];J=n[h>>2];K=n[p>>2];L=n[g>>2];M=n[m>>2];N=n[C>>2];O=n[B>>2];w=n[a+4232>>2];y=y-1&4095;m=(y<<4)+k|0;l=n[m+4>>2];f=q(q(w*n[I>>2])+q(l*q(.6180340051651001)));h=r<<3;g=h+G|0;n[g+4>>2]=l-q(f*q(.6180340051651001));l=e;e=q(q(s*w)-q(e*q(.6180340051651001)));n[g>>2]=l+q(e*q(.6180340051651001));n[i>>2]=f;n[m+4>>2]=e;u=u&1023;g=(u<<3)+H|0;s=n[g+4>>2];z=z-1&4095;p=(z<<4)+k|0;f=n[p+8>>2];w=n[a+4236>>2];e=q(w*n[g>>2]);A=A-1&4095;g=(A<<4)+k|0;l=n[g+12>>2];e=q(e+q(l*q(.6180340051651001)));h=h+H|0;n[h+4>>2]=l-q(e*q(.6180340051651001));l=f;f=q(q(s*w)-q(f*q(.6180340051651001)));n[h>>2]=l+q(f*q(.6180340051651001));n[p+8>>2]=e;n[g+12>>2]=f;f=q(n[i>>2]+e);e=q(O+q(1.0000000031710769e-30));n[D>>2]=f+q(n[a+4224>>2]*e);f=q(N+q(1.0000000031710769e-30));n[E>>2]=q(q(n[a+4224>>2]*f)+n[m+4>>2])+n[g+12>>2];h=(t<<4)+k|0;s=n[a+4228>>2];e=q(s*e);n[h>>2]=q(q(n[a+4240>>2]*n[i>>2])+e)+q(M*n[a+4244>>2]);f=q(s*f);n[h+4>>2]=q(q(n[a+4248>>2]*n[m+4>>2])+f)+q(L*n[a+4252>>2]);n[h+8>>2]=q(q(n[a+4256>>2]*n[p+8>>2])-f)+q(K*n[a+4260>>2]);n[h+12>>2]=q(q(n[a+4264>>2]*n[g+12>>2])+e)+q(J*n[a+4268>>2]);h=g+12|0;p=p+8|0;g=m+4|0;E=E+4|0;D=D+4|0;C=C+4|0;B=B+4|0;u=u-1|0;v=v-1|0;r=r-1&1023;t=t-1&4095;m=i;F=F-1|0;if(F){continue}break}}j[a+4300>>2]=r;j[a+4296>>2]=t;Th(a,b,c,Rc(o,0),Rc(o,1),d)}}function Fla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0;c=Za-208|0;Za=c;f=1;e=j[a+12>>2];h=1<<e;if(e&1){i=h>>>1|0;if(i){e=0;while(1){k=e+i|0;f=_b(b,k);d=j[f+12>>2];j[c+200>>2]=j[f+8>>2];j[c+204>>2]=d;d=j[f+4>>2];j[c+192>>2]=j[f>>2];j[c+196>>2]=d;Yh(c+176|0,_b(b,e),c+192|0);f=_b(b,k);d=j[c+188>>2];j[f+8>>2]=j[c+184>>2];j[f+12>>2]=d;k=j[c+180>>2];j[f>>2]=j[c+176>>2];j[f+4>>2]=k;Pw(_b(b,e),c+192|0);e=e+1|0;if((i|0)!=(e|0)){continue}break}e=j[a+12>>2]}f=2;h=h>>>3|0}else{h=h>>>2|0}k=e&-2;if(k){while(1){if(f){r=p(h,3);s=h<<1;i=0;while(1){e=_b(a,i<<1);d=j[e+12>>2];j[c+200>>2]=j[e+8>>2];j[c+204>>2]=d;d=j[e+4>>2];j[c+192>>2]=j[e>>2];j[c+196>>2]=d;e=_b(a,i);d=j[e+12>>2];j[c+184>>2]=j[e+8>>2];j[c+188>>2]=d;d=j[e+4>>2];j[c+176>>2]=j[e>>2];j[c+180>>2]=d;nh(c+160|0,c+176|0,c+192|0);e=i<<k;n=h+e|0;if(e>>>0<n>>>0){while(1){d=_b(b,e);g=j[d+12>>2];j[c+152>>2]=j[d+8>>2];j[c+156>>2]=g;g=j[d+4>>2];j[c+144>>2]=j[d>>2];j[c+148>>2]=g;g=e+h|0;nh(c+128|0,c+192|0,_b(b,g));l=e+s|0;nh(c+112|0,c+176|0,_b(b,l));q=e+r|0;nh(c+96|0,c+160|0,_b(b,q));Kj(c+80|0,c+144|0,c+112|0);Yh(c- -64|0,c+144|0,c+112|0);Kj(c+48|0,c+128|0,c+96|0);cl(c+16|0,-o[3858],-o[3859]);Yh(c,c+128|0,c+96|0);nh(c+32|0,c+16|0,c);Kj(c+16|0,c+80|0,c+48|0);d=_b(b,e);m=j[c+28>>2];j[d+8>>2]=j[c+24>>2];j[d+12>>2]=m;m=j[c+20>>2];j[d>>2]=j[c+16>>2];j[d+4>>2]=m;Yh(c+16|0,c+80|0,c+48|0);d=_b(b,g);m=j[c+28>>2];j[d+8>>2]=j[c+24>>2];j[d+12>>2]=m;g=j[c+20>>2];j[d>>2]=j[c+16>>2];j[d+4>>2]=g;Kj(c+16|0,c- -64|0,c+32|0);d=_b(b,l);l=j[c+28>>2];j[d+8>>2]=j[c+24>>2];j[d+12>>2]=l;g=j[c+20>>2];j[d>>2]=j[c+16>>2];j[d+4>>2]=g;Yh(c+16|0,c- -64|0,c+32|0);d=_b(b,q);l=j[c+28>>2];j[d+8>>2]=j[c+24>>2];j[d+12>>2]=l;g=j[c+20>>2];j[d>>2]=j[c+16>>2];j[d+4>>2]=g;e=e+1|0;if((n|0)!=(e|0)){continue}break}}i=i+1|0;if((f|0)!=(i|0)){continue}break}}h=h>>>2|0;f=f<<2;k=k-2|0;if(k){continue}break}}Za=c+208|0}function O8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0;e=Za-96|0;Za=e;a:{if(Ec(c)){break a}g=k[pG(c)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;Uq(e+80|0,c,0,nb(c)-1|0);ob(c,e+80|0);gb(e+80|0)}ld(e+80|0);f=j[e+80>>2];ld(e+72|0);g=oG(f,j[e+76>>2],c);ld(e+80|0);c:{d:{e:{f:{g:{if(j[e+84>>2]==(g|0)){if(Dd(c,38235)){a=R(8)|0;j[114626]=0;b=E(85,e+80|0,39169)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}Wb(a,b);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}c=D()|0;C()|0;gb(b);break d}if(!d){break g}a=R(8)|0;j[114626]=0;I(2128,e+80|0,39179,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){Wb(a,e+80|0);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}c=D()|0;C()|0;gb(e+80|0);break d}c=D()|0;C()|0;S(a|0);break d}f=Db(e+80|0);h:{i:{j:{k:{switch(j[g+4>>2]){case 0:oh(e- -64|0,c);j[114626]=0;c=j[e+68>>2];j[e+8>>2]=j[e+64>>2];j[e+12>>2]=c;b=K(2070,b|0,e+8|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){j[114626]=0;h[e+72|0]=b;F(2133,a|0,e+72|0);a=j[114626];j[114626]=0;if((a|0)!=1){break h}}break j;case 1:oh(e+56|0,c);j[114626]=0;c=j[e+60>>2];j[e+16>>2]=j[e+56>>2];j[e+20>>2]=c;b=IB(b,e+16|0,d);c=ab;d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;j[e+72>>2]=b;j[e+76>>2]=c;F(2135,a|0,e+72|0);a=j[114626];j[114626]=0;if((a|0)!=1){break h}}break j;case 2:oh(e+48|0,c);j[114626]=0;c=j[e+52>>2];j[e+24>>2]=j[e+48>>2];j[e+28>>2]=c;i=+ca(2072,b|0,e+24|0,d|0);b=j[114626];j[114626]=0;if((b|0)!=1){j[114626]=0;o[e+72>>3]=i;F(2136,a|0,e+72|0);a=j[114626];j[114626]=0;if((a|0)!=1){break h}}break j;case 3:break k;default:break i}}oh(e+40|0,c);j[114626]=0;c=j[e+44>>2];j[e+32>>2]=j[e+40>>2];j[e+36>>2]=c;L(2073,a|0,b|0,e+32|0,d|0);a=j[114626];j[114626]=0;if((a|0)!=1){break h}}c=D()|0;C()|0;gb(f);break d}Nc(a,f)}gb(f);break f}Db(a)}Za=e+96|0;return}c=D()|0;C()|0;S(a|0)}G(c|0)}z()}function Iua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=Za-48|0;Za=g;y=j[a+16>>2];l=j[a+44>>2];j[g+32>>2]=l;o=j[a+48>>2];j[g+36>>2]=o;k=j[a+52>>2];j[g+40>>2]=k;h=j[a+56>>2];j[g+44>>2]=h;s=j[a+40>>2];t=j[a+36>>2];e=j[a+4>>2];m=j[a>>2];j[g+24>>2]=m;j[g+28>>2]=e;f=j[a+12>>2];j[g+16>>2]=j[a+8>>2];j[g+20>>2]=f;a:{if(!d){n=s>>12;f=t>>12;break a}while(1){o=1;e=((((e&2147483647)<<1|m>>>31)&2147483646)<<1)+y|0;f=(((m>>>16|0)+4&131064)<<1)+b|0;m=i[f+38>>1];h=i[f+36>>1];n=i[f+34>>1];q=i[f+32>>1];u=i[f+30>>1];v=i[f+28>>1];r=i[f+26>>1];w=i[f+24>>1];l=0;k=1;f=0;while(1){x=(g+8|0)+(f<<2)|0;f=f<<1;j[x>>2]=(((((p(i[e+(f|8)>>1],n)+p(i[e+(f|4)>>1],q)|0)+p(h,i[e+(f|12)>>1])|0)+p(m,i[e+(f|16)>>1])|0)/2|0)+((((p(i[e+(f|-8)>>1],r)+p(i[e+(f|-12)>>1],w)|0)+p(i[e+(f|-4)>>1],v)|0)+p(i[e+f>>1],u)|0)/2|0)|0)/16384;x=k&1;k=0;f=1;if(x){continue}break}while(1){k=(g+8|0)+(l<<2)|0;m=j[k>>2];h=j[a+60>>2];n=h;f=(g+32|0)+(l<<3)|0;q=j[f>>2];e=Gb(q,-16777216,16776704);u=j[a+64>>2];l=Gb(j[f+4>>2],-16777216,16776704);r=j[a+68>>2];w=r;r=r>>31;j[f+4>>2]=q;q=j[a+72>>2];v=h>>31;m=m<<8;h=m;h=OMa(n,v,h,h>>31);n=ab;v=k;k=h;h=OMa(u,u>>31,e,e>>31);k=k+h|0;e=ab+n|0;e=k>>>0<h>>>0?e+1|0:e;h=k;k=OMa(w,r,l,l>>31);l=h+k|0;e=ab+e|0;e=l>>>0<k>>>0?e+1|0:e;l=l+8388608|0;if(l>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|l>>>24;j[v>>2]=(e|0)/256;j[f>>2]=e-(m&q);l=1;e=o&1;o=0;if(e){continue}break}e=j[a+32>>2];t=j[a+28>>2]+t|0;f=t>>12;j[c>>2]=j[c>>2]+p(f,j[g+8>>2]);s=e+s|0;n=s>>12;j[c+4>>2]=j[c+4>>2]+p(n,j[g+12>>2]);Bb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;m=j[g+24>>2];e=j[g+28>>2];continue}break}m=j[g+24>>2];e=j[g+28>>2];h=j[g+44>>2];k=j[g+40>>2];o=j[g+36>>2];l=j[g+32>>2]}j[a+40>>2]=s;j[a+20>>2]=f;j[a+36>>2]=t;j[a+56>>2]=h;j[a+52>>2]=k;j[a+48>>2]=o;j[a+44>>2]=l;j[a+24>>2]=n;j[a>>2]=m;j[a+4>>2]=e;Za=g+48|0}function Jua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=Za-48|0;Za=g;y=j[a+16>>2];m=j[a+44>>2];j[g+32>>2]=m;q=j[a+48>>2];j[g+36>>2]=q;l=j[a+52>>2];j[g+40>>2]=l;k=j[a+56>>2];j[g+44>>2]=k;t=j[a+40>>2];u=j[a+36>>2];e=j[a+4>>2];n=j[a>>2];j[g+24>>2]=n;j[g+28>>2]=e;f=j[a+12>>2];j[g+16>>2]=j[a+8>>2];j[g+20>>2]=f;a:{if(!d){f=t>>12;o=u>>12;break a}while(1){e=(((e&2147483647)<<1|n>>>31)&-2)+y|0;q=1;f=(((n>>>16|0)+4&131064)<<1)+b|0;n=i[f+38>>1];k=i[f+36>>1];o=i[f+34>>1];r=i[f+32>>1];v=i[f+30>>1];w=i[f+28>>1];s=i[f+26>>1];x=i[f+24>>1];m=0;l=1;f=0;while(1){j[(g+8|0)+(f<<2)>>2]=(((((p(h[e+(f|4)|0],o)+p(h[e+(f|2)|0],r)|0)+p(k,h[e+(f|6)|0])|0)+p(n,h[e+(f|8)|0])<<8)/2|0)+((((p(h[e+(f|-4)|0],s)+p(h[e+(f|-6)|0],x)|0)+p(h[e+(f|-2)|0],w)|0)+p(h[e+f|0],v)<<8)/2|0)|0)/16384;z=l&1;l=0;f=1;if(z){continue}break}while(1){l=(g+8|0)+(m<<2)|0;n=j[l>>2];k=j[a+60>>2];o=k;f=(g+32|0)+(m<<3)|0;r=j[f>>2];e=Gb(r,-16777216,16776704);v=j[a+64>>2];m=Gb(j[f+4>>2],-16777216,16776704);s=j[a+68>>2];x=s;s=s>>31;j[f+4>>2]=r;r=j[a+72>>2];w=k>>31;n=n<<8;k=n;k=OMa(o,w,k,k>>31);o=ab;w=l;l=k;k=OMa(v,v>>31,e,e>>31);l=l+k|0;e=ab+o|0;e=l>>>0<k>>>0?e+1|0:e;k=l;l=OMa(x,s,m,m>>31);m=k+l|0;e=ab+e|0;e=m>>>0<l>>>0?e+1|0:e;m=m+8388608|0;if(m>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|m>>>24;j[w>>2]=(e|0)/256;j[f>>2]=e-(n&r);m=1;e=q&1;q=0;if(e){continue}break}e=j[a+32>>2];u=j[a+28>>2]+u|0;o=u>>12;j[c>>2]=j[c>>2]+p(o,j[g+8>>2]);t=e+t|0;f=t>>12;j[c+4>>2]=j[c+4>>2]+p(f,j[g+12>>2]);Bb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;n=j[g+24>>2];e=j[g+28>>2];continue}break}n=j[g+24>>2];e=j[g+28>>2];k=j[g+44>>2];l=j[g+40>>2];q=j[g+36>>2];m=j[g+32>>2]}j[a+40>>2]=t;j[a+20>>2]=o;j[a+36>>2]=u;j[a+56>>2]=k;j[a+52>>2]=l;j[a+48>>2]=q;j[a+44>>2]=m;j[a+24>>2]=f;j[a>>2]=n;j[a+4>>2]=e;Za=g+48|0}function qGa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=q(0);c=Za+ -64|0;Za=c;SFa(a,b+16|0);fQ(b+48|0);h[b+143|0]=0;j[b+152>>2]=-2147483648;j[b+156>>2]=-2147483648;d=hf(a);cd(c+48|0,a,d);j[114626]=0;e=H(337,c+48|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}if(!e){break b}j[114626]=0;e=b+4|0;F(507,e|0,d|0);f=j[114626];j[114626]=0;if((f|0)==1){break c}e=j[e>>2];j[114626]=0;K(698,c+48|0,e|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break b}}a=D()|0;C()|0;break a}j[114626]=0;d=H(390,a|0)|0;e=j[114626];j[114626]=0;d:{if((e|0)==1){break d}j[114626]=0;I(341,c+32|0,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}j[114626]=0;a=H(337,c+32|0)|0;d=j[114626];j[114626]=0;e:{if((d|0)!=1){f:{g:{h:{if(!a){break h}while(1){j[114626]=0;a=E(258,c+32|0,5)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}if(!a){break h}j[114626]=0;E(699,c+32|0,c+28|0)|0;a=j[114626];j[114626]=0;i:{if((a|0)!=1){a=4;if((k[c+28|0]|k[c+29|0]<<8|(k[c+30|0]<<16|k[c+31|0]<<24))==1414682436|(k[c+28|0]|k[c+29|0]<<8|(k[c+30|0]<<16|k[c+31|0]<<24))==1196380752){break i}j[114626]=0;a=H(390,c+32|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break i}a=D()|0;C()|0;break e}a=D()|0;C()|0;break e}j[114626]=0;I(341,c+8|0,c+32|0,a|0);a=j[114626];j[114626]=0;j:{k:{if((a|0)!=1){if((k[c+28|0]|k[c+29|0]<<8|(k[c+30|0]<<16|k[c+31|0]<<24))!=1414682436){break k}j[114626]=0;g=q(oa(700,c+8|0));a=j[114626];j[114626]=0;if((a|0)==1){break f}n[b+144>>2]=g;break j}a=D()|0;C()|0;break e}if((k[c+28|0]|k[c+29|0]<<8|(k[c+30|0]<<16|k[c+31|0]<<24))!=1196380752){break j}j[114626]=0;a=H(390,c+8|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}j[b+148>>2]=a}jb(c+8|0);continue}}jb(c+32|0);jb(c+48|0);Za=c- -64|0;return}a=D()|0;C()|0;break e}a=D()|0;C()|0;jb(c+8|0);break e}a=D()|0;C()|0}jb(c+32|0);break a}a=D()|0;C()|0}jb(c+48|0);G(a|0);z()}function _fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=q(0),f=0,g=q(0),h=0,i=q(0),k=0,l=0,m=q(0),o=q(0),p=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=q(0),A=0,B=0,C=q(0),D=0,E=0,F=q(0);a:{if(!j[a+4276>>2]){break a}k=a+44|0;if(!Yg(k)){break a}s=wd(k,0);t=wd(k,1);u=Rc(k,0);v=Rc(k,1);B=bb[j[j[a>>2]+188>>2]](a)|0;e=q(bb[j[j[a>>2]+196>>2]](a));z=q(bb[j[j[a>>2]+184>>2]](a));w=bb[j[j[a>>2]+208>>2]](a)|0;if(d){C=q(e*q(.009999999776482582));D=w&1;l=a+4260|0;p=j[a+4256>>2];f=j[a+4272>>2];x=d;while(1){i=n[s>>2];m=n[t>>2];h=tm(a,f+p|0);f=tm(a,f);e=n[xb(l,h)>>2];E=xb(l,f),F=q(q(C*e)+q(q(m+i)*q(.5))),n[E>>2]=F;b:{if(B){g=n[a+4244>>2];e=q(n[a+4236>>2]+g);n[a+4236>>2]=e;g=q(g+n[a+4240>>2]);n[a+4240>>2]=g;if(!(e<=q(1))){e=q(e+q(-2));n[a+4236>>2]=e}if(!(g<=q(1))){n[a+4240>>2]=g+q(-2)}e=q(r(e));e=q(q(e+e)+q(-1));g=q(r(n[a+4240>>2]));g=q(q(g+g)+q(-1));break b}g=n[a+4244>>2];o=n[a+4240>>2];e=q(q(g*o)+n[a+4236>>2]);n[a+4236>>2]=e;g=q(o-q(e*g));n[a+4240>>2]=g}o=n[xb(l,tm(a,j[a+4280>>2]+j[a+4272>>2]|0))>>2];E=u,F=q(q(q(q(o-i)+q(q(q(n[xb(l,tm(a,j[a+4284>>2]+j[a+4272>>2]|0))>>2]-o)*q(.000244140625))*q(j[a+4280>>2]&4095)))*z)+i),n[E>>2]=F;i=n[xb(l,tm(a,j[a+4288>>2]+j[a+4272>>2]|0))>>2];E=v,F=q(q(q(q(i-m)+q(q(q(n[xb(l,tm(a,j[a+4292>>2]+j[a+4272>>2]|0))>>2]-i)*q(.000244140625))*q(j[a+4288>>2]&4095)))*z)+m),n[E>>2]=F;y=a;p=j[a+4256>>2];f=p;i=n[a+4248>>2];m=q(i*(D?g:e));c:{if(q(r(m))<q(2147483648)){h=~~m;break c}h=-2147483648}A=f+(w>>>0>1?h:0-h|0)|0;j[y+4288>>2]=A;f=w>>>0<4;y=a;e=q(i*e);d:{if(q(r(e))<q(2147483648)){h=~~e;break d}h=-2147483648}f=(f?h:0-h|0)+p|0;j[y+4280>>2]=f;j[a+4292>>2]=A+4096;j[a+4284>>2]=f+4096;t=t+4|0;s=s+4|0;v=v+4|0;u=u+4|0;h=a;f=j[a+4272>>2];if((f|0)<=0){f=f+(j[a+4276>>2]<<12)|0}f=f-4096|0;j[h+4272>>2]=f;x=x-1|0;if(x){continue}break}}Th(a,b,c,Rc(k,0),Rc(k,1),d)}}function N0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,k=0,l=0,m=0;i=Za-432|0;Za=i;j[i+424>>2]=37;j[i+428>>2]=0;k=sq(i+424|1,62202,j[c+4>>2]);j[i+380>>2]=i+384;a=Wd();a:{if(k){l=j[c+8>>2];j[i+72>>2]=g;j[i+76>>2]=h;m=i- -64|0;j[m>>2]=e;j[m+4>>2]=f;j[i+48>>2]=l;a=Ke(i+384|0,30,a,i+424|0,i+48|0);break a}j[i+80>>2]=e;j[i+84>>2]=f;j[i+88>>2]=g;j[i+92>>2]=h;a=Ke(i+384|0,30,a,i+424|0,i+80|0)}j[i+128>>2]=2412;l=yd(i+368|0,0,i+128|0);b:{c:{d:{if((a|0)>=30){e:{if(k){j[114626]=0;a=T(2437)|0;k=j[114626];j[114626]=0;if((k|0)==1){break c}k=j[c+8>>2];j[i+16>>2]=e;j[i+20>>2]=f;j[i+24>>2]=g;j[i+28>>2]=h;j[i>>2]=k;j[114626]=0;a=P(2459,i+380|0,a|0,i+424|0,i|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break e}break c}j[114626]=0;a=T(2437)|0;k=j[114626];j[114626]=0;if((k|0)==1){break c}j[i+32>>2]=e;j[i+36>>2]=f;j[114626]=0;j[i+40>>2]=g;j[i+44>>2]=h;a=P(2459,i+380|0,a|0,i+424|0,i+32|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}}e=j[i+380>>2];if(!e){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)==1){break c}break d}fe(l,e)}e=j[i+380>>2];g=e+a|0;h=Tf(e,g,c);j[i+116>>2]=2412;f=yd(i+120|0,0,i+116|0);f:{g:{if(j[i+380>>2]==(i+384|0)){a=i+128|0;e=i+384|0;break g}a=_c(a<<3);if(!a){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)!=1){break d}c=D()|0;C()|0;break f}fe(f,a);e=j[i+380>>2]}j[114626]=0;hc(i+104|0,c);k=j[114626];j[114626]=0;h:{i:{if((k|0)!=1){j[114626]=0;Z(2470,e|0,h|0,g|0,a|0,i+116|0,i+112|0,i+104|0);e=j[114626];j[114626]=0;if((e|0)==1){break i}wb(i+104|0);j[114626]=0;a=_(2471,b|0,a|0,j[i+116>>2],j[i+112>>2],c|0,d|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break h}mc(f);mc(l);Za=i+432|0;return a|0}c=D()|0;C()|0;break f}c=D()|0;C()|0;wb(i+104|0);break f}c=D()|0;C()|0}mc(f);break b}z()}c=D()|0;C()|0}mc(l);G(c|0);z()}function Y0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,k=0,l=0,m=0;i=Za-256|0;Za=i;j[i+248>>2]=37;j[i+252>>2]=0;k=sq(i+248|1,62202,j[c+4>>2]);j[i+204>>2]=i+208;a=Wd();a:{if(k){l=j[c+8>>2];j[i+72>>2]=g;j[i+76>>2]=h;m=i- -64|0;j[m>>2]=e;j[m+4>>2]=f;j[i+48>>2]=l;a=Ke(i+208|0,30,a,i+248|0,i+48|0);break a}j[i+80>>2]=e;j[i+84>>2]=f;j[i+88>>2]=g;j[i+92>>2]=h;a=Ke(i+208|0,30,a,i+248|0,i+80|0)}j[i+128>>2]=2412;l=yd(i+192|0,0,i+128|0);b:{c:{d:{if((a|0)>=30){e:{if(k){j[114626]=0;a=T(2437)|0;k=j[114626];j[114626]=0;if((k|0)==1){break c}k=j[c+8>>2];j[i+16>>2]=e;j[i+20>>2]=f;j[i+24>>2]=g;j[i+28>>2]=h;j[i>>2]=k;j[114626]=0;a=P(2459,i+204|0,a|0,i+248|0,i|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break e}break c}j[114626]=0;a=T(2437)|0;k=j[114626];j[114626]=0;if((k|0)==1){break c}j[i+32>>2]=e;j[i+36>>2]=f;j[114626]=0;j[i+40>>2]=g;j[i+44>>2]=h;a=P(2459,i+204|0,a|0,i+248|0,i+32|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}}e=j[i+204>>2];if(!e){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)==1){break c}break d}fe(l,e)}e=j[i+204>>2];g=e+a|0;h=Tf(e,g,c);j[i+116>>2]=2412;f=yd(i+120|0,0,i+116|0);f:{g:{if(j[i+204>>2]==(i+208|0)){a=i+128|0;e=i+208|0;break g}a=_c(a<<1);if(!a){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)!=1){break d}c=D()|0;C()|0;break f}fe(f,a);e=j[i+204>>2]}j[114626]=0;hc(i+104|0,c);k=j[114626];j[114626]=0;h:{i:{if((k|0)!=1){j[114626]=0;Z(2460,e|0,h|0,g|0,a|0,i+116|0,i+112|0,i+104|0);e=j[114626];j[114626]=0;if((e|0)==1){break i}wb(i+104|0);j[114626]=0;a=_(17,b|0,a|0,j[i+116>>2],j[i+112>>2],c|0,d|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break h}mc(f);mc(l);Za=i+256|0;return a|0}c=D()|0;C()|0;break f}c=D()|0;C()|0;wb(i+104|0);break f}c=D()|0;C()|0}mc(f);break b}z()}c=D()|0;C()|0}mc(l);G(c|0);z()}function d9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=Za-32|0;Za=e;g=Mg(a);a=b+24|0;f=Fb(j[a>>2]+484360|0);j[114626]=0;i=H(2185,f|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;F(1525,g|0,i|0);f=j[114626];j[114626]=0;if((f|0)==1){break c}d:{e:{if(i){f=0;while(1){c=l[ac(Fb(j[a>>2]+484360|0),f)>>1];d=j[a>>2];j[114626]=0;d=E(913,d+484344|0,c|0)|0;h=j[114626];j[114626]=0;if((h|0)==1){break b}f:{if(d){c=Ib(j[a>>2]+484344|0,l[ac(Fb(j[a>>2]+484360|0),f)>>1]);j[114626]=0;F(2183,e|0,c|0);c=j[114626];j[114626]=0;g:{h:{i:{if((c|0)!=1){j[114626]=0;I(2177,e+16|0,b|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break i}j[114626]=0;F(1527,g|0,e+16|0);c=j[114626];j[114626]=0;if((c|0)==1){break h}gb(e+16|0);gb(e);break f}a=D()|0;C()|0;break a}a=D()|0;C()|0;break g}a=D()|0;C()|0;gb(e+16|0)}gb(e);break a}j[114626]=0;d=T(959)|0;h=j[114626];j[114626]=0;if((h|0)==1){break b}if((c|0)==(d|0)){j[114626]=0;c=E(85,e+16|0,38847)|0;d=j[114626];j[114626]=0;j:{if((d|0)!=1){j[114626]=0;F(1527,g|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break j}gb(c);break f}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(c);break a}j[114626]=0;d=T(958)|0;h=j[114626];j[114626]=0;if((h|0)==1){break b}if((c|0)==(d|0)){j[114626]=0;c=E(85,e+16|0,38856)|0;d=j[114626];j[114626]=0;k:{if((d|0)!=1){j[114626]=0;F(1527,g|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break k}gb(c);break f}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(c);break a}j[114626]=0;c=E(85,e+16|0,38865)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}j[114626]=0;F(1527,g|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break d}gb(c)}f=f+1|0;if((i|0)!=(f|0)){continue}break}}Za=e+32|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(c);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0}Uc(g);G(a|0);z()}function pma(a,b,c){var d=0,e=0,f=0,g=0,i=0;i=Za-16|0;Za=i;d=a+1074308|0;mb(i+8|0,d,71);a:{if(kb(i+8|0)){e=(p(b,896)+a|0)+1075843|0;d=h[e|0];if((d|0)>-1){break a}if(!(k[a+480209|0]&16|k[(p(b,896)+a|0)+1075811|0]!=18)){f=d&-33;h[e|0]=f;b:{c:{if((f|0)!=-64){d=d&223;if((d|0)!=128){break c}d=k[(p(b,896)+a|0)+1075844|0]>>>4|-64;break b}d=k[(p(b,896)+a|0)+1075844|0]&15|-128;break b}d=d-1|0}h[e|0]=d;e=(p(b,896)+a|0)+1075072|0;j[e>>2]=j[e>>2]|2097152}if((d&224)!=128){break a}j[c>>2]=0;break a}if(k[(p(b,896)+a|0)+1075811|0]!=18){break a}mb(i+8|0,d,22);d:{if(kb(i+8|0)){g=p(b,896)+a|0;e=g+1075843|0;f=k[e|0];d=f<<24>>24;if(!((d|0)>-1|!j[g+1075060>>2])){e:{f:{if((f|0)!=192){if((f|0)!=128){break f}d=k[(p(b,896)+a|0)+1075844|0]>>>4|-64;break e}d=k[(p(b,896)+a|0)+1075844|0]&15|-128;break e}d=d-1|0}h[e|0]=d}if((d&192)!=128){break d}j[c>>2]=0;break d}d=k[(p(b,896)+a|0)+1075844|0];e=d>>>4|0;f=e+(d&15)|0;if(!(k[a+480208|0]&4?0:j[a+480180>>2]&16777248)){f=f+2|0;e=e+1|0}g=(p(b,896)+a|0)+1075843|0;d=k[g|0];if(!(j[a+480180>>2]&4)){d=(d&255)>>>0<f>>>0?d:0;if((d&255)>>>0>=e>>>0){j[c>>2]=0}h[g|0]=d+1;break d}g:{if(k[a+480209|0]&16){d=d&255?d-1|0:0;break g}h[g|0]=d+1}if(((d&255)>>>0)%(f>>>0)>>>0<e>>>0){break d}j[c>>2]=0}d=(p(b,896)+a|0)+1075072|0;j[d>>2]=j[d>>2]|2097152}d=p(b,896)+a|0;h:{if(k[d+1075811|0]!=18){break h}f=d+1075640|0;d=j[f>>2];if(!d|!k[d+34|0]|k[d+15|0]&2){break h}d=p(b,896)+a|0;if(j[d+1075072>>2]&134218752){break h}e=d+1075805|0;if(!Ld(k[e|0])){break h}f=j[f>>2];d=j[(p(k[f+34|0],160)+a|0)+906140>>2];if(!d){break h}g=bb[j[j[d>>2]+96>>2]](d,k[e|0],b)|0;c=j[c>>2];if(!(!g|c)){bb[j[j[d>>2]+88>>2]](d,f,k[e|0]+255|0,0,b);break h}if(g|!c){break h}bb[j[j[d>>2]+88>>2]](d,f,k[e|0],l[(p(b,896)+a|0)+1075672>>1],b)}Za=i+16|0}function f6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0;e=Za-16|0;Za=e;d=-2;a:{if(!a){break a}c=j[a+28>>2];if(!c){break a}b=(b|0)==1?2:b;if(b>>>0>4|!(1<<b&21)){break a}f=j[c+11e3>>2];k=j[a+4>>2];j[c+11e3>>2]=0;b:{if(j[c+43780>>2]<0){break b}h=(b|0)==4;g=j[c+11004>>2];if(g?!h:0){break a}d=j[c+11008>>2]>0?9:8;j[c+11004>>2]=h|g;if(!(!f|(b|0)!=4)){j[e+12>>2]=j[a+4>>2];j[e+8>>2]=j[a+16>>2];b=j[a+12>>2];b=cF(c,j[a>>2],e+12|0,b,b,e+8|0,d|4);j[c+43780>>2]=b;d=j[e+12>>2];j[a>>2]=d+j[a>>2];j[a+4>>2]=j[a+4>>2]-d;j[a+8>>2]=d+j[a+8>>2];j[a+48>>2]=j[c+28>>2];d=j[e+8>>2];j[a+12>>2]=d+j[a+12>>2];j[a+16>>2]=j[a+16>>2]-d;j[a+20>>2]=d+j[a+20>>2];d=-3;if((b|0)<0){break a}if(!b){d=1;break a}j[c+43780>>2]=-1;d=-5;break a}f=j[c+10996>>2];if(!f){i=(b|0)!=4;l=i?d|2:d;h=c+11012|0;b=j[c+10992>>2];while(1){d=j[a+4>>2];j[e+8>>2]=32768-b;j[e+12>>2]=d;f=cF(c,j[a>>2],e+12|0,h,b+h|0,e+8|0,l);j[c+43780>>2]=f;b=j[e+12>>2];j[a>>2]=b+j[a>>2];j[a+4>>2]=j[a+4>>2]-b;j[a+8>>2]=b+j[a+8>>2];j[a+48>>2]=j[c+28>>2];b=j[e+8>>2];j[c+10996>>2]=b;d=j[a+16>>2];b=b>>>0<d>>>0?b:d;Vb(j[a+12>>2],h+j[c+10992>>2]|0,b);j[a+12>>2]=b+j[a+12>>2];j[a+16>>2]=j[a+16>>2]-b;j[a+20>>2]=b+j[a+20>>2];g=j[c+10996>>2]-b|0;j[c+10996>>2]=g;b=b+j[c+10992>>2]&32767;j[c+10992>>2]=b;if((f|0)<0){break b}d=-5;if((f|0)==1?!k:0){break a}if(!i){if(!f){d=g?-5:1;break a}if(j[a+16>>2]){continue}break a}if(f){d=0;if(g|!j[a+4>>2]){break a}if(j[a+16>>2]){continue}break a}break}d=!g;break a}b=j[a+16>>2];b=b>>>0>f>>>0?f:b;Vb(j[a+12>>2],(j[c+10992>>2]+c|0)+11012|0,b);j[a+12>>2]=b+j[a+12>>2];j[a+16>>2]=j[a+16>>2]-b;j[a+20>>2]=b+j[a+20>>2];a=j[c+10996>>2]-b|0;j[c+10996>>2]=a;j[c+10992>>2]=b+j[c+10992>>2]&32767;d=0;if(j[c+43780>>2]){break a}d=!a;break a}d=-3}Za=e+16|0;return d|0}function Ywa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,l=0,m=0,n=0,o=0;e=Za-32|0;Za=e;m=c+484344|0;If(m,k[b+70|0]|k[b+71|0]<<8);a:{if(k[b+70|0]|k[b+71|0]<<8){while(1){f=j[a+8>>2];g=hf(a);Jb(a,1);b:{if((k[b+58|0]|k[b+59|0]<<8)==258){c=dd(a)+1|0;break b}c=Of(a)}d=Of(a);xc(a,f+g|0);cd(e+16|0,a,d);j[114626]=0;c=K(402,m|0,l&65535,(c?c>>>0<1024?c:1024:64)|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}c:{if(!d|c^1){break c}c=Ib(m,l);n=e,o=Lb(c),j[n+8>>2]=o;n=e,o=Mb(c),j[n>>2]=o;if(!rb(e+8|0,e)){break c}while(1){d=j[e+8>>2];j[114626]=0;c=H(387,e+16|0)|0;f=j[114626];j[114626]=0;d:{e:{f:{if((f|0)!=1){if(!(c&128)){break f}if(c&1){j[114626]=0;f=H(387,e+16|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break a}h[d|0]=f}if(c&2){break e}break d}break a}h[d|0]=c;c=255}j[114626]=0;f=H(387,e+16|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break a}h[d+1|0]=f}f=0;if(c&4){j[114626]=0;f=H(387,e+16|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break a}}if(c&8){j[114626]=0;g=H(387,e+16|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break a}h[d+3|0]=g}if(c&16){j[114626]=0;c=H(387,e+16|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break a}h[d+5|0]=c}c=d;g:{h:{g=k[d|0];if(!g){break h}i=255;if((g|0)==97){break g}if(g>>>0>96){break h}i=g+12|0;break g}i=0}h[c|0]=i;i:{if(k[d+5|0]|k[d+3|0]){j[114626]=0;N(574,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){break i}break a}h[d+3|0]=0}if(k[d+1|0]==255){h[d+1|0]=0}c=f-16|0;j:{if((c&255)>>>0<=64){h[d+4|0]=c;h[d+2|0]=1;break j}if(f>>>0<96){break j}c=f&15;h[d+4|0]=c;f=f-96>>4;h[d+2|0]=k[f+17983|0];if((f|0)!=6){break j}h[d+4|0]=c<<2}kk(e+8|0);if(rb(e+8|0,e)){continue}break}}jb(e+16|0);l=l+1|0;if(l>>>0<(k[b+70|0]|k[b+71|0]<<8)>>>0){continue}break}}Za=e+32|0;return}a=D()|0;C()|0;jb(e+16|0);G(a|0);z()}function Ika(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,l=0,m=0,n=0;e=Za-1136|0;Za=e;rc(b);d=e+1112|0;h=tka(b,d);if(!h){DI(d)}a:{if(!h){break a}if(!HI(e+1112|0)){break a}d=e+1120|0;if((k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24))!=(jj(b)|0)){break a}d=e+1128|0;if((k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24))!=(ef(b)|0)){break a}if(!c){f=1;break a}Ab(e+1056|0,0,56);if(g6(e+1056|0)){break a}d=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);j[e+1052>>2]=d;f=e+1132|0;f=k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24);g=(f|0)!=0;h=hz(e+1040|0,f);b:{c:{d:{e:{if(!f|!d){break e}while(1){j[114626]=0;j[e+12>>2]=1024;d=E(629,e+12|0,e+1052|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break d}d=j[d>>2];j[114626]=0;K(261,b|0,e+16|0,d|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;i=K(1549,i|0,e+16|0,d|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[e+1072>>2]=f;j[e+1060>>2]=d;j[e+1056>>2]=e+16;g=j[h>>2];j[114626]=0;j[e+1068>>2]=g+l;m=E(1550,e+1056|0,0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}n=j[e+1052>>2]-d|0;j[e+1052>>2]=n;d=j[e+1072>>2];g=(d|0)!=0;if(!d|(m|0)==1){break e}l=(f+l|0)-d|0;f=d;if(n){continue}break}}j[114626]=0;H(1551,e+1056|0)|0;b=j[114626];j[114626]=0;f:{g:{if((b|0)!=1){f=0;b=e+1124|0;if(!((k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))!=(i|0)|g|(m|0)!=1)){j[114626]=0;F(831,e|0,h|0);b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;b=K(832,e+16|0,e|0,0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break g}j[114626]=0;f=K(1489,a|0,b|0,c|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break f}jb(b)}Od(h);break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;break b}a=D()|0;C()|0;jb(b);break b}a=D()|0;C()|0;break b}a=D()|0;C()|0}Od(h);G(a|0);z()}Za=e+1136|0;return f|0}function tf(a,b,c,d,e){var f=0,g=0,h=0,m=0,n=0;h=j[a+8>>2]+(p(l[a+14>>1],(k[a+80|0]?c:0)+b|0)>>>1|0)|0;j[a+8>>2]=h;g=k[a+79|0]?l[j[a>>2]+3836>>1]:g;b=l[a+20>>1];m=l[a+22>>1];n=l[a+70>>1];a:{b:{c:{switch(j[a+16>>2]){case 0:c=l[j[a>>2]+3832>>1];c=b+(c&l[a+34>>1]?0:l[a+24>>1]?p((b^-1)<<16>>16,l[a+36>>1]>>>l[j[a+40>>2]+((c>>>l[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0)|0;i[a+20>>1]=c;if(c<<16>>16>0){break b}j[a+16>>2]=1;i[a+20>>1]=0;break b;case 1:c=l[j[a>>2]+3832>>1];c=b+(c&l[a+46>>1]?0:l[a+26>>1]?l[a+48>>1]>>>l[j[a+52>>2]+((c>>>l[a+44>>1]&7)<<1)>>1]|0:0)|0;i[a+20>>1]=c;f=c<<16>>16;c=l[a+28>>1];if((f|0)<(c|0)){break b}j[a+16>>2]=2;i[a+20>>1]=c;break b;case 2:if(k[a+78|0]){break b};case 3:c=0;f=l[j[a>>2]+3832>>1];f=b+(f&l[a+58>>1]?0:l[a+30>>1]?l[a+60>>1]>>>l[j[a+64>>2]+((f>>>l[a+56>>1]&7)<<1)>>1]|0:0)|0;i[a+20>>1]=f;if(f<<16>>16<511){break b}j[a+16>>2]=-1;i[a+20>>1]=511;j[a+72>>2]=0;break a;default:break c}}c=0;j[a+72>>2]=0;break a}g=((b+m|0)+n|0)+g<<3;if(e){d=(i[a+74>>1]+i[a+72>>1]>>e)+d|0}d=(h>>>10|0)+d|0;c=d&255;b=d&65535;d:{e:{switch(l[a+12>>1]){case 0:d=(b&512)>>>9|0;b=l[((b&256?c^255:c)<<1)+19296>>1];break d;case 1:d=0;b=l[((b&512?0:b&256?c^255:c)<<1)+19296>>1];break d;case 2:d=0;b=l[((b&256?c^255:c)<<1)+19296>>1];break d;case 3:d=0;b=l[((b&256?0:c)<<1)+19296>>1];break d;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=l[(e<<1)+19296>>1];break d;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=l[(b<<1)+19296>>1];break d;case 6:d=(d&512)>>>9|0;b=0;break d;default:break e}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}i[a+74>>1]=l[a+72>>1];e=a;a=b+g|0;a=(a&65535)>>>0<8191?a:8191;c=0-d^l[((a&255)<<1)+18784>>1]+1024>>>((a&65280)>>>8)<<1;i[e+72>>1]=c}return c<<16>>16}function y5(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,l=0,m=0,n=0;a:{b:{c:{f=j[a+1420>>2];if((f|0)<1){break c}while(1){j[(p(d,20)+a|0)+1436>>2]=0;d=d+1|0;if((f|0)!=(d|0)){continue}break}if((f|0)<=3){break c}g=c;break b}if((c|0)<4){break a}h=c-3|0;d:{while(1){e:{e=b+g|0;if(k[e|0]!=79|(k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))!=(k[84672]|k[84673]<<8|(k[84674]<<16|k[84675]<<24))){break e}l=g+26|0;if((l|0)>=(h|0)){break d}i=g+27|0;n=b+l|0;c=k[n|0];if((h|0)<=(i+c|0)){break d}m=c+27|0;d=0;if(c){while(1){m=k[(d+i|0)+b|0]+m|0;d=d+1|0;if((c|0)!=(d|0)){continue}break}}d=0;c=0;while(1){i=22;d=Gv(d,k[(c+g|0)+b|0]);c=c+1|0;if((c|0)!=22){continue}break}while(1){d=Gv(d,0);i=i+1|0;if((i|0)!=26){continue}break}j[a+1420>>2]=f+1;c=p(f,20)+a|0;j[c+1432>>2]=d;j[c+1428>>2]=m-26;j[c+1424>>2]=k[e+22|0]|k[e+23|0]<<8|(k[e+24|0]<<16|k[e+25|0]<<24);if(k[(l+k[n|0]|0)+b|0]==255){d=-1}else{d=k[e+6|0]|k[e+7|0]<<8|(k[e+8|0]<<16|k[e+9|0]<<24)}j[c+1436>>2]=l;j[c+1440>>2]=d;f=j[a+1420>>2];if((f|0)!=4){break e}g=h;break b}g=g+1|0;if((h|0)!=(g|0)){continue}break}g=h}if((f|0)<1){break a}}h=0;while(1){e=p(h,20)+a|0;i=e+1432|0;c=j[i>>2];d=0;l=j[e+1436>>2];f=g-l|0;n=e+1428|0;m=j[n>>2];f=(f|0)<(m|0)?f:m;if((f|0)>=1){while(1){c=Gv(c,k[(d+l|0)+b|0]);d=d+1|0;if((f|0)!=(d|0)){continue}break}}d=m-f|0;j[n>>2]=d;j[i>>2]=c;f:{if(!d){d=c;c=e+1424|0;if((d|0)==j[c>>2]){j[a+1380>>2]=-1;j[a+992>>2]=0;j[a+1420>>2]=-1;b=j[(p(h,20)+a|0)+1440>>2];j[a+1060>>2]=b;j[a+1064>>2]=(b|0)!=-1;return f+l|0}d=j[a+1420>>2]-1|0;j[a+1420>>2]=d;d=p(d,20)+a|0;j[c+16>>2]=j[d+1440>>2];e=d+1432|0;f=j[e+4>>2];j[c+8>>2]=j[e>>2];j[c+12>>2]=f;d=d+1424|0;e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;break f}h=h+1|0}if(j[a+1420>>2]>(h|0)){continue}break}}return g}function BT(a,b,c){var d=0,e=0,f=0,g=0,l=0,m=0;e=Za-32|0;Za=e;a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))==1229999433){Ot(e,3,a+32|0);qc(e+16|0,e);j[114626]=0;E(369,b+492|0,e+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}gb(e+16|0);si(e,1,a+4|0);qc(e+16|0,e);j[114626]=0;E(369,b+524|0,e+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}gb(e+16|0);d=a+20|0;j[b>>2]=(k[d|0]|k[d+1|0]<<8)<<5;j[b+4>>2]=k[a+24|0]>>>1;kc(b+4|0,64);d=a+25|0;f=k[d|0]&127;j[b+8>>2]=f>>>0>64?128:f<<2;h[b+15|0]=k[b+15|0]&254|((k[d|0]^-1)&128)>>>7;h[e+16|0]=k[a+26|0];h[e|0]=100;l=b,m=k[Yb(e+16|0,e)|0],h[l+20|0]=m;h[e+16|0]=k[a+27|0];h[e|0]=64;l=b,m=k[Yb(e+16|0,e)|0],h[l+19|0]=m;h[b+16|0]=k[a+17|0];h[b+17|0]=k[a+18|0];h[b+18|0]=k[a+19|0];h[b+26|0]=k[a+22|0];h[b+27|0]=k[a+23|0];d=a+58|0;Kt(b,k[d|0]&127,k[d|0]>>>7|0);d=a+59|0;Jt(b,k[d|0]&127,k[d|0]>>>7|0);b:{c:{d:{d=a+28|0;if(!((k[d|0]|k[d+1|0]<<8)==514|(k[d|0]|k[d+1|0]<<8)==529|(k[d|0]|k[d+1|0]<<8)==544)){if((k[d|0]|k[d+1|0]<<8)!=532){break d}}d=a+61|0;if(k[d|0]==255){break d}if(k[d|0]<=128){h[b+30|0]=k[d|0]}d=k[a+62|0]|k[a+63|0]<<8;if(d>>>0<129){break c}break b}d=0;f=a+61|0;if(h[f|0]>=0){h[b+30|0]=k[f|0]+1}f=a+62|0;if(h[f|0]>=0){d=k[f|0]+1|0}f=a+63|0;if(h[f|0]<0){break c}d=(k[f|0]<<7)+d|0}i[b+28>>1]=d}d=h[a+60|0];h[b+31|0]=d;if((d|0)<=-1){h[b+31|0]=0;h[b+34|0]=d^128}d=0;c=c&16777216?240:25;Qt(a+304|0,b+48|0,0,c);Qt(a+386|0,b+68|0,32,c);Qt(a+468|0,b+88|0,32,c);h[b+100|0]=k[b+100|0]&239|k[a+468|0]>>>3&16;c=b+108|0;f=b+236|0;a=a- -64|0;while(1){g=d<<1;b=k[g+a|0];g=k[a+(g|1)|0];l=Oc(f,d),m=g,i[l>>1]=m;l=Pb(c,d),m=(b>>>0<120?b:d)+1|0,h[l|0]=m;d=d+1|0;if((d|0)!=120){continue}break}d=554}Za=e+32|0;return d}a=D()|0;C()|0;gb(e+16|0);G(a|0);z()}function wq(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=Za-128|0;Za=l;j[l+120>>2]=b;n=us(c,d);j[l+4>>2]=2412;p=yd(l+8|0,0,l+4|0);m=l+16|0;a:{b:{if(n>>>0>=101){m=_c(n);if(!m){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;break b}fe(p,m)}i=m;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{j[114626]=0;i=E(2414,a|0,l+120|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}if(!(i&(n|0)!=0)){j[114626]=0;b=E(2415,a|0,l+120|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}if(!b){break d}j[f>>2]=j[f>>2]|2;break d}j[114626]=0;q=H(2416,a|0)|0;b=j[114626];j[114626]=0;g:{if((b|0)!=1){if(g){break g}j[114626]=0;q=E(2417,e|0,q|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break g}}b=D()|0;C()|0;break b}r=t+1|0;u=0;i=m;b=c;while(1){if((b|0)==(d|0)){t=r;if(!u){continue e}j[114626]=0;H(2418,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){i=m;b=c;if(n+o>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(k[i|0]!=2){break h}if((nb(b)|0)==(r|0)){break h}h[i|0]=0;o=o-1|0}i=i+1|0;b=b+12|0;continue}}b=D()|0;C()|0;break b}i:{if(k[i|0]!=1){break i}s=h[Ub(b,t)|0];j:{if(g){break j}j[114626]=0;s=E(2417,e|0,s<<24>>24)|0;v=j[114626];j[114626]=0;if((v|0)!=1){break j}b=D()|0;C()|0;break b}k:{if((q&255)==(s&255)){u=1;if((nb(b)|0)!=(r|0)){break i}h[i|0]=2;o=o+1|0;break k}h[i|0]=0}n=n-1|0}i=i+1|0;b=b+12|0;continue}}break}b=D()|0;C()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(k[m|0]!=2){m=m+1|0;c=c+12|0;continue}break}d=c;break l}j[f>>2]=j[f>>2]|4}mc(p);Za=l+128|0;return d|0}b=D()|0;C()|0}else{n:{if(!Ec(b)){h[i|0]=1;break n}h[i|0]=2;o=o+1|0;n=n-1|0}i=i+1|0;b=b+12|0;continue}break}}mc(p);G(b|0)}z()}function gX(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0;g=j[a+4>>2];d=g&-8;f=d+a|0;a:{if(!(g&3)){if(b>>>0<256){break a}if(d>>>0>=b+4>>>0){c=a;if(d-b>>>0<=j[116056]<<1>>>0){break a}}return 0}b:{if(b>>>0<=d>>>0){c=d-b|0;if(c>>>0<16){break b}j[a+4>>2]=g&1|b|2;b=a+b|0;j[b+4>>2]=c|3;j[f+4>>2]=j[f+4>>2]|1;fq(b,c);break b}if(j[115942]==(f|0)){d=d+j[115939]|0;if(d>>>0<=b>>>0){break a}j[a+4>>2]=g&1|b|2;c=a+b|0;b=d-b|0;j[c+4>>2]=b|1;j[115939]=b;j[115942]=c;break b}if(j[115941]==(f|0)){d=d+j[115938]|0;if(d>>>0<b>>>0){break a}c=d-b|0;c:{if(c>>>0>=16){j[a+4>>2]=g&1|b|2;b=a+b|0;j[b+4>>2]=c|1;d=a+d|0;j[d>>2]=c;j[d+4>>2]=j[d+4>>2]&-2;break c}j[a+4>>2]=d|g&1|2;b=a+d|0;j[b+4>>2]=j[b+4>>2]|1;c=0;b=0}j[115941]=b;j[115938]=c;break b}e=j[f+4>>2];if(e&2){break a}h=d+(e&-8)|0;if(h>>>0<b>>>0){break a}k=h-b|0;d:{if(e>>>0<=255){c=j[f+8>>2];e=e>>>3|0;d=j[f+12>>2];if((d|0)==(c|0)){m=463744,n=j[115936]&TMa(-2,e),j[m>>2]=n;break d}j[c+12>>2]=d;j[d+8>>2]=c;break d}i=j[f+24>>2];d=j[f+12>>2];e:{if((f|0)!=(d|0)){c=j[f+8>>2];j[c+12>>2]=d;j[d+8>>2]=c;break e}f:{c=f+20|0;e=j[c>>2];if(e){break f}c=f+16|0;e=j[c>>2];if(e){break f}d=0;break e}while(1){l=c;d=e;c=d+20|0;e=j[c>>2];if(e){continue}c=d+16|0;e=j[d+16>>2];if(e){continue}break}j[l>>2]=0}if(!i){break d}c=j[f+28>>2];e=(c<<2)+464048|0;g:{if(j[e>>2]==(f|0)){j[e>>2]=d;if(d){break g}m=463748,n=j[115937]&TMa(-2,c),j[m>>2]=n;break d}j[i+(j[i+16>>2]==(f|0)?16:20)>>2]=d;if(!d){break d}}j[d+24>>2]=i;c=j[f+16>>2];if(c){j[d+16>>2]=c;j[c+24>>2]=d}c=j[f+20>>2];if(!c){break d}j[d+20>>2]=c;j[c+24>>2]=d}if(k>>>0<=15){j[a+4>>2]=g&1|h|2;b=a+h|0;j[b+4>>2]=j[b+4>>2]|1;break b}j[a+4>>2]=g&1|b|2;b=a+b|0;j[b+4>>2]=k|3;c=a+h|0;j[c+4>>2]=j[c+4>>2]|1;fq(b,k)}c=a}return c}function L$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,l=0,n=0,o=0;a=Za-624|0;Za=a;j[a+608>>2]=c;j[a+616>>2]=b;j[a+16>>2]=2474;b=yd(a+200|0,a+208|0,a+16|0);j[114626]=0;hc(a+192|0,e);i=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((i|0)!=1){j[114626]=0;i=H(2441,a+192|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break j}h[a+191|0]=0;e=j[e+4>>2];j[114626]=0;c=ha(2485,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,i|0,b|0,a+196|0,a+608|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}if(!c){break f}c=k[62443]|k[62444]<<8|(k[62445]<<16|k[62446]<<24);h[a+183|0]=c;h[a+184|0]=c>>>8;h[a+185|0]=c>>>16;h[a+186|0]=c>>>24;c=k[62440]|k[62441]<<8|(k[62442]<<16|k[62443]<<24);j[a+176>>2]=k[62436]|k[62437]<<8|(k[62438]<<16|k[62439]<<24);j[a+180>>2]=c;j[114626]=0;P(2455,i|0,a+176|0,a+186|0,a+128|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break i}j[a+4>>2]=2412;d=yd(a+8|0,0,a+4|0);c=a+16|0;if((j[a+196>>2]-j[b>>2]|0)<393){break g}fe(d,_c((j[a+196>>2]-j[b>>2]>>2)+2|0));if(j[d>>2]){break h}j[114626]=0;M(2413);c=j[114626];j[114626]=0;if((c|0)==1){break d}break a}e=D()|0;C()|0;break b}e=D()|0;C()|0;break c}e=D()|0;C()|0;break c}c=j[d>>2]}if(k[a+191|0]){h[c|0]=45;c=c+1|0}e=j[b>>2];while(1){if(m[a+196>>2]<=e>>>0){h[c|0]=0;j[a>>2]=g;if((vD(a+16|0,a)|0)!=1){j[114626]=0;N(2476,62420);c=j[114626];j[114626]=0;if((c|0)!=1){break a}break d}mc(d)}else{n=c,o=k[(a+176|0)+(Tu(a+128|0,a+168|0,e)-(a+128|0)>>2)|0],h[n|0]=o;c=c+1|0;e=e+4|0;continue}break}}j[114626]=0;c=E(2447,a+616|0,a+608|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}if(c){j[f>>2]=j[f>>2]|2}c=j[a+616>>2];wb(a+192|0);mc(b);Za=a+624|0;return c|0}e=D()|0;C()|0;break c}e=D()|0;C()|0;mc(d)}wb(a+192|0)}mc(b);G(e|0);z()}z()}function i1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=Za-352|0;Za=a;j[a+336>>2]=c;j[a+344>>2]=b;h=Db(a+208|0);j[114626]=0;hc(a+16|0,d);b=j[114626];j[114626]=0;a:{b:{c:{d:{if((b|0)!=1){j[114626]=0;b=H(2441,a+16|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break d}j[114626]=0;P(2455,b|0,62160,62186,a+224|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}wb(a+16|0);c=Db(a+192|0);b=sc(c);j[114626]=0;F(149,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}b=Ub(c,0);j[a+188>>2]=b;j[a+12>>2]=a+16;j[a+8>>2]=0;while(1){e:{j[114626]=0;d=E(2446,a+344|0,a+336|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break e}if(!d){break c}if(j[a+188>>2]==(nb(c)+b|0)){d=nb(c);b=nb(c);j[114626]=0;F(149,c|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break b}b=sc(c);j[114626]=0;F(149,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}b=Ub(c,0);j[a+188>>2]=d+b}j[114626]=0;d=H(2448,a+344|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break e}j[114626]=0;d=wj(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=j[114626];j[114626]=0;if((g|0)==1){break e}if(d){break c}j[114626]=0;H(2450,a+344|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){continue}}break}break b}b=D()|0;C()|0;break a}b=D()|0;C()|0;wb(a+16|0);break a}j[114626]=0;F(149,c|0,j[a+188>>2]-b|0);b=j[114626];j[114626]=0;f:{if((b|0)==1){break f}b=zb(c);j[114626]=0;d=T(2437)|0;g=j[114626];j[114626]=0;if((g|0)==1){break f}j[a>>2]=f;j[114626]=0;b=P(2438,b|0,d|0,62193,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}if((b|0)!=1){j[e>>2]=4}j[114626]=0;b=E(2447,a+344|0,a+336|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}if(b){j[e>>2]=j[e>>2]|2}b=j[a+344>>2];gb(c);gb(h);Za=a+352|0;return b|0}}b=D()|0;C()|0;gb(c)}gb(h);G(b|0);z()}function uq(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=Za-128|0;Za=l;j[l+120>>2]=b;n=us(c,d);j[l+4>>2]=2412;p=yd(l+8|0,0,l+4|0);m=l+16|0;a:{b:{if(n>>>0>=101){m=_c(n);if(!m){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;break b}fe(p,m)}i=m;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{j[114626]=0;i=E(2446,a|0,l+120|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}if(!(i&(n|0)!=0)){j[114626]=0;b=E(2447,a|0,l+120|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}if(!b){break d}j[f>>2]=j[f>>2]|2;break d}j[114626]=0;q=H(2448,a|0)|0;b=j[114626];j[114626]=0;g:{if((b|0)!=1){if(g){break g}j[114626]=0;q=E(2449,e|0,q|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break g}}b=D()|0;C()|0;break b}r=t+1|0;u=0;i=m;b=c;while(1){if((b|0)==(d|0)){t=r;if(!u){continue e}j[114626]=0;H(2450,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){i=m;b=c;if(n+o>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(k[i|0]!=2){break h}if((nb(b)|0)==(r|0)){break h}h[i|0]=0;o=o-1|0}i=i+1|0;b=b+12|0;continue}}b=D()|0;C()|0;break b}i:{if(k[i|0]!=1){break i}s=j[Li(b,t)>>2];j:{if(g){break j}j[114626]=0;s=E(2449,e|0,s|0)|0;v=j[114626];j[114626]=0;if((v|0)!=1){break j}b=D()|0;C()|0;break b}k:{if((q|0)==(s|0)){u=1;if((nb(b)|0)!=(r|0)){break i}h[i|0]=2;o=o+1|0;break k}h[i|0]=0}n=n-1|0}i=i+1|0;b=b+12|0;continue}}break}b=D()|0;C()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(k[m|0]!=2){m=m+1|0;c=c+12|0;continue}break}d=c;break l}j[f>>2]=j[f>>2]|4}mc(p);Za=l+128|0;return d|0}b=D()|0;C()|0}else{n:{if(!Ec(b)){h[i|0]=1;break n}h[i|0]=2;o=o+1|0;n=n-1|0}i=i+1|0;b=b+12|0;continue}break}}mc(p);G(b|0)}z()}function Mua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=Za-48|0;Za=f;v=j[a+16>>2];e=j[a+44>>2];j[f+32>>2]=e;k=j[a+48>>2];j[f+36>>2]=k;n=j[a+52>>2];j[f+40>>2]=n;o=j[a+56>>2];j[f+44>>2]=o;w=j[a+24>>2];x=j[a+20>>2];g=j[a+4>>2];l=j[a>>2];j[f+24>>2]=l;j[f+28>>2]=g;h=j[a+12>>2];j[f+16>>2]=j[a+8>>2];j[f+20>>2]=h;if(d){while(1){o=1;h=((((g&2147483647)<<1|l>>>31)&2147483646)<<1)+v|0;e=(((l>>>16|0)+4&131064)<<1)+b|0;l=i[e+38>>1];m=i[e+36>>1];r=i[e+34>>1];s=i[e+32>>1];t=i[e+30>>1];q=i[e+28>>1];u=i[e+26>>1];y=i[e+24>>1];n=0;e=1;k=0;while(1){g=k<<1;j[(f+8|0)+(k<<2)>>2]=(((((p(i[h+(g|8)>>1],r)+p(i[h+(g|4)>>1],s)|0)+p(i[h+(g|12)>>1],m)|0)+p(l,i[h+(g|16)>>1])|0)/2|0)+((((p(i[h+(g|-8)>>1],u)+p(i[h+(g|-12)>>1],y)|0)+p(i[h+(g|-4)>>1],q)|0)+p(i[h+g>>1],t)|0)/2|0)|0)/16384;g=e;e=0;k=1;if(g){continue}break}while(1){k=(f+8|0)+(n<<2)|0;l=j[k>>2];m=j[a+60>>2];r=m;g=(f+32|0)+(n<<3)|0;n=j[g>>2];e=Gb(n,-16777216,16776704);s=j[a+64>>2];h=Gb(j[g+4>>2],-16777216,16776704);q=j[a+68>>2];u=q;q=q>>31;j[g+4>>2]=n;n=j[a+72>>2];m=m>>31;l=l<<8;m=OMa(r,m,l,l>>31);r=ab;t=k;k=m;m=OMa(s,s>>31,e,e>>31);k=k+m|0;e=ab+r|0;e=k>>>0<m>>>0?e+1|0:e;m=k;k=OMa(u,q,h,h>>31);h=m+k|0;e=ab+e|0;e=h>>>0<k>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|h>>>24;j[t>>2]=(e|0)/256;j[g>>2]=e-(l&n);n=1;e=o&1;o=0;if(e){continue}break}j[c>>2]=j[c>>2]+p(j[f+8>>2],x);j[c+4>>2]=j[c+4>>2]+p(j[f+12>>2],w);Bb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;l=j[f+24>>2];g=j[f+28>>2];continue}break}l=j[f+24>>2];g=j[f+28>>2];o=j[f+44>>2];n=j[f+40>>2];k=j[f+36>>2];e=j[f+32>>2]}j[a+56>>2]=o;j[a+52>>2]=n;j[a+48>>2]=k;j[a+44>>2]=e;j[a>>2]=l;j[a+4>>2]=g;Za=f+48|0}function E1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=Za-272|0;Za=a;j[a+256>>2]=c;j[a+264>>2]=b;h=Db(a+208|0);j[114626]=0;hc(a+16|0,d);b=j[114626];j[114626]=0;a:{b:{c:{d:{if((b|0)!=1){j[114626]=0;b=H(21,a+16|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break d}j[114626]=0;P(2432,b|0,62160,62186,a+224|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}wb(a+16|0);c=Db(a+192|0);b=sc(c);j[114626]=0;F(149,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}b=Ub(c,0);j[a+188>>2]=b;j[a+12>>2]=a+16;j[a+8>>2]=0;while(1){e:{j[114626]=0;d=E(2414,a+264|0,a+256|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break e}if(!d){break c}if(j[a+188>>2]==(nb(c)+b|0)){d=nb(c);b=nb(c);j[114626]=0;F(149,c|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break b}b=sc(c);j[114626]=0;F(149,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}b=Ub(c,0);j[a+188>>2]=d+b}j[114626]=0;d=H(2416,a+264|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break e}j[114626]=0;d=xj(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=j[114626];j[114626]=0;if((g|0)==1){break e}if(d){break c}j[114626]=0;H(2418,a+264|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){continue}}break}break b}b=D()|0;C()|0;break a}b=D()|0;C()|0;wb(a+16|0);break a}j[114626]=0;F(149,c|0,j[a+188>>2]-b|0);b=j[114626];j[114626]=0;f:{if((b|0)==1){break f}b=zb(c);j[114626]=0;d=T(2437)|0;g=j[114626];j[114626]=0;if((g|0)==1){break f}j[a>>2]=f;j[114626]=0;b=P(2438,b|0,d|0,62193,a|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}if((b|0)!=1){j[e>>2]=4}j[114626]=0;b=E(2415,a+264|0,a+256|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}if(b){j[e>>2]=j[e>>2]|2}b=j[a+264>>2];gb(c);gb(h);Za=a+272|0;return b|0}}b=D()|0;C()|0;gb(c)}gb(h);G(b|0);z()}function U$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,l=0,n=0,o=0;a=Za-288|0;Za=a;j[a+272>>2]=c;j[a+280>>2]=b;j[a+16>>2]=2474;b=yd(a+152|0,a+160|0,a+16|0);j[114626]=0;hc(a+144|0,e);i=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((i|0)!=1){j[114626]=0;i=H(21,a+144|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break j}h[a+143|0]=0;e=j[e+4>>2];j[114626]=0;c=ha(2475,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,i|0,b|0,a+148|0,a+260|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}if(!c){break f}c=k[62443]|k[62444]<<8|(k[62445]<<16|k[62446]<<24);h[a+135|0]=c;h[a+136|0]=c>>>8;h[a+137|0]=c>>>16;h[a+138|0]=c>>>24;c=k[62440]|k[62441]<<8|(k[62442]<<16|k[62443]<<24);j[a+128>>2]=k[62436]|k[62437]<<8|(k[62438]<<16|k[62439]<<24);j[a+132>>2]=c;j[114626]=0;P(2432,i|0,a+128|0,a+138|0,a+118|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break i}j[a+4>>2]=2412;d=yd(a+8|0,0,a+4|0);c=a+16|0;if((j[a+148>>2]-j[b>>2]|0)<99){break g}fe(d,_c((j[a+148>>2]-j[b>>2]|0)+2|0));if(j[d>>2]){break h}j[114626]=0;M(2413);c=j[114626];j[114626]=0;if((c|0)==1){break d}break a}e=D()|0;C()|0;break b}e=D()|0;C()|0;break c}e=D()|0;C()|0;break c}c=j[d>>2]}if(k[a+143|0]){h[c|0]=45;c=c+1|0}e=j[b>>2];while(1){if(m[a+148>>2]<=e>>>0){h[c|0]=0;j[a>>2]=g;if((vD(a+16|0,a)|0)!=1){j[114626]=0;N(2476,62420);c=j[114626];j[114626]=0;if((c|0)!=1){break a}break d}mc(d)}else{n=c,o=k[((xm(a+118|0,a+128|0,e)-a|0)+a|0)+10|0],h[n|0]=o;c=c+1|0;e=e+1|0;continue}break}}j[114626]=0;c=E(2415,a+280|0,a+272|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}if(c){j[f>>2]=j[f>>2]|2}c=j[a+280>>2];wb(a+144|0);mc(b);Za=a+288|0;return c|0}e=D()|0;C()|0;break c}e=D()|0;C()|0;mc(d)}wb(a+144|0)}mc(b);G(e|0);z()}z()}function ava(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=Za-16|0;Za=l;a:{b:{c:{m=j[a+8>>2];g=j[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?m>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?m>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?m>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?m>>>0>2147483648:0){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}v=j[a+16>>2];f=j[a+48>>2];o=j[a+40>>2];q=j[a+36>>2];e=j[a+44>>2];k=j[a+4>>2];n=j[a>>2];j[l+8>>2]=n;j[l+12>>2]=k;j[l>>2]=m;j[l+4>>2]=g;e:{if(!d){g=o>>12;m=q>>12;break e}while(1){b=k+v|0;g=h[b+4|0];k=(n>>>16&65520)+s|0;n=i[k+14>>1];m=h[b+3|0];w=i[k+12>>1];x=h[b+2|0];y=i[k+10>>1];z=h[b+1|0];A=i[k+8>>1];B=h[b|0];C=i[k+6>>1];D=h[b-1|0];E=i[k+4>>1];F=h[b-2|0];G=i[k+2>>1];H=h[b-3|0];I=i[k>>1];b=j[a+60>>2];J=b;K=b>>31;b=e;e=Gb(e,-16777216,16776704);r=j[a+64>>2];f=Gb(f,-16777216,16776704);L=j[a+72>>2];M=j[a+32>>2];k=c;N=j[k>>2];e=OMa(r,r>>31,e,e>>31);r=ab;t=e;e=j[a+68>>2];u=OMa(e,e>>31,f,f>>31);e=t+u|0;f=ab+r|0;f=e>>>0<u>>>0?f+1|0:f;t=e;n=(((((((p(F,G)+p(H,I)|0)+p(D,E)|0)+p(B,C)|0)+p(z,A)|0)+p(x,y)|0)+p(m,w)|0)+p(g,n)<<8)/32768<<8;e=n;g=OMa(J,K,e,e>>31);e=t+g|0;f=ab+f|0;f=e>>>0<g>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;q=j[a+28>>2]+q|0;m=q>>12;j[k>>2]=p(f,m)+N;o=o+M|0;g=o>>12;j[c+4>>2]=j[c+4>>2]+p(f,g);e=e-(n&L)|0;Bb(l+8|0,l);d=d-1|0;if(d){c=c+8|0;n=j[l+8>>2];k=j[l+12>>2];f=b;continue}break}n=j[l+8>>2];k=j[l+12>>2];f=b}j[a+40>>2]=o;j[a+20>>2]=m;j[a+36>>2]=q;j[a+48>>2]=f;j[a+44>>2]=e;j[a+24>>2]=g;j[a>>2]=n;j[a+4>>2]=k;Za=l+16|0}function $ua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;k=Za-16|0;Za=k;a:{b:{c:{l=j[a+8>>2];g=j[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?l>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?l>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?l>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?l>>>0>2147483648:0){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}v=j[a+16>>2];e=j[a+48>>2];n=j[a+40>>2];o=j[a+36>>2];m=j[a+44>>2];h=j[a+4>>2];f=j[a>>2];j[k+8>>2]=f;j[k+12>>2]=h;j[k>>2]=l;j[k+4>>2]=g;e:{if(!d){g=n>>12;l=o>>12;break e}while(1){b=(f>>>16&65520)+s|0;g=i[b>>1];h=(h<<1)+v|0;l=i[h-6>>1];q=i[b+2>>1];w=i[h-4>>1];x=i[b+4>>1];y=i[h-2>>1];z=i[b+6>>1];A=i[h>>1];B=i[b+8>>1];C=i[h+2>>1];D=i[b+10>>1];E=i[h+4>>1];F=i[b+12>>1];G=i[h+6>>1];H=i[b+14>>1];I=i[h+8>>1];u=j[a+60>>2];b=m;f=Gb(b,-16777216,16776704);r=j[a+64>>2];m=Gb(e,-16777216,16776704);J=j[a+72>>2];K=j[a+32>>2];h=c;L=j[h>>2];e=OMa(r,r>>31,f,f>>31);r=ab;t=e;q=(((((((p(q,w)+p(g,l)|0)+p(x,y)|0)+p(z,A)|0)+p(B,C)|0)+p(D,E)|0)+p(F,G)|0)+p(H,I)|0)/32768<<8;e=q;g=OMa(u,u>>31,e,e>>31);f=t+g|0;e=ab+r|0;e=f>>>0<g>>>0?e+1|0:e;t=f;f=j[a+68>>2];m=OMa(f,f>>31,m,m>>31);f=t+m|0;e=ab+e|0;e=f>>>0<m>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;o=j[a+28>>2]+o|0;l=o>>12;j[h>>2]=p(e,l)+L;n=n+K|0;g=n>>12;j[c+4>>2]=j[c+4>>2]+p(e,g);m=f-(q&J)|0;Bb(k+8|0,k);d=d-1|0;if(d){c=c+8|0;f=j[k+8>>2];h=j[k+12>>2];e=b;continue}break}f=j[k+8>>2];h=j[k+12>>2];e=b}j[a+40>>2]=n;j[a+20>>2]=l;j[a+36>>2]=o;j[a+48>>2]=e;j[a+44>>2]=m;j[a+24>>2]=g;j[a>>2]=f;j[a+4>>2]=h;Za=k+16|0}function Nua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=Za-48|0;Za=f;w=j[a+16>>2];g=j[a+44>>2];j[f+32>>2]=g;e=j[a+48>>2];j[f+36>>2]=e;n=j[a+52>>2];j[f+40>>2]=n;q=j[a+56>>2];j[f+44>>2]=q;x=j[a+24>>2];y=j[a+20>>2];o=j[a+4>>2];l=j[a>>2];j[f+24>>2]=l;j[f+28>>2]=o;k=j[a+12>>2];j[f+16>>2]=j[a+8>>2];j[f+20>>2]=k;if(d){while(1){k=(((o&2147483647)<<1|l>>>31)&-2)+w|0;q=1;e=(((l>>>16|0)+4&131064)<<1)+b|0;l=i[e+38>>1];m=i[e+36>>1];s=i[e+34>>1];t=i[e+32>>1];u=i[e+30>>1];r=i[e+28>>1];v=i[e+26>>1];z=i[e+24>>1];n=0;e=1;g=0;while(1){j[(f+8|0)+(g<<2)>>2]=(((((p(h[k+(g|4)|0],s)+p(h[k+(g|2)|0],t)|0)+p(h[k+(g|6)|0],m)|0)+p(l,h[k+(g|8)|0])<<8)/2|0)+((((p(h[k+(g|-4)|0],v)+p(h[k+(g|-6)|0],z)|0)+p(h[k+(g|-2)|0],r)|0)+p(h[g+k|0],u)<<8)/2|0)|0)/16384;o=e;e=0;g=1;if(o){continue}break}while(1){k=(f+8|0)+(n<<2)|0;l=j[k>>2];m=j[a+60>>2];s=m;o=(f+32|0)+(n<<3)|0;n=j[o>>2];e=Gb(n,-16777216,16776704);t=j[a+64>>2];g=Gb(j[o+4>>2],-16777216,16776704);r=j[a+68>>2];v=r;r=r>>31;j[o+4>>2]=n;n=j[a+72>>2];m=m>>31;l=l<<8;m=OMa(s,m,l,l>>31);s=ab;u=k;k=m;m=OMa(t,t>>31,e,e>>31);k=k+m|0;e=ab+s|0;e=k>>>0<m>>>0?e+1|0:e;m=k;k=OMa(v,r,g,g>>31);g=m+k|0;e=ab+e|0;e=g>>>0<k>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;j[u>>2]=(e|0)/256;j[o>>2]=e-(l&n);n=1;e=q&1;q=0;if(e){continue}break}j[c>>2]=j[c>>2]+p(j[f+8>>2],y);j[c+4>>2]=j[c+4>>2]+p(j[f+12>>2],x);Bb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;l=j[f+24>>2];o=j[f+28>>2];continue}break}l=j[f+24>>2];o=j[f+28>>2];q=j[f+44>>2];n=j[f+40>>2];g=j[f+32>>2];e=j[f+36>>2]}j[a+56>>2]=q;j[a+52>>2]=n;j[a+48>>2]=e;j[a+44>>2]=g;j[a>>2]=l;j[a+4>>2]=o;Za=f+48|0}function Daa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Za-128|0;Za=e;a:{if(Ec(b)){break a}f=k[pG(b)|0];g=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}g=0}d=g;Uq(e+112|0,b,0,nb(b)-1|0);ob(b,e+112|0);gb(e+112|0)}ld(e+112|0);f=j[e+112>>2];ld(e+96|0);f=oG(f,j[e+100>>2],b);ld(e+112|0);c:{d:{e:{f:{if((f|0)==j[e+116>>2]){if(Dd(b,38235)){a=R(8)|0;j[114626]=0;I(2128,e+112|0,39300,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break e}Wb(a,e+112|0);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}b=D()|0;C()|0;gb(e+112|0);break d}if(!d){break f}a=R(8)|0;j[114626]=0;I(2128,e+80|0,39179,b|0);b=j[114626];j[114626]=0;g:{h:{i:{j:{k:{if((b|0)!=1){j[114626]=0;I(2129,e+96|0,e+80|0,39315);b=j[114626];j[114626]=0;if((b|0)==1){break k}j[114626]=0;I(800,e+112|0,e+96|0,c|0);b=j[114626];j[114626]=0;c=1;if((b|0)==1){break j}Wb(a,e+112|0);j[114626]=0;I(2002,a|0,83632,2010);b=j[114626];j[114626]=0;if((b|0)!=1){break c}b=D()|0;C()|0;gb(e+112|0);c=0;break i}b=D()|0;C()|0;break g}b=D()|0;c=1;C()|0;break h}b=D()|0;C()|0}gb(e+96|0)}gb(e+80|0);if(!c){break d}}S(a|0);break d}l:{switch(j[f+4>>2]){case 0:oh(e+72|0,b);b=(ZF(c)|0)!=0;c=j[e+76>>2];j[e>>2]=j[e+72>>2];j[e+4>>2]=c;nG(a,e,b,d);break f;case 1:oh(e- -64|0,b);b=S8(c);c=j[e+68>>2];j[e+8>>2]=j[e+64>>2];j[e+12>>2]=c;mG(a,e+8|0,b,ab,d);break f;case 2:oh(e+56|0,b);h=H8(c);b=j[e+60>>2];j[e+16>>2]=j[e+56>>2];j[e+20>>2]=b;lG(a,e+16|0,h,d);break f;case 3:break l;default:break f}}oh(e+48|0,b);oh(e+40|0,c);b=j[e+52>>2];j[e+32>>2]=j[e+48>>2];j[e+36>>2]=b;b=j[e+44>>2];j[e+24>>2]=j[e+40>>2];j[e+28>>2]=b;kG(a,e+32|0,e+24|0,d)}Za=e+128|0;return}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function ova(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Za-48|0;Za=b;v=j[a+16>>2];h=j[a+44>>2];j[b+32>>2]=h;n=j[a+48>>2];j[b+36>>2]=n;k=j[a+52>>2];j[b+40>>2]=k;g=j[a+56>>2];j[b+44>>2]=g;r=j[a+40>>2];s=j[a+36>>2];e=j[a+4>>2];l=j[a>>2];j[b+24>>2]=l;j[b+28>>2]=e;f=j[a+12>>2];j[b+16>>2]=j[a+8>>2];j[b+20>>2]=f;a:{if(!d){m=r>>12;f=s>>12;break a}while(1){n=1;e=((((e&2147483647)<<1|l>>>31)&2147483646)<<1)+v|0;h=(l>>>21&2040)+27888|0;l=i[h+6>>1];g=i[h+4>>1];m=i[h+2>>1];o=i[h>>1];h=0;k=1;f=0;while(1){q=(b+8|0)+(f<<2)|0;f=f<<1;j[q>>2]=(((p(i[f+e>>1],m)+p(i[e+(f|-4)>>1],o)|0)+p(g,i[e+(f|4)>>1])|0)+p(l,i[e+(f|8)>>1])|0)/16384;t=k&1;k=0;f=1;if(t){continue}break}while(1){k=(b+8|0)+(h<<2)|0;l=j[k>>2];g=j[a+60>>2];m=g;h=(b+32|0)+(h<<3)|0;o=j[h>>2];e=Gb(o,-16777216,16776704);t=j[a+64>>2];f=Gb(j[h+4>>2],-16777216,16776704);q=j[a+68>>2];w=q;q=q>>31;j[h+4>>2]=o;o=j[a+72>>2];u=g>>31;l=l<<8;g=l;g=OMa(m,u,g,g>>31);m=ab;u=k;k=g;g=OMa(t,t>>31,e,e>>31);k=k+g|0;e=ab+m|0;e=k>>>0<g>>>0?e+1|0:e;g=k;k=OMa(w,q,f,f>>31);f=g+k|0;e=ab+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;j[u>>2]=(e|0)/256;j[h>>2]=e-(l&o);h=1;e=n&1;n=0;if(e){continue}break}e=j[a+32>>2];s=j[a+28>>2]+s|0;f=s>>12;j[c>>2]=j[c>>2]+p(f,j[b+8>>2]);r=e+r|0;m=r>>12;j[c+4>>2]=j[c+4>>2]+p(m,j[b+12>>2]);Bb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;l=j[b+24>>2];e=j[b+28>>2];continue}break}l=j[b+24>>2];e=j[b+28>>2];g=j[b+44>>2];k=j[b+40>>2];n=j[b+36>>2];h=j[b+32>>2]}j[a+40>>2]=r;j[a+20>>2]=f;j[a+36>>2]=s;j[a+56>>2]=g;j[a+52>>2]=k;j[a+48>>2]=n;j[a+44>>2]=h;j[a+24>>2]=m;j[a>>2]=l;j[a+4>>2]=e;Za=b+48|0}function Kw(a,b,c){var d=0,e=0,f=0,g=0,i=0,j=0,l=0;f=Za-16|0;Za=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=k[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}h[a|0]=1;h[f+15|0]=64;j=b,l=k[Yb(b,f+15|0)|0],h[j|0]=l;break a}d=k[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}h[b|0]=(d&252)>>>2;h[a|0]=12;e=1;break a}d=k[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}h[b|0]=(d&252)>>>2;h[a|0]=13;e=1;break a}g=k[b|0];if(g>>>0<240){d=0;while(1){i=k[d+20832|0];m:{n:{if(c){if(g>>>0<=i>>>0){break n}break m}if((g|0)!=(i|0)){break m}}h[a|0]=11;h[b|0]=d;break a}e=d>>>0<9;d=d+1|0;if((d|0)!=10){continue}break}break a}h[a|0]=11;h[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=k[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}h[b|0]=0;h[a|0]=0;e=1;break a}h[a|0]=2;h[b|0]=k[b|0]<<2&60|2;e=1;break a}e=0;c=k[b|0];if(!c){break a}d=c&15;if(!d){h[b|0]=c>>>4;h[a|0]=3;e=1;break a}g=c&240;if(!g){h[a|0]=4;e=1;break a}if((d|0)==15){h[b|0]=c>>>4;h[a|0]=5;e=1;break a}if((g|0)!=240){break a}h[b|0]=d;h[a|0]=6;e=1;break a}c=b;b=k[b|0];h[c|0]=(b|0)==255?64:b>>>2|0;h[a|0]=2;break a}r:{if(c){h[b|0]=0;break r}e=0;if(k[b|0]){break a}}h[a|0]=8;e=1;break a}s:{if(c){h[f+14|0]=k[b|0]&15;h[f+13|0]=9;d=k[Yb(f+14|0,f+13|0)|0];break s}e=0;d=k[b|0];if((d&14)>>>0>9|d&240){break a}}h[b|0]=d&15;h[a|0]=8;e=1}Za=f+16|0;return e}function g9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Za+ -64|0;Za=c;f=Mg(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(Qh(b)){eo(c+56|0);break n}j[114626]=0;F(2181,c+40|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break m}j[114626]=0;F(2167,c+56|0,c+40|0);a=j[114626];j[114626]=0;if((a|0)==1){break l}Ye(c+40|0)}a=b+36|0;o:{if(Qh(b)){break o}a=j[c+56>>2]}e=pd(a);j[114626]=0;F(1525,f|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break k}h=c,i=Lb(a),j[h+32>>2]=i;h=c,i=Mb(a),j[h+24>>2]=i;if(rb(c+32|0,c+24|0)){a=b+24|0;while(1){e=j[c+32>>2];b=gi(j[a>>2]+484360|0,k[e+16|0]);j[114626]=0;F(2182,c+8|0,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break j}j[114626]=0;I(9,c+40|0,0,c+8|0);d=j[114626];j[114626]=0;if((d|0)==1){break i}j[114626]=0;F(1527,f|0,c+40|0);d=j[114626];j[114626]=0;if((d|0)==1){break h}gb(c+40|0);gb(c+8|0);p:{if(!Ec(VF(f))){break p}d=k[e+12|0];j[114626]=0;d=E(546,b|0,d|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!d){break p}d=j[a>>2];j[114626]=0;d=H(686,d|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break f}b=Ib(j[a>>2]+484344|0,l[ac(b,j[e+12>>2])>>1]);j[114626]=0;F(2183,c+8|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;L(438,c+40|0,0,d|0,c+8|0);b=j[114626];j[114626]=0;if((b|0)==1){break d}ob(VF(f),c+40|0);gb(c+40|0);gb(c+8|0)}fk(c+32|0);if(rb(c+32|0,c+24|0)){continue}break}}Gj(c+56|0);Za=c- -64|0;return}b=D()|0;C()|0;break a}b=D()|0;C()|0;Ye(c+40|0);break a}b=D()|0;C()|0;break b}b=D()|0;C()|0;break b}b=D()|0;C()|0;break g}b=D()|0;C()|0;gb(c+40|0)}gb(c+8|0);break b}b=D()|0;C()|0;break b}b=D()|0;C()|0;break b}b=D()|0;C()|0;gb(c+8|0);break b}b=D()|0;C()|0}Gj(c+56|0)}Uc(f);G(b|0);z()}function Moa(a,b,c){var d=0,e=0,f=0,g=0,i=0;d=c&15;f=p(b,896)+a|0;e=f+1074984|0;a:{b:{switch(c>>>4|0){case 0:if(!l[a+480188>>1]){break a}b=(c&1)<<14;c=0;while(1){d=(p(c,896)+a|0)+1075072|0;j[d>>2]=(b|j[d>>2]&-16385)^16384;c=c+1|0;if(c>>>0<l[a+480188>>1]){continue}break}break a;case 1:if(j[a+480180>>2]&1048580?0:!d){break a}fK(a,e,d);return;case 2:if(j[a+480180>>2]&1048580?0:!d){break a}dK(a,e,d);return;case 3:a=f+1075072|0;j[a>>2]=j[a>>2]&-1048577|((d|0)!=0)<<20;return;case 4:h[f+1075826|0]=c&7;return;case 5:if(!(k[a+480209|0]&16)){break a}if(j[a+480180>>2]&69206025){c=p(b,896)+a|0;e=c+1075752|0;j[e>>2]=d<<28>>24;d=c+1075684|0;if(!j[d>>2]){break a}if(!Lf(c+1075794|0)){break a}c=a;a=p(b,896)+a|0;g=d,i=Zf(c,k[a+1075803|0],j[e>>2],j[a+1075688>>2]),j[g>>2]=i;return}f=j[a+480180>>2];e=Lf((p(b,896)+a|0)+1075794|0);if((f|0)==16){if(!e){break a}c=p(b,896)+a|0;e=j[c+1075088>>2];if(!e){break a}h[e+37|0]=d;j[c+1075752>>2]=d;c=c+1075684|0;if(!j[c>>2]){break a}e=a;a=p(b,896)+a|0;g=c,i=Zf(e,k[a+1075803|0],d,j[a+1075688>>2]),j[g>>2]=i;return}if(!e){break a}b=p(b,896)+a|0;c=c<<28>>24^-128;j[b+1075752>>2]=c;d=b+1075684|0;if(!j[d>>2]){break a}g=d,i=Zf(a,k[b+1075803|0],c,j[b+1075688>>2]),j[g>>2]=i;return;case 7:h[f+1075829|0]=c&7;return;case 8:if(!(k[a+480209|0]&16)){break a}$k(a,e,d,4);return;case 9:sx(a,b,d,0);return;case 10:if(j[a+480180>>2]&1048580?0:!d){break a}Do(a,e,d,0);return;case 11:if(j[a+480180>>2]&1048580?0:!d){break a}Co(a,e,d,0);return;case 12:ux(a,b,d,0);return;case 15:break b;default:break a}}if(j[a+480180>>2]==1){h[(p(b,896)+a|0)+1075850|0]=d;if(!(k[a+480209|0]&16)){break a}qK(a,e);return}h[(p(b,896)+a|0)+1075848|0]=d}}function _La(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,l=0,n=0;f=Za-16|0;Za=f;rc(c);a:{if(!yb(c,3)){break a}while(1){Ft(f+8|0,c);l=Pc(f+8|0);d=Bf(f+8|0);g=f+8|0;if(m[a+12>>2]<=k[g|0]){break a}e=Se(a,k[g|0],b);i=k[l|0];b:{if(i>>>0<=126){if(!(i|k[d|0])){h[e|0]=254;break b}h[e|0]=i+1;if(k[d|0]==255){break b}if(!k[e+1|0]){h[e+1|0]=n}h[e+2|0]=1;h[e+4|0]=k[d|0];break b}c:{switch(i-127|0){case 0:d=k[g|0]+h[d|0]|0;if((d|0)<0|(d|0)>=j[a+12>>2]<<16>>16){break b}d=Se(a,d,b);g=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);h[e|0]=g;h[e+1|0]=g>>>8;h[e+2|0]=g>>>16;h[e+3|0]=g>>>24;d=k[d+4|0]|k[d+5|0]<<8;h[e+4|0]=d;h[e+5|0]=d>>>8;break b;case 1:n=k[d|0]+1|0;h[e+1|0]=n;break b;default:break c}}d=h[d|0];h[f+7|0]=d;g=0;i=i&127;if(i>>>0<=23){g=k[i+12144|0]}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{i=k[l|0];switch((i&127)-2|0){case 21:break g;case 18:break h;case 17:break i;case 16:case 20:break j;case 15:break k;case 2:break l;case 1:break m;case 0:case 8:case 9:break n;default:break e}}if((d|0)>-1){break f}d=0-d&15;break e}h[f+6|0]=64;d=k[Yb(f+7|0,f+6|0)|0];if(k[e+2|0]>1){break e}h[e+4|0]=d;h[e+2|0]=1;break b}if((d|0)>-1){g=3;break d}d=0-d&127;h[f+7|0]=d;break e}if(!d){break b}if((d|0)<=-1){d=0-d|-16;h[f+7|0]=d;break e}d=d<<4|15;h[f+7|0]=d;break e}if(!d){break b}g=(d|0)>-1;if(!g){d=0-d&15;h[f+7|0]=d;i=k[l|0]}g=g?3:2;d=((i|0)==22?-32:-16)|d;h[f+7|0]=d;break d}d=d&15|-48;h[f+7|0]=d;break e}d=d&15|-64;h[f+7|0]=d;break e}d=d- -64&127;if(!k[e+3|0]){break e}o:{switch(k[e+2|0]){case 0:case 2:break o;default:break b}}h[e+2|0]=2;h[e+4|0]=d>>>1;break b}d=d<<4}if(!(g&255)){break b}}h[e+5|0]=d;h[e+3|0]=g}if(yb(c,3)){continue}break}}Za=f+16|0}function nMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=Za-384|0;Za=d;rc(b);f=d+344|0;g=OLa(b,f);if(!g){CS(f)}a:{b:{if(!g){break b}if(!WS(d+344|0)){break b}if(!yb(b,Wc(VS(d+344|0),ab))){break b}c:{if(!c){break c}od(a,2097152);_h(a);Oi(a,1);i[a+480188>>1]=8;j[a+480196>>2]=k[d+376|0];j[a+480204>>2]=p(k[d+377|0],1e4);i[a+480190>>1]=k[d+378|0];if(k[d+381|0]<k[d+380|0]){Ge(Fb(a+484360|0),k[d+381|0])}e=Eb(d+80|0,12002);ob(a+1304436|0,e);gb(e);e=Eb(d+80|0,12022);ob(a+1304448|0,e);gb(e);j[a+1304496>>2]=4;Yz(b,d+80|0);At(Fb(a+484360|0),d+80|0,k[d+380|0],65535,65535);if(l[a+480190>>1]){e=1;f=1;while(1){TS(b,d+40|0);mMa(d+40|0,(p(e,104)+a|0)+484380|0);on(d+8|0,2,d+40|0);qc(d+24|0,d+8|0);j[114626]=0;E(369,((e<<5)+a|0)+946300|0,d+24|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break a}gb(d+24|0);f=f+1|0;e=f&65535;if(e>>>0<=l[a+480190>>1]){continue}break}}Jb(b,p(64-k[d+378|0]|0,37));g=a+484344|0;If(g,k[d+379|0]);if(k[d+379|0]){n=c&1;f=0;while(1){d:{e:{if(n){if(Wf(g,f&65535,64)){break e}}Jb(b,2048);break d}e=Ib(g,f);s=d,t=Lb(e),j[s+40>>2]=t;s=d,t=Mb(e),j[s+24>>2]=t;if(!rb(d+40|0,d+24|0)){break d}while(1){e=j[d+40>>2];nn(d+8|0,b);o=Pc(d+8|0);q=Bf(d+8|0);r=pi(d+8|0);m=k[d+8|0];if((m-1&255)>>>0<=106){h[e|0]=m+13}h[e+1|0]=k[o|0];h[e+3|0]=k[q|0];h[e+5|0]=k[r|0];Yi(e);kk(d+40|0);if(rb(d+40|0,d+24|0)){continue}break}}f=f+1|0;if(f>>>0<k[d+379|0]){continue}break}}if(!(c&2)){break c}e=1;c=Mc(d+40|0,8,1,0,0);if(!l[a+480190>>1]){break c}while(1){$f(c,(p(e&65535,104)+a|0)+484380|0,b);e=e+1|0;if(l[a+480190>>1]>=(e&65535)>>>0){continue}break}}e=1}Za=d+384|0;return e|0}a=D()|0;C()|0;gb(d+24|0);G(a|0);z()}function O5(a,b){var c=0,d=q(0),e=q(0),f=0,g=q(0),h=q(0),i=q(0),j=0,k=0,l=0,m=0,o=q(0),r=q(0),s=0,t=q(0),u=q(0),v=q(0),w=q(0),x=q(0),y=q(0),z=q(0);j=Za-128|0;if((b|0)>=1){while(1){k=(s<<2)+a|0;f=0;c=j;l=c;while(1){r=n[p(31-f|0,72)+k>>2];m=p(f,72)+k|0;g=n[m>>2];h=q(r+g);e=n[m+1152>>2];d=n[p(15-f|0,72)+k>>2];i=q(e+d);n[l>>2]=h+i;m=p(f,12)+49040|0;g=q(n[m+4>>2]*q(g-r));e=q(n[m>>2]*q(d-e));n[l+64>>2]=g+e;d=n[m+8>>2];n[l+32>>2]=d*q(h-i);n[l+96>>2]=q(g-e)*d;l=l+4|0;f=f+1|0;if((f|0)!=8){continue}break}f=0;while(1){t=n[c+28>>2];u=n[c>>2];v=q(t+u);w=n[c+16>>2];x=n[c+12>>2];y=q(w+x);o=q(v+y);z=n[c+24>>2];r=n[c+4>>2];h=q(z+r);i=n[c+20>>2];g=n[c+8>>2];e=q(i+g);d=q(h+e);n[c>>2]=o+d;n[c+16>>2]=q(o-d)*q(.7071067690849304);o=q(v-y);d=q(q(o+q(h-e))*q(.7071067690849304));n[c+24>>2]=q(o-d)*q(1.3065630197525024);n[c+8>>2]=q(d+o)*q(.5411961078643799);e=q(r-z);d=q(g-i);i=q(q(e+d)*q(.7071067690849304));h=q(u-t);g=q(i+h);e=q(h+e);d=q(q(q(x-w)+d)+q(e*q(-.1989123672246933)));e=q(q(d*q(.3826834261417389))+e);n[c+28>>2]=q(g-e)*q(2.562915563583374);n[c+4>>2]=q(e+g)*q(.509795606136322);e=q(d+q(e*q(-.1989123672246933)));d=q(h-i);n[c+20>>2]=q(e+d)*q(.8999761939048767);n[c+12>>2]=q(d-e)*q(.601344883441925);c=c+32|0;f=f+1|0;if((f|0)!=4){continue}break}f=0;g=n[j+32>>2];d=n[j+96>>2];h=n[j+64>>2];while(1){c=k;n[c>>2]=n[(f<<2)+j>>2];f=f+1|0;k=(f<<2)+j|0;e=n[k+96>>2];i=q(e+d);n[c+72>>2]=i+h;d=n[k+32>>2];n[c+144>>2]=d+g;h=n[k- -64>>2];n[c+216>>2]=i+h;k=c+288|0;g=d;d=e;if((f|0)!=7){continue}break}n[c+288>>2]=n[j+28>>2];e=n[j+124>>2];n[c+360>>2]=e+n[j+92>>2];d=n[j+60>>2];n[c+504>>2]=e;n[c+432>>2]=d;s=s+1|0;if((s|0)!=(b|0)){continue}break}}}function pva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=Za-48|0;Za=b;w=j[a+16>>2];l=j[a+44>>2];j[b+32>>2]=l;o=j[a+48>>2];j[b+36>>2]=o;k=j[a+52>>2];j[b+40>>2]=k;g=j[a+56>>2];j[b+44>>2]=g;r=j[a+40>>2];s=j[a+36>>2];e=j[a+4>>2];m=j[a>>2];j[b+24>>2]=m;j[b+28>>2]=e;f=j[a+12>>2];j[b+16>>2]=j[a+8>>2];j[b+20>>2]=f;a:{if(!d){f=r>>12;n=s>>12;break a}while(1){e=(((e&2147483647)<<1|m>>>31)&-2)+w|0;f=(m>>>21&2040)+27888|0;m=i[f+6>>1];g=i[f+4>>1];n=i[f+2>>1];q=i[f>>1];l=0;o=1;k=1;f=0;while(1){j[(b+8|0)+(f<<2)>>2]=(((p(h[e+f|0],n)+p(h[e+(f|-2)|0],q)|0)+p(g,h[e+(f|2)|0])|0)+p(m,h[e+(f|4)|0])<<8)/16384;t=k&1;k=0;f=1;if(t){continue}break}while(1){k=(b+8|0)+(l<<2)|0;m=j[k>>2];g=j[a+60>>2];n=g;f=(b+32|0)+(l<<3)|0;q=j[f>>2];e=Gb(q,-16777216,16776704);t=j[a+64>>2];l=Gb(j[f+4>>2],-16777216,16776704);u=j[a+68>>2];x=u;u=u>>31;j[f+4>>2]=q;q=j[a+72>>2];v=g>>31;m=m<<8;g=m;g=OMa(n,v,g,g>>31);n=ab;v=k;k=g;g=OMa(t,t>>31,e,e>>31);k=k+g|0;e=ab+n|0;e=k>>>0<g>>>0?e+1|0:e;g=k;k=OMa(x,u,l,l>>31);l=g+k|0;e=ab+e|0;e=l>>>0<k>>>0?e+1|0:e;l=l+8388608|0;if(l>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|l>>>24;j[v>>2]=(e|0)/256;j[f>>2]=e-(m&q);l=1;e=o&1;o=0;if(e){continue}break}e=j[a+32>>2];s=j[a+28>>2]+s|0;n=s>>12;j[c>>2]=j[c>>2]+p(n,j[b+8>>2]);r=e+r|0;f=r>>12;j[c+4>>2]=j[c+4>>2]+p(f,j[b+12>>2]);Bb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;m=j[b+24>>2];e=j[b+28>>2];continue}break}m=j[b+24>>2];e=j[b+28>>2];g=j[b+44>>2];k=j[b+40>>2];o=j[b+36>>2];l=j[b+32>>2]}j[a+40>>2]=r;j[a+20>>2]=n;j[a+36>>2]=s;j[a+56>>2]=g;j[a+52>>2]=k;j[a+48>>2]=o;j[a+44>>2]=l;j[a+24>>2]=f;j[a>>2]=m;j[a+4>>2]=e;Za=b+48|0}function Og(a,b,c){var d=0,e=0,f=0,g=0,m=0;g=Za-16|0;Za=g;a:{if((b|0)==189){h[a+3843|0]=c>>>7;h[a+3844|0]=c>>>6&1;break a}d=b&224;if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=p(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;m=c&d;b:{if(m){Km(e,f);break b}Km(e,0)}h[f+40|0]=!m;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}h[a+3842|0]=c>>>6&1;b=0;while(1){Ox((p(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if((d-160&65535)>>>0<=32){d=b&15;if(d>>>0>8){break a}d=(p(b&256?d+9|0:d,44)+a|0)+16|0;j[g+8>>2]=d;e=j[d+36>>2];j[g+12>>2]=e;a=1;f=e?2:1;c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}a=c&32;HL(d,a>>>5|0);m=c>>>2&7;GL(d,m);c=c&3;FL(d,c);if(!e){break a}b=1;d=f>>>0>1?f:1;f=(a|0)!=0;while(1){a=j[(g+8|0)+(b<<2)>>2];HL(a,f);GL(a,m);FL(a,c);b=b+1|0;if((d|0)!=(b|0)){continue}break}break a}EL(d,c);if(!e){break a}b=f>>>0>1?f:1;while(1){EL(j[(g+8|0)+(a<<2)>>2],c);a=a+1|0;if((b|0)!=(a|0)){continue}break}break a}h[d+42|0]=(c&32)>>>5;h[d+41|0]=(c&16)>>>4;a=c>>>1&7;i[d+30>>1]=a?9-a|0:0;i[d+32>>1]=c&1;break a}if((d|0)!=224?d>>>0>=129:0){break a}f=b&31;if(-4144960>>>f&1){break a}e=a;a=h[f+19888|0];a=(e+p(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:h[a+79|0]=c>>>7;h[a+80|0]=(c&64)>>>6;h[a+78|0]=(c&32)>>>5;h[a+77|0]=(c&16)>>>4;Lm(a);i[a+14>>1]=l[((c&15)<<1)+19920>>1];break a;case 1:i[a+68>>1]=k[(c>>>6|0)+19952|0];DL(a);i[a+22>>1]=(c&63)<<2;break a;case 2:i[a+24>>1]=c>>>4;Lm(a);i[a+26>>1]=c&15;Lm(a);break a;case 3:b=c>>>4|0;i[a+28>>1]=b>>>0<15?b<<4:496;i[a+30>>1]=c&15;Lm(a);break a;case 6:break d;default:break a}}i[a+12>>1]=c&7}Za=g+16|0}function qia(a,b){var c=0,d=0,e=0,f=0,g=0,i=0;a:{b:{e=j[b>>2];c:{if(!e){d=b;break c}if(!j[b+4>>2]){d=b;break b}d=bP(b);e=j[d>>2];if(e){break b}}e=j[d+4>>2];if(e){break b}e=0;g=1;break a}j[e+8>>2]=j[d+8>>2];g=0}d:{e:{if(Qg(d)){j[j[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=j[d+8>>2]+4|0;break e}j[j[d+8>>2]+4>>2]=e;c=j[d+8>>2]}c=j[c>>2]}i=!k[d+12|0];if((b|0)!=(d|0)){j[d+8>>2]=j[b+8>>2];f:{if(Qg(b)){f=j[d+8>>2];break f}f=j[d+8>>2]+4|0}j[f>>2]=d;f=j[b>>2];j[d>>2]=f;Ym(f,d);f=j[b+4>>2];j[d+4>>2]=f;if(f){Ym(f,d)}h[d+12|0]=k[b+12|0];a=(a|0)==(b|0)?d:a}if(!(i|!a)){if(g){while(1){d=Qg(c);b=k[c+12|0];g:{h:{if(!d){if(!b){h[c+12|0]=1;h[j[c+8>>2]+12|0]=0;gp(j[c+8>>2]);b=j[c>>2];a=(b|0)==(a|0)?c:a;c=j[b+4>>2]}d=j[c>>2];i:{j:{k:{if(!(k[d+12|0]?0:d)){b=j[c+4>>2];if(k[b+12|0]?0:b){break k}h[c+12|0]=0;l:{b=j[c+8>>2];if((b|0)!=(a|0)){if(k[b+12|0]){break l}a=b}h[a+12|0]=1;return}if(!Qg(b)){break h}b=j[b+8>>2]+4|0;break g}b=j[c+4>>2];if(!b){break j}}if(!k[b+12|0]){break i}}h[d+12|0]=1;h[c+12|0]=0;fp(c);c=j[c+8>>2]}h[c+12|0]=k[j[c+8>>2]+12|0];h[j[c+8>>2]+12|0]=1;h[j[c+4>>2]+12|0]=1;gp(j[c+8>>2]);return}if(!b){h[c+12|0]=1;h[j[c+8>>2]+12|0]=0;fp(j[c+8>>2]);b=j[c+4>>2];a=(b|0)==(a|0)?c:a;c=j[b>>2]}d=j[c>>2];m:{if(k[d+12|0]?0:d){break m}b=j[c+4>>2];if(!(k[b+12|0]?0:b)){h[c+12|0]=0;b=j[c+8>>2];if(!(k[b+12|0]?(b|0)!=(a|0):0)){h[b+12|0]=1;return}if(Qg(b)){b=j[b+8>>2]+4|0;break g}b=j[b+8>>2];break g}if(d){if(!k[d+12|0]){break m}b=j[c+4>>2]}h[b+12|0]=1;h[c+12|0]=0;gp(c);c=j[c+8>>2]}h[c+12|0]=k[j[c+8>>2]+12|0];h[j[c+8>>2]+12|0]=1;h[j[c>>2]+12|0]=1;fp(j[c+8>>2]);return}b=j[b+8>>2]}c=j[b>>2];continue}}h[e+12|0]=1}}function uua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=Za-48|0;Za=g;s=j[a+16>>2];h=wf(g+16|0);j[h+8>>2]=a+112;j[h+16>>2]=j[a+128>>2];w=h,x=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[w+12>>2]=x;b=j[h+16>>2];if(b){w=h,x=vf(a+8|0,b),j[w>>2]=x;j[h+4>>2]=ab}m=j[a+48>>2];n=j[a+40>>2];o=j[a+36>>2];b=j[a+44>>2];f=j[a+4>>2];e=j[a>>2];j[g+8>>2]=e;j[g+12>>2]=f;q=j[a+12>>2];j[g>>2]=j[a+8>>2];j[g+4>>2]=q;a:{if(!d){k=n>>12;l=o>>12;break a}while(1){q=b;b=0;k=b;j[g+40>>2]=e;j[g+44>>2]=b;f=(f<<1)+s|0;b:{b=j[h+16>>2];if((b|0)<=0){break b}while(1){id(j[h+8>>2],i[(k<<1)+f>>1]/4<<16>>16);hd(j[h+8>>2],4);Bb(g+40|0,h);if((b|0)<2){break b}b=b-1|0;k=j[g+44>>2];continue}}d=d-1|0;b=j[h+8>>2];Bb(b,b+8|0);b=j[h+8>>2];e=j[b+4>>2];if(e){id(b,i[f+(j[g+44>>2]<<1)>>1]/4<<16>>16);hd(j[h+8>>2],e);b=j[h+8>>2];e=j[b>>2];j[b>>2]=e;j[b+4>>2]=0}e=qf(b,j[h+12>>2]);k=j[a+60>>2];b=Gb(q,-16777216,16776704);l=j[a+64>>2];f=Gb(m,-16777216,16776704);t=j[a+72>>2];u=j[a+32>>2];m=c;v=j[c>>2];r=e<<8;e=r;e=OMa(k,k>>31,e,e>>31);k=ab;l=OMa(l,l>>31,b,b>>31);e=l+e|0;b=ab+k|0;b=e>>>0<l>>>0?b+1|0:b;k=e;e=j[a+68>>2];e=OMa(e,e>>31,f,f>>31);f=k+e|0;b=ab+b|0;b=f>>>0<e>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}f=(b&16777215)<<8|f>>>24;b=(f|0)/256|0;o=j[a+28>>2]+o|0;l=o>>12;j[m>>2]=p(b,l)+v;n=n+u|0;k=n>>12;j[c+4>>2]=j[c+4>>2]+p(b,k);b=f-(t&r)|0;Bb(g+8|0,g);if(d){c=c+8|0;e=j[g+8>>2];f=j[g+12>>2];m=q;continue}break}e=j[g+8>>2];f=j[g+12>>2];m=q}j[a+40>>2]=n;j[a+20>>2]=l;j[a+36>>2]=o;j[a+48>>2]=m;j[a+44>>2]=b;j[a+24>>2]=k;j[a>>2]=e;j[a+4>>2]=f;Za=g+48|0}



function _za(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,j=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=Za-16|0;Za=d;a:{if(!yb(a,2)){Wf(c+484344|0,b,64);break a}m=c+484344|0;i=kd(tp(a),1,1024);if(!Wf(m,b,i)|!i){break a}n=l[c+480188>>1];while(1){r=Dp(Ib(m,b),j);g=0;if(n){while(1){nn(d+8|0,a);e=Pc(d+8|0);s=Bf(d+8|0);c=p(g,6)+r|0;f=k[pi(d+8|0)|0];h[c+5|0]=f;o=0;q=k[d+8|0];if((q-1&255)>>>0<=35){h[c|0]=q+48;o=k[e|0]+1|0}e=c+5|0;h[c+1|0]=o;b:{c:{d:{switch(k[s|0]){case 1:h[c+3|0]=2;h[e|0]=f&15;break b;case 2:h[c+3|0]=3;h[e|0]=f&15;break b;case 12:if(!f){break b}h[c+3|0]=1;break b;case 13:if(!f){break b}h[c+3|0]=36;h[d+7|0]=15;t=e,u=k[Yb(d+7|0,e)|0]|16,h[t|0]=u;break b;case 30:if(!f){break b}h[c+3|0]=35;h[d+6|0]=15;t=e,u=k[Yb(d+6|0,e)|0]|16,h[t|0]=u;break b;case 21:if(!f){break b}h[c+3|0]=36;h[d+5|0]=15;t=e,u=k[Yb(d+5|0,e)|0]|80,h[t|0]=u;break b;case 17:if(!f){break b}h[c+3|0]=35;h[d+4|0]=15;t=e,u=k[Yb(d+4|0,e)|0]|80,h[t|0]=u;break b;case 15:h[c+3|0]=19;h[e|0]=(f|0)!=0;break b;case 25:h[c+3|0]=12;break b;case 27:As(c);h[c|0]=255;break b;case 28:h[c+3|0]=16;break b;case 31:h[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}h[e|0]=f&15;break b;case 5:h[e|0]=f<<4;break b;case 6:h[d+3|0]=f&15;h[d+2|0]=14;t=e,u=k[Yb(d+3|0,d+2|0)|0]|240,h[t|0]=u;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}h[d+1|0]=f&15;h[d|0]=14;t=e,u=k[Yb(d+1|0,d)|0]<<4|15,h[t|0]=u;break b}h[c+4|0]=f;h[c+2|0]=1}h[c+3|0]=0;break c;case 0:break c;default:break d}}h[c+3|0]=0}h[e|0]=0}g=g+1|0;if((n|0)!=(g|0)){continue}break}}j=j+1|0;if((j|0)!=(i|0)){continue}break}}Za=d+16|0}function Jr(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,n=0,o=0;f=Za-160|0;Za=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}d=j[c+4>>2];if(!d&m[c>>2]>=Xg(b)>>>0|d){break h}b=R(8)|0;j[114626]=0;E(214,b|0,20525)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break g}a=D()|0;C()|0;S(b|0);break a}if(!j[b>>2]){b=R(8)|0;j[114626]=0;E(1397,b|0,20525)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break f}a=D()|0;C()|0;S(b|0);break a}k=Gna(f+136|0,bh(f+128|0,b));i:{j:{if(a&2){d=ro(f+104|0,k);j[114626]=0;g=E(1398,d|0,c|0)|0;e=j[114626];j[114626]=0;d=1;if((e|0)==1){break i}if((g|0)==1){break j}e=ro(f+80|0,k);j[114626]=0;e=E(1399,e|0,c|0)|0;h=j[114626];j[114626]=0;if((h|0)==1){break e}l=(e|0)==1;if(l){break j}h=ro(f+56|0,k);j[114626]=0;h=E(1400,h|0,c|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break d}n=(h|0)==1;if(n){break j}i=ro(f+32|0,k);j[114626]=0;i=E(1401,i|0,c|0)|0;o=j[114626];j[114626]=0;if((o|0)==1){break c}if((i|0)==1){break j}d=(g|0)==-1?-1:0;d=l?d:(e|0)==-1?-1:d;g=(i|0)==-1?-1:n?d:(h|0)==-1?-1:d}if(a&1){a=77936;while(1){d=j[a>>2];if(d){e=ro(f+8|0,k);j[114626]=0;e=E(d|0,e|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}d=1;if((e|0)==1){break j}g=(e|0)==-1?-1:g}a=a+12|0;if((a|0)!=78392){continue}break}}if(c){d=0;if((g|0)!=-1){break j}a=j[c+4>>2];c=j[c>>2];j[114626]=0;a=ig(446,c,a);c=j[114626];j[114626]=0;if((c|0)!=1){d=Xg(b)>>>0<a>>>0?-1:0;break j}a=D()|0;C()|0;break a}d=0;if((g|0)!=-1){break j}d=Xg(b)>>>0>2047?1:-1}Za=f+160|0;return d}a=D()|0;C()|0;break a}Y(b|0,71656,24);z()}Y(b|0,71552,24);z()}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0}G(a|0);z()}function aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=Za-144|0;Za=c;e=Ek(c+40|0,a);j[114626]=0;d=E(683,c+24|0,32299)|0;a=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){j[114626]=0;j[c>>2]=19465728;j[c+4>>2]=0;I(684,e|0,d|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break n}qb(d);if(j[e>>2]&1073741824){break e}j[114626]=0;d=E(683,c+24|0,32304)|0;a=j[114626];j[114626]=0;if((a|0)==1){break m}j[114626]=0;P(1562,e|0,b|0,d|0,1563)|0;a=j[114626];j[114626]=0;if((a|0)==1){break l}qb(d);j[114626]=0;j[c+20>>2]=0;j[c+16>>2]=0;d=E(683,c+24|0,32309)|0;a=j[114626];j[114626]=0;if((a|0)==1){break k}j[114626]=0;K(1564,e|0,c+20|0,d|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break j}qb(d);j[114626]=0;d=E(683,c+24|0,32314)|0;a=j[114626];j[114626]=0;if((a|0)==1){break i}j[114626]=0;K(1564,e|0,c+16|0,d|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break h}qb(d);pka(b,j[c+20>>2],j[c+16>>2]);d=nx(c+24|0);j[114626]=0;f=E(683,c|0,32319)|0;a=j[114626];j[114626]=0;if((a|0)==1){break d}j[114626]=0;P(1565,e|0,d|0,f|0,675)|0;a=j[114626];j[114626]=0;if((a|0)==1){break g}qb(f);if(ad(d)){break f}j[114626]=0;I(1566,d|0,j[c+20>>2],16777216);a=j[114626];j[114626]=0;if((a|0)!=1){break f}break c}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(d);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(d);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(d);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;qb(d);break a}a=D()|0;C()|0;qb(f);break b}j[114626]=0;F(1567,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Ud(d)}ag(e);Za=c+144|0;return}a=D()|0;C()|0;break b}a=D()|0;C()|0}Ud(d)}ag(e);G(a|0);z()}function XGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Za-96|0;Za=d;b=b&4095;i[d+94>>1]=b;a:{b:{c:{d:{e:{f:{g:{if(b>>>0>=81){e=((b|0)==4095?c:b-80|0)+734016|0;c=OMa(e,e>>31,1e4,0)+14780|0;b=ab;b=PMa(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((((b|0)/-4|0)+e|0)+p(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<=-1){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+p(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}e=Eb(d- -64|0,13390);j[114626]=0;F(219,d+80|0,e|0);f=j[114626];j[114626]=0;h=(p(c,100)+52|0)/3060|0;h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=1){j[114626]=0;g=b;b=h+2|0;f=(b|0)/12|0;j[d+44>>2]=g+f;F(191,d+48|0,d+44|0);g=j[114626];j[114626]=0;if((g|0)==1){break o}j[114626]=0;j[d+28>>2]=(b-p(f,12)|0)+1;F(193,d+32|0,d+28|0);b=j[114626];j[114626]=0;if((b|0)==1){break n}j[114626]=0;j[d+12>>2]=(((p(h,306)+5|0)/-10|0)+c|0)+1;F(193,d+16|0,d+12|0);b=j[114626];j[114626]=0;if((b|0)==1){break m}j[114626]=0;V(619,a|0,d+80|0,d+48|0,d+32|0,d+16|0);a=j[114626];j[114626]=0;if((a|0)==1){break l}gb(d+16|0);gb(d+32|0);gb(d+48|0);qb(d+80|0);gb(e);break g}b=D()|0;C()|0;break h}b=D()|0;C()|0;break i}b=D()|0;C()|0;break j}b=D()|0;C()|0;break k}b=D()|0;C()|0;gb(d+16|0)}gb(d+32|0)}gb(d+48|0)}qb(d+80|0)}gb(e);break a}c=Eb(d,13414);j[114626]=0;F(219,d+80|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break f}j[114626]=0;F(620,d+48|0,d+94|0);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;I(247,a|0,d+80|0,d+48|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}gb(d+48|0);qb(d+80|0);gb(c)}Za=d+96|0;return}b=D()|0;C()|0;break b}b=D()|0;C()|0;break c}b=D()|0;C()|0;gb(d+48|0)}qb(d+80|0)}gb(c)}G(b|0);z()}function AB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-128|0;Za=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{b=j[b>>2];l:{if(!b){Eb(a,7037);break l}if(!(b&65535)){e=Eb(c+96|0,7045);j[114626]=0;F(219,c+112|0,e|0);d=j[114626];j[114626]=0;m:{n:{o:{p:{q:{r:{if((d|0)!=1){j[114626]=0;j[c+24>>2]=b>>>24;F(220,c+80|0,c+24|0);d=j[114626];j[114626]=0;if((d|0)==1){break r}j[114626]=0;j[c+8>>2]=b>>>16&255;F(221,c- -64|0,c+8|0);b=j[114626];j[114626]=0;if((b|0)==1){break q}j[114626]=0;L(222,a|0,c+112|0,c+80|0,c- -64|0);a=j[114626];j[114626]=0;if((a|0)==1){break p}gb(c- -64|0);gb(c+80|0);qb(c+112|0);gb(e);break l}b=D()|0;C()|0;break m}b=D()|0;C()|0;break n}b=D()|0;C()|0;break o}b=D()|0;C()|0;gb(c- -64|0)}gb(c+80|0)}qb(c+112|0)}break a}e=Eb(c+48|0,7051);j[114626]=0;F(219,c+112|0,e|0);d=j[114626];j[114626]=0;if((d|0)==1){break k}j[114626]=0;j[c+44>>2]=b>>>24;F(220,c+80|0,c+44|0);d=j[114626];j[114626]=0;if((d|0)==1){break j}j[114626]=0;j[c+40>>2]=b>>>16&255;F(221,c- -64|0,c+40|0);d=j[114626];j[114626]=0;if((d|0)==1){break i}j[114626]=0;j[c+20>>2]=b>>>8&255;F(221,c+24|0,c+20|0);d=j[114626];j[114626]=0;if((d|0)==1){break h}j[114626]=0;j[c+4>>2]=b&255;F(221,c+8|0,c+4|0);b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;aa(223,a|0,c+112|0,c+80|0,c- -64|0,c+24|0,c+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break f}gb(c+8|0);gb(c+24|0);gb(c- -64|0);gb(c+80|0);qb(c+112|0);gb(e)}Za=c+128|0;return}b=D()|0;C()|0;break a}b=D()|0;C()|0;break b}b=D()|0;C()|0;break c}b=D()|0;C()|0;break d}b=D()|0;C()|0;break e}b=D()|0;C()|0;gb(c+8|0)}gb(c+24|0)}gb(c- -64|0)}gb(c+80|0)}qb(c+112|0)}gb(e);G(b|0);z()}function P0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,k=0,l=0,m=0;f=Za-384|0;Za=f;j[f+376>>2]=37;j[f+380>>2]=0;g=sq(f+376|1,62201,j[c+4>>2]);j[f+332>>2]=f+336;a=Wd();a:{if(g){h=j[c+8>>2];o[f+40>>3]=e;j[f+32>>2]=h;a=Ke(f+336|0,30,a,f+376|0,f+32|0);break a}o[f+48>>3]=e;a=Ke(f+336|0,30,a,f+376|0,f+48|0)}j[f+80>>2]=2412;h=yd(f+320|0,0,f+80|0);b:{c:{d:{if((a|0)>=30){e:{if(g){j[114626]=0;a=T(2437)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[f>>2]=j[c+8>>2];j[114626]=0;o[f+8>>3]=e;a=P(2459,f+332|0,a|0,f+376|0,f|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){break e}break c}j[114626]=0;a=T(2437)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}o[f+16>>3]=e;j[114626]=0;a=P(2459,f+332|0,a|0,f+376|0,f+16|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}}g=j[f+332>>2];if(!g){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)==1){break c}break d}fe(h,g)}g=j[f+332>>2];k=g+a|0;l=Tf(g,k,c);j[f+68>>2]=2412;i=yd(f+72|0,0,f+68|0);f:{g:{if(j[f+332>>2]==(f+336|0)){a=f+80|0;g=f+336|0;break g}a=_c(a<<3);if(!a){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)!=1){break d}c=D()|0;C()|0;break f}fe(i,a);g=j[f+332>>2]}j[114626]=0;hc(f+56|0,c);m=j[114626];j[114626]=0;h:{i:{if((m|0)!=1){j[114626]=0;Z(2470,g|0,l|0,k|0,a|0,f+68|0,f- -64|0,f+56|0);g=j[114626];j[114626]=0;if((g|0)==1){break i}wb(f+56|0);j[114626]=0;a=_(2471,b|0,a|0,j[f+68>>2],j[f+64>>2],c|0,d|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break h}mc(i);mc(h);Za=f+384|0;return a|0}c=D()|0;C()|0;break f}c=D()|0;C()|0;wb(f+56|0);break f}c=D()|0;C()|0}mc(i);break b}z()}c=D()|0;C()|0}mc(h);G(c|0);z()}function $0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,k=0,l=0,m=0;f=Za-208|0;Za=f;j[f+200>>2]=37;j[f+204>>2]=0;g=sq(f+200|1,62201,j[c+4>>2]);j[f+156>>2]=f+160;a=Wd();a:{if(g){h=j[c+8>>2];o[f+40>>3]=e;j[f+32>>2]=h;a=Ke(f+160|0,30,a,f+200|0,f+32|0);break a}o[f+48>>3]=e;a=Ke(f+160|0,30,a,f+200|0,f+48|0)}j[f+80>>2]=2412;h=yd(f+144|0,0,f+80|0);b:{c:{d:{if((a|0)>=30){e:{if(g){j[114626]=0;a=T(2437)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[f>>2]=j[c+8>>2];j[114626]=0;o[f+8>>3]=e;a=P(2459,f+156|0,a|0,f+200|0,f|0)|0;g=j[114626];j[114626]=0;if((g|0)!=1){break e}break c}j[114626]=0;a=T(2437)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}o[f+16>>3]=e;j[114626]=0;a=P(2459,f+156|0,a|0,f+200|0,f+16|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}}g=j[f+156>>2];if(!g){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)==1){break c}break d}fe(h,g)}g=j[f+156>>2];k=g+a|0;l=Tf(g,k,c);j[f+68>>2]=2412;i=yd(f+72|0,0,f+68|0);f:{g:{if(j[f+156>>2]==(f+160|0)){a=f+80|0;g=f+160|0;break g}a=_c(a<<1);if(!a){j[114626]=0;M(2413);a=j[114626];j[114626]=0;if((a|0)!=1){break d}c=D()|0;C()|0;break f}fe(i,a);g=j[f+156>>2]}j[114626]=0;hc(f+56|0,c);m=j[114626];j[114626]=0;h:{i:{if((m|0)!=1){j[114626]=0;Z(2460,g|0,l|0,k|0,a|0,f+68|0,f- -64|0,f+56|0);g=j[114626];j[114626]=0;if((g|0)==1){break i}wb(f+56|0);j[114626]=0;a=_(17,b|0,a|0,j[f+68>>2],j[f+64>>2],c|0,d|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break h}mc(i);mc(h);Za=f+208|0;return a|0}c=D()|0;C()|0;break f}c=D()|0;C()|0;wb(f+56|0);break f}c=D()|0;C()|0}mc(i);break b}z()}c=D()|0;C()|0}mc(h);G(c|0);z()}function vua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=Za-48|0;Za=g;s=j[a+16>>2];i=wf(g+16|0);j[i+8>>2]=a+112;j[i+16>>2]=j[a+128>>2];w=i,x=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[w+12>>2]=x;b=j[i+16>>2];if(b){w=i,x=vf(a+8|0,b),j[w>>2]=x;j[i+4>>2]=ab}m=j[a+48>>2];n=j[a+40>>2];o=j[a+36>>2];b=j[a+44>>2];f=j[a+4>>2];e=j[a>>2];j[g+8>>2]=e;j[g+12>>2]=f;q=j[a+12>>2];j[g>>2]=j[a+8>>2];j[g+4>>2]=q;a:{if(!d){k=n>>12;l=o>>12;break a}while(1){q=b;b=0;k=b;j[g+40>>2]=e;j[g+44>>2]=b;f=f+s|0;b:{b=j[i+16>>2];if((b|0)<=0){break b}while(1){id(j[i+8>>2],h[f+k|0]<<6);hd(j[i+8>>2],4);Bb(g+40|0,i);if((b|0)<2){break b}b=b-1|0;k=j[g+44>>2];continue}}d=d-1|0;b=j[i+8>>2];Bb(b,b+8|0);b=j[i+8>>2];e=j[b+4>>2];if(e){id(b,h[f+j[g+44>>2]|0]<<6);hd(j[i+8>>2],e);b=j[i+8>>2];e=j[b>>2];j[b>>2]=e;j[b+4>>2]=0}e=qf(b,j[i+12>>2]);k=j[a+60>>2];b=Gb(q,-16777216,16776704);l=j[a+64>>2];f=Gb(m,-16777216,16776704);t=j[a+72>>2];u=j[a+32>>2];m=c;v=j[c>>2];r=e<<8;e=r;e=OMa(k,k>>31,e,e>>31);k=ab;l=OMa(l,l>>31,b,b>>31);e=l+e|0;b=ab+k|0;b=e>>>0<l>>>0?b+1|0:b;k=e;e=j[a+68>>2];e=OMa(e,e>>31,f,f>>31);f=k+e|0;b=ab+b|0;b=f>>>0<e>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}f=(b&16777215)<<8|f>>>24;b=(f|0)/256|0;o=j[a+28>>2]+o|0;l=o>>12;j[m>>2]=p(b,l)+v;n=n+u|0;k=n>>12;j[c+4>>2]=j[c+4>>2]+p(b,k);b=f-(t&r)|0;Bb(g+8|0,g);if(d){c=c+8|0;e=j[g+8>>2];f=j[g+12>>2];m=q;continue}break}e=j[g+8>>2];f=j[g+12>>2];m=q}j[a+40>>2]=n;j[a+20>>2]=l;j[a+36>>2]=o;j[a+48>>2]=m;j[a+44>>2]=b;j[a+24>>2]=k;j[a>>2]=e;j[a+4>>2]=f;Za=g+48|0}function j1(a,b,c,d,e){var f=0,g=0;f=Za-384|0;Za=f;j[f+368>>2]=b;j[f+376>>2]=a;Uu(f+216|0,c,f+240|0,f+236|0,f+232|0);b=Db(f+200|0);a=sc(b);j[114626]=0;F(149,b|0,a|0);a=j[114626];j[114626]=0;a:{b:{if((a|0)!=1){a=Ub(b,0);j[f+196>>2]=a;j[f+28>>2]=f+32;j[f+24>>2]=0;h[f+23|0]=1;h[f+22|0]=69;while(1){c:{j[114626]=0;c=E(2446,f+376|0,f+368|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+196>>2]==(nb(b)+a|0)){c=nb(b);a=nb(b);j[114626]=0;F(149,b|0,a<<1);a=j[114626];j[114626]=0;if((a|0)==1){break a}a=sc(b);j[114626]=0;F(149,b|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}a=Ub(b,0);j[f+196>>2]=c+a}j[114626]=0;c=H(2448,f+376|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=tq(c,f+23|0,f+22|0,a,f+196|0,j[f+236>>2],j[f+232>>2],f+216|0,f+32|0,f+28|0,f+24|0,f+240|0);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2450,f+376|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+216|0)|!k[f+23|0]){break d}c=j[f+28>>2];if((c-(f+32|0)|0)>159){break d}j[f+28>>2]=c+4;j[c>>2]=j[f+24>>2]}j[114626]=0;L(2435,f|0,a|0,j[f+196>>2],d|0);a=j[114626];j[114626]=0;e:{if((a|0)==1){break e}a=j[f+8>>2];c=j[f+12>>2];g=j[f+4>>2];j[e>>2]=j[f>>2];j[e+4>>2]=g;j[e+8>>2]=a;j[e+12>>2]=c;j[114626]=0;le(f+216|0,f+32|0,j[f+28>>2],d);a=j[114626];j[114626]=0;if((a|0)==1){break e}j[114626]=0;a=E(2447,f+376|0,f+368|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(a){j[d>>2]=j[d>>2]|2}a=j[f+376>>2];gb(b);gb(f+216|0);Za=f+384|0;return a}}a=D()|0;C()|0;gb(b);gb(f+216|0);G(a|0);z()}function G1(a,b,c,d,e){var f=0,g=0;f=Za-288|0;Za=f;j[f+272>>2]=b;j[f+280>>2]=a;Wu(f+224|0,c,f+240|0,f+239|0,f+238|0);b=Db(f+208|0);a=sc(b);j[114626]=0;F(149,b|0,a|0);a=j[114626];j[114626]=0;a:{b:{if((a|0)!=1){a=Ub(b,0);j[f+204>>2]=a;j[f+28>>2]=f+32;j[f+24>>2]=0;h[f+23|0]=1;h[f+22|0]=69;while(1){c:{j[114626]=0;c=E(2414,f+280|0,f+272|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+204>>2]==(nb(b)+a|0)){c=nb(b);a=nb(b);j[114626]=0;F(149,b|0,a<<1);a=j[114626];j[114626]=0;if((a|0)==1){break a}a=sc(b);j[114626]=0;F(149,b|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}a=Ub(b,0);j[f+204>>2]=c+a}j[114626]=0;c=H(2416,f+280|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=vq(c,f+23|0,f+22|0,a,f+204|0,h[f+239|0],h[f+238|0],f+224|0,f+32|0,f+28|0,f+24|0,f+240|0);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2418,f+280|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+224|0)|!k[f+23|0]){break d}c=j[f+28>>2];if((c-(f+32|0)|0)>159){break d}j[f+28>>2]=c+4;j[c>>2]=j[f+24>>2]}j[114626]=0;L(2435,f|0,a|0,j[f+204>>2],d|0);a=j[114626];j[114626]=0;e:{if((a|0)==1){break e}a=j[f+8>>2];c=j[f+12>>2];g=j[f+4>>2];j[e>>2]=j[f>>2];j[e+4>>2]=g;j[e+8>>2]=a;j[e+12>>2]=c;j[114626]=0;le(f+224|0,f+32|0,j[f+28>>2],d);a=j[114626];j[114626]=0;if((a|0)==1){break e}j[114626]=0;a=E(2415,f+280|0,f+272|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(a){j[d>>2]=j[d>>2]|2}a=j[f+280>>2];gb(b);gb(f+224|0);Za=f+288|0;return a}}a=D()|0;C()|0;gb(b);gb(f+224|0);G(a|0);z()}function Gva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Za-48|0;Za=b;v=j[a+16>>2];n=j[a+44>>2];j[b+32>>2]=n;f=j[a+48>>2];j[b+36>>2]=f;l=j[a+52>>2];j[b+40>>2]=l;m=j[a+56>>2];j[b+44>>2]=m;o=j[a+40>>2];q=j[a+36>>2];e=j[a+4>>2];k=j[a>>2];j[b+24>>2]=k;j[b+28>>2]=e;g=j[a+12>>2];j[b+16>>2]=j[a+8>>2];j[b+20>>2]=g;a:{if(!d){g=o>>12;h=q>>12;break a}while(1){f=k>>>18|0;n=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+v|0;g=0;l=1;h=0;while(1){m=h<<1;k=i[m+e>>1];j[(b+8|0)+(h<<2)>>2]=k+((p(f,i[e+(m|4)>>1]-k|0)|0)/16384|0);k=l&1;l=0;h=1;if(k){continue}break}while(1){h=(b+8|0)+(g<<2)|0;l=j[h>>2];f=j[a+60>>2];m=f;k=(b+32|0)+(g<<3)|0;r=j[k>>2];e=Gb(r,-16777216,16776704);u=j[a+64>>2];g=Gb(j[k+4>>2],-16777216,16776704);s=j[a+68>>2];w=s;s=s>>31;j[k+4>>2]=r;r=j[a+72>>2];t=f>>31;l=l<<8;f=l;f=OMa(m,t,f,f>>31);m=ab;t=h;h=f;f=OMa(u,u>>31,e,e>>31);h=h+f|0;e=ab+m|0;e=h>>>0<f>>>0?e+1|0:e;f=h;h=OMa(w,s,g,g>>31);g=f+h|0;e=ab+e|0;e=g>>>0<h>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;j[t>>2]=(e|0)/256;j[k>>2]=e-(l&r);g=1;e=n&1;n=0;if(e){continue}break}e=j[a+32>>2];q=j[a+28>>2]+q|0;h=q>>12;j[c>>2]=j[c>>2]+p(h,j[b+8>>2]);o=e+o|0;g=o>>12;j[c+4>>2]=j[c+4>>2]+p(g,j[b+12>>2]);Bb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;k=j[b+24>>2];e=j[b+28>>2];continue}break}k=j[b+24>>2];e=j[b+28>>2];m=j[b+44>>2];l=j[b+40>>2];f=j[b+36>>2];n=j[b+32>>2]}j[a+40>>2]=o;j[a+20>>2]=h;j[a+36>>2]=q;j[a+56>>2]=m;j[a+52>>2]=l;j[a+48>>2]=f;j[a+44>>2]=n;j[a+24>>2]=g;j[a>>2]=k;j[a+4>>2]=e;Za=b+48|0}function dva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=Za-16|0;Za=h;a:{b:{c:{l=j[a+8>>2];g=j[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?l>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?l>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?l>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?l>>>0>2147483648:0){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}s=j[a+16>>2];f=j[a+48>>2];t=j[a+24>>2];u=j[a+20>>2];m=j[a+44>>2];e=j[a+4>>2];k=j[a>>2];j[h+8>>2]=k;j[h+12>>2]=e;j[h>>2]=l;j[h+4>>2]=g;e:{if(!d){b=m;m=f;break e}while(1){b=(k>>>16&65520)+o|0;g=i[b>>1];e=(e<<1)+s|0;k=i[e-6>>1];l=i[b+2>>1];v=i[e-4>>1];w=i[b+4>>1];x=i[e-2>>1];y=i[b+6>>1];z=i[e>>1];A=i[b+8>>1];B=i[e+2>>1];C=i[b+10>>1];D=i[e+4>>1];E=i[b+12>>1];F=i[e+6>>1];G=i[b+14>>1];e=i[e+8>>1];r=j[a+60>>2];b=Gb(m,-16777216,16776704);n=j[a+64>>2];f=Gb(f,-16777216,16776704);H=j[a+72>>2];I=j[c>>2];b=OMa(n,n>>31,b,b>>31);n=ab;q=b;k=(((((((p(l,v)+p(g,k)|0)+p(w,x)|0)+p(y,z)|0)+p(A,B)|0)+p(C,D)|0)+p(E,F)|0)+p(e,G)|0)/32768<<8;b=k;g=OMa(r,r>>31,b,b>>31);e=q+g|0;b=ab+n|0;b=e>>>0<g>>>0?b+1|0:b;q=e;e=j[a+68>>2];e=OMa(e,e>>31,f,f>>31);f=q+e|0;b=ab+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;j[c>>2]=p(f,u)+I;j[c+4>>2]=j[c+4>>2]+p(f,t);b=b-(k&H)|0;Bb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;k=j[h+8>>2];e=j[h+12>>2];f=m;m=b;continue}break}k=j[h+8>>2];e=j[h+12>>2]}j[a+48>>2]=m;j[a+44>>2]=b;j[a>>2]=k;j[a+4>>2]=e;Za=h+16|0}function eva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;k=Za-16|0;Za=k;a:{b:{c:{l=j[a+8>>2];g=j[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?l>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?l>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?l>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?l>>>0>2147483648:0){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}s=j[a+16>>2];f=j[a+48>>2];t=j[a+24>>2];u=j[a+20>>2];n=j[a+44>>2];e=j[a+4>>2];m=j[a>>2];j[k+8>>2]=m;j[k+12>>2]=e;j[k>>2]=l;j[k+4>>2]=g;e:{if(!d){b=n;n=f;break e}while(1){b=e+s|0;g=h[b+4|0];e=(m>>>16&65520)+q|0;m=i[e+14>>1];l=h[b+3|0];v=i[e+12>>1];w=h[b+2|0];x=i[e+10>>1];y=h[b+1|0];z=i[e+8>>1];A=h[b|0];B=i[e+6>>1];C=h[b-1|0];D=i[e+4>>1];E=h[b-2|0];F=i[e+2>>1];G=h[b-3|0];e=i[e>>1];b=j[a+60>>2];H=b;I=b>>31;b=Gb(n,-16777216,16776704);o=j[a+64>>2];f=Gb(f,-16777216,16776704);J=j[a+72>>2];K=j[c>>2];b=OMa(o,o>>31,b,b>>31);o=ab;L=b;b=j[a+68>>2];r=OMa(b,b>>31,f,f>>31);f=L+r|0;b=ab+o|0;b=f>>>0<r>>>0?b+1|0:b;e=(((((((p(E,F)+p(e,G)|0)+p(C,D)|0)+p(A,B)|0)+p(y,z)|0)+p(w,x)|0)+p(l,v)|0)+p(g,m)<<8)/32768<<8;g=OMa(H,I,e,e>>31);f=f+g|0;b=ab+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;j[c>>2]=p(f,u)+K;j[c+4>>2]=j[c+4>>2]+p(f,t);b=b-(e&J)|0;Bb(k+8|0,k);d=d-1|0;if(d){c=c+8|0;m=j[k+8>>2];e=j[k+12>>2];f=n;n=b;continue}break}m=j[k+8>>2];e=j[k+12>>2]}j[a+48>>2]=n;j[a+44>>2]=b;j[a>>2]=m;j[a+4>>2]=e;Za=k+16|0}function vCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,j=0,l=0,m=0,n=0,o=0,p=0;g=Za-16|0;Za=g;if(c){o=b,p=dd(a),h[o|0]=p;j=b+1|0;l=c-1|0;a:{if(!l){break a}while(1){b:{c:{d=f<<1;f=d&254;d:{if(!f){if(!re(a,g+15|0)){break a}d=k[g+15|0]<<1|1;f=d&255;if(d>>>0>255){break d}break c}if((d&65535)>>>0<256){break c}}i=1;while(1){e:{f:{g:{e=f<<1&254;d=f>>>0>127;h:{if(e){break h}if(!re(a,g+14|0)){break g}d=k[g+14|0]<<1|1;e=d&255;d=d>>>0>255}i=d|i<<1;f=e<<1&254;if(f){break f}if(!re(a,g+13|0)){break g}d=k[g+13|0]<<1|1;f=d&255;if(d>>>0>255){continue}break e}f=0;break e}if(e>>>0>127){continue}}break}i:{if((i|0)<=2){n=0;i=i-2|0;break i}if(!re(a,g+12|0)){break a}d=(k[g+12|0]|i<<8)-768|0;n=((d|0)>1279?2:1)+((d|0)>31999)|0;m=d^-1;i=0}e=f<<1&254;d=f>>>0>127;j:{if(e){break j}if(!re(a,g+11|0)){break a}d=k[g+11|0]<<1|1;e=d&255;d=d>>>0>255}f=e<<1&254;e=e>>>0>127;k:{if(f){break k}if(!re(a,g+10|0)){break a}e=k[g+10|0]<<1|1;f=e&255;e=e>>>0>255}e=e|(i<<2|(d?2:0));if(!e){i=1;while(1){l:{m:{n:{e=f<<1&254;d=f>>>0>127;o:{if(e){break o}if(!re(a,g+9|0)){break n}d=k[g+9|0]<<1|1;e=d&255;d=d>>>0>255}i=d|i<<1;f=e<<1&254;if(f){break m}if(!re(a,g+8|0)){break n}d=k[g+8|0]<<1|1;f=d&255;if(d>>>0>255){continue}break l}f=0;break l}if(e>>>0>127){continue}}break}e=i+2|0}if((m|0)>-1){break a}e=e+n|0;if(l>>>0<e>>>0|(e|0)<1|((j-b|0)+m|0)<0){break a}i=j+m|0;l=l-e|0;while(1){h[j|0]=k[i|0];j=j+1|0;i=i+1|0;d=(e|0)>1;e=e-1|0;if(d){continue}break}break b}if(!re(a,j)){break a}l=l-1|0;j=j+1|0}if(l){continue}break}}a=(j-b|0)==(c|0)}else{a=0}Za=g+16|0;return a|0}function Hva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Za-48|0;Za=b;t=j[a+16>>2];l=j[a+44>>2];j[b+32>>2]=l;n=j[a+48>>2];j[b+36>>2]=n;k=j[a+52>>2];j[b+40>>2]=k;m=j[a+56>>2];j[b+44>>2]=m;o=j[a+40>>2];q=j[a+36>>2];e=j[a+4>>2];i=j[a>>2];j[b+24>>2]=i;j[b+28>>2]=e;g=j[a+12>>2];j[b+16>>2]=j[a+8>>2];j[b+20>>2]=g;a:{if(!d){g=o>>12;f=q>>12;break a}while(1){l=i>>>10&4194048;e=(((e&2147483647)<<1|i>>>31)&-2)+t|0;f=0;n=1;k=1;g=0;while(1){i=h[e+g|0];j[(b+8|0)+(g<<2)>>2]=((p(l,h[e+(g|2)|0]-i|0)|0)/16384|0)+(i<<8);i=k&1;k=0;g=1;if(i){continue}break}while(1){k=(b+8|0)+(f<<2)|0;l=j[k>>2];m=j[a+60>>2];i=(b+32|0)+(f<<3)|0;f=j[i>>2];e=Gb(f,-16777216,16776704);s=j[a+64>>2];g=Gb(j[i+4>>2],-16777216,16776704);r=j[a+68>>2];u=r;r=r>>31;j[i+4>>2]=f;v=j[a+72>>2];l=l<<8;f=l;f=OMa(m,m>>31,f,f>>31);m=ab;w=k;k=OMa(s,s>>31,e,e>>31);f=k+f|0;e=ab+m|0;e=f>>>0<k>>>0?e+1|0:e;k=f;f=OMa(u,r,g,g>>31);g=k+f|0;e=ab+e|0;e=g>>>0<f>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;j[w>>2]=(e|0)/256;j[i>>2]=e-(l&v);f=1;e=n&1;n=0;if(e){continue}break}e=j[a+32>>2];q=j[a+28>>2]+q|0;f=q>>12;j[c>>2]=j[c>>2]+p(f,j[b+8>>2]);o=e+o|0;g=o>>12;j[c+4>>2]=j[c+4>>2]+p(g,j[b+12>>2]);Bb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=j[b+24>>2];e=j[b+28>>2];continue}break}i=j[b+24>>2];e=j[b+28>>2];m=j[b+44>>2];k=j[b+40>>2];n=j[b+36>>2];l=j[b+32>>2]}j[a+40>>2]=o;j[a+20>>2]=f;j[a+36>>2]=q;j[a+56>>2]=m;j[a+52>>2]=k;j[a+48>>2]=n;j[a+44>>2]=l;j[a+24>>2]=g;j[a>>2]=i;j[a+4>>2]=e;Za=b+48|0}function d6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,i=0,l=0,m=0,n=0,o=0,q=0,r=0;f=Za-17168|0;Za=f;j[f+17164>>2]=0;a:{b:{c:{if(k[a+6152|0]!=255|(c|0)<5){break c}if(!bo(a+6152|0,b)){break c}i=Lv(b,j[a+6148>>2])+ao(b)|0;j[f+17164>>2]=i;if((c|0)==(i|0)){i=c;break b}d:{if((i+4|0)<=(c|0)){if(bo(b,b+i|0)){break d}}j[f+17164>>2]=0;break c}if(i){break b}}g=c6(b,c,Ab(a,0,6668)+6148|0,f+17164|0);i=j[f+17164>>2];if((g+i|0)<=(c|0)?i:0){break b}j[e>>2]=g;g=0;break a}c=b+g|0;j[a+6152>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[e+4>>2]=g;j[e>>2]=g+i;j[e+8>>2]=k[c+3|0]>191?1:2;q=e,r=bF(c),j[q+12>>2]=r;j[e+16>>2]=4-(k[c+1|0]>>>1&3);q=e,r=Kv(c),j[q+20>>2]=r;if(!d){g=Jv(c);break a}aF(f+17152|0,c+4|0,i-4|0);if(!(h[c+1|0]&1)){Bd(f+17152|0,16)}e:{if(j[e+16>>2]==3){g=0;b=b6(f+17152|0,f+3740|0,c);if(!((b|0)<0|j[f+17156>>2]>j[f+17160>>2])){i=a6(a,f+17152|0,f+912|0,b);if(i){l=a+2304|0;g=j[e+8>>2];m=f+8620|0;n=f+3852|0;b=0;while(1){o=Ab(n,0,4608);$5(a,f+912|0,(p(p(b,g),28)+f|0)+3740|0,g);$E(l,o,18,j[e+8>>2],d,m);g=j[e+8>>2];d=p(g,1152)+d|0;b=b+1|0;if(b>>>0<(k[c+1|0]&8?2:1)>>>0){continue}break}}_5(a,f+912|0);break e}Mv(a);break a}Z5(c,f+17152|0,f);g=0;b=Ab(f+3852|0,0,4608);i=a+2304|0;l=f+8620|0;c=0;f:{while(1){c=Y5(((c<<2)+f|0)+3852|0,f+17152|0,f,j[e+16>>2]|1)+c|0;if((c|0)==12){X5(f,(g<<2)+f|0,b);$E(i,b,12,j[e+8>>2],d,l);Ab(b,0,4608);d=p(j[e+8>>2],768)+d|0;c=0}if(j[f+17156>>2]<=j[f+17160>>2]){g=g+1|0;if((g|0)==3){break f}continue}break}Mv(a);g=0;break a}i=1}g=p(Jv(a+6152|0),i)}Za=f+17168|0;return g|0}function v$(a,b,c,d,e,f,g,i,l,m,n,o,p,q,r){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=Za-16|0;Za=x;j[c>>2]=a;A=d&512;while(1){if((z|0)==4){if(nb(q)>>>0>1){C=x,D=nd(q),j[C+8>>2]=D;C=c,D=aj(So(x+8|0,1),tj(q),j[c>>2]),j[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=j[c>>2]}j[b>>2]=a}Za=x+16|0}else{a:{b:{switch(h[l+z|0]){case 0:j[b>>2]=j[c>>2];break a;case 1:j[b>>2]=j[c>>2];t=Eq(g,32);s=j[c>>2];j[c>>2]=s+4;j[s>>2]=t;break a;case 3:if(Ec(q)){break a}t=j[Li(q,0)>>2];s=j[c>>2];j[c>>2]=s+4;j[s>>2]=t;break a;case 2:if(Ec(p)|!A){break a}C=c,D=aj(nd(p),tj(p),j[c>>2]),j[C>>2]=D;break a;case 4:break b;default:break a}}B=j[c>>2];e=i?e+4|0:e;u=e;while(1){c:{if(f>>>0<=u>>>0){break c}if(!zj(g,2048,j[u>>2])){break c}u=u+4|0;continue}break}s=r;if((s|0)>=1){while(1){t=(s|0)<1;if(!(t|e>>>0>=u>>>0)){u=u-4|0;v=j[u>>2];t=j[c>>2];j[c>>2]=t+4;j[t>>2]=v;s=s-1|0;continue}break}if(t){y=0}else{y=Eq(g,48)}t=j[c>>2];while(1){v=t+4|0;if((s|0)>=1){j[t>>2]=y;s=s-1|0;t=v;continue}break}j[c>>2]=v;j[t>>2]=m}d:{if((e|0)==(u|0)){t=Eq(g,48);s=j[c>>2];u=s+4|0;j[c>>2]=u;j[s>>2]=t;break d}v=-1;e:{if(Ec(o)){break e}v=h[Ub(o,0)|0]}s=0;w=0;while(1){if((e|0)!=(u|0)){f:{if((s|0)!=(v|0)){t=s;break f}t=j[c>>2];j[c>>2]=t+4;j[t>>2]=n;t=0;w=w+1|0;if(nb(o)>>>0<=w>>>0){v=s;break f}if(k[Ub(o,w)|0]==127){v=-1;break f}v=h[Ub(o,w)|0]}u=u-4|0;y=j[u>>2];s=j[c>>2];j[c>>2]=s+4;j[s>>2]=y;s=t+1|0;continue}break}u=j[c>>2]}On(B,u)}z=z+1|0;continue}break}}function Ysa(a,b,c){var d=0,e=0,f=0,g=0;d=Za-160|0;Za=d;f=Ek(d+56|0,a);j[114626]=0;e=E(683,d+8|0,18638)|0;a=j[114626];j[114626]=0;a:{b:{c:{d:{if((a|0)!=1){j[114626]=0;j[d+48>>2]=19465728;j[d+52>>2]=0;I(684,f|0,e|0,d+48|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}qb(e);if(!(j[f>>2]&1073741824)){break c}break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;qb(e);break b}j[114626]=0;h[d+48|0]=0;h[d+47|0]=0;e=E(683,d+8|0,18630)|0;a=j[114626];j[114626]=0;e:{if((a|0)!=1){j[114626]=0;K(1182,f|0,d+48|0,e|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}qb(e);if(!k[d+48|0]){break a}Ae(d+48|0,50);j[114626]=0;e=E(683,d+8|0,18646)|0;a=j[114626];j[114626]=0;f:{g:{h:{i:{if((a|0)!=1){j[114626]=0;K(1182,f|0,d+47|0,e|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break i}qb(e);e=rh(b);a=k[d+48|0];if(e>>>0<a>>>0){e=Rx(d+8|0,j[b+12>>2]);j[114626]=0;I(1183,b|0,a|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break h}dl(e)}e=l[gi(b,0)+28>>1];h[d+7|0]=0;if(k[d+48|0]){a=0;while(1){Ge(gi(b,a&255),e);a=gi(b,k[d+7|0]);j[114626]=0;F(1184,d+8|0,d+7|0);g=j[114626];j[114626]=0;if((g|0)==1){break g}j[114626]=0;L(1185,f|0,a|0,d+8|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break f}qb(d+8|0);a=k[d+7|0]+1|0;h[d+7|0]=a;if(k[d+48|0]>(a&255)>>>0){continue}break}}a=k[d+47|0];c=rh(b);h[b+16|0]=a>>>0<c>>>0?k[d+47|0]:0;break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;qb(e);break b}a=D()|0;C()|0;dl(e);break b}a=D()|0;C()|0;break b}a=D()|0;C()|0;qb(d+8|0);break b}a=D()|0;C()|0;break b}a=D()|0;C()|0;qb(e)}ag(f);G(a|0);z()}ag(f);Za=d+160|0}function OK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;h=Za-16|0;Za=h;a:{if((b|0)==(c|0)){break a}j[h+12>>2]=-1953789045;MK(b,c,h+12|0);d=c-b>>2;j[h+8>>2]=d;o=sb(a);g=o+1|0;j[h+4>>2]=g;l=j[Gc(h+4|0,h+8|0)>>2];k=j[((j[h+8>>2]<<2)+b|0)-4>>2];c=d;e=c;f=11;b:{if(c>>>0>622){break b}f=7;if(d>>>0>67){break b}f=5;if(d>>>0>38){break b}f=3;if(d>>>0>6){break b}f=d-1>>>1|0}m=e-f>>>1|0;c=(m<<2)+b|0;e=p(Xr(k^(j[c>>2]^j[b>>2])),1664525);j[c>>2]=e+j[c>>2];q=m+f|0;c=(q<<2)+b|0;d=c;f=j[c>>2];c=e+o|0;j[d>>2]=f+c;j[b>>2]=c;if(o){n=j[h+8>>2];c=1;while(1){e=c-1|0;d=((c+m>>>0)%(n>>>0)<<2)+b|0;f=(c>>>0)%(n>>>0)|0;i=(f<<2)+b|0;r=p(Xr(j[((e>>>0)%(n>>>0)<<2)+b>>2]^(j[d>>2]^j[i>>2])),1664525);j[d>>2]=r+j[d>>2];d=xb(a,e);n=j[h+8>>2];e=((c+q>>>0)%(n>>>0)<<2)+b|0;k=e;s=j[e>>2];e=j[d>>2]+(f+r|0)|0;j[k>>2]=s+e;j[i>>2]=e;c=c+1|0;if(o>>>0>=c>>>0){continue}break}}c=j[h+8>>2];if(g>>>0<l>>>0){while(1){a=((g+m>>>0)%(c>>>0)<<2)+b|0;d=(g>>>0)%(c>>>0)|0;e=(d<<2)+b|0;i=p(Xr(j[((g-1>>>0)%(c>>>0)<<2)+b>>2]^(j[a>>2]^j[e>>2])),1664525);j[a>>2]=i+j[a>>2];c=j[h+8>>2];a=((g+q>>>0)%(c>>>0)<<2)+b|0;f=a;k=j[a>>2];a=d+i|0;j[f>>2]=k+a;j[e>>2]=a;g=g+1|0;if((l|0)!=(g|0)){continue}break}}if(c+l>>>0<=l>>>0){break a}g=l;while(1){a=((g+m>>>0)%(c>>>0)<<2)+b|0;d=(g>>>0)%(c>>>0)|0;e=(d<<2)+b|0;i=p(Xr(j[((g-1>>>0)%(c>>>0)<<2)+b>>2]+(j[a>>2]+j[e>>2]|0)|0),1566083941);j[a>>2]=i^j[a>>2];c=j[h+8>>2];a=((g+q>>>0)%(c>>>0)<<2)+b|0;f=a;k=j[a>>2];a=i-d|0;j[f>>2]=k^a;j[e>>2]=a;g=g+1|0;if(g>>>0<c+l>>>0){continue}break}}Za=h+16|0}function tva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=Za-48|0;Za=e;s=j[a+16>>2];b=j[a+44>>2];j[e+32>>2]=b;h=j[a+48>>2];j[e+36>>2]=h;f=j[a+52>>2];j[e+40>>2]=f;n=j[a+56>>2];j[e+44>>2]=n;t=j[a+24>>2];u=j[a+20>>2];g=j[a+4>>2];k=j[a>>2];j[e+24>>2]=k;j[e+28>>2]=g;l=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=l;if(d){while(1){n=1;l=((((g&2147483647)<<1|k>>>31)&2147483646)<<1)+s|0;b=(k>>>21&2040)+27888|0;k=i[b+6>>1];m=i[b+4>>1];r=i[b+2>>1];o=i[b>>1];f=0;b=1;h=0;while(1){g=h<<1;j[(e+8|0)+(h<<2)>>2]=(((p(i[g+l>>1],r)+p(i[l+(g|-4)>>1],o)|0)+p(i[l+(g|4)>>1],m)|0)+p(k,i[l+(g|8)>>1])|0)/16384;g=b;b=0;h=1;if(g){continue}break}while(1){k=(e+8|0)+(f<<2)|0;l=j[k>>2];m=j[a+60>>2];g=(e+32|0)+(f<<3)|0;f=j[g>>2];b=Gb(f,-16777216,16776704);o=j[a+64>>2];h=Gb(j[g+4>>2],-16777216,16776704);q=j[a+68>>2];v=q;q=q>>31;j[g+4>>2]=f;w=j[a+72>>2];l=l<<8;f=l;f=OMa(m,m>>31,f,f>>31);m=ab;x=k;k=OMa(o,o>>31,b,b>>31);f=k+f|0;b=ab+m|0;b=f>>>0<k>>>0?b+1|0:b;r=f;f=OMa(v,q,h,h>>31);h=r+f|0;b=ab+b|0;b=f>>>0>h>>>0?b+1|0:b;h=h+8388608|0;if(h>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|h>>>24;j[x>>2]=(b|0)/256;j[g>>2]=b-(l&w);f=1;b=n&1;n=0;if(b){continue}break}j[c>>2]=j[c>>2]+p(j[e+8>>2],u);j[c+4>>2]=j[c+4>>2]+p(j[e+12>>2],t);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=j[e+24>>2];g=j[e+28>>2];continue}break}k=j[e+24>>2];g=j[e+28>>2];n=j[e+44>>2];f=j[e+40>>2];h=j[e+36>>2];b=j[e+32>>2]}j[a+56>>2]=n;j[a+52>>2]=f;j[a+48>>2]=h;j[a+44>>2]=b;j[a>>2]=k;j[a+4>>2]=g;Za=e+48|0}function rw(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Za-208|0;Za=d;a:{b:{c:{if(k[c|0]&2){if(j[b>>2]==-2147483648){e=gj(d+48|0,1,45);b=j[b>>2];j[114626]=0;j[d+188>>2]=b;I(137,d+192|0,d+188|0,c|0);b=j[114626];j[114626]=0;d:{e:{if((b|0)!=1){j[114626]=0;I(138,a|0,e|0,d+192|0);a=j[114626];j[114626]=0;if((a|0)==1){break e}gb(d+192|0);gb(e);break b}c=D()|0;C()|0;break d}c=D()|0;C()|0;gb(d+192|0)}gb(e);break a}e=j[b>>2];if((e|0)>-1){break c}e=gj(d+48|0,1,45);b=j[b>>2];j[114626]=0;j[d+188>>2]=0-b;I(137,d+192|0,d+188|0,c|0);b=j[114626];j[114626]=0;f:{g:{if((b|0)!=1){j[114626]=0;I(138,a|0,e|0,d+192|0);a=j[114626];j[114626]=0;if((a|0)==1){break g}gb(d+192|0);gb(e);break b}c=D()|0;C()|0;break f}c=D()|0;C()|0;gb(d+192|0)}gb(e);break a}e=Lg(d+48|0);f=j[j[e>>2]-12>>2];j[114626]=0;g=T(122)|0;h=j[114626];j[114626]=0;h:{i:{j:{k:{l:{if((h|0)==1){break l}j[114626]=0;I(123,d+40|0,f+(d+48|0)|0,g|0);f=j[114626];j[114626]=0;if((f|0)==1){break l}wb(d+40|0);j[114626]=0;F(139,e|0,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break l}j[114626]=0;F(124,e|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break l}j[114626]=0;F(125,d+8|0,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break l}j[114626]=0;I(140,d+24|0,d+8|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break k}j[114626]=0;I(141,a|0,d+24|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break j}gb(d+24|0);gb(d+8|0);Hd(e);break b}c=D()|0;C()|0;break h}c=D()|0;C()|0;break i}c=D()|0;C()|0;gb(d+24|0)}gb(d+8|0)}Hd(e);break a}j[d+48>>2]=e;wr(a,d+48|0,c)}Za=d+208|0;return}G(c|0);z()}function ara(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Za-48|0;Za=d;md(b,2);dk(d+16|0,2,a+1|0);qc(d+32|0,d+16|0);j[114626]=0;E(370,b+43|0,d+32|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){gb(d+32|0);a:{if(!(k[a|0]?k[a|0]!=1:0)){if(k[a|0]==1){c=a+16|0;j[b>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+20|0;j[d+32>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[d+16>>2]=j[b>>2]-1;f=b,g=j[tb(d+32|0,d+16|0)>>2],j[f+4>>2]=g;c=a+24|0;j[d+32>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);f=b,g=j[tb(d+32|0,b)>>2],j[f+8>>2]=g;i[b+34>>1]=l[b+34>>1]&65533|k[a+31|0]<<1&2}c=j[b+8>>2];if(c>>>0>m[b+4>>2]?c>>>0>=2:0){break a}i[b+34>>1]=0;j[b+4>>2]=0;j[b+8>>2]=0;break a}if(k[a|0]!=2){break a}ah(d+16|0,a+16|0);c=d+32|0;e=j[d+16>>2];e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);h[c|0]=e;h[c+1|0]=e>>>8;h[c+2|0]=e>>>16;h[c+3|0]=e>>>24;ah(d+16|0,a+20|0);c=d+32|0;e=j[d+16>>2];e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);h[c+4|0]=e;h[c+5|0]=e>>>8;h[c+6|0]=e>>>16;h[c+7|0]=e>>>24;ah(d+16|0,a+24|0);c=d+32|0;e=j[d+16>>2];e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);h[c+8|0]=e;h[c+9|0]=e>>>8;h[c+10|0]=e>>>16;h[c+11|0]=e>>>24;j[d+8>>2]=j[d+40>>2];c=j[d+36>>2];j[d>>2]=j[d+32>>2];j[d+4>>2]=c;Ro(b,1,d)}h[d+32|0]=k[a+28|0];h[d+16|0]=64;f=b,g=k[Yb(d+32|0,d+16|0)|0]<<2,i[f+30>>1]=g;a=a+32|0;a=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);j[b+24>>2]=a;b:{c:{if(!a){c=8363;break c}c=1024;if(a>>>0>1023){break b}}j[b+24>>2]=c}Za=d+48|0;return}a=D()|0;C()|0;gb(d+32|0);G(a|0);z()}function mna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,i=0,n=0,o=0,q=0;d=Za-48|0;Za=d;c=l[a+480190>>1];h[d+32|0]=0;gL(b,c+1|0,d+32|0);if(l[a+480192>>1]){g=Wt(d+32|0);c=a+484344|0;o=d,q=Lb(c),j[o+24>>2]=q;o=d,q=Mb(c),j[o+16>>2]=q;if(rb(d+24|0,d+16|0)){while(1){a:{i=j[d+24>>2];if(!th(i)){break a}c=l[a+480188>>1];j[114626]=0;h[d|0]=0;I(1417,g|0,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){b:{o=d,q=Lb(i),j[o+8>>2]=q;n=0;if(!j[i+12>>2]){break a}while(1){f=0;c:{if(!l[a+480188>>1]){break c}while(1){d:{c=j[d+8>>2];j[114626]=0;c=H(553,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break d}e:{if(!c){break e}c=k[j[d+8>>2]+1|0];if(!k[j[d+8>>2]+1|0]){c=k[fc(g,f)|0]}e=c&255;if(e){f:{if(e>>>0>256){break f}e=j[((k[j[d+8>>2]+1|0]<<2)+a|0)+900380>>2];if(!e){break f}e=l[Oc(e+236|0,k[j[d+8>>2]]-1|0)>>1];if(e>>>0>l[a+480190>>1]){break f}Nd(d,b,e);Qd(d,1)}o=fc(g,f),q=c,h[o|0]=q;break e}c=l[a+480192>>1];if(!c){break e}while(1){e=c;c=j[((c<<2)+a|0)+900380>>2];g:{if(!c){break g}c=l[Oc(c+236|0,k[j[d+8>>2]]-1|0)>>1];if(c>>>0>l[a+480190>>1]){break g}Nd(d,b,c);Qd(d,1)}c=e-1|0;if((e&65535)!=1){continue}break}}kk(d+8|0);f=f+1|0;if(f>>>0<l[a+480188>>1]){continue}break c}break}break b}n=n+1|0;if(n>>>0<m[i+12>>2]){continue}break}break a}}a=D()|0;C()|0;Od(g);G(a|0);z()}Hx(d+24|0);if(rb(d+24|0,d+16|0)){continue}break}}c=l[a+480190>>1];h:{if(!c){f=0;break h}f=0;while(1){Nd(d,b,c);if(!kb(d)){f=ke((p(c,104)+a|0)+484380|0)+f|0}e=c&65535;c=c-1|0;if((e|0)!=1){continue}break}}Od(g)}Za=d+48|0;return f&65535}function z$(a,b,c,d,e,f,g,i,l,m,n,o,p,q,r){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=Za-16|0;Za=x;j[c>>2]=a;A=d&512;while(1){if((y|0)==4){if(nb(q)>>>0>1){C=x,D=nd(q),j[C+8>>2]=D;C=c,D=aj($e(x+8|0,1),_e(q),j[c>>2]),j[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=j[c>>2]}j[b>>2]=a}Za=x+16|0;return}a:{b:{switch(h[l+y|0]){case 0:j[b>>2]=j[c>>2];break a;case 1:j[b>>2]=j[c>>2];t=qk(g,32);s=j[c>>2];j[c>>2]=s+1;h[s|0]=t;break a;case 3:if(Ec(q)){break a}t=k[Ub(q,0)|0];s=j[c>>2];j[c>>2]=s+1;h[s|0]=t;break a;case 2:if(Ec(p)|!A){break a}C=c,D=aj(nd(p),_e(p),j[c>>2]),j[C>>2]=D;break a;case 4:break b;default:break a}}B=j[c>>2];e=i?e+1|0:e;u=e;while(1){c:{if(f>>>0<=u>>>0){break c}if(!ng(g,2048,h[u|0])){break c}u=u+1|0;continue}break}t=r;if((t|0)>=1){while(1){s=(t|0)<1;if(!(s|e>>>0>=u>>>0)){u=u-1|0;s=k[u|0];v=j[c>>2];j[c>>2]=v+1;h[v|0]=s;t=t-1|0;continue}break}if(s){s=0}else{s=qk(g,48)}while(1){v=j[c>>2];j[c>>2]=v+1;if((t|0)>=1){h[v|0]=s;t=t-1|0;continue}break}h[v|0]=m}d:{if((e|0)==(u|0)){t=qk(g,48);s=j[c>>2];j[c>>2]=s+1;h[s|0]=t;break d}s=-1;e:{if(Ec(o)){break e}s=h[Ub(o,0)|0]}t=0;w=0;while(1){if((e|0)==(u|0)){break d}f:{if((t|0)!=(s|0)){v=t;break f}s=j[c>>2];j[c>>2]=s+1;h[s|0]=n;v=0;w=w+1|0;if(nb(o)>>>0<=w>>>0){s=t;break f}if(k[Ub(o,w)|0]==127){s=-1;break f}s=h[Ub(o,w)|0]}u=u-1|0;t=k[u|0];z=j[c>>2];j[c>>2]=z+1;h[z|0]=t;t=v+1|0;continue}}uj(B,j[c>>2])}y=y+1|0;continue}}function yua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=Za-48|0;Za=f;o=j[a+16>>2];h=wf(f+16|0);j[h+8>>2]=a+112;j[h+16>>2]=j[a+128>>2];v=h,w=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[v+12>>2]=w;b=j[h+16>>2];if(b){v=h,w=vf(a+8|0,b),j[v>>2]=w;j[h+4>>2]=ab}k=j[a+48>>2];q=j[a+24>>2];r=j[a+20>>2];m=j[a+44>>2];e=j[a+4>>2];g=j[a>>2];j[f+8>>2]=g;j[f+12>>2]=e;b=j[a+12>>2];j[f>>2]=j[a+8>>2];j[f+4>>2]=b;a:{if(!d){b=m;m=k;break a}while(1){b=0;l=b;j[f+40>>2]=g;j[f+44>>2]=b;e=(e<<1)+o|0;b:{b=j[h+16>>2];if((b|0)<=0){break b}while(1){id(j[h+8>>2],i[(l<<1)+e>>1]/4<<16>>16);hd(j[h+8>>2],4);Bb(f+40|0,h);if((b|0)<2){break b}b=b-1|0;l=j[f+44>>2];continue}}d=d-1|0;b=j[h+8>>2];Bb(b,b+8|0);b=j[h+8>>2];g=j[b+4>>2];if(g){id(b,i[e+(j[f+44>>2]<<1)>>1]/4<<16>>16);hd(j[h+8>>2],g);b=j[h+8>>2];g=j[b>>2];j[b>>2]=g;j[b+4>>2]=0}e=qf(b,j[h+12>>2]);g=j[a+60>>2];l=g;b=Gb(m,-16777216,16776704);n=j[a+64>>2];k=Gb(k,-16777216,16776704);s=j[a+72>>2];t=j[c>>2];u=g>>31;g=e<<8;e=g;e=OMa(l,u,e,e>>31);l=ab;n=OMa(n,n>>31,b,b>>31);e=n+e|0;b=ab+l|0;b=e>>>0<n>>>0?b+1|0:b;l=e;e=j[a+68>>2];e=OMa(e,e>>31,k,k>>31);k=l+e|0;b=ab+b|0;b=e>>>0>k>>>0?b+1|0:b;k=k+8388608|0;if(k>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|k>>>24;k=(b|0)/256|0;j[c>>2]=p(k,r)+t;j[c+4>>2]=j[c+4>>2]+p(k,q);b=b-(g&s)|0;Bb(f+8|0,f);if(d){c=c+8|0;g=j[f+8>>2];e=j[f+12>>2];k=m;m=b;continue}break}g=j[f+8>>2];e=j[f+12>>2]}j[a+48>>2]=m;j[a+44>>2]=b;j[a>>2]=g;j[a+4>>2]=e;Za=f+48|0}function uva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=Za-48|0;Za=e;t=j[a+16>>2];g=j[a+44>>2];j[e+32>>2]=g;b=j[a+48>>2];j[e+36>>2]=b;f=j[a+52>>2];j[e+40>>2]=f;o=j[a+56>>2];j[e+44>>2]=o;u=j[a+24>>2];v=j[a+20>>2];l=j[a+4>>2];k=j[a>>2];j[e+24>>2]=k;j[e+28>>2]=l;m=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=m;if(d){while(1){m=(((l&2147483647)<<1|k>>>31)&-2)+t|0;b=(k>>>21&2040)+27888|0;k=i[b+6>>1];n=i[b+4>>1];s=i[b+2>>1];q=i[b>>1];f=0;o=1;b=1;g=0;while(1){j[(e+8|0)+(g<<2)>>2]=(((p(h[g+m|0],s)+p(h[m+(g|-2)|0],q)|0)+p(h[m+(g|2)|0],n)|0)+p(k,h[m+(g|4)|0])<<8)/16384;l=b;b=0;g=1;if(l){continue}break}while(1){k=(e+8|0)+(f<<2)|0;m=j[k>>2];n=j[a+60>>2];l=(e+32|0)+(f<<3)|0;f=j[l>>2];b=Gb(f,-16777216,16776704);q=j[a+64>>2];g=Gb(j[l+4>>2],-16777216,16776704);r=j[a+68>>2];w=r;r=r>>31;j[l+4>>2]=f;x=j[a+72>>2];m=m<<8;f=m;f=OMa(n,n>>31,f,f>>31);n=ab;y=k;k=OMa(q,q>>31,b,b>>31);f=k+f|0;b=ab+n|0;b=f>>>0<k>>>0?b+1|0:b;s=f;f=OMa(w,r,g,g>>31);g=s+f|0;b=ab+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;j[y>>2]=(b|0)/256;j[l>>2]=b-(m&x);f=1;b=o&1;o=0;if(b){continue}break}j[c>>2]=j[c>>2]+p(j[e+8>>2],v);j[c+4>>2]=j[c+4>>2]+p(j[e+12>>2],u);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=j[e+24>>2];l=j[e+28>>2];continue}break}k=j[e+24>>2];l=j[e+28>>2];o=j[e+44>>2];f=j[e+40>>2];g=j[e+32>>2];b=j[e+36>>2]}j[a+56>>2]=o;j[a+52>>2]=f;j[a+48>>2]=b;j[a+44>>2]=g;j[a>>2]=k;j[a+4>>2]=l;Za=e+48|0}function o1(a,b,c,d,e){var f=0,g=0,i=q(0);f=Za-368|0;Za=f;j[f+352>>2]=b;j[f+360>>2]=a;Uu(f+200|0,c,f+224|0,f+220|0,f+216|0);b=Db(f+184|0);a=sc(b);j[114626]=0;F(149,b|0,a|0);a=j[114626];j[114626]=0;a:{b:{if((a|0)!=1){a=Ub(b,0);j[f+180>>2]=a;j[f+12>>2]=f+16;j[f+8>>2]=0;h[f+7|0]=1;h[f+6|0]=69;while(1){c:{j[114626]=0;c=E(2446,f+360|0,f+352|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+180>>2]==(nb(b)+a|0)){c=nb(b);a=nb(b);j[114626]=0;F(149,b|0,a<<1);a=j[114626];j[114626]=0;if((a|0)==1){break a}a=sc(b);j[114626]=0;F(149,b|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}a=Ub(b,0);j[f+180>>2]=c+a}j[114626]=0;c=H(2448,f+360|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=tq(c,f+7|0,f+6|0,a,f+180|0,j[f+220>>2],j[f+216>>2],f+200|0,f+16|0,f+12|0,f+8|0,f+224|0);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2450,f+360|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+200|0)|!k[f+7|0]){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;i=q(ja(2431,a|0,j[f+180>>2],d|0));a=j[114626];j[114626]=0;e:{if((a|0)==1){break e}n[e>>2]=i;j[114626]=0;le(f+200|0,f+16|0,j[f+12>>2],d);a=j[114626];j[114626]=0;if((a|0)==1){break e}j[114626]=0;a=E(2447,f+360|0,f+352|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(a){j[d>>2]=j[d>>2]|2}a=j[f+360>>2];gb(b);gb(f+200|0);Za=f+368|0;return a}}a=D()|0;C()|0;gb(b);gb(f+200|0);G(a|0);z()}function N1(a,b,c,d,e){var f=0,g=0,i=q(0);f=Za-272|0;Za=f;j[f+256>>2]=b;j[f+264>>2]=a;Wu(f+208|0,c,f+224|0,f+223|0,f+222|0);b=Db(f+192|0);a=sc(b);j[114626]=0;F(149,b|0,a|0);a=j[114626];j[114626]=0;a:{b:{if((a|0)!=1){a=Ub(b,0);j[f+188>>2]=a;j[f+12>>2]=f+16;j[f+8>>2]=0;h[f+7|0]=1;h[f+6|0]=69;while(1){c:{j[114626]=0;c=E(2414,f+264|0,f+256|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(b)+a|0)){c=nb(b);a=nb(b);j[114626]=0;F(149,b|0,a<<1);a=j[114626];j[114626]=0;if((a|0)==1){break a}a=sc(b);j[114626]=0;F(149,b|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}a=Ub(b,0);j[f+188>>2]=c+a}j[114626]=0;c=H(2416,f+264|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=vq(c,f+7|0,f+6|0,a,f+188|0,h[f+223|0],h[f+222|0],f+208|0,f+16|0,f+12|0,f+8|0,f+224|0);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2418,f+264|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)|!k[f+7|0]){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;i=q(ja(2431,a|0,j[f+188>>2],d|0));a=j[114626];j[114626]=0;e:{if((a|0)==1){break e}n[e>>2]=i;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);a=j[114626];j[114626]=0;if((a|0)==1){break e}j[114626]=0;a=E(2415,f+264|0,f+256|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(a){j[d>>2]=j[d>>2]|2}a=j[f+264>>2];gb(b);gb(f+208|0);Za=f+272|0;return a}}a=D()|0;C()|0;gb(b);gb(f+208|0);G(a|0);z()}function l1(a,b,c,d,e){var f=0,g=0,i=0;f=Za-368|0;Za=f;j[f+352>>2]=b;j[f+360>>2]=a;Uu(f+200|0,c,f+224|0,f+220|0,f+216|0);b=Db(f+184|0);a=sc(b);j[114626]=0;F(149,b|0,a|0);a=j[114626];j[114626]=0;a:{b:{if((a|0)!=1){a=Ub(b,0);j[f+180>>2]=a;j[f+12>>2]=f+16;j[f+8>>2]=0;h[f+7|0]=1;h[f+6|0]=69;while(1){c:{j[114626]=0;c=E(2446,f+360|0,f+352|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+180>>2]==(nb(b)+a|0)){c=nb(b);a=nb(b);j[114626]=0;F(149,b|0,a<<1);a=j[114626];j[114626]=0;if((a|0)==1){break a}a=sc(b);j[114626]=0;F(149,b|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}a=Ub(b,0);j[f+180>>2]=c+a}j[114626]=0;c=H(2448,f+360|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=tq(c,f+7|0,f+6|0,a,f+180|0,j[f+220>>2],j[f+216>>2],f+200|0,f+16|0,f+12|0,f+8|0,f+224|0);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2450,f+360|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+200|0)|!k[f+7|0]){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;i=+ca(2434,a|0,j[f+180>>2],d|0);a=j[114626];j[114626]=0;e:{if((a|0)==1){break e}o[e>>3]=i;j[114626]=0;le(f+200|0,f+16|0,j[f+12>>2],d);a=j[114626];j[114626]=0;if((a|0)==1){break e}j[114626]=0;a=E(2447,f+360|0,f+352|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(a){j[d>>2]=j[d>>2]|2}a=j[f+360>>2];gb(b);gb(f+200|0);Za=f+368|0;return a}}a=D()|0;C()|0;gb(b);gb(f+200|0);G(a|0);z()}function K1(a,b,c,d,e){var f=0,g=0,i=0;f=Za-272|0;Za=f;j[f+256>>2]=b;j[f+264>>2]=a;Wu(f+208|0,c,f+224|0,f+223|0,f+222|0);b=Db(f+192|0);a=sc(b);j[114626]=0;F(149,b|0,a|0);a=j[114626];j[114626]=0;a:{b:{if((a|0)!=1){a=Ub(b,0);j[f+188>>2]=a;j[f+12>>2]=f+16;j[f+8>>2]=0;h[f+7|0]=1;h[f+6|0]=69;while(1){c:{j[114626]=0;c=E(2414,f+264|0,f+256|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(b)+a|0)){c=nb(b);a=nb(b);j[114626]=0;F(149,b|0,a<<1);a=j[114626];j[114626]=0;if((a|0)==1){break a}a=sc(b);j[114626]=0;F(149,b|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}a=Ub(b,0);j[f+188>>2]=c+a}j[114626]=0;c=H(2416,f+264|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=vq(c,f+7|0,f+6|0,a,f+188|0,h[f+223|0],h[f+222|0],f+208|0,f+16|0,f+12|0,f+8|0,f+224|0);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2418,f+264|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)|!k[f+7|0]){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;i=+ca(2434,a|0,j[f+188>>2],d|0);a=j[114626];j[114626]=0;e:{if((a|0)==1){break e}o[e>>3]=i;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);a=j[114626];j[114626]=0;if((a|0)==1){break e}j[114626]=0;a=E(2415,f+264|0,f+256|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(a){j[d>>2]=j[d>>2]|2}a=j[f+264>>2];gb(b);gb(f+208|0);Za=f+272|0;return a}}a=D()|0;C()|0;gb(b);gb(f+208|0);G(a|0);z()}function Wra(a){var b=0,c=0,d=0,e=0;b=Za-400|0;Za=b;rL(b+384|0,8);j[114626]=0;fa(1205,b+368|0,9);e=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((e|0)!=1){j[114626]=0;e=E(1206,b+352|0,14)|0;c=j[114626];j[114626]=0;if((c|0)==1){break k}j[114626]=0;F(1207,b+384|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break j}j[114626]=0;F(1207,b+368|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break j}qL(b+280|0,4900);qL(b+208|0,32e3);nL(b+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);j[114626]=0;c=E(1208,b+104|0,b+384|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break i}fs(b+120|0,b+280|0,c);sf(c);j[114626]=0;c=E(1208,b+72|0,b+368|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break h}fs(b+88|0,b+208|0,c);sf(c);j[114626]=0;c=E(1208,b+40|0,b+120|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}fs(b+56|0,b+136|0,c);sf(c);j[114626]=0;c=E(1208,b+8|0,b+88|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}fs(b+24|0,b+136|0,c);sf(c);Mo(b+120|0);Mo(b+56|0);Mo(b+88|0);Mo(b+24|0);Mo(b+368|0);Lo(b+120|0,ai(a,0));Lo(b+56|0,ai(a,1));Lo(b+88|0,ai(a,2));Lo(b+24|0,ai(a,3));Lo(b+368|0,ai(a,4));sf(b+24|0);sf(b+56|0);sf(b+88|0);sf(b+120|0);Ko(e);sf(b+368|0);sf(b+384|0);Za=b+400|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;break c}a=D()|0;C()|0;break c}a=D()|0;C()|0;break d}a=D()|0;C()|0;break e}a=D()|0;C()|0;sf(b+56|0)}sf(b+88|0)}sf(b+120|0)}Ko(e)}sf(b+368|0)}sf(b+384|0);G(a|0);z()}function ix(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=92;i=91;j=85;k=84;l=83;m=5;n=107;o=106;p=96;c=88;q=82;r=80;s=78;t=79;u=77;v=57;w=47;d=10;e=8;f=7;a=mx(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if((b|0)!=32?!c:0){break c}vb(a,0,1);vb(a,7,1);vb(a,8,1);vb(a,9,1);vb(a,10,1);vb(a,11,1);vb(a,12,1);vb(a,13,1);vb(a,14,1);vb(a,15,1);vb(a,16,1);vb(a,17,1);vb(a,18,1);vb(a,19,1);vb(a,20,1);vb(a,21,1);vb(a,22,1);vb(a,23,1);vb(a,24,1);vb(a,25,1);vb(a,26,1);vb(a,27,1);vb(a,28,1);vb(a,29,1);vb(a,30,1);vb(a,31,1);vb(a,32,1);vb(a,33,1);vb(a,34,1);vb(a,35,1);vb(a,36,1);vb(a,37,1);vb(a,38,1);vb(a,39,1);vb(a,40,1);vb(a,41,1);vb(a,42,1);vb(a,43,1);vb(a,44,1);vb(a,45,1);vb(a,46,1);vb(a,47,1);vb(a,48,1);vb(a,103,1);vb(a,50,1);vb(a,87,1);vb(a,88,1);vb(a,100,1);vb(a,102,1);vb(a,104,1);if(!c){break a}d=108;e=105;f=99;break b;case 3:vb(a,0,1);vb(a,4,1);vb(a,8,1);vb(a,9,1);vb(a,10,1);vb(a,17,1);vb(a,40,1);vb(a,51,1);vb(a,52,1);vb(a,53,1);vb(a,54,1);vb(a,55,1);vb(a,56,1);vb(a,57,1);vb(a,58,1);vb(a,59,1);vb(a,60,1);vb(a,61,1);vb(a,62,1);vb(a,63,1);vb(a,64,1);vb(a,65,1);vb(a,66,1);vb(a,67,1);vb(a,68,1);n=98;o=93;p=90;c=89;q=88;r=86;s=76;t=75;u=74;v=73;w=72;d=71;e=70;g=69;case 1:vb(a,g,1);vb(a,e,1);vb(a,d,1);vb(a,w,1);vb(a,v,1);vb(a,u,1);vb(a,t,1);m=s;l=r;k=q;j=c;i=p;h=o;c=n;break;case 2:break c;case 0:break d}}vb(a,m,1);vb(a,l,1);vb(a,k,1);g=j;f=i;e=h;d=c}vb(a,g,1)}vb(a,f,1);vb(a,e,1);vb(a,d,1)}}function $I(a,b){var c=0,d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;c=Za-16|0;Za=c;d=p(b,896)+a|0;a:{if(j[d+1075072>>2]&134218752){break a}if(!Qi(d+1074984|0)){break a}m=j[(p(b,896)+a|0)+1075640>>2];if(k[m+15|0]&2){break a}d=Zk(a,b,2,1);if(d-251>>>0<5|!d){break a}g=j[(p(d,160)+a|0)+906140>>2];if(!g){break a}e=p(b,896)+a|0;d=k[e+1075794|0];b:{if(k[e+1075796|0]==1){h[c+8|0]=64;f=k[Yb(e+1075798|0,c+8|0)|0];break b}f=255;if(k[e+1075797|0]!=13){break b}h[c+8|0]=64;f=k[Yb((p(b,896)+a|0)+1075799|0,c+8|0)|0]}o=a+1074308|0;mb(c+8|0,o,2);if(kb(c+8|0)){if(d){e=a;f=b;if(Ld(d)){d=k[Pb(m+108|0,d-1|0)|0]}Mj(e,f,d,l[(p(b,896)+a|0)+1075672>>1]);break a}if((f|0)==255){break a}bb[j[j[g>>2]+76>>2]](g,39,f,b);break a}q=j[m+4>>2];if(d){e=q<<2;j[c+4>>2]=e;if(!k[m+35|0]){e=j[(p(b,896)+a|0)+1075672>>2];j[c+4>>2]=e}n=i[(p(b,896)+a|0)+1075772>>1];mb(c+8|0,o,28);r=c,s=(kb(c+8|0)?n<<2:n)+e|0,j[r+4>>2]=s;Md(c+4|0,0,256);e=d;n=b;if(Ld(d)){e=k[Pb(m+108|0,d-1|0)|0]}Mj(a,n,e&255,l[c+4>>1])}e=k[m+35|0];mb(c+8|0,o,101);a=(d|0)!=0;c:{if(kb(c+8|0)){break c}a=Ld(d)}a=a^1;if(a|(e|0)!=1?!(a&(f|0)!=255):0){break a}d:{switch(k[m+36|0]){case 1:if((f|0)!=255){sH(g,f<<1);break a}sH(g,q<<1);break a;case 0:break d;default:break a}}if((f|0)!=255){h[c+8|0]=127;h[c+4|0]=f<<1;s=g,t=7,u=k[Yb(c+8|0,c+4|0)|0],v=b,r=j[j[g>>2]+76>>2],bb[r](s|0,t|0,u|0,v|0);break a}j[c+8>>2]=127;j[c+4>>2]=q<<1;v=g,u=7,t=k[tb(c+8|0,c+4|0)|0],s=b,r=j[j[g>>2]+76>>2],bb[r](v|0,u|0,t|0,s|0)}Za=c+16|0}function Mea(a){var b=0,c=0,d=q(0),e=q(0),f=0,g=q(0),h=0,i=q(0),k=0,l=q(0),m=0;f=Za-16|0;Za=f;g=n[a+4268>>2];d=q(n[a+4232>>2]*q(.30000001192092896));n[f+12>>2]=n[a+4240>>2]*q(.10000000149011612);j[f+8>>2]=1000593162;b=a;i=n[pw(f+12|0,f+8|0)>>2];e=q(g*q(q(d+q(.007000000216066837))+i));a:{if(q(r(e))<q(2147483648)){c=~~e;break a}c=-2147483648}j[b+4352>>2]=c;b=1;while(1){h=((p(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=q(q(q(n[(b<<2)+33600>>2]*i)+d)*g);b:{if(q(r(e))<q(2147483648)){c=~~e;break b}c=-2147483648}j[h>>2]=c;b=b+1|0;if((b|0)!=12){continue}break}n[f+12>>2]=q(q(n[a+4248>>2]*q(100))*q(.009091000072658062))+q(.09091000258922577);j[f+8>>2]=1065353216;d=q(n[Rk(f+12|0,f+8|0)>>2]*g);i=q(d*q(.07500000298023224));d=q(d*q(.06700000166893005));b=0;while(1){c=(b<<2)+a|0;m=c+4316|0;k=b+k|0;e=Yd(q(.9300000071525574),q(k|0));l=q(i*e);c:{if(q(r(l))<q(2147483648)){h=~~l;break c}h=-2147483648}j[m>>2]=h;h=c+4292|0;e=q(d*e);d:{if(q(r(e))<q(2147483648)){c=~~e;break d}c=-2147483648}j[h>>2]=c;b=b+1|0;if((b|0)!=6){continue}break}c=a+4348|0;d=q(g*q(.0035299998708069324));e:{if(q(r(d))<q(2147483648)){b=~~d;break e}b=-2147483648}j[c>>2]=b;c=a+4344|0;d=q(g*q(.0032500000670552254));f:{if(q(r(d))<q(2147483648)){b=~~d;break f}b=-2147483648}j[c>>2]=b;c=a+4340|0;g=q(g*q(.009999999776482582));g:{if(q(r(g))<q(2147483648)){b=~~g;break g}b=-2147483648}j[c>>2]=b;b=0;while(1){XG((p(b,24)+a|0)+4504|0,j[((b<<2)+a|0)+4292>>2]);b=b+1|0;if(b>>>0<15){continue}break}Za=f+16|0}function zua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=Za-48|0;Za=f;o=j[a+16>>2];i=wf(f+16|0);j[i+8>>2]=a+112;j[i+16>>2]=j[a+128>>2];v=i,w=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[v+12>>2]=w;b=j[i+16>>2];if(b){v=i,w=vf(a+8|0,b),j[v>>2]=w;j[i+4>>2]=ab}k=j[a+48>>2];q=j[a+24>>2];r=j[a+20>>2];m=j[a+44>>2];e=j[a+4>>2];g=j[a>>2];j[f+8>>2]=g;j[f+12>>2]=e;b=j[a+12>>2];j[f>>2]=j[a+8>>2];j[f+4>>2]=b;a:{if(!d){b=m;m=k;break a}while(1){b=0;l=b;j[f+40>>2]=g;j[f+44>>2]=b;e=e+o|0;b:{b=j[i+16>>2];if((b|0)<=0){break b}while(1){id(j[i+8>>2],h[e+l|0]<<6);hd(j[i+8>>2],4);Bb(f+40|0,i);if((b|0)<2){break b}b=b-1|0;l=j[f+44>>2];continue}}d=d-1|0;b=j[i+8>>2];Bb(b,b+8|0);b=j[i+8>>2];g=j[b+4>>2];if(g){id(b,h[e+j[f+44>>2]|0]<<6);hd(j[i+8>>2],g);b=j[i+8>>2];g=j[b>>2];j[b>>2]=g;j[b+4>>2]=0}e=qf(b,j[i+12>>2]);g=j[a+60>>2];l=g;b=Gb(m,-16777216,16776704);n=j[a+64>>2];k=Gb(k,-16777216,16776704);s=j[a+72>>2];t=j[c>>2];u=g>>31;g=e<<8;e=g;e=OMa(l,u,e,e>>31);l=ab;n=OMa(n,n>>31,b,b>>31);e=n+e|0;b=ab+l|0;b=e>>>0<n>>>0?b+1|0:b;l=e;e=j[a+68>>2];e=OMa(e,e>>31,k,k>>31);k=l+e|0;b=ab+b|0;b=e>>>0>k>>>0?b+1|0:b;k=k+8388608|0;if(k>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|k>>>24;k=(b|0)/256|0;j[c>>2]=p(k,r)+t;j[c+4>>2]=j[c+4>>2]+p(k,q);b=b-(g&s)|0;Bb(f+8|0,f);if(d){c=c+8|0;g=j[f+8>>2];e=j[f+12>>2];k=m;m=b;continue}break}g=j[f+8>>2];e=j[f+12>>2]}j[a+48>>2]=m;j[a+44>>2]=b;j[a>>2]=g;j[a+4>>2]=e;Za=f+48|0}function Kua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;k=Za-16|0;Za=k;f=j[a+48>>2];o=j[a+40>>2];q=j[a+36>>2];e=j[a+44>>2];t=j[a+16>>2];g=j[a+4>>2];l=j[a>>2];j[k+8>>2]=l;j[k+12>>2]=g;h=j[a+12>>2];j[k>>2]=j[a+8>>2];j[k+4>>2]=h;a:{if(!d){m=o>>12;r=q>>12;break a}while(1){h=(g<<1)+t|0;m=i[h-6>>1];g=(((l>>>16|0)+4&131064)<<1)+b|0;l=i[g+24>>1];r=i[h-4>>1];u=i[g+26>>1];v=i[h-2>>1];w=i[g+28>>1];x=i[h>>1];y=i[g+30>>1];z=i[h+2>>1];A=i[g+32>>1];B=i[h+4>>1];C=i[g+34>>1];D=i[h+6>>1];E=i[g+36>>1];F=i[h+8>>1];G=i[g+38>>1];h=j[a+60>>2];H=h;I=h>>31;h=e;e=Gb(e,-16777216,16776704);n=j[a+64>>2];f=Gb(f,-16777216,16776704);J=j[a+72>>2];K=j[a+32>>2];g=c;L=j[g>>2];e=OMa(n,n>>31,e,e>>31);n=ab;M=e;e=j[a+68>>2];s=OMa(e,e>>31,f,f>>31);e=M+s|0;f=ab+n|0;f=e>>>0<s>>>0?f+1|0:f;n=e;l=(((((p(B,C)+p(z,A)|0)+p(D,E)|0)+p(F,G)|0)/2|0)+((((p(r,u)+p(l,m)|0)+p(v,w)|0)+p(x,y)|0)/2|0)|0)/16384<<8;e=l;m=OMa(H,I,e,e>>31);e=n+m|0;f=ab+f|0;f=e>>>0<m>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;q=j[a+28>>2]+q|0;r=q>>12;j[g>>2]=p(f,r)+L;o=o+K|0;m=o>>12;j[c+4>>2]=j[c+4>>2]+p(f,m);e=e-(l&J)|0;Bb(k+8|0,k);d=d-1|0;if(d){c=c+8|0;l=j[k+8>>2];g=j[k+12>>2];f=h;continue}break}l=j[k+8>>2];g=j[k+12>>2];f=h}j[a+40>>2]=o;j[a+20>>2]=r;j[a+36>>2]=q;j[a+48>>2]=f;j[a+44>>2]=e;j[a+24>>2]=m;j[a>>2]=l;j[a+4>>2]=g;Za=k+16|0}function y1(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=Za-352|0;Za=f;j[f+336>>2]=b;j[f+344>>2]=a;h=Dg(c);i=Yl(c,f+224|0);Xl(f+208|0,c,f+332|0);a=Db(f+192|0);b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=Ub(a,0);j[f+188>>2]=b;j[f+12>>2]=f+16;j[f+8>>2]=0;while(1){c:{j[114626]=0;c=E(2446,f+344|0,f+336|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(a)+b|0)){c=nb(a);b=nb(a);j[114626]=0;F(149,a|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=Ub(a,0);j[f+188>>2]=c+b}j[114626]=0;c=H(2448,f+344|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=wj(c,h,b,f+188|0,f+8|0,j[f+332>>2],f+208|0,f+16|0,f+12|0,i);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2450,f+344|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;b=Hn(2425,b,j[f+188>>2],d,h);c=ab;h=j[114626];j[114626]=0;e:{if((h|0)==1){break e}j[e>>2]=b;j[e+4>>2]=c;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=E(2447,f+344|0,f+336|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(b){j[d>>2]=j[d>>2]|2}b=j[f+344>>2];gb(a);gb(f+208|0);Za=f+352|0;return b}}b=D()|0;C()|0;gb(a);gb(f+208|0);G(b|0);z()}function q1(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=Za-352|0;Za=f;j[f+336>>2]=b;j[f+344>>2]=a;h=Dg(c);i=Yl(c,f+224|0);Xl(f+208|0,c,f+332|0);a=Db(f+192|0);b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=Ub(a,0);j[f+188>>2]=b;j[f+12>>2]=f+16;j[f+8>>2]=0;while(1){c:{j[114626]=0;c=E(2446,f+344|0,f+336|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(a)+b|0)){c=nb(a);b=nb(a);j[114626]=0;F(149,a|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=Ub(a,0);j[f+188>>2]=c+b}j[114626]=0;c=H(2448,f+344|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=wj(c,h,b,f+188|0,f+8|0,j[f+332>>2],f+208|0,f+16|0,f+12|0,i);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2450,f+344|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;b=Hn(2429,b,j[f+188>>2],d,h);c=ab;h=j[114626];j[114626]=0;e:{if((h|0)==1){break e}j[e>>2]=b;j[e+4>>2]=c;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=E(2447,f+344|0,f+336|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(b){j[d>>2]=j[d>>2]|2}b=j[f+344>>2];gb(a);gb(f+208|0);Za=f+352|0;return b}}b=D()|0;C()|0;gb(a);gb(f+208|0);G(b|0);z()}function Xva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Za-48|0;Za=b;v=j[a+16>>2];l=j[a+44>>2];j[b+32>>2]=l;n=j[a+48>>2];j[b+36>>2]=n;g=j[a+52>>2];j[b+40>>2]=g;h=j[a+56>>2];j[b+44>>2]=h;o=j[a+40>>2];q=j[a+36>>2];e=j[a+4>>2];k=j[a>>2];j[b+24>>2]=k;j[b+28>>2]=e;f=j[a+12>>2];j[b+16>>2]=j[a+8>>2];j[b+20>>2]=f;a:{if(!d){m=o>>12;f=q>>12;break a}while(1){e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+v|0;h=i[e>>1];j[b+8>>2]=h;j[b+12>>2]=i[e+2>>1];f=0;n=1;while(1){g=j[a+60>>2];m=g;k=(b+32|0)+(f<<3)|0;r=j[k>>2];e=Gb(r,-16777216,16776704);u=j[a+64>>2];l=Gb(j[k+4>>2],-16777216,16776704);s=j[a+68>>2];w=s;s=s>>31;j[k+4>>2]=r;r=j[a+72>>2];t=g>>31;h=h<<8;g=h;g=OMa(m,t,g,g>>31);m=ab;t=(b+8|0)+(f<<2)|0;f=g;g=OMa(u,u>>31,e,e>>31);f=f+g|0;e=ab+m|0;e=f>>>0<g>>>0?e+1|0:e;l=OMa(w,s,l,l>>31);f=l+f|0;e=ab+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;j[t>>2]=(e|0)/256;j[k>>2]=e-(h&r);if(n){f=1;n=0;h=j[b+12>>2];continue}break}e=j[a+32>>2];q=j[a+28>>2]+q|0;f=q>>12;j[c>>2]=j[c>>2]+p(f,j[b+8>>2]);o=e+o|0;m=o>>12;j[c+4>>2]=j[c+4>>2]+p(m,j[b+12>>2]);Bb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;k=j[b+24>>2];e=j[b+28>>2];continue}break}k=j[b+24>>2];e=j[b+28>>2];h=j[b+44>>2];g=j[b+40>>2];n=j[b+36>>2];l=j[b+32>>2]}j[a+40>>2]=o;j[a+20>>2]=f;j[a+36>>2]=q;j[a+56>>2]=h;j[a+52>>2]=g;j[a+48>>2]=n;j[a+44>>2]=l;j[a+24>>2]=m;j[a>>2]=k;j[a+4>>2]=e;Za=b+48|0}function Lua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=Za-16|0;Za=l;f=j[a+48>>2];q=j[a+40>>2];r=j[a+36>>2];e=j[a+44>>2];u=j[a+16>>2];g=j[a+4>>2];m=j[a>>2];j[l+8>>2]=m;j[l+12>>2]=g;k=j[a+12>>2];j[l>>2]=j[a+8>>2];j[l+4>>2]=k;a:{if(!d){n=q>>12;s=r>>12;break a}while(1){k=g+u|0;n=h[k-3|0];g=(((m>>>16|0)+4&131064)<<1)+b|0;m=i[g+24>>1];s=h[k-2|0];v=i[g+26>>1];w=h[k-1|0];x=i[g+28>>1];y=h[k|0];z=i[g+30>>1];A=h[k+1|0];B=i[g+32>>1];C=h[k+2|0];D=i[g+34>>1];E=h[k+3|0];F=i[g+36>>1];G=h[k+4|0];H=i[g+38>>1];k=j[a+60>>2];I=k;J=k>>31;k=e;e=Gb(e,-16777216,16776704);o=j[a+64>>2];f=Gb(f,-16777216,16776704);K=j[a+72>>2];L=j[a+32>>2];g=c;M=j[g>>2];e=OMa(o,o>>31,e,e>>31);o=ab;N=e;e=j[a+68>>2];t=OMa(e,e>>31,f,f>>31);e=N+t|0;f=ab+o|0;f=e>>>0<t>>>0?f+1|0:f;o=e;m=(((((p(C,D)+p(A,B)|0)+p(E,F)|0)+p(G,H)<<8)/2|0)+((((p(s,v)+p(m,n)|0)+p(w,x)|0)+p(y,z)<<8)/2|0)|0)/16384<<8;e=m;n=OMa(I,J,e,e>>31);e=o+n|0;f=ab+f|0;f=e>>>0<n>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;r=j[a+28>>2]+r|0;s=r>>12;j[g>>2]=p(f,s)+M;q=q+L|0;n=q>>12;j[c+4>>2]=j[c+4>>2]+p(f,n);e=e-(m&K)|0;Bb(l+8|0,l);d=d-1|0;if(d){c=c+8|0;m=j[l+8>>2];g=j[l+12>>2];f=k;continue}break}m=j[l+8>>2];g=j[l+12>>2];f=k}j[a+40>>2]=q;j[a+20>>2]=s;j[a+36>>2]=r;j[a+48>>2]=f;j[a+44>>2]=e;j[a+24>>2]=n;j[a>>2]=m;j[a+4>>2]=g;Za=l+16|0}function mCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,p=0;e=Za-16|0;Za=e;a:{if((c|0)!=4){g=b+236|0;m=b+108|0;while(1){f=(d<<2)+a|0;n=k[f+4|0];o=Pb(m,d),p=n+1|0,h[o|0]=p;f=f+6|0;f=k[f|0]|k[f+1|0]<<8;o=Oc(g,d),p=f+1|0,i[o>>1]=p;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){m=((d<<2)+a|0)+6|0;m=k[m|0]|k[m+1|0]<<8;o=Oc(g,d+12|0),p=m+1|0,i[o>>1]=p;d=d+1|0;if((d|0)!=96){continue}break}}Ey(a+484|0,b+48|0,0);Ey(a+590|0,b+68|0,0);Ey(a+696|0,b+88|0,5);d=a+806|0;j[b>>2]=k[d|0]|k[d+1|0]<<8;d=a+808|0;g=k[d|0];b:{if(h[d|0]<=-1){h[b+34|0]=g-127;break b}if(!(!(h[a|0]&1)|g>>>0>16)){h[b+31|0]=k[d|0]+1;break b}if(!k[d|0]|k[d|0]>16){break b}h[b+31|0]=k[d|0]+1}if(k[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(h[d|0]>=0){i[b+28>>1]=k[d|0]+1}d=a+810|0;if(h[d|0]<0){break c}}h[b+30|0]=k[d|0]+1}h[b+33|0]=k[a+811|0]}if((c|0)==32){h[e+15|0]=k[a+812|0];h[e+14|0]=128;o=b,p=k[Yb(e+15|0,e+14|0)|0]>>>1|0,j[o+4>>2]=p}c=a+813|0;if((k[c|0]|k[c+1|0]<<8)>>>0<=256){j[b+8>>2]=k[c|0]|k[c+1|0]<<8;h[b+15|0]=k[b+15|0]|1}h[b+16|0]=k[a+815|0];h[b+26|0]=k[a+816|0];h[b+27|0]=k[a+817|0];h[b+17|0]=k[a+818|0];h[b+18|0]=k[a+819|0];c=a+820|0;i[e+12>>1]=k[c|0]|k[c+1|0]<<8;i[e+10>>1]=100;o=b,p=k[gf(e+12|0,e+10|0)|0],h[o+20|0]=p;c=a+822|0;i[e+8>>1]=k[c|0]|k[c+1|0]<<8;i[e+6>>1]=256;o=b,p=l[gf(e+8|0,e+6|0)>>1]>>>2|0,h[o+19|0]=p;c=a+824|0;Kt(b,k[c|0]&127,k[c|0]>>>7|0);a=a+825|0;Jt(b,k[a|0]&127,k[a|0]>>>7|0);Za=e+16|0}function Wka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;f=Za-16|0;Za=f;a:{if(Rs(a)){break a}q=d+484344|0;m=kd(dd(a)+1|0,1,1024);if(!Wf(q,b,m)){break a}d=l[d+480188>>1];if(!d|!m){break a}r=d-1|0;while(1){if(!yb(a,1)){break a}g=dd(a);b:{if(!g){n=n+1|0;break b}d=Ib(q,b);i[f+14>>1]=g&31;i[f+12>>1]=r;d=Se(d,n,l[gf(f+14|0,f+12|0)>>1]);if(!(g&224)){break b}c:{if(!(g&128)){break c}t=d,u=dd(a),h[t+5|0]=u;d:{e=dd(a);if(e>>>0>=26){break d}e=k[e+31824|0];h[d+3|0]=e;e:{switch(e-1|0){case 0:if(!k[d+5|0]){break d}break c;case 12:if(k[d+2|0]){break c}h[d+2|0]=1;e=kd(k[d+5|0],0,64);h[d+5|0]=0;h[d+3|0]=0;h[d+4|0]=e;break c;case 5:case 6:case 10:case 23:case 28:e=k[d+5|0]&240;if(!e){break c}h[d+5|0]=e;break c;case 8:e=k[d+5|0];if(e>>>0<=128){t=d,u=$i(e<<1),h[t+5|0]=u;break c}if((e|0)!=164){break c}h[d+5|0]=145;h[d+3|0]=20;break c;case 13:e=k[d+5|0];h[d+5|0]=p(e>>>4|0,10)+(e&15);break c;case 18:Lw(d);break c;case 16:if(k[d+5|0]>31){break c}h[d+3|0]=16;break c;case 27:break e;default:break c}}s=d;e=k[d+5|0];j=e&240;o=2;f:{g:{if((j|0)==16){break g}if((j|0)!=32){break f}o=3}h[s+3|0]=o}h[d+5|0]=e&15|224;break c}h[d+3|0]=0}h:{if(!(g&64)){break h}zt(f+8|0,a);e=Pc(f+8|0);h[d+1|0]=k[f+8|0];e=k[e|0];h[d|0]=e;j=255;if((e|0)!=128){j=253;if(e>>>0<129){break h}}h[d|0]=j}if(!(g&32)){break b}h[d+2|0]=1;e=dd(a);h[d+4|0]=e;if(!c){break b}h[d+4|0]=(e<<6>>>0)/127}if(n>>>0<m>>>0){continue}break}}Za=f+16|0}function Vra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;d=Za-48|0;Za=d;e=pL(d+32|0,1<<j[b+12>>2]);if(fg(a)){while(1){g=o[uk(a,c)>>3];oL(_b(e,c),g);c=c+1|0;if(fg(a)>>>0>c>>>0){continue}break}}j[114626]=0;F(1210,b|0,e|0);c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}h=d,i=Lb(e),j[h>>2]=i;h=d,i=Mb(e),j[h+24>>2]=i;b:{if(rb(d,d+24|0)){while(1){c=j[d>>2];j[114626]=0;g=+$(1211,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break b}oL(c,Xn(g));yf(d);if(rb(d,d+24|0)){continue}break}}j[114626]=0;F(1212,b|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}j[114626]=0;N(1213,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}if(Xc(e)>>>0>3){c=1;while(1){Kx(_b(e,c),2);Kx(_b(e,(Xc(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<Xc(e)>>>1>>>0){continue}break}}j[114626]=0;F(1210,b|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}h=d,i=Lb(e),j[h+24>>2]=i;h=d,i=Mb(e),j[h+16>>2]=i;if(rb(d+24|0,d+16|0)){while(1){c=j[d+24>>2];j[114626]=0;F(1214,d|0,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break b}f=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=f;f=j[d+12>>2];j[c+8>>2]=j[d+8>>2];j[c+12>>2]=f;yf(d+24|0);if(rb(d+24|0,d+16|0)){continue}break}}j[114626]=0;F(1212,b|0,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;N(1213,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}if(fg(a)){c=0;while(1){g=o[_b(e,c)>>3];h=uk(a,c),k=g,o[h>>3]=k;c=c+1|0;if(fg(a)>>>0>c>>>0){continue}break}}Ko(e);Za=d+48|0;return}}a=D()|0;C()|0;Ko(e);G(a|0);z()}function w1(a,b,c,d,e){var f=0,g=0,h=0,k=0;f=Za-352|0;Za=f;j[f+336>>2]=b;j[f+344>>2]=a;h=Dg(c);k=Yl(c,f+224|0);Xl(f+208|0,c,f+332|0);a=Db(f+192|0);b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=Ub(a,0);j[f+188>>2]=b;j[f+12>>2]=f+16;j[f+8>>2]=0;while(1){c:{j[114626]=0;c=E(2446,f+344|0,f+336|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(a)+b|0)){c=nb(a);b=nb(a);j[114626]=0;F(149,a|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=Ub(a,0);j[f+188>>2]=c+b}j[114626]=0;c=H(2448,f+344|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=wj(c,h,b,f+188|0,f+8|0,j[f+332>>2],f+208|0,f+16|0,f+12|0,k);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2450,f+344|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;b=P(2426,b|0,j[f+188>>2],d|0,h|0)|0;c=j[114626];j[114626]=0;e:{if((c|0)==1){break e}i[e>>1]=b;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=E(2447,f+344|0,f+336|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(b){j[d>>2]=j[d>>2]|2}b=j[f+344>>2];gb(a);gb(f+208|0);Za=f+352|0;return b}}b=D()|0;C()|0;gb(a);gb(f+208|0);G(b|0);z()}function u1(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=Za-352|0;Za=f;j[f+336>>2]=b;j[f+344>>2]=a;h=Dg(c);i=Yl(c,f+224|0);Xl(f+208|0,c,f+332|0);a=Db(f+192|0);b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=Ub(a,0);j[f+188>>2]=b;j[f+12>>2]=f+16;j[f+8>>2]=0;while(1){c:{j[114626]=0;c=E(2446,f+344|0,f+336|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(a)+b|0)){c=nb(a);b=nb(a);j[114626]=0;F(149,a|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=Ub(a,0);j[f+188>>2]=c+b}j[114626]=0;c=H(2448,f+344|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=wj(c,h,b,f+188|0,f+8|0,j[f+332>>2],f+208|0,f+16|0,f+12|0,i);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2450,f+344|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;b=P(2427,b|0,j[f+188>>2],d|0,h|0)|0;c=j[114626];j[114626]=0;e:{if((c|0)==1){break e}j[e>>2]=b;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=E(2447,f+344|0,f+336|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(b){j[d>>2]=j[d>>2]|2}b=j[f+344>>2];gb(a);gb(f+208|0);Za=f+352|0;return b}}b=D()|0;C()|0;gb(a);gb(f+208|0);G(b|0);z()}function s1(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=Za-352|0;Za=f;j[f+336>>2]=b;j[f+344>>2]=a;h=Dg(c);i=Yl(c,f+224|0);Xl(f+208|0,c,f+332|0);a=Db(f+192|0);b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=Ub(a,0);j[f+188>>2]=b;j[f+12>>2]=f+16;j[f+8>>2]=0;while(1){c:{j[114626]=0;c=E(2446,f+344|0,f+336|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(a)+b|0)){c=nb(a);b=nb(a);j[114626]=0;F(149,a|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=Ub(a,0);j[f+188>>2]=c+b}j[114626]=0;c=H(2448,f+344|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=wj(c,h,b,f+188|0,f+8|0,j[f+332>>2],f+208|0,f+16|0,f+12|0,i);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2450,f+344|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;b=P(2428,b|0,j[f+188>>2],d|0,h|0)|0;c=j[114626];j[114626]=0;e:{if((c|0)==1){break e}j[e>>2]=b;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=E(2447,f+344|0,f+336|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(b){j[d>>2]=j[d>>2]|2}b=j[f+344>>2];gb(a);gb(f+208|0);Za=f+352|0;return b}}b=D()|0;C()|0;gb(a);gb(f+208|0);G(b|0);z()}function Yva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Za-48|0;Za=b;v=j[a+16>>2];l=j[a+44>>2];j[b+32>>2]=l;n=j[a+48>>2];j[b+36>>2]=n;g=j[a+52>>2];j[b+40>>2]=g;i=j[a+56>>2];j[b+44>>2]=i;o=j[a+40>>2];q=j[a+36>>2];e=j[a+4>>2];k=j[a>>2];j[b+24>>2]=k;j[b+28>>2]=e;f=j[a+12>>2];j[b+16>>2]=j[a+8>>2];j[b+20>>2]=f;a:{if(!d){m=o>>12;f=q>>12;break a}while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+v|0;i=h[e|0]<<8;j[b+8>>2]=i;j[b+12>>2]=h[e+1|0]<<8;f=0;n=1;while(1){g=j[a+60>>2];m=g;k=(b+32|0)+(f<<3)|0;r=j[k>>2];e=Gb(r,-16777216,16776704);u=j[a+64>>2];l=Gb(j[k+4>>2],-16777216,16776704);s=j[a+68>>2];w=s;s=s>>31;j[k+4>>2]=r;r=j[a+72>>2];t=g>>31;i=i<<8;g=i;g=OMa(m,t,g,g>>31);m=ab;t=(b+8|0)+(f<<2)|0;f=g;g=OMa(u,u>>31,e,e>>31);f=f+g|0;e=ab+m|0;e=f>>>0<g>>>0?e+1|0:e;l=OMa(w,s,l,l>>31);f=l+f|0;e=ab+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;j[t>>2]=(e|0)/256;j[k>>2]=e-(i&r);if(n){f=1;n=0;i=j[b+12>>2];continue}break}e=j[a+32>>2];q=j[a+28>>2]+q|0;f=q>>12;j[c>>2]=j[c>>2]+p(f,j[b+8>>2]);o=e+o|0;m=o>>12;j[c+4>>2]=j[c+4>>2]+p(m,j[b+12>>2]);Bb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;k=j[b+24>>2];e=j[b+28>>2];continue}break}k=j[b+24>>2];e=j[b+28>>2];i=j[b+44>>2];g=j[b+40>>2];n=j[b+36>>2];l=j[b+32>>2]}j[a+40>>2]=o;j[a+20>>2]=f;j[a+36>>2]=q;j[a+56>>2]=i;j[a+52>>2]=g;j[a+48>>2]=n;j[a+44>>2]=l;j[a+24>>2]=m;j[a>>2]=k;j[a+4>>2]=e;Za=b+48|0}function A1(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=Za-352|0;Za=f;j[f+336>>2]=b;j[f+344>>2]=a;h=Dg(c);i=Yl(c,f+224|0);Xl(f+208|0,c,f+332|0);a=Db(f+192|0);b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=Ub(a,0);j[f+188>>2]=b;j[f+12>>2]=f+16;j[f+8>>2]=0;while(1){c:{j[114626]=0;c=E(2446,f+344|0,f+336|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(a)+b|0)){c=nb(a);b=nb(a);j[114626]=0;F(149,a|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=Ub(a,0);j[f+188>>2]=c+b}j[114626]=0;c=H(2448,f+344|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=wj(c,h,b,f+188|0,f+8|0,j[f+332>>2],f+208|0,f+16|0,f+12|0,i);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2450,f+344|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;b=P(2421,b|0,j[f+188>>2],d|0,h|0)|0;c=j[114626];j[114626]=0;e:{if((c|0)==1){break e}j[e>>2]=b;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=E(2447,f+344|0,f+336|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(b){j[d>>2]=j[d>>2]|2}b=j[f+344>>2];gb(a);gb(f+208|0);Za=f+352|0;return b}}b=D()|0;C()|0;gb(a);gb(f+208|0);G(b|0);z()}function Q1(a,b,c,d,e){var f=0,g=0,i=0;f=Za-272|0;Za=f;j[f+256>>2]=b;j[f+264>>2]=a;i=Dg(c);Zl(f+208|0,c,f+255|0);a=Db(f+192|0);b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=Ub(a,0);j[f+188>>2]=b;j[f+12>>2]=f+16;j[f+8>>2]=0;while(1){c:{j[114626]=0;c=E(2414,f+264|0,f+256|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(a)+b|0)){c=nb(a);b=nb(a);j[114626]=0;F(149,a|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=Ub(a,0);j[f+188>>2]=c+b}j[114626]=0;c=H(2416,f+264|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=xj(c,i,b,f+188|0,f+8|0,h[f+255|0],f+208|0,f+16|0,f+12|0,62160);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2418,f+264|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;b=Hn(2429,b,j[f+188>>2],d,i);c=ab;i=j[114626];j[114626]=0;e:{if((i|0)==1){break e}j[e>>2]=b;j[e+4>>2]=c;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=E(2415,f+264|0,f+256|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(b){j[d>>2]=j[d>>2]|2}b=j[f+264>>2];gb(a);gb(f+208|0);Za=f+272|0;return b}}b=D()|0;C()|0;gb(a);gb(f+208|0);G(b|0);z()}function $1(a,b,c,d,e){var f=0,g=0,i=0;f=Za-272|0;Za=f;j[f+256>>2]=b;j[f+264>>2]=a;i=Dg(c);Zl(f+208|0,c,f+255|0);a=Db(f+192|0);b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=Ub(a,0);j[f+188>>2]=b;j[f+12>>2]=f+16;j[f+8>>2]=0;while(1){c:{j[114626]=0;c=E(2414,f+264|0,f+256|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(a)+b|0)){c=nb(a);b=nb(a);j[114626]=0;F(149,a|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=Ub(a,0);j[f+188>>2]=c+b}j[114626]=0;c=H(2416,f+264|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=xj(c,i,b,f+188|0,f+8|0,h[f+255|0],f+208|0,f+16|0,f+12|0,62160);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2418,f+264|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;b=Hn(2425,b,j[f+188>>2],d,i);c=ab;i=j[114626];j[114626]=0;e:{if((i|0)==1){break e}j[e>>2]=b;j[e+4>>2]=c;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=E(2415,f+264|0,f+256|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(b){j[d>>2]=j[d>>2]|2}b=j[f+264>>2];gb(a);gb(f+208|0);Za=f+272|0;return b}}b=D()|0;C()|0;gb(a);gb(f+208|0);G(b|0);z()}function D9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=Za-176|0;Za=b;d=Eb(b+8|0,38719);j[114626]=0;E(85,b+20|0,38724)|0;e=j[114626];j[114626]=0;c=1;a:{b:{if((e|0)==1){break b}j[114626]=0;E(85,b+32|0,38734)|0;c=j[114626];j[114626]=0;if((c|0)==1){c=2;break b}j[114626]=0;E(85,b+44|0,38747)|0;c=j[114626];j[114626]=0;if((c|0)==1){c=3;break b}j[114626]=0;E(85,b+56|0,38765)|0;c=j[114626];j[114626]=0;if((c|0)==1){c=4;break b}j[114626]=0;E(85,b+68|0,38775)|0;c=j[114626];j[114626]=0;if((c|0)==1){c=5;break b}j[114626]=0;E(85,b+80|0,38790)|0;c=j[114626];j[114626]=0;if((c|0)==1){c=6;break b}j[114626]=0;E(85,b+92|0,38798)|0;c=j[114626];j[114626]=0;if((c|0)==1){c=7;break b}j[114626]=0;E(85,b+104|0,38805)|0;c=j[114626];j[114626]=0;if((c|0)==1){c=8;break b}j[114626]=0;E(85,b+116|0,38811)|0;c=j[114626];j[114626]=0;if((c|0)==1){c=9;break b}j[114626]=0;E(85,b+128|0,38816)|0;c=j[114626];j[114626]=0;if((c|0)==1){c=10;break b}j[114626]=0;E(85,b+140|0,38824)|0;c=j[114626];j[114626]=0;if((c|0)==1){c=11;break b}j[114626]=0;E(85,b+152|0,38836)|0;c=j[114626];j[114626]=0;if((c|0)==1){c=12;break b}j[114626]=0;j[b+172>>2]=13;j[b+168>>2]=d;c=j[b+172>>2];j[b>>2]=j[b+168>>2];j[b+4>>2]=c;E(2171,a|0,b|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){c=b+164|0;while(1){c=gb(c-12|0);if((d|0)!=(c|0)){continue}break}Za=b+176|0;return}c=b+164|0;break a}c=(b+8|0)+p(c,12)|0}a=D()|0;C()|0;while(1){c=gb(c-12|0);if((d|0)!=(c|0)){continue}break}G(a|0);z()}function mea(a,b,c){var d=0,e=0,f=q(0),g=0,h=0,k=0,m=0,o=0,s=0,u=0,v=0,w=q(0);e=j[a+24>>2];j[b>>2]=e;d=j[a+16>>2];j[b+4>>2]=d;j[b+8>>2]=j[a+4>>2];h=(d|0)<(e|0)?e:d;if((h|0)<=-601){g=d;d=h+600|0;j[b+4>>2]=g-d;j[b>>2]=e-d}d=b;f=q(n[a+36>>2]*q(79.30999755859375));a:{if(q(r(f))<q(2147483648)){e=~~f;break a}e=-2147483648}j[d+16>>2]=e- -8192;e=b;f=q(q(n[a+32>>2]*q(117.9612045288086))+q(4915.05029296875));b:{if(q(r(f))<q(2147483648)){d=~~f;break b}d=-2147483648}j[e+20>>2]=(d|0)<32512?d:32512;h=0;f=q(q(t(n[a+20>>2],q(.10000000149011612)))*c);c:{if(q(r(f))<q(2147483648)){e=~~f;break c}e=-2147483648}d=(e|0)<96;k=d?96:e;m=(k|0)>7500;g=m?k-7500|0:0;d=d?e-96|0:0;f=q(n[a+28>>2]*c);d:{if(q(r(f))<q(2147483648)){e=~~f;break d}e=-2147483648}f=n[a+8>>2];e=g+(d+e|0)|0;d=(e|0)<128;g=d?128:e;o=(g|0)>3800;s=o?3800:g;j[b+24>>2]=s;e=d?e-128|0:0;d=b;c=q(f*c);e:{if(q(r(c))<q(2147483648)){u=~~c;break e}u=-2147483648}g=(u+e|0)+(o?g-3800|0:0)|0;j[d+32>>2]=g;k=m?7500:k;while(1){d=p(h,12);e=d+b|0;d=d+34032|0;i[e+42>>1]=l[d+10>>1];i[e+36>>1]=l[d+4>>1];m=l[d+6>>1]|l[d+8>>1]<<16;i[e+38>>1]=m;i[e+40>>1]=m>>>16;j[e+44>>2]=k+((p(j[d>>2],s)+50|0)/100|0);h=h+1|0;if((h|0)!=8){continue}break}d=b;c=q(g|0);f=q(Yd(q(.0010000000474974513),(g|0)<4721?q(1):q(q(4720)/c))*q(32768));f:{if(q(r(f))<q(2147483648)){e=~~f;break f}e=-2147483648}j[d+12>>2]=e;c=q(n[a+12>>2]*c);v=b,w=Yd(q(.0010000000474974513),c>q(4720)?q(q(4720)/c):q(1)),n[v+28>>2]=w}function TE(a){var b=0,c=0,d=0,e=0;Fd(a,j[a+20>>2]);if(j[a+24>>2]>=1){while(1){Fd(a,j[j[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<j[a+24>>2]){continue}break}}Fd(a,j[a+28>>2]);a:{b=j[a+396>>2];if(!b|j[a+264>>2]<1){break a}while(1){c=p(e,24)+b|0;b=j[c+16>>2];if(b){d=a;if(j[(j[a+124>>2]+p(k[c+13|0],2096)|0)+4>>2]>=1){Fd(a,j[b>>2]);b=1;if(j[(j[a+124>>2]+p(k[c+13|0],2096)|0)+4>>2]>=2){while(1){Fd(a,j[j[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<j[(j[a+124>>2]+p(k[c+13|0],2096)|0)+4>>2]){continue}break}}b=j[c+16>>2]}Fd(d,b)}Fd(a,j[c+20>>2]);e=e+1|0;if((e|0)>=j[a+264>>2]){break a}b=j[a+396>>2];continue}}b=j[a+124>>2];if(b){d=a;if(j[a+120>>2]>=1){c=0;while(1){b=p(c,2096)+b|0;Fd(a,j[b+8>>2]);Fd(a,j[b+28>>2]);Fd(a,j[b+32>>2]);Fd(a,j[b+2084>>2]);b=j[b+2088>>2];Fd(a,b?b-4|0:0);c=c+1|0;if((c|0)<j[a+120>>2]){b=j[a+124>>2];continue}break}b=j[a+124>>2]}Fd(d,b)}Fd(a,j[a+260>>2]);Fd(a,j[a+396>>2]);d=j[a+404>>2];if(d){b=1;c=a;if(j[a+400>>2]>=1){Fd(a,j[d+4>>2]);if(j[a+400>>2]>=2){while(1){Fd(a,j[(j[a+404>>2]+p(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<j[a+400>>2]){continue}break}}d=j[a+404>>2]}Fd(c,d)}c=1;b:{if(j[a+4>>2]<1){break b}b=0;while(1){d=(b<<2)+a|0;Fd(a,j[d+800>>2]);Fd(a,j[d+928>>2]);Fd(a,j[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<j[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;Fd(a,j[b+1068>>2]);Fd(a,j[b+1076>>2]);Fd(a,j[b+1084>>2]);Fd(a,j[b+1092>>2]);Fd(a,j[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function c2(a,b,c,d,e){var f=0,g=0,i=0;f=Za-272|0;Za=f;j[f+256>>2]=b;j[f+264>>2]=a;i=Dg(c);Zl(f+208|0,c,f+255|0);a=Db(f+192|0);b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=Ub(a,0);j[f+188>>2]=b;j[f+12>>2]=f+16;j[f+8>>2]=0;while(1){c:{j[114626]=0;c=E(2414,f+264|0,f+256|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(a)+b|0)){c=nb(a);b=nb(a);j[114626]=0;F(149,a|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=Ub(a,0);j[f+188>>2]=c+b}j[114626]=0;c=H(2416,f+264|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=xj(c,i,b,f+188|0,f+8|0,h[f+255|0],f+208|0,f+16|0,f+12|0,62160);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2418,f+264|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;b=P(2421,b|0,j[f+188>>2],d|0,i|0)|0;c=j[114626];j[114626]=0;e:{if((c|0)==1){break e}j[e>>2]=b;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=E(2415,f+264|0,f+256|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(b){j[d>>2]=j[d>>2]|2}b=j[f+264>>2];gb(a);gb(f+208|0);Za=f+272|0;return b}}b=D()|0;C()|0;gb(a);gb(f+208|0);G(b|0);z()}function X1(a,b,c,d,e){var f=0,g=0,k=0;f=Za-272|0;Za=f;j[f+256>>2]=b;j[f+264>>2]=a;k=Dg(c);Zl(f+208|0,c,f+255|0);a=Db(f+192|0);b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=Ub(a,0);j[f+188>>2]=b;j[f+12>>2]=f+16;j[f+8>>2]=0;while(1){c:{j[114626]=0;c=E(2414,f+264|0,f+256|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(a)+b|0)){c=nb(a);b=nb(a);j[114626]=0;F(149,a|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=Ub(a,0);j[f+188>>2]=c+b}j[114626]=0;c=H(2416,f+264|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=xj(c,k,b,f+188|0,f+8|0,h[f+255|0],f+208|0,f+16|0,f+12|0,62160);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2418,f+264|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;b=P(2426,b|0,j[f+188>>2],d|0,k|0)|0;c=j[114626];j[114626]=0;e:{if((c|0)==1){break e}i[e>>1]=b;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=E(2415,f+264|0,f+256|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(b){j[d>>2]=j[d>>2]|2}b=j[f+264>>2];gb(a);gb(f+208|0);Za=f+272|0;return b}}b=D()|0;C()|0;gb(a);gb(f+208|0);G(b|0);z()}function U1(a,b,c,d,e){var f=0,g=0,i=0;f=Za-272|0;Za=f;j[f+256>>2]=b;j[f+264>>2]=a;i=Dg(c);Zl(f+208|0,c,f+255|0);a=Db(f+192|0);b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=Ub(a,0);j[f+188>>2]=b;j[f+12>>2]=f+16;j[f+8>>2]=0;while(1){c:{j[114626]=0;c=E(2414,f+264|0,f+256|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(a)+b|0)){c=nb(a);b=nb(a);j[114626]=0;F(149,a|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=Ub(a,0);j[f+188>>2]=c+b}j[114626]=0;c=H(2416,f+264|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=xj(c,i,b,f+188|0,f+8|0,h[f+255|0],f+208|0,f+16|0,f+12|0,62160);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2418,f+264|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;b=P(2427,b|0,j[f+188>>2],d|0,i|0)|0;c=j[114626];j[114626]=0;e:{if((c|0)==1){break e}j[e>>2]=b;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=E(2415,f+264|0,f+256|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(b){j[d>>2]=j[d>>2]|2}b=j[f+264>>2];gb(a);gb(f+208|0);Za=f+272|0;return b}}b=D()|0;C()|0;gb(a);gb(f+208|0);G(b|0);z()}function S1(a,b,c,d,e){var f=0,g=0,i=0;f=Za-272|0;Za=f;j[f+256>>2]=b;j[f+264>>2]=a;i=Dg(c);Zl(f+208|0,c,f+255|0);a=Db(f+192|0);b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=Ub(a,0);j[f+188>>2]=b;j[f+12>>2]=f+16;j[f+8>>2]=0;while(1){c:{j[114626]=0;c=E(2414,f+264|0,f+256|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}if(!c){break b}if(j[f+188>>2]==(nb(a)+b|0)){c=nb(a);b=nb(a);j[114626]=0;F(149,a|0,b<<1);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=sc(a);j[114626]=0;F(149,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=Ub(a,0);j[f+188>>2]=c+b}j[114626]=0;c=H(2416,f+264|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;c=xj(c,i,b,f+188|0,f+8|0,h[f+255|0],f+208|0,f+16|0,f+12|0,62160);g=j[114626];j[114626]=0;if((g|0)==1){break c}if(c){break b}j[114626]=0;H(2418,f+264|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!nb(f+208|0)){break d}c=j[f+12>>2];if((c-(f+16|0)|0)>159){break d}j[f+12>>2]=c+4;j[c>>2]=j[f+8>>2]}j[114626]=0;b=P(2428,b|0,j[f+188>>2],d|0,i|0)|0;c=j[114626];j[114626]=0;e:{if((c|0)==1){break e}j[e>>2]=b;j[114626]=0;le(f+208|0,f+16|0,j[f+12>>2],d);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;b=E(2415,f+264|0,f+256|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}if(b){j[d>>2]=j[d>>2]|2}b=j[f+264>>2];gb(a);gb(f+208|0);Za=f+272|0;return b}}b=D()|0;C()|0;gb(a);gb(f+208|0);G(b|0);z()}function Kva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=Za-48|0;Za=e;r=j[a+16>>2];f=j[a+44>>2];j[e+32>>2]=f;h=j[a+48>>2];j[e+36>>2]=h;n=j[a+52>>2];j[e+40>>2]=n;k=j[a+56>>2];j[e+44>>2]=k;s=j[a+24>>2];t=j[a+20>>2];b=j[a+4>>2];g=j[a>>2];j[e+24>>2]=g;j[e+28>>2]=b;l=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=l;u=a;if(d){while(1){l=g>>>18|0;n=1;k=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;f=0;b=1;h=0;while(1){m=h<<1;g=i[m+k>>1];j[(e+8|0)+(h<<2)>>2]=g+((p(l,i[k+(m|4)>>1]-g|0)|0)/16384|0);g=b;b=0;h=1;if(g){continue}break}while(1){h=(e+8|0)+(f<<2)|0;l=j[h>>2];m=j[a+60>>2];g=(e+32|0)+(f<<3)|0;f=j[g>>2];b=Gb(f,-16777216,16776704);q=j[a+64>>2];k=Gb(j[g+4>>2],-16777216,16776704);o=j[a+68>>2];v=o;o=o>>31;j[g+4>>2]=f;w=j[a+72>>2];l=l<<8;f=l;f=OMa(m,m>>31,f,f>>31);m=ab;x=h;h=OMa(q,q>>31,b,b>>31);f=h+f|0;b=ab+m|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=OMa(v,o,k,k>>31);k=h+f|0;b=ab+b|0;b=f>>>0>k>>>0?b+1|0:b;k=k+8388608|0;if(k>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|k>>>24;j[x>>2]=(b|0)/256;j[g>>2]=b-(l&w);f=1;b=n&1;n=0;if(b){continue}break}j[c>>2]=j[c>>2]+p(j[e+8>>2],t);j[c+4>>2]=j[c+4>>2]+p(j[e+12>>2],s);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=j[e+24>>2];b=j[e+28>>2];continue}break}g=j[e+24>>2];b=j[e+28>>2];n=j[e+40>>2];h=j[e+36>>2];f=j[e+32>>2];k=j[e+44>>2]}j[u+56>>2]=k;j[a+52>>2]=n;j[a+48>>2]=h;j[a+44>>2]=f;j[a>>2]=g;j[a+4>>2]=b;Za=e+48|0}function Lva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=Za-48|0;Za=e;t=j[a+16>>2];f=j[a+44>>2];j[e+32>>2]=f;k=j[a+48>>2];j[e+36>>2]=k;b=j[a+52>>2];j[e+40>>2]=b;n=j[a+56>>2];j[e+44>>2]=n;u=j[a+24>>2];v=j[a+20>>2];i=j[a+4>>2];g=j[a>>2];j[e+24>>2]=g;j[e+28>>2]=i;m=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=m;if(d){while(1){m=g>>>10&4194048;g=(((i&2147483647)<<1|g>>>31)&-2)+t|0;k=0;n=1;b=1;f=0;while(1){i=h[g+f|0];j[(e+8|0)+(f<<2)>>2]=((p(m,h[g+(f|2)|0]-i|0)|0)/16384|0)+(i<<8);i=b;b=0;f=1;if(i){continue}break}while(1){f=(e+8|0)+(k<<2)|0;m=j[f>>2];l=j[a+60>>2];q=l;i=(e+32|0)+(k<<3)|0;k=j[i>>2];b=Gb(k,-16777216,16776704);s=j[a+64>>2];g=Gb(j[i+4>>2],-16777216,16776704);o=j[a+68>>2];w=o;o=o>>31;j[i+4>>2]=k;k=j[a+72>>2];r=l>>31;m=m<<8;l=m;l=OMa(q,r,l,l>>31);q=ab;r=f;f=l;l=OMa(s,s>>31,b,b>>31);f=f+l|0;b=ab+q|0;b=f>>>0<l>>>0?b+1|0:b;l=f;f=OMa(w,o,g,g>>31);g=l+f|0;b=ab+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;j[r>>2]=(b|0)/256;j[i>>2]=b-(k&m);k=1;b=n&1;n=0;if(b){continue}break}j[c>>2]=j[c>>2]+p(j[e+8>>2],v);j[c+4>>2]=j[c+4>>2]+p(j[e+12>>2],u);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=j[e+24>>2];i=j[e+28>>2];continue}break}g=j[e+24>>2];i=j[e+28>>2];n=j[e+44>>2];k=j[e+36>>2];f=j[e+32>>2];b=j[e+40>>2]}j[a+56>>2]=n;j[a+52>>2]=b;j[a+48>>2]=k;j[a+44>>2]=f;j[a>>2]=g;j[a+4>>2]=i;Za=e+48|0}function T0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;n=Za-16|0;Za=n;o=nv(g);g=Vu(g);Uf(n,g);a:{b:{if(Ec(n)){j[114626]=0;P(2455,o|0,a|0,c|0,d|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;j[f>>2]=g;break a}j[f>>2]=d;c:{d:{m=a;i=k[m|0];switch(i-43|0){case 0:case 2:break d;default:break c}}j[114626]=0;m=E(2467,o|0,i<<24>>24)|0;i=j[114626];j[114626]=0;if((i|0)==1){break b}i=j[f>>2];j[f>>2]=i+4;j[i>>2]=m;m=a+1|0}if(!(k[m|0]!=48|(c-m|0)<2|(k[m+1|0]|32)!=120)){j[114626]=0;i=E(2467,o|0,48)|0;l=j[114626];j[114626]=0;if((l|0)==1){break b}l=j[f>>2];j[f>>2]=l+4;j[l>>2]=i;i=h[m+1|0];j[114626]=0;i=E(2467,o|0,i|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break b}l=j[f>>2];j[f>>2]=l+4;j[l>>2]=i;m=m+2|0}l=0;j[114626]=0;uj(m,c);i=j[114626];j[114626]=0;if((i|0)==1){break b}j[114626]=0;r=H(2452,g|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}i=0;g=m;while(1){e:{if(c>>>0<=g>>>0){g=j[f>>2];j[114626]=0;On((m-a<<2)+d|0,g);g=j[114626];j[114626]=0;if((g|0)==1){break e}g=j[f>>2];break a}f:{if(!k[Ub(n,i)|0]){break f}if(h[Ub(n,i)|0]!=(l|0)){break f}l=j[f>>2];j[f>>2]=l+4;j[l>>2]=r;i=(nb(n)-1>>>0>i>>>0)+i|0;l=0}q=h[g|0];j[114626]=0;q=E(2467,o|0,q|0)|0;p=j[114626];j[114626]=0;if((p|0)!=1){p=j[f>>2];j[f>>2]=p+4;j[p>>2]=q;g=g+1|0;l=l+1|0;continue}}break}}a=D()|0;C()|0;gb(n);G(a|0);z()}j[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;gb(n);Za=n+16|0}function Ho(a,b,c,d){var e=0,f=q(0),g=q(0),o=q(0),r=0,s=0,t=0,u=0,v=q(0),w=0,x=0,y=0;e=Za-16|0;Za=e;j[e+12>>2]=i[b+792>>1]+k[b+857|0];j[e+8>>2]=i[b+794>>1]+(k[b+858|0]&127);Md(e+12|0,0,127);Md(e+8|0,0,127);t=a+1074308|0;mb(e,t,1);r=kb(e);s=j[e+12>>2];if(!r){i[b+792>>1]=0;h[b+857|0]=s;r=j[e+8>>2];i[b+794>>1]=0;h[b+858|0]=r}mb(e,t,36);r=p(s,d+256|0);s=(r|0)/256|0;w=kb(e);u=j[e+8>>2];a:{if(!(u|!w|(r|0)<65024)){s=-1;a=b+810|0;if(!Lf(a)){break a}if(Zr(a)|l[b+808>>1]|(j[b>>2]|j[b+4>>2])){break a}a=j[b+88>>2];if(a&8192){break a}j[b+88>>2]=a&-32769;break a}j[b+88>>2]=j[b+88>>2]|32768;f=Yd(q(10),q(q(0-u|0)*q(.00937500037252903)));d=tpa(a,j[e+12>>2],d);mb(e,t,36);o=q(q(d>>>0)*q(6.2831854820251465));b:{if(!(!kb(e)|j[a+480208>>2]&32768)){g=q(q(m[a+24620>>2])/o);o=q(q(f+q(-1))+q(g*f));n[e>>2]=o;f=q(g*g);break b}g=q(o/q(m[a+24620>>2]));f=q(f+f);n[e>>2]=g*q(q(1)-f);LK(e,q(2));o=q(q(f-n[e>>2])/g);n[e>>2]=o;f=q(q(1)/q(g*g))}g=q(q(o+f)+q(1));o=q(q(q(f+f)+o)/g);v=q(q(16777216)/g);f=q(q(-f)/g);c:{if(k[b+865|0]==1){x=b,y=qh(q(q(16777216)-v)),j[x+60>>2]=y;x=b,y=qh(q(o*q(16777216))),j[x+64>>2]=y;x=b,y=qh(q(f*q(16777216))),j[x+68>>2]=y;a=-1;break c}x=b,y=qh(v),j[x+60>>2]=y;x=b,y=qh(q(o*q(16777216))),j[x+64>>2]=y;x=b,y=qh(q(f*q(16777216))),j[x+68>>2]=y;a=0;if(j[b+60>>2]){break c}j[b+60>>2]=1}j[b+72>>2]=a;if(!c){break a}j[b+44>>2]=0;j[b+48>>2]=0;j[b+52>>2]=0;j[b+56>>2]=0}Za=e+16|0;return s}function d1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;n=Za-16|0;Za=n;o=Xt(g);g=Yu(g);Uf(n,g);a:{b:{if(Ec(n)){j[114626]=0;P(2432,o|0,a|0,c|0,d|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;j[f>>2]=g;break a}j[f>>2]=d;c:{d:{m=a;i=k[m|0];switch(i-43|0){case 0:case 2:break d;default:break c}}j[114626]=0;m=E(22,o|0,i<<24>>24)|0;i=j[114626];j[114626]=0;if((i|0)==1){break b}i=j[f>>2];j[f>>2]=i+1;h[i|0]=m;m=a+1|0}if(!(k[m|0]!=48|(c-m|0)<2|(k[m+1|0]|32)!=120)){j[114626]=0;i=E(22,o|0,48)|0;l=j[114626];j[114626]=0;if((l|0)==1){break b}l=j[f>>2];j[f>>2]=l+1;h[l|0]=i;i=h[m+1|0];j[114626]=0;i=E(22,o|0,i|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break b}l=j[f>>2];j[f>>2]=l+1;h[l|0]=i;m=m+2|0}l=0;j[114626]=0;uj(m,c);i=j[114626];j[114626]=0;if((i|0)==1){break b}j[114626]=0;r=H(2423,g|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}i=0;g=m;while(1){e:{if(c>>>0<=g>>>0){g=j[f>>2];j[114626]=0;uj((m-a|0)+d|0,g);g=j[114626];j[114626]=0;if((g|0)==1){break e}g=j[f>>2];break a}f:{if(!k[Ub(n,i)|0]){break f}if(h[Ub(n,i)|0]!=(l|0)){break f}l=j[f>>2];j[f>>2]=l+1;h[l|0]=r;i=(nb(n)-1>>>0>i>>>0)+i|0;l=0}q=h[g|0];j[114626]=0;q=E(22,o|0,q|0)|0;p=j[114626];j[114626]=0;if((p|0)!=1){p=j[f>>2];j[f>>2]=p+1;h[p|0]=q;g=g+1|0;l=l+1|0;continue}}break}}a=D()|0;C()|0;gb(n);G(a|0);z()}j[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;gb(n);Za=n+16|0}function rba(a,b){var c=0,d=0;c=Za-32|0;Za=c;a:{b:{c:{if(Dd(b,38235)){Db(a);break c}if(Dd(b,38236)){qba(a);break c}if(Dd(b,38252)){j[c>>2]=0;ir(a,c);break c}if(Dd(b,38274)){j[c>>2]=5;ir(a,c);break c}if(Dd(b,38296)){j[c>>2]=4;ir(a,c);break c}if(Dd(b,38318)){b=Za-16|0;Za=b;bba(a);Za=b+16|0;break c}if(Dd(b,38341)){d=Eb(c,38235);b=nb(d);j[114626]=0;E(85,a|0,(b?38370:38368)|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break b}gb(d);break c}if(Dd(b,38372)){pba(a);break c}if(Dd(b,38389)){oba(a);break c}if(Dd(b,38402)){nba(a);break c}if(Dd(b,38413)){mba(a);break c}if(Dd(b,38425)){lba(a);break c}if(Dd(b,38441)){vk(c);b=k[c+16|0];j[114626]=0;E(85,a|0,(b?38368:38370)|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Je(c);break c}b=D()|0;C()|0;Je(c);break a}if(Dd(b,38460)){vk(c);b=k[c+17|0];j[114626]=0;E(85,a|0,(b?38368:38370)|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Je(c);break c}b=D()|0;C()|0;Je(c);break a}if(Dd(b,38486)){vk(c);b=k[c+18|0];j[114626]=0;E(85,a|0,(b?38368:38370)|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Je(c);break c}b=D()|0;C()|0;Je(c);break a}if(Dd(b,38504)){kba(a);break c}if(Dd(b,38510)){jba(a);break c}if(Dd(b,38525)){iba(a);break c}if(Dd(b,38533)){hba(a);break c}if(Dd(b,38541)){gba(a);break c}if(Dd(b,38549)){fba(a);break c}if(Dd(b,38553)){eba(a);break c}if(Dd(b,38571)){dba(a);break c}Db(a)}Za=c+32|0;return}b=D()|0;C()|0;gb(d)}G(b|0);z()}function Zea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,o=0,p=0,r=q(0),s=q(0),t=0,u=0,v=q(0),w=0;g=Za-16|0;Za=g;p=a+44|0;if(Yg(p)){k=wd(p,0);l=wd(p,1);h=Rc(p,0);i=Rc(p,1);v=n[a+4212>>2];j[g+12>>2]=d;if(d){e=j[a+4224>>2];while(1){w=a;f=j[a+4220>>2];a:{if(f>>>0>e>>>0){j[g+8>>2]=f-e;f=j[tb(g+12|0,g+8|0)>>2];b:{if(!(v<q(1))){e=0;if(!f){break b}while(1){n[h>>2]=n[k>>2];n[i>>2]=n[l>>2];i=i+4|0;l=l+4|0;h=h+4|0;k=k+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}break b}e=j[a+4224>>2];o=f+e|0;if(e>>>0>=o>>>0){break b}s=q(q(1)/q(m[a+4220>>2]));while(1){r=q(q(e>>>0)*s);n[h>>2]=r*n[k>>2];n[i>>2]=r*n[l>>2];i=i+4|0;l=l+4|0;h=h+4|0;k=k+4|0;e=e+1|0;if((o|0)!=(e|0)){continue}break}}o=j[g+12>>2]-f|0;j[g+12>>2]=o;e=f+j[a+4224>>2]|0;break a}j[g+4>>2]=j[a+4216>>2]-e;f=j[tb(g+12|0,g+4|0)>>2];c:{d:{e:{if(!(v<q(1))){e=0;if(f){break e}break d}t=j[a+4216>>2];u=j[a+4224>>2];e=t-u|0;o=e-f|0;if(e>>>0<=o>>>0){break c}s=q(q(1)/q(m[a+4220>>2]));while(1){r=q(q(e>>>0)*s);n[h>>2]=r*n[k>>2];n[i>>2]=r*n[l>>2];i=i+4|0;l=l+4|0;h=h+4|0;k=k+4|0;e=e-1|0;if(o>>>0<e>>>0){continue}break}break c}while(1){j[h>>2]=0;j[i>>2]=0;i=i+4|0;h=h+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}}e=f<<2;l=e+l|0;k=e+k|0;t=j[a+4216>>2];u=j[a+4224>>2]}o=j[g+12>>2]-f|0;j[g+12>>2]=o;e=f+u|0;e=e>>>0<t>>>0?e:0}j[w+4224>>2]=e;if(o){continue}break}}Th(a,b,c,Rc(p,0),Rc(p,1),d)}Za=g+16|0}function yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;g=Za-32|0;Za=g;m=a+24604|0;if(!xma(m)){EJ(g+16|0,20656,20676,207);sba(g+16|0)}i=a+946300|0;e=a+906300|0;while(1){a:{n=j[e>>2];e=e+160|0;if((i|0)==(e|0)){break a}if(!n){continue}}break}b:{if(!b){break b}e=j[a+480208>>2];if(e&512){break b}r=a+8204|0;s=a+1074328|0;t=a+393352|0;i=a+12|0;o=a+1304392|0;h=j[a+1074380>>2];while(1){c:{if(h){break c}l=a;h=e|512;d:{if(e&256){break d}if(wma(a)){e=j[a+480208>>2];break c}h=j[a+480208>>2]|512;if(k[a+1304512|0]){break d}e=Bma(a);f=j[a+480208>>2];h=f|256;if(e){break d}h=f|512}e=h;j[l+480208>>2]=e}if(e&512){u=a+1074392|0,v=Yk(a),j[u>>2]=v;break b}j[g+16>>2]=512;e=j[a+1074380>>2];j[g+12>>2]=3;j[g+24>>2]=b;j[g+20>>2]=e;j[g+8>>2]=g+16;e=j[g+12>>2];j[g>>2]=j[g+8>>2];j[g+4>>2]=e;f=SQ(g);if(j[a+24632>>2]){zma(a,d,f)}$T(a,f);if(bd(o)){rsa(j[o>>2],i,f,(p(j[a+480232>>2],j[a+480236>>2])>>>0)/48|0)}jea(t,i,f);if(n){XT(a,f)}if(j[a+24624>>2]==1){mua(i,f)}if(k[s+36|0]){vma(a,f)}if(j[m>>2]!=128){hma(a+12|0,a+8204|0,j[a+24624>>2],f,j[a+24604>>2])}h=c;l=i;e=j[a+24624>>2];if((e|0)==4){oua(i,r,f);e=j[a+24624>>2]}bb[j[j[c>>2]+8>>2]](h,l,e,f);h=j[a+1074380>>2]-f|0;j[a+1074380>>2]=h;j[a+1074376>>2]=f+j[a+1074376>>2];q=f+q|0;b=b-f|0;if(!b){break b}e=j[a+480208>>2];if(!(e&512)){continue}break}}Za=g+32|0;return q|0}function sv(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:while(1){i=b-4|0;b:while(1){d=a;c:while(1){d:{e:{f:{g:{h:{i:{j:{k:{a=b-d|0;e=a>>2;switch(e|0){case 4:break j;case 2:break k;case 0:case 1:break d;case 3:break g;case 5:break i;default:break h}}a=b-4|0;if(!rd(a,d)){break d}Hb(d,a);return}rv(d,d+4|0,d+8|0,b-4|0);return}qv(d,d+4|0,d+8|0,d+12|0,b-4|0);return}if((a|0)<=123){v4(d,b);return}g=((e|0)/2<<2)+d|0;l:{if((a|0)>=3997){a=(e|0)/4<<2;h=qv(d,a+d|0,g,a+g|0,i);break l}h=em(d,g,i)}a=i;if(!rd(d,g)){while(1){a=a-4|0;if((d|0)==(a|0)){f=d+4|0;if(rd(d,i)){break e}while(1){if((f|0)==(i|0)){break d}if(rd(d,f)){Hb(f,i);f=f+4|0;break e}else{f=f+4|0;continue}}}if(!rd(a,g)){continue}break}Hb(d,a);h=h+1|0}e=d+4|0;if(e>>>0>=a>>>0){break f}while(1){f=e;e=e+4|0;if(rd(f,g)){continue}while(1){a=a-4|0;if(!rd(a,g)){continue}break}if(a>>>0<f>>>0){e=f;break f}else{Hb(f,a);g=(f|0)==(g|0)?a:g;h=h+1|0;continue}}}em(d,d+4|0,b-4|0);break d}m:{if((e|0)==(g|0)){break m}if(!rd(g,e)){break m}Hb(e,g);h=h+1|0}if(!h){f=mE(d,e);a=e+4|0;if(mE(a,b)){b=e;a=d;if(!f){continue a}break d}if(f){continue b}}if((e-d|0)<(b-e|0)){sv(d,e,c);a=e+4|0;continue b}sv(e+4|0,b,c);b=e;a=d;continue a}a=i;if((f|0)==(a|0)){break d}while(1){e=f;f=e+4|0;if(!rd(d,e)){continue}while(1){a=a-4|0;if(rd(d,a)){continue}break}if(a>>>0<=e>>>0){d=e;continue c}else{Hb(e,a);continue}}}break}break}break}}function Hta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0;f=Za-32|0;Za=f;d=b&5;a:{if(!(c&5)){if(!d){break a}g=a,m=ms(h[a+36|0],h[a+37|0]),j[g+24>>2]=m;i[a+36>>1]=0;if((b|0)!=1){break a}e=OMa(j[a+24>>2],0,8272,0)+4181|0;d=ab;g=a,m=Wc(RMa(e,e>>>0<4181?d+1|0:d,8363,0),ab),j[g+24>>2]=m;break a}if(d){break a}if((c|0)==1){e=OMa(j[a+24>>2],0,8363,0)+4136|0;d=ab;g=a,m=Wc(RMa(e,e>>>0<4136?d+1|0:d,8272,0),ab),j[g+24>>2]=m}Gta(a)}if(c&3){i[a+38>>1]=0;i[a+40>>1]=0;h[a+36|0]=0;i[a+34>>1]=l[a+34>>1]&65499}if(c&7){i[a+32>>1]=64;d=l[a+34>>1];if(d&8){e=j[a+16>>2];j[a+4>>2]=j[a+12>>2];j[a+8>>2]=e;d=d&16?d|6:d&65529|2}j[a+12>>2]=0;j[a+16>>2]=0;i[a+34>>1]=d&65511}d=c&4;if(d){e=l[a+34>>1];if(!(e&32)){i[a+28>>1]=128;i[a+34>>1]=e|32}Ae(a+40|0,15);Ae(a+41|0,63)}b:{if(!k[a+41|0]|(!(b&16777248)|!d?!(c&16777248?b&4:0):0)){break b}d=k[a+40|0];if(!d){break b}b=k[a+39|0];if(b){g=a,m=Vm(Wc(((d<<8|b>>>1)>>>0)/(b>>>0)|0,0)),h[g+39|0]=m;break b}h[a+39|0]=255}c:{d:{if((c|0)!=4){if((c|0)==16777216){break c}if((c|0)!=32|k[a+38|0]!=2){break d}h[a+38|0]=3;break d}if(k[a+38|0]!=4){break d}h[a+38|0]=0}i[a+34>>1]=l[a+34>>1]&49151}e:{if(!(!(k[a+35|0]&2)|c&16777218)){j[f+24>>2]=0;j[f+8>>2]=0;j[f+16>>2]=0;j[f+20>>2]=0;j[f>>2]=0;j[f+4>>2]=0;Ro(a,0,f);break e}if(!(k[a+35|0]&2)|(c|0)!=2){break e}a=a+68|0;b=Pb(a,8);h[b|0]=k[b|0]&3;a=Pb(a,9);h[a|0]=k[a|0]&3}Za=f+32|0}function J4(a){var b=0,c=q(0),d=q(0),e=q(0),f=0,g=q(0);a:{b:{c:{d:{e:{b=(ZMa(a),VMa(2));f=b&2147483647;if(f>>>0>=1100331076){if(f>>>0>2139095040){break a}if((b|0)<0){return q(-1)}if(a>q(88.7216796875)^1){break e}return q(a*q(1.7014118346046923e+38))}if(f>>>0<1051816473){break c}if(f>>>0>1065686417){break e}if((b|0)>=0){b=1;g=q(905800061445916e-20);e=q(a+q(-.6931381225585938));break d}b=-1;g=q(-905800061445916e-20);e=q(a+q(.6931381225585938));break d}c=q(q(a*q(1.4426950216293335))+(WMa(2,(ZMa(a),VMa(2))&-2147483648|1056964608),_Ma()));f:{if(q(r(c))<q(2147483648)){b=~~c;break f}b=-2147483648}c=q(b|0);g=q(c*q(905800061445916e-20));e=q(a+q(c*q(-.6931381225585938)))}a=e;a=q(a-g);g=q(q(e-a)-g);break b}if(f>>>0<855638016){break a}b=0}c=q(a*q(.5));d=q(a*c);e=q(q(d*q(q(d*q(.0015807170420885086))+q(-.03333321213722229)))+q(1));c=q(q(3)-q(c*e));c=q(d*q(q(e-c)/q(q(6)-q(a*c))));if(!b){return q(a-q(q(a*c)-d))}d=q(q(q(a*q(c-g))-g)-d);g:{switch(b+1|0){case 0:return q(q(q(a-d)*q(.5))+q(-.5));case 2:if(!(a<q(-.25)^1)){return q(q(d-q(a+q(.5)))*q(-2))}a=q(a-d);return q(q(a+a)+q(1));default:break g}}f=b<<23;e=(WMa(2,f+1065353216|0),_Ma());if(b>>>0>=57){a=q(q(a-d)+q(1));return q(((b|0)==128?q(q(a+a)*q(1.7014118346046923e+38)):q(a*e))+q(-1))}c=(WMa(2,1065353216-f|0),_Ma());b=(b|0)<23;a=q(q((b?q(q(1)-c):q(a-q(d+c)))+(b?q(a-d):q(1)))*e)}return a}function Xw(a,b,c){var d=0,e=0,f=0,g=0,i=0,m=0,n=0,o=0,p=0,q=0;e=Za-16|0;Za=e;i=dJ(b,c);a:{if(!j[b+656>>2]|!(h[i|0]&1)){break a}g=j[i+4>>2];m=a+1074308|0;mb(e+8|0,m,31);f=kb(e+8|0);d=Gt(j[b+656>>2],c);if(ad(d)){break a}g=g+(f^1)|0;mb(e+8|0,m,31);n=kb(e+8|0);f=k[d+12|0];b:{c:{if(!n){d:{if(!(f&2)){break d}f=l[xb(d,k[d+14|0])>>1]+!(j[a+480180>>2]&1048580)|0;if(!(!(k[b+89|0]&8)|(!(k[d+12|0]&4)|k[d+14|0]!=k[d+16|0]))){mb(e+8|0,m,70);o=kb(e+8|0)}if((g|0)!=(f|0)|o){break d}g=l[xb(d,k[d+13|0])>>1]}if(!(!(k[d+12|0]&4)|k[b+89|0]&8)){if((l[xb(d,k[d+16|0])>>1]+1|0)!=(g|0)){break b}g=l[xb(d,k[d+15|0])>>1];mb(e+8|0,m,93);if(!kb(e+8|0)|(c|0)!=1|j[b+88>>2]&2048){break b}h[i|0]=k[i|0]&254;break b}if(l[Ri(d)>>1]>=g>>>0){break b}o=1;g=l[Ri(d)>>1];break c}e:{f:{if(!(!(f&4)|k[b+669|0]&8)){if(j[i+8>>2]==-1){break f}mb(e+8|0,m,97);if(kb(e+8|0)){break f}f=k[d+12|0]}if(f&2){f=l[xb(d,k[d+13|0])>>1];n=l[xb(d,k[d+14|0])>>1]+1|0;break e}f=l[Ri(d)>>1];o=g>>>0>f>>>0;n=f;break e}f=l[xb(d,k[d+15|0])>>1];n=l[xb(d,k[d+16|0])>>1]+1|0}g=g>>>0<n>>>0?g:f}if(!o|c){break b}if(!(!(k[b+89|0]&8)|j[a+480180>>2]==16384?!(j[a+480180>>2]&16777248):0)){j[b+88>>2]=j[b+88>>2]|4096}if(k[Ri(d)+2|0]|(j[a+480180>>2]&16777248?0:!l[b+808>>1])){break b}j[b+696>>2]=0;j[b+720>>2]=0;j[b+680>>2]=0;j[b+88>>2]=j[b+88>>2]|4096}mb(e+8|0,m,31);p=i,q=kb(e+8|0)+g|0,j[p+4>>2]=q}Za=e+16|0}function fva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=Za-32|0;Za=g;a:{b:{c:{h=j[a+8>>2];e=j[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=j[a+16>>2];l=j[a+40>>2];m=j[a+36>>2];f=j[a+4>>2];k=j[a>>2];j[g+24>>2]=k;j[g+28>>2]=f;j[g+16>>2]=h;j[g+20>>2]=e;e:{if(!d){b=l>>12;h=m>>12;break e}while(1){e=((((f&2147483647)<<1|k>>>31)&2147483646)<<1)+o|0;b=(k>>>16&65520)+n|0;k=i[b+14>>1];q=i[b+12>>1];r=i[b+10>>1];s=i[b+8>>1];t=i[b+6>>1];u=i[b+4>>1];v=i[b+2>>1];w=i[b>>1];h=0;b=1;while(1){f=h<<1;j[(g+8|0)+(h<<2)>>2]=(((((((p(i[(f|-8)+e>>1],v)+p(i[(f|-12)+e>>1],w)|0)+p(i[(f|-4)+e>>1],u)|0)+p(i[e+f>>1],t)|0)+p(i[(f|4)+e>>1],s)|0)+p(i[(f|8)+e>>1],r)|0)+p(i[(f|12)+e>>1],q)|0)+p(i[(f|16)+e>>1],k)|0)/32768;f=b;b=0;h=1;if(f){continue}break}b=j[a+32>>2];m=j[a+28>>2]+m|0;h=m>>12;j[c>>2]=j[c>>2]+p(h,j[g+8>>2]);l=b+l|0;b=l>>12;j[c+4>>2]=j[c+4>>2]+p(b,j[g+12>>2]);Bb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=j[g+24>>2];f=j[g+28>>2];continue}break}k=j[g+24>>2];f=j[g+28>>2]}j[a+40>>2]=l;j[a+20>>2]=h;j[a+36>>2]=m;j[a+24>>2]=b;j[a>>2]=k;j[a+4>>2]=f;Za=g+32|0}function eF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0;g=Za-16|0;Za=g;a:{b:{c:{d:{e:{m=(b|0)>=0;n=a+8|0;f:{if(Pk(n)){f=Pk(n);break f}f=fr(n)}if(!((f|0)>(b|0)?m:0)){a=R(8)|0;j[114626]=0;b=E(85,g|0,40673)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}Wb(a,b);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}c=D()|0;C()|0;gb(b);break d}if(c>>>0>=120){a=R(8)|0;j[114626]=0;b=E(85,g|0,40692)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Wb(a,b);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break c}c=D()|0;C()|0;gb(b);break d}c=D()|0;C()|0;S(a|0);break d}o=c+1|0;f=255;i[g>>1]=255;if((Qk(n)|0)>255){break a}q=a+32|0;m=255;c=255;while(1){m=j[q>>2]+p(m,896)|0;if(!j[m+1075060>>2]){break b}if(k[m+1075073|0]&16){i[g>>1]=c;f=c}c=c-1|0;m=c&65535;if((Qk(n)|0)<=(m|0)){continue}break}break a}c=D()|0;C()|0;S(a|0)}G(c|0)}z()}i[g>>1]=c;f=c}a=a+32|0;c=j[a>>2]+p(f&65535,896)|0;f=c+1074984|0;Pm(f,j[a>>2],65535);h[c+1075808|0]=o;h[c+1075805|0]=o;i[c+1075792>>1]=0;_k(f);Fo(j[a>>2],f,b+1|0,0,1,1);j[c+1075680>>2]=65536;Vr(j[a>>2],f,o,0,1,1,65535);r=c+1075676|0,s=Mm(zx(e*128,-128,128)+128),j[r>>2]=s;r=c+1075672|0,s=Mm(zx(d*256,0,256)),j[r>>2]=s;b=j[a>>2]+1074466|0;b=Dx(b,o6(b,b+(l[j[a>>2]+480212>>1]<<1)|0,g));i[j[a>>2]+480212>>1]=b;Za=g+16|0;return l[g>>1]}function Aua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=Za-48|0;Za=e;o=j[a+16>>2];f=wf(e+16|0);j[f+8>>2]=a+112;j[f+16>>2]=j[a+128>>2];q=f,r=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[q+12>>2]=r;b=j[f+16>>2];if(b){q=f,r=vf(a+8|0,b),j[q>>2]=r;j[f+4>>2]=ab}l=j[a+40>>2];m=j[a+36>>2];h=j[a+4>>2];g=j[a>>2];j[e+8>>2]=g;j[e+12>>2]=h;b=j[a+12>>2];j[e>>2]=j[a+8>>2];j[e+4>>2]=b;a:{if(!d){b=l>>12;k=m>>12;break a}while(1){b=0;k=b;n=g;j[e+40>>2]=g;j[e+44>>2]=b;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+o|0;b:{b=j[f+16>>2];if((b|0)<=0){break b}while(1){g=(k&2147483647)<<1|n>>>31;id(j[f+8>>2],(i[(g<<1|2)+h>>1]+i[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);hd(j[f+8>>2],4);Bb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;n=j[e+40>>2];k=j[e+44>>2];continue}}d=d-1|0;b=j[f+8>>2];Bb(b,b+8|0);b=j[f+8>>2];g=j[b+4>>2];if(g){k=b;b=(j[e+44>>2]&2147483647)<<1|j[e+40>>2]>>>31;id(k,(i[(b<<1|2)+h>>1]+i[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);hd(j[f+8>>2],g);b=j[f+8>>2];g=j[b>>2];j[b>>2]=g;j[b+4>>2]=0}h=qf(b,j[f+12>>2]);b=j[a+32>>2];m=j[a+28>>2]+m|0;k=m>>12;j[c>>2]=j[c>>2]+p(h,k);l=b+l|0;b=l>>12;j[c+4>>2]=j[c+4>>2]+p(h,b);Bb(e+8|0,e);if(d){c=c+8|0;g=j[e+8>>2];h=j[e+12>>2];continue}break}g=j[e+8>>2];h=j[e+12>>2]}j[a+40>>2]=l;j[a+20>>2]=k;j[a+36>>2]=m;j[a+24>>2]=b;j[a>>2]=g;j[a+4>>2]=h;Za=e+48|0}function zT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-32|0;Za=d;a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))==1397771593){md(b,32);si(d,1,a+4|0);qc(d+16|0,d);j[114626]=0;E(370,b+43|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}gb(d+16|0);i[b+30>>1]=k[a+19|0]<<2;Sf(b+30|0,256);i[b+32>>1]=k[a+17|0];Sf(b+32|0,64);c=a+47|0;i[b+28>>1]=(k[c|0]&127)<<2;Sf(b+28|0,256);if(h[c|0]<=-1){i[b+34>>1]=l[b+34>>1]|32}c=a+18|0;if(k[c|0]&16){i[b+34>>1]=l[b+34>>1]|2}if(k[c|0]&32){i[b+34>>1]=l[b+34>>1]|8}if(k[c|0]&64){i[b+34>>1]=l[b+34>>1]|4}if(h[c|0]<=-1){i[b+34>>1]=l[b+34>>1]|16}c=a+60|0;c=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=c?c:8363;j[b+24>>2]=c>>>0>256?c:256;c=a+48|0;j[b>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+52|0;j[b+4>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+56|0;j[b+8>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a- -64|0;j[b+12>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+68|0;j[b+16>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);Nm(b);h[b+38|0]=k[(k[a+79|0]&7)+27872|0];h[b+41|0]=k[a+76|0];h[b+40|0]=k[a+77|0]&127;h[b+39|0]=k[a+78|0];c=512;e=a+46|0;b:{if(k[e|0]!=64){c=16384;if(k[e|0]!=128){break b}}i[b+34>>1]=l[b+34>>1]|c}a=a+72|0;c=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24)}Za=d+32|0;return c|0}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function Oua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=Za-16|0;Za=h;f=j[a+48>>2];o=j[a+24>>2];q=j[a+20>>2];m=j[a+44>>2];r=j[a+16>>2];g=j[a+4>>2];k=j[a>>2];j[h+8>>2]=k;j[h+12>>2]=g;e=j[a+12>>2];j[h>>2]=j[a+8>>2];j[h+4>>2]=e;a:{if(!d){e=m;m=f;break a}while(1){e=(g<<1)+r|0;s=i[e-6>>1];g=(((k>>>16|0)+4&131064)<<1)+b|0;k=i[g+24>>1];t=i[e-4>>1];u=i[g+26>>1];v=i[e-2>>1];w=i[g+28>>1];x=i[e>>1];y=i[g+30>>1];z=i[e+2>>1];A=i[g+32>>1];B=i[e+4>>1];C=i[g+34>>1];D=i[e+6>>1];E=i[g+36>>1];F=i[e+8>>1];g=i[g+38>>1];e=j[a+60>>2];G=e;H=e>>31;e=Gb(m,-16777216,16776704);l=j[a+64>>2];f=Gb(f,-16777216,16776704);I=j[a+72>>2];J=j[c>>2];e=OMa(l,l>>31,e,e>>31);l=ab;K=e;e=j[a+68>>2];n=OMa(e,e>>31,f,f>>31);e=K+n|0;f=ab+l|0;f=e>>>0<n>>>0?f+1|0:f;l=e;g=(((((p(B,C)+p(z,A)|0)+p(D,E)|0)+p(g,F)|0)/2|0)+((((p(t,u)+p(k,s)|0)+p(v,w)|0)+p(x,y)|0)/2|0)|0)/16384<<8;e=g;k=OMa(G,H,e,e>>31);e=l+k|0;f=ab+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;j[c>>2]=p(e,q)+J;j[c+4>>2]=j[c+4>>2]+p(e,o);e=f-(g&I)|0;Bb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;k=j[h+8>>2];g=j[h+12>>2];f=m;m=e;continue}break}k=j[h+8>>2];g=j[h+12>>2]}j[a+48>>2]=m;j[a+44>>2]=e;j[a>>2]=k;j[a+4>>2]=g;Za=h+16|0}function Zf(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,m=0,n=0;f=Za-16|0;Za=f;j[f+12>>2]=d;e=b-1|0;g=0;a:{if(e>>>0>249){break a}h=Zs(a);g=j[a+480180>>2];if(!h){if(g&17408){a=((e&255)>>>0)/12|0;g=l[((e-p(a,12)&255)<<1)+21424>>1]<<4>>>a|0;break a}if(!(j[a+480180>>2]!=64?!(k[a+480208|0]&16):0)){mb(f,a+1074308|0,7);if(!(i=!kb(f),m=0,n=j[a+480180>>2]!=64,n?i:m)){a=((e&255)>>>0)/12|0;b=OMa(j[f+12>>2],0,j[(e-p(a,12)<<6&960)+25312>>2]<<a,0);a=ab;c=a>>>21|0;g=Wc((a&2097151)<<11|b>>>21,c);break a}a=((e&255)>>>0)/12|0;g=l[((e-p(a,12)&255)<<1)+21424>>1]<<5>>>a|0;break a}if(!d){j[f+12>>2]=8363}a=((e&255)>>>0)/12|0;kc(f+12|0,-1>>>a|0);g=Wc(RMa(OMa(l[((e-p(a,12)&255)<<1)+21424>>1],0,267616,0),ab,j[f+12>>2]<<a,0),ab);break a}if(g&20){d=e>>>0>12;if(j[a+480180>>2]==16){b=c<<4}else{mb(f,a+1074308|0,76);b=kb(f)?c&-8:c}c=d?e:12;if(k[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;g=(a|0)>1?a:1;break a}c=c-12|0;a=((c&255)>>>0)/12|0;c=((b|0)/16|0)+(c-p(a,12)<<3&248)|0;j[f>>2]=c+8;Md(f,0,103);c=c+((b|0)<0?-1:1)|0;c=(c|0)>-8?c:-8;d=b;b=b>>31;b=(d+b^b)&15;g=p(l[((((c|0)<95?c:95)<<1)+21904|0)+16>>1],b)+p(l[(j[f>>2]<<1)+21904>>1],16-b|0)<<1>>>a|0;break a}a=c>>>4&15;if(!(e>>>0<108?!(a|e>>>0<24):0)){b=p(a,12);a=((e&255)>>>0)/12|0;g=l[(b+(e-p(a,12)&255)<<1)+21024>>1]<<5>>>a|0;break a}g=l[(b<<1)+20798>>1]<<2}Za=f+16|0;return g}function Pua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;k=Za-16|0;Za=k;f=j[a+48>>2];q=j[a+24>>2];r=j[a+20>>2];n=j[a+44>>2];s=j[a+16>>2];g=j[a+4>>2];l=j[a>>2];j[k+8>>2]=l;j[k+12>>2]=g;e=j[a+12>>2];j[k>>2]=j[a+8>>2];j[k+4>>2]=e;a:{if(!d){e=n;n=f;break a}while(1){e=g+s|0;t=h[e-3|0];g=(((l>>>16|0)+4&131064)<<1)+b|0;l=i[g+24>>1];u=h[e-2|0];v=i[g+26>>1];w=h[e-1|0];x=i[g+28>>1];y=h[e|0];z=i[g+30>>1];A=h[e+1|0];B=i[g+32>>1];C=h[e+2|0];D=i[g+34>>1];E=h[e+3|0];F=i[g+36>>1];G=h[e+4|0];g=i[g+38>>1];e=j[a+60>>2];H=e;I=e>>31;e=Gb(n,-16777216,16776704);m=j[a+64>>2];f=Gb(f,-16777216,16776704);J=j[a+72>>2];K=j[c>>2];e=OMa(m,m>>31,e,e>>31);m=ab;L=e;e=j[a+68>>2];o=OMa(e,e>>31,f,f>>31);e=L+o|0;f=ab+m|0;f=e>>>0<o>>>0?f+1|0:f;m=e;g=(((((p(C,D)+p(A,B)|0)+p(E,F)|0)+p(g,G)<<8)/2|0)+((((p(u,v)+p(l,t)|0)+p(w,x)|0)+p(y,z)<<8)/2|0)|0)/16384<<8;e=g;l=OMa(H,I,e,e>>31);e=m+l|0;f=ab+f|0;f=e>>>0<l>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;j[c>>2]=p(e,r)+K;j[c+4>>2]=j[c+4>>2]+p(e,q);e=f-(g&J)|0;Bb(k+8|0,k);d=d-1|0;if(d){c=c+8|0;l=j[k+8>>2];g=j[k+12>>2];f=n;n=e;continue}break}l=j[k+8>>2];g=j[k+12>>2]}j[a+48>>2]=n;j[a+44>>2]=e;j[a>>2]=l;j[a+4>>2]=g;Za=k+16|0}function $va(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Za-48|0;Za=b;t=j[a+16>>2];l=j[a+44>>2];j[b+32>>2]=l;f=j[a+48>>2];j[b+36>>2]=f;h=j[a+52>>2];j[b+40>>2]=h;m=j[a+56>>2];j[b+44>>2]=m;u=j[a+24>>2];v=j[a+20>>2];e=j[a+4>>2];k=j[a>>2];j[b+24>>2]=k;j[b+28>>2]=e;g=j[a+12>>2];j[b+16>>2]=j[a+8>>2];j[b+20>>2]=g;if(d){while(1){e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+t|0;h=i[e>>1];j[b+8>>2]=h;j[b+12>>2]=i[e+2>>1];f=0;m=1;while(1){g=j[a+60>>2];q=g;k=(b+32|0)+(f<<3)|0;n=j[k>>2];e=Gb(n,-16777216,16776704);s=j[a+64>>2];l=Gb(j[k+4>>2],-16777216,16776704);o=j[a+68>>2];w=o;o=o>>31;j[k+4>>2]=n;n=j[a+72>>2];r=g>>31;h=h<<8;g=h;g=OMa(q,r,g,g>>31);q=ab;r=(b+8|0)+(f<<2)|0;f=g;g=OMa(s,s>>31,e,e>>31);f=f+g|0;e=ab+q|0;e=f>>>0<g>>>0?e+1|0:e;l=OMa(w,o,l,l>>31);f=l+f|0;e=ab+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;j[r>>2]=(e|0)/256;j[k>>2]=e-(h&n);if(m){f=1;m=0;h=j[b+12>>2];continue}break}j[c>>2]=j[c>>2]+p(j[b+8>>2],v);j[c+4>>2]=j[c+4>>2]+p(j[b+12>>2],u);Bb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;k=j[b+24>>2];e=j[b+28>>2];continue}break}k=j[b+24>>2];m=j[b+44>>2];h=j[b+40>>2];l=j[b+32>>2];f=j[b+36>>2];e=j[b+28>>2]}j[a+56>>2]=m;j[a+52>>2]=h;j[a+48>>2]=f;j[a+44>>2]=l;j[a>>2]=k;j[a+4>>2]=e;Za=b+48|0}function gva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=Za-32|0;Za=f;a:{b:{c:{g=j[a+8>>2];e=j[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}q=j[a+16>>2];m=j[a+40>>2];n=j[a+36>>2];l=j[a+4>>2];k=j[a>>2];j[f+24>>2]=k;j[f+28>>2]=l;j[f+16>>2]=g;j[f+20>>2]=e;e:{if(!d){b=m>>12;e=n>>12;break e}while(1){g=(((l&2147483647)<<1|k>>>31)&-2)+q|0;b=(k>>>16&65520)+o|0;k=i[b+14>>1];r=i[b+12>>1];s=i[b+10>>1];t=i[b+8>>1];u=i[b+6>>1];v=i[b+4>>1];w=i[b+2>>1];x=i[b>>1];b=0;e=1;while(1){j[(f+8|0)+(b<<2)>>2]=(((((((p(h[(b|-4)+g|0],w)+p(h[(b|-6)+g|0],x)|0)+p(h[(b|-2)+g|0],v)|0)+p(h[b+g|0],u)|0)+p(h[(b|2)+g|0],t)|0)+p(h[(b|4)+g|0],s)|0)+p(h[(b|6)+g|0],r)|0)+p(h[(b|8)+g|0],k)<<8)/32768;l=e;e=0;b=1;if(l){continue}break}b=j[a+32>>2];n=j[a+28>>2]+n|0;e=n>>12;j[c>>2]=j[c>>2]+p(e,j[f+8>>2]);m=b+m|0;b=m>>12;j[c+4>>2]=j[c+4>>2]+p(b,j[f+12>>2]);Bb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;k=j[f+24>>2];l=j[f+28>>2];continue}break}k=j[f+24>>2];l=j[f+28>>2]}j[a+40>>2]=m;j[a+20>>2]=e;j[a+36>>2]=n;j[a+24>>2]=b;j[a>>2]=k;j[a+4>>2]=l;Za=f+32|0}function xta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,m=0,n=0,o=0;c=Za+ -64|0;Za=c;i[c+62>>1]=b;f=Ui(a);e=vta(c+48|0,f);a:{b:{if(!f){break b}b=0;while(1){n=ac(e,b),o=b-d|0,i[n>>1]=o;j[114626]=0;g=E(1165,a|0,b|0)|0;m=j[114626];j[114626]=0;if((m|0)==1){break a}d=(l[g>>1]==l[c+62>>1])+d|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}if(!(d&65535)){break b}b=Lb(a);d=Mb(a);j[114626]=0;b=K(1166,b|0,d|0,c+62|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[c+32>>2]=b;b=Cd(c+40|0,c+32|0);n=c,o=Mb(a),j[n+16>>2]=o;d=j[Cd(c+24|0,c+16|0)>>2];b=j[b>>2];j[114626]=0;K(1167,a|0,b|0,d|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}n=c,o=Lb(a),j[n+32>>2]=o;n=c,o=Mb(a),j[n+16>>2]=o;if(rb(c+32|0,c+16|0)){while(1){b=l[j[c+32>>2]>>1];d=j[a+24>>2];j[114626]=0;d=E(442,d+484344|0,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}c:{if(!d){break c}b=Ib(j[a+24>>2]+484344|0,b);n=c,o=Lb(b),j[n+8>>2]=o;n=c,o=Mb(b),j[n>>2]=o;if(!rb(c+8|0,c)){break c}while(1){b=j[c+8>>2];d:{if(k[b+3|0]!=12){break d}d=k[b+5|0];if(bc(e)>>>0<=d>>>0){break d}n=b,o=k[ac(e,k[b+5|0])|0],h[n+5|0]=o}kk(c+8|0);if(rb(c+8|0,c)){continue}break}}je(c+32|0);if(rb(c+32|0,c+16|0)){continue}break}}b=l[a+28>>1];if(bc(e)>>>0<=b>>>0){break b}n=a,o=l[ac(e,l[a+28>>1])>>1],i[n+28>>1]=o}ff(e);Za=c- -64|0;return}a=D()|0;C()|0;ff(e);G(a|0);z()}function awa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Za-48|0;Za=b;t=j[a+16>>2];l=j[a+44>>2];j[b+32>>2]=l;f=j[a+48>>2];j[b+36>>2]=f;i=j[a+52>>2];j[b+40>>2]=i;m=j[a+56>>2];j[b+44>>2]=m;u=j[a+24>>2];v=j[a+20>>2];e=j[a+4>>2];k=j[a>>2];j[b+24>>2]=k;j[b+28>>2]=e;g=j[a+12>>2];j[b+16>>2]=j[a+8>>2];j[b+20>>2]=g;if(d){while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+t|0;i=h[e|0]<<8;j[b+8>>2]=i;j[b+12>>2]=h[e+1|0]<<8;f=0;m=1;while(1){g=j[a+60>>2];q=g;k=(b+32|0)+(f<<3)|0;n=j[k>>2];e=Gb(n,-16777216,16776704);s=j[a+64>>2];l=Gb(j[k+4>>2],-16777216,16776704);o=j[a+68>>2];w=o;o=o>>31;j[k+4>>2]=n;n=j[a+72>>2];r=g>>31;i=i<<8;g=i;g=OMa(q,r,g,g>>31);q=ab;r=(b+8|0)+(f<<2)|0;f=g;g=OMa(s,s>>31,e,e>>31);f=f+g|0;e=ab+q|0;e=f>>>0<g>>>0?e+1|0:e;l=OMa(w,o,l,l>>31);f=l+f|0;e=ab+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;j[r>>2]=(e|0)/256;j[k>>2]=e-(i&n);if(m){f=1;m=0;i=j[b+12>>2];continue}break}j[c>>2]=j[c>>2]+p(j[b+8>>2],v);j[c+4>>2]=j[c+4>>2]+p(j[b+12>>2],u);Bb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;k=j[b+24>>2];e=j[b+28>>2];continue}break}k=j[b+24>>2];m=j[b+44>>2];i=j[b+40>>2];l=j[b+32>>2];f=j[b+36>>2];e=j[b+28>>2]}j[a+56>>2]=m;j[a+52>>2]=i;j[a+48>>2]=f;j[a+44>>2]=l;j[a>>2]=k;j[a+4>>2]=e;Za=b+48|0}function hHa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{b=k[a+3|0];switch(b-14|0){case 2:case 3:case 4:case 5:break b;case 8:break f;case 6:case 7:break g;case 1:break h;case 0:break i;default:break j}}switch(b-31|0){case 2:break d;case 0:break e;default:break b}}k:{l:{b=k[a+5|0];if((b|0)!=240){if((b|0)==15){break l}if(b){break k}h[a+3|0]=11;break a}h[a+5|0]=239;break c}h[a+5|0]=254;break c}if(b>>>0>=16){h[a+5|0]=b|15;break c}h[a+5|0]=b|240;break c}h[c+15|0]=k[a+5|0]>>>4;h[c+14|0]=15;e=a,f=k[Yb(c+15|0,c+14|0)|0]|32,h[e+5|0]=f;break c}b=k[a+5|0];if(b>>>0>=16){h[c+13|0]=b>>>4;h[c+12|0]=15;e=a,f=k[Yb(c+13|0,c+12|0)|0]|240,h[e+5|0]=f;break c}h[a+5|0]=b|224;break c}h[a+5|0]=((k[a+5|0]^-1)&254)>>>1;break c}e=a,f=$i(k[a+5|0]<<1),h[e+5|0]=f;break c}b=32;m:{n:{o:{p:{q:{r:{s:{t:{d=k[a+5|0];switch(d>>>4|0){case 3:break m;case 5:break n;case 14:break o;case 12:case 13:break p;case 11:break q;case 10:break r;case 8:break s;case 0:break c;default:break t}}h[a+3|0]=0;break c}b=64;break m}b=176;break m}b=224;break m}if(d){break c}h[a+3|0]=0;break c}h[a+5|0]=119;break c}b=48}h[a+5|0]=d&15|b}b=k[a+3|0]}if(b>>>0>=36){h[a+3|0]=0;break a}h[a+3|0]=k[b+13344|0];if(k[a+2|0]|(b|0)!=12){break a}h[a+2|0]=1;h[a+3|0]=0;b=k[a+5|0];h[a+5|0]=0;h[a+4|0]=b}Za=c+16|0}function EZ(a,b,c,d,e,f){var g=0,h=0,l=0,m=0,n=0,o=0;j[c>>2]=a;j[f>>2]=d;a:{b:{c:{while(1){d:{d=j[c>>2];if(d>>>0>=b>>>0){break d}h=j[f>>2];if(h>>>0>=e>>>0){break d}m=2;a=k[d|0];if(a>>>0>1114111){break a}o=c;e:{if(a<<24>>24>=0){i[h>>1]=a;a=d+1|0;break e}if(a>>>0<194){break a}if(a>>>0<=223){if((b-d|0)<2){break b}g=k[d+1|0];if((g&192)!=128){break c}a=g&63|a<<6&1984;if(a>>>0>1114111){break c}i[h>>1]=a;a=d+2|0;break e}if(a>>>0<=239){if((b-d|0)<3){break b}l=k[d+2|0];g=k[d+1|0];f:{g:{if((a|0)!=237){if((a|0)!=224){break g}if((g&224)==160){break f}break c}if((g&224)==128){break f}break c}if((g&192)!=128){break c}}if((l&192)!=128){break c}a=l&63|((g&63)<<6|a<<12);if((a&65535)>>>0>1114111){break c}i[h>>1]=a;a=d+3|0;break e}if(a>>>0>244){break a}m=1;if((b-d|0)<4){break c}l=k[d+3|0];g=k[d+2|0];d=k[d+1|0];h:{i:{switch(a-240|0){case 0:if((d+112&255)>>>0>=48){break a}break h;case 4:if((d&240)!=128){break a}break h;default:break i}}if((d&192)!=128){break a}}if((g&192)!=128|(l&192)!=128){break a}if((e-h|0)<4){break c}m=2;l=l&63;n=g<<6;a=a&7;if((l|(n&4032|(d<<12&258048|a<<18)))>>>0>1114111){break c}d=d<<2;i[h>>1]=(g>>>4&3|(d&192|a<<8|d&60))+16320|55296;j[f>>2]=h+2;i[h+2>>1]=l|n&960|56320;a=j[c>>2]+4|0}j[o>>2]=a;j[f>>2]=j[f>>2]+2;continue}break}m=b>>>0>d>>>0}return m}return 1}return 2}function u$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0;a=Za-496|0;Za=a;hc(a+488|0,d);j[114626]=0;m=H(2441,a+488|0)|0;g=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(nb(f)){g=j[Li(f,0)>>2];j[114626]=0;i=E(2467,m|0,45)|0;k=j[114626];j[114626]=0;if((k|0)==1){break g}n=(g|0)==(i|0)}k=Db(a+456|0);i=Me(a+440|0);g=Me(a+424|0);j[114626]=0;ba(2495,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,i|0,g|0,a+420|0);c=j[114626];j[114626]=0;if((c|0)==1){break f}j[a+4>>2]=2412;l=yd(a+8|0,0,a+4|0);h:{if((nb(f)|0)>j[a+420>>2]){c=nb(f);h=j[a+420>>2];h=(nb(g)+(c-h<<1)|0)+1|0;break h}h=nb(g)+2|0}c=a+16|0;h=(nb(i)+h|0)+j[a+420>>2]|0;if(h>>>0<101){break e}fe(l,_c(h<<2));c=j[l>>2];if(c){break e}j[114626]=0;M(2413);b=j[114626];j[114626]=0;if((b|0)==1){break d}z()}f=D()|0;C()|0;break b}f=D()|0;C()|0;break b}f=D()|0;C()|0;break c}h=j[d+4>>2];o=zb(f);p=zb(f);f=nb(f);j[114626]=0;ga(2496,c|0,a+4|0,a|0,h|0,o|0,(f<<2)+p|0,m|0,n|0,a+480|0,j[a+476>>2],j[a+472>>2],k|0,i|0,g|0,j[a+420>>2]);f=j[114626];j[114626]=0;if((f|0)!=1){j[114626]=0;b=_(2471,b|0,c|0,j[a+4>>2],j[a>>2],d|0,e|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break a}}}f=D()|0;C()|0;mc(l)}pc(g);pc(i);gb(k)}wb(a+488|0);G(f|0);z()}mc(l);pc(g);pc(i);gb(k);wb(a+488|0);Za=a+496|0;return b|0}function GT(a,b){var c=0,d=0,e=0,f=0,g=0,l=0,m=0,n=0,o=0,p=0,q=0;d=Za-32|0;Za=d;a:{b:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=1229999433){break b}Ot(d,3,a+32|0);qc(d+16|0,d);j[114626]=0;E(369,b+492|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}gb(d+16|0);si(d,1,a+4|0);qc(d+16|0,d);j[114626]=0;E(369,b+524|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}gb(d+16|0);c=a+24|0;c=k[c|0]|k[c+1|0]<<8;j[b+4>>2]=64;j[b+8>>2]=128;j[b>>2]=c<<6;h[b+16|0]=k[a+26|0];h[b+17|0]=k[a+27|0];l=b+108|0;m=b+236|0;c=0;e=a- -64|0;while(1){f=c<<1;g=k[f+e|0];f=k[e+(f|1)|0];p=Oc(m,c),q=f,i[p>>1]=q;p=Pb(l,c),q=(g>>>0<120?g:c)+1|0,h[p|0]=q;c=c+1|0;if((c|0)!=120){continue}break}c=a+17|0;h[b+60|0]=k[b+60|0]&254|h[c|0]&1;h[b+60|0]=k[b+60|0]&253|k[c|0]&2;h[b+60|0]=k[b+60|0]&251|k[c|0]&4;l=b+61|0;h[l|0]=k[a+18|0];m=b+62|0;h[m|0]=k[a+19|0];f=b+63|0;h[f|0]=k[a+20|0];n=b- -64|0;h[n|0]=k[a+21|0];e=b+48|0;Nf(e,25);c=0;while(1){c:{o=c<<1;g=k[(o+a|0)+504|0];p=xb(e,c),q=g,i[p>>1]=q;if((g|0)==255){Nf(e,c);break c}g=k[((o|1)+a|0)+504|0];p=xb(e,c),q=g,h[p+2|0]=q;c=c+1|0;if((c|0)!=25){continue}}break}a=k[Wg(l,m)|0];if(sb(e)>>>0<=a>>>0){h[b+60|0]=k[b+60|0]&253}a=k[Wg(f,n)|0];if(sb(e)>>>0>a>>>0){break b}h[b+60|0]=k[b+60|0]&251}Za=d+32|0;return}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function y$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=Za-192|0;Za=a;hc(a+184|0,d);j[114626]=0;o=H(21,a+184|0)|0;g=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(nb(f)){g=k[Ub(f,0)|0];j[114626]=0;l=E(22,o|0,45)|0;m=j[114626];j[114626]=0;if((m|0)==1){break g}p=(g|0)==(l&255)}m=Db(a+160|0);l=Db(a+144|0);g=Db(a+128|0);j[114626]=0;ba(2493,c|0,p|0,a+184|0,a+176|0,a+175|0,a+174|0,m|0,l|0,g|0,a+124|0);c=j[114626];j[114626]=0;if((c|0)==1){break f}j[a+4>>2]=2412;n=yd(a+8|0,0,a+4|0);h:{if((nb(f)|0)>j[a+124>>2]){c=nb(f);i=j[a+124>>2];i=(nb(g)+(c-i<<1)|0)+1|0;break h}i=nb(g)+2|0}c=a+16|0;i=(nb(l)+i|0)+j[a+124>>2]|0;if(i>>>0<101){break e}fe(n,_c(i));c=j[n>>2];if(c){break e}j[114626]=0;M(2413);b=j[114626];j[114626]=0;if((b|0)==1){break d}z()}f=D()|0;C()|0;break b}f=D()|0;C()|0;break b}f=D()|0;C()|0;break c}i=j[d+4>>2];q=zb(f);r=zb(f);f=nb(f);j[114626]=0;ga(2494,c|0,a+4|0,a|0,i|0,q|0,f+r|0,o|0,p|0,a+176|0,h[a+175|0],h[a+174|0],m|0,l|0,g|0,j[a+124>>2]);f=j[114626];j[114626]=0;if((f|0)!=1){j[114626]=0;b=_(17,b|0,c|0,j[a+4>>2],j[a>>2],d|0,e|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break a}}}f=D()|0;C()|0;mc(n)}gb(g);gb(l);gb(m)}wb(a+184|0);G(f|0);z()}mc(n);gb(g);gb(l);gb(m);wb(a+184|0);Za=a+192|0;return b|0}function ADa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,j=0,m=0,n=0,o=0,p=0,q=0;d=Za-432|0;Za=d;rc(b);My(b,d+376|0,d+296|0,d+8|0);e=d;if(k[d+408|0]|k[d+409|0]<<8|(k[d+410|0]<<16|k[d+411|0]<<24)){f=k[d+427|0]+1|0}else{f=1}p=e,q=$i(f),h[p+4|0]=q;g=k[Yb(15087,d+4|0)|0];h[d+7|0]=g;i[d+4>>1]=4;a:{b:{if(!g){break b}g=d+291|0;while(1){c:{f=k[d+8|0]|k[d+9|0]<<8;e=f<<8&16711680|f<<24;if(!(e>>16<0|k[g|0]>63)){if(f){e=(e|(f>>>8&65280|f>>>24))>>>16|0;n=e>>>0>1?e:1;f=0;while(1){e=k[d+392|0]|k[d+393|0]<<8|(k[d+394|0]<<16|k[d+395|0]<<24);d:{if(!xc(b,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+(f<<2)|0)){break d}if(!xc(b,Dz(b))){break d}e=d;e:{if(!c){m=dd(b);break e}m=tp(b)}i[e+2>>1]=m;p=d,q=l[ui(d+4|0,d+2|0)>>1],i[p+4>>1]=q}f=f+1|0;if((n|0)!=(f|0)){continue}break}}e=k[d+296|0]|k[d+297|0]<<8|(k[d+298|0]<<16|k[d+299|0]<<24);if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0>o>>>0){e=k[d+296|0]|k[d+297|0]<<8|(k[d+298|0]<<16|k[d+299|0]<<24);if(xc(b,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))){break c}}h[d+7|0]=j+1;break b}jA(a);break a}e=k[d+296|0]|k[d+297|0]<<8|(k[d+298|0]<<16|k[d+299|0]<<24);My(b,d+376|0,d+296|0,d+8|0);o=e<<8&16711680|e<<24|(e>>>8&65280|e>>>24);j=j+1|0;if(k[d+7|0]>(j&255)>>>0){continue}break}}i[a>>1]=l[d+4>>1];h[a+2|0]=k[d+7|0]}Za=d+432|0}function Bua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=Za-48|0;Za=e;o=j[a+16>>2];f=wf(e+16|0);j[f+8>>2]=a+112;j[f+16>>2]=j[a+128>>2];q=f,r=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[q+12>>2]=r;b=j[f+16>>2];if(b){q=f,r=vf(a+8|0,b),j[q>>2]=r;j[f+4>>2]=ab}l=j[a+40>>2];m=j[a+36>>2];i=j[a+4>>2];g=j[a>>2];j[e+8>>2]=g;j[e+12>>2]=i;b=j[a+12>>2];j[e>>2]=j[a+8>>2];j[e+4>>2]=b;a:{if(!d){b=l>>12;k=m>>12;break a}while(1){b=0;k=b;n=g;j[e+40>>2]=g;j[e+44>>2]=b;i=(((i&2147483647)<<1|g>>>31)&-2)+o|0;b:{b=j[f+16>>2];if((b|0)<=0){break b}while(1){g=(k&2147483647)<<1|n>>>31;id(j[f+8>>2],h[(g|1)+i|0]+h[i+(g&-2)|0]<<5);hd(j[f+8>>2],4);Bb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;n=j[e+40>>2];k=j[e+44>>2];continue}}d=d-1|0;b=j[f+8>>2];Bb(b,b+8|0);b=j[f+8>>2];g=j[b+4>>2];if(g){k=b;b=(j[e+44>>2]&2147483647)<<1|j[e+40>>2]>>>31;id(k,h[(b|1)+i|0]+h[i+(b&-2)|0]<<5);hd(j[f+8>>2],g);b=j[f+8>>2];g=j[b>>2];j[b>>2]=g;j[b+4>>2]=0}i=qf(b,j[f+12>>2]);b=j[a+32>>2];m=j[a+28>>2]+m|0;k=m>>12;j[c>>2]=j[c>>2]+p(i,k);l=b+l|0;b=l>>12;j[c+4>>2]=j[c+4>>2]+p(i,b);Bb(e+8|0,e);if(d){c=c+8|0;g=j[e+8>>2];i=j[e+12>>2];continue}break}g=j[e+8>>2];i=j[e+12>>2]}j[a+40>>2]=l;j[a+20>>2]=k;j[a+36>>2]=m;j[a+24>>2]=b;j[a>>2]=g;j[a+4>>2]=i;Za=e+48|0}function jma(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,m=0,n=0,o=0,q=0;h=Za-16|0;Za=h;j[b+28>>2]=0;j[b+32>>2]=0;q=b;a:{b:{c=j[b+88>>2];if(!(c&65536)){e=j[b+676>>2];d=j[b+672>>2];break b}d=j[b+20>>2];f=j[b+672>>2];c:{if((d|0)!=(f|0)){e=j[b+24>>2];g=j[b+676>>2];break c}e=j[b+24>>2];g=j[b+676>>2];if((e|0)==(g|0)){break b}}m=a+24604|0;c=h;f=(d|0)<(f|0);d:{if(!((e|0)>=(g|0)?!f:0)){d=sM(m);break d}d=rM(m)}j[c+12>>2]=d;mb(h,a+1074308|0,4);if(!(!kb(h)|!(j[a+480180>>2]&4))){d=j[a+24620>>2];d=OMa(d,d>>31,5,0)+500|0;c=ab;d=ic(PMa(d,d>>>0<500?c+1|0:c,1e3,0),ab);j[h+12>>2]=d}c=j[b+656>>2];e:{if(!(!c|!(f|(e|0)<(g|0)))){e=d;c=l[c+12>>1];if(c){e=(p(c,j[a+24620>>2])>>>0)/1e5|0}n=(c|0)!=0;break e}e=j[h+12>>2];n=0}i=e?e:1;g=j[b+676>>2];o=j[b+24>>2];m=g-o<<12;c=j[b+672>>2];f=j[b+20>>2];e=c-f<<12;if(!(k[b+90|0]&32|(!(f|o)|(!(c|g)|n)))){j[h+12>>2]=j[a+1074380>>2];Md(h+12|0,d,2048);g=j[b+676>>2];i=j[h+12>>2];c=j[b+672>>2]}f=(m|0)/(i|0)|0;j[b+32>>2]=f;a=(e|0)/(i|0)|0;j[b+28>>2]=a;e=((p(f,i)|0)/-4096|0)+g|0;j[b+24>>2]=e;d=((p(a,i)|0)/-4096|0)+c|0;j[b+20>>2]=d;if(a|f){j[b+100>>2]=i;a=j[b+88>>2];break a}j[b+24>>2]=g;j[b+20>>2]=c;e=g;d=c;a=j[b+88>>2]&-65537;break a}j[b+24>>2]=e;j[b+20>>2]=d;a=c&-65537}j[q+88>>2]=a&-2097153;j[b+40>>2]=e<<12;j[b+36>>2]=d<<12;Za=h+16|0}function b6(a,b,c){var d=0,e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;e=k[c+1|0];g=p((e>>>3&1)+(e>>>4&1)|0,3)+(k[c+2|0]>>>2&3)|0;m=g-((g|0)!=0)|0;g=k[c+3|0]>191?1:2;a:{if(e&8){n=Bd(a,9);g=g<<1;d=Bd(a,g+7|0);break a}n=Bd(a,g|8)>>>g|0}e=p(m,40);r=e+42768|0;s=e+43088|0;t=p(m,23)+42576|0;m=0;b:{while(1){e=k[c+3|0];o=Bd(a,12);i[b+4>>1]=o;f=Bd(a,9);i[b+6>>1]=f;if((f&65535)>>>0>288){break b}e=e>>>0>191?d<<4:d;u=b,v=Bd(a,8),h[u+10|0]=v;d=Bd(a,k[c+1|0]&8?4:9);h[b+13|0]=22;h[b+14|0]=0;j[b>>2]=t;i[b+8>>1]=d;c:{if(Bd(a,1)){d=Bd(a,2);h[b+11|0]=d;if(!(d&255)){break b}f=Bd(a,1);i[b+18>>1]=65287;h[b+12|0]=f;if(k[b+11|0]==2){d=b;d:{if(!(f&255)){j[b>>2]=r;h[b+18|0]=8;q=39;f=0;break d}j[b>>2]=s;q=30;f=k[c+1|0]&8?8:6}h[d+14|0]=q;h[b+13|0]=f;e=e&3855}d=Bd(a,10);u=b,v=Bd(a,3),h[u+21|0]=v;u=b,v=Bd(a,3),h[u+22|0]=v;u=b,v=Bd(a,3),h[u+23|0]=v;d=d<<5;break c}h[b+11|0]=0;h[b+12|0]=0;d=Bd(a,15);u=b,v=Bd(a,4),h[u+18|0]=v;f=Bd(a,3);h[b+20|0]=255;h[b+19|0]=f}h[b+17|0]=d&31;h[b+15|0]=d>>>10;h[b+16|0]=d>>>5&31;m=(o&65535)+m|0;d=b;e:{if(k[c+1|0]&8){f=Bd(a,1);break e}f=l[b+8>>1]>499}h[d+24|0]=f;u=b,v=Bd(a,1),h[u+25|0]=v;d=Bd(a,1);h[b+27|0]=e>>>12&15;h[b+26|0]=d;b=b+28|0;d=e<<4;g=g-1|0;if(g){continue}break}return(j[a+4>>2]+m|0)>(j[a+8>>2]+(n<<3)|0)?-1:n}return-1}function MMa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{g=b;if(g){e=c;if(!e){break j}f=d;if(!f){break i}f=s(f)-s(g)|0;if(f>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;_a=a-p(b,c)|0;$a=0;ab=0;return b}e=d;if(!a){break g}if(!e){break f}f=e-1|0;if(f&e){break f}_a=a;$a=f&g;a=g>>>NMa(e)|0;ab=0;return a}f=e-1|0;if(!(f&e)){break e}j=(s(e)+33|0)-s(g)|0;h=0-j|0;break c}j=f+1|0;h=63-f|0;break c}_a=0;a=(g>>>0)/(e>>>0)|0;$a=g-p(a,e)|0;ab=0;return a}f=s(e)-s(g)|0;if(f>>>0<31){break d}break b}_a=a&f;$a=0;if((e|0)==1){break a}c=a;a=NMa(e);d=a&31;if((a&63)>>>0>=32){f=0;a=b>>>d|0}else{f=b>>>d|0;a=((1<<d)-1&b)<<32-d|c>>>d}ab=f;return a}j=f+1|0;h=63-f|0}e=b;g=a;f=j&63;i=f&31;if((f&63)>>>0>=32){f=0;l=e>>>i|0}else{f=e>>>i|0;l=((1<<i)-1&e)<<32-i|g>>>i}a=h&63;h=a&31;if((a&63)>>>0>=32){e=g<<h;a=0}else{e=(1<<h)-1&g>>>32-h|b<<h;a=g<<h}b=e;if(j){g=d-1|0;e=c-1|0;g=(e|0)!=-1?g+1|0:g;h=e;while(1){e=l;f=f<<1|e>>>31;e=e<<1;k=f;f=b>>>31|e;m=k;e=k;k=f;i=g-((f>>>0>h>>>0)+e|0)|0;e=i>>31;i=i>>31;f=c&i;l=k-f|0;f=m-((d&e)+(f>>>0>k>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;e=0;m=e;k=i&1;n=k;j=j-1|0;if(j){continue}break}}_a=l;$a=f;e=b<<1|a>>>31;a=k|a<<1;ab=e|m;return a}_a=a;$a=b;a=0;b=0}ab=b;return a}function Fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=Za-144|0;Za=c;e=Ek(c+40|0,a);j[114626]=0;d=E(683,c+24|0,32325)|0;a=j[114626];j[114626]=0;a:{b:{c:{d:{if((a|0)!=1){j[114626]=0;j[c+16>>2]=19465728;j[c+20>>2]=0;I(684,e|0,d|0,c+16|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}qb(d);if(!(j[e>>2]&1073741824)){break c}break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;qb(d);break b}a=me(b);j[114626]=0;i[c+16>>1]=a;i[c+14>>1]=65535;d=E(683,c+24|0,32331)|0;a=j[114626];j[114626]=0;e:{if((a|0)!=1){j[114626]=0;a=K(1178,e|0,c+14|0,d|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break e}qb(d);if((a|0)!=1){i[c+16>>1]=l[c+14>>1]}Sf(c+16|0,l[j[19859]+10>>1]);f:{if(l[c+16>>1]<=me(b)>>>0){break f}j[114626]=0;F(401,b|0,l[c+16>>1]);a=j[114626];j[114626]=0;if((a|0)!=1){break f}a=D()|0;C()|0;break b}i[c+12>>1]=0;if(!l[c+16>>1]){break a}a=0;g:{while(1){h:{a=Ib(b,a&65535);j[114626]=0;F(1580,c+24|0,c+12|0);d=j[114626];j[114626]=0;if((d|0)==1){break h}j[114626]=0;P(1562,e|0,a|0,c+24|0,1581)|0;a=j[114626];j[114626]=0;if((a|0)==1){break g}qb(c+24|0);a=l[c+12>>1]+1|0;i[c+12>>1]=a;if(l[c+16>>1]>(a&65535)>>>0){continue}break a}break}a=D()|0;C()|0;break b}a=D()|0;C()|0;qb(c+24|0);break b}a=D()|0;C()|0;break b}a=D()|0;C()|0;qb(d)}ag(e);G(a|0);z()}ag(e);Za=c+144|0}function TT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0;f=Za-1072|0;Za=f;e=zh(f+16|0);i=Jl(a,e);jb(e);j[a+1060>>2]=0;j[a+1064>>2]=0;j[a+1056>>2]=c;e=a+1068|0;j[e>>2]=0;j[e+4>>2]=0;j[a+1076>>2]=0;h[a+1080|0]=d;a:{b:{if(be(c)){k=a+1060|0;e=0;while(1){j[a+1060>>2]=0;j[a+1064>>2]=0;c:{if(!j[c>>2]){break c}while(1){j[114626]=0;d=E(258,b|0,2)|0;g=j[114626];j[114626]=0;d:{e:{f:{g:{if((g|0)!=1){if(!d){break c}j[114626]=0;d=H(357,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break g}if(!d){break d}j[114626]=0;I(341,f|0,b|0,d|0);d=j[114626];j[114626]=0;if((d|0)==1){break f}d=Jl(f+16|0,f);Ed(i,d);Vb(i+16|0,d+16|0,1040);jb(f+16|0);jb(f);j[a+1072>>2]=0;j[a+1076>>2]=0;g=Op(j[a+1056>>2]);d=j[a+1056>>2];if(g>>>0>=2){d=j[d+20>>2];j[114626]=0;F(358,a|0,d+(e<<1)|0);d=j[114626];j[114626]=0;if((d|0)!=1){break d}break e}d=j[d+20>>2];j[114626]=0;F(359,a|0,d+e|0);d=j[114626];j[114626]=0;if((d|0)==1){break e}break d}d=D()|0;C()|0;break a}d=D()|0;C()|0;break a}d=D()|0;C()|0;break a}d=J(77072)|0;if((C()|0)!=(W(77072)|0)){break a}O(d|0)|0;j[114626]=0;M(20);d=j[114626];j[114626]=0;if((d|0)==1){break b}}if(m[k>>2]<m[c>>2]){continue}break}}e=e+1|0;if(be(j[a+1056>>2])>>>0>e>>>0){continue}break}}Za=f+1072|0;return a|0}d=D()|0;C()|0}jb(a);G(d|0);z()}function JGa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,i=0,l=0,m=0;c=Za-32|0;Za=c;a:{b:{if(!yb(b,9)){break b}i=a+484344|0;l=a+480280|0;while(1){$m(b,c+28|0);d=hf(b);c:{if(!((k[c+28|0]|k[c+29|0]<<8|(k[c+30|0]<<16|k[c+31|0]<<24))==1229999433|(k[c+28|0]|k[c+29|0]<<8|(k[c+30|0]<<16|k[c+31|0]<<24))==1397771593|((k[c+28|0]|k[c+29|0]<<8|(k[c+30|0]<<16|k[c+31|0]<<24))==1297110104|(k[c+28|0]|k[c+29|0]<<8|(k[c+30|0]<<16|k[c+31|0]<<24))==1297110099))){if(yb(b,d)){break c}}cg(b,8);break b}cd(c+8|0,b,d);d=l;d:{if((k[c+28|0]|k[c+29|0]<<8|(k[c+30|0]<<16|k[c+31|0]<<24))==1481001027){while(1){j[114626]=0;e=H(390,c+8|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}h[d+8|0]=e;d=d+32|0;if((i|0)!=(d|0)){continue}break d}}e:{if(k[c+28|0]!=70){break e}d=k[c+29|0];e=(d|0)==88;if((d-48&255)>>>0>9?!e:0){break e}f=k[c+30|0];if((f-48&255)>>>0>9){break e}g=k[c+31|0];if((g-48&255)>>>0>9){break e}d=(p(f,10)+(e?-16:p(d,100)+48|0)|0)+g&255;if(d>>>0>249){break d}j[114626]=0;F(667,c+8|0,(p(d,160)+a|0)+906300|0);d=j[114626];j[114626]=0;if((d|0)!=1){break d}break a}if((k[c+28|0]|k[c+29|0]<<8|(k[c+30|0]<<16|k[c+31|0]<<24))!=1430540109){break d}j[a+1074304>>2]=0;m=1}jb(c+8|0);if(yb(b,9)){continue}break}}Za=c+32|0;return m|0}a=D()|0;C()|0;jb(c+8|0);G(a|0);z()}function sxa(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,i=0,k=0,l=0;b=Za-48|0;Za=b;f=b+40|0;a=f;j[a>>2]=-1;j[a+4>>2]=-1;zsa();k=b,l=t4(),j[k+8>>2]=l;j[b+12>>2]=ab;a=j[b+12>>2];j[b+16>>2]=j[b+8>>2];j[b+20>>2]=a;a=Za-16|0;Za=a;c=ssa(b+16|0);Za=a+16|0;j[b+24>>2]=c;j[b+28>>2]=ab;d=j[b+24>>2];e=d<<8&16711680|d<<24;a=j[b+28>>2];c=a<<24|d>>>8;g=c&65280;c=a<<8|d>>>24;e=c&255|g|e;c=b+32|0;a=((a&255)<<24|d>>>8)&-16777216|((a&16777215)<<8|d>>>24)&16711680|(a>>>8&65280|a>>>24)|i;h[c|0]=a;h[c+1|0]=a>>>8;h[c+2|0]=a>>>16;h[c+3|0]=a>>>24;a=e;h[c+4|0]=a;h[c+5|0]=a>>>8;h[c+6|0]=a>>>16;h[c+7|0]=a>>>24;a=j[b+36>>2];j[b+24>>2]=j[b+32>>2];j[b+28>>2]=a;vM(f,b+24|0,hb(b+24|0));k=b,l=q4(),j[k+8>>2]=l;j[b+12>>2]=ab;a=j[b+12>>2];j[b+16>>2]=j[b+8>>2];j[b+20>>2]=a;a=Za-16|0;Za=a;c=psa(b+16|0);Za=a+16|0;j[b+24>>2]=c;j[b+28>>2]=ab;d=j[b+24>>2];e=d<<8&16711680|d<<24;a=j[b+28>>2];c=a<<24|d>>>8;g=c&65280;c=a<<8|d>>>24;e=c&255|g|e;c=b+32|0;a=((a&255)<<24|d>>>8)&-16777216|((a&16777215)<<8|d>>>24)&16711680|(a>>>8&65280|a>>>24)|i;h[c|0]=a;h[c+1|0]=a>>>8;h[c+2|0]=a>>>16;h[c+3|0]=a>>>24;a=e;h[c+4|0]=a;h[c+5|0]=a>>>8;h[c+6|0]=a>>>16;h[c+7|0]=a>>>24;a=j[b+36>>2];j[b+24>>2]=j[b+32>>2];j[b+28>>2]=a;vM(f,b+24|0,hb(b+24|0));Za=b+48|0;ab=j[f+4>>2];return j[f>>2]}function OKa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,i=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;l=Za-32|0;Za=l;h[l+12|0]=0;o=_R(l+16|0,d,l+12|0);i=j[o>>2];j[l+12>>2]=d;f=d;a:{if(!b|!f){break a}while(1){p=l;g=b-1|0;f=k[a|0];b:{c:{if(!(!g|(f|0)!=(e&255))){f=k[a+1|0];j[114626]=0;j[l+8>>2]=f;f=E(33,l+8|0,l+12|0)|0;g=j[114626];j[114626]=0;d:{if((g|0)!=1){n=a+2|0;g=b-2|0;if(!g){break d}m=j[f>>2];if(!(m&255)){break d}g=k[n|0];while(1){h[i|0]=g;f=j[l+12>>2]-1|0;j[l+12>>2]=f;i=i+1|0;m=m-1|0;if(m&255){continue}break}g=b-3|0;n=a+3|0;break b}a=D()|0;C()|0;Np(o);G(a|0);z()}h[i|0]=e;f=j[l+12>>2]-1|0;break c}n=a+1|0;h[i|0]=f;f=j[l+12>>2]-1|0}j[p+12>>2]=f;i=i+1|0}if(!g){break a}a=n;b=g;if(f){continue}break}}n=j[o>>2];e=d-f|0;e:{if(!e){break e}i=128;g=0;while(1){b=k[n|0];m=0;f=0;while(1){a=c+g|0;p=a;r=k[a|0];a=b&i;h[p|0]=r|(a<<8|a)>>>(f-m&7);a=g+1|0;g=a>>>0<d>>>0?a:0;f=(a>>>0>=d>>>0)+f|0;i=(i<<8|i)>>>1&255;a=m&65535;m=m+1|0;if(a>>>0<7){continue}break}i=(i<<8|i)>>>f&255;n=n+1|0;q=q+1|0;if((q|0)!=(e|0)){continue}break}if(!e){break e}m=0;while(1){d=c;f=d;g=m<<24>>24;b=h[d|0];d=128;f:{if((b|0)==-128){break f}a=b;d=a;if((a|0)>-1){break f}d=0-(b&127)|0}m=g-(d&255)|0;h[f|0]=m;c=c+1|0;e=e-1|0;if(e){continue}break}}Np(o);Za=l+32|0}function DO(a,b){var c=0;a:{b:{c:{d:{if(Jd(a,15629)){break d}if(Jd(a,15656)){break d}if(Jd(a,15661)){break d}if(Jd(a,16153)){break d}if(!Jd(a,16158)){break c}}i[b+8>>1]=4;j[b>>2]=16163;break b}e:{f:{if(Jd(a,15634)){break f}if(Jd(a,15639)){break f}if(!Jd(a,16196)){break e}}h[b+10|0]=1;i[b+8>>1]=4;j[b>>2]=16201;return 1}g:{if(!Jd(a,16214)){if(!Jd(a,16219)){break g}}i[b+8>>1]=8;j[b>>2]=16224;break b}h:{if(!Jd(a,16234)){if(!Jd(a,16239)){break h}}j[b>>2]=16244;i[b+8>>1]=h[a+2|0]-48;break b}i:{if(!Jd(a,15619)){if(!Jd(a,15624)){break i}}j[b+4>>2]=1;j[b>>2]=16262;i[b+8>>1]=k[a|0]==56?8:4;return 1}if(!(Yc(a,16293,3)|(k[a+3|0]-52&255)>>>0>4)){j[b>>2]=16297;i[b+8>>1]=h[a+3|0]-48;break b}j:{if(Yc(a,16313,3)){if(Yc(a,16317,3)){break j}}if((k[a+3|0]-52&255)>>>0>5){break j}h[b+13|0]=1;h[b+11|0]=1;j[b>>2]=16321;i[b+8>>1]=h[a+3|0]-48;return 1}k:{if((k[a|0]-49&255)>>>0>8){break k}if(!Yc(a+1|0,16333,3)){h[b+12|0]=1;j[b>>2]=16337;i[b+8>>1]=h[a|0]-48;return 1}if((k[a+1|0]-48&255)>>>0>9|((k[a+2|0]|k[a+3|0]<<8)!=20035?(k[a+2|0]|k[a+3|0]<<8)!=18499:0)){break k}h[b+12|0]=1;j[b>>2]=16337;i[b+8>>1]=(h[a+1|0]+p(h[a|0],10)|0)-528;return 1}if(Yc(a,16368,3)|(k[a+3|0]-52&255)>>>0>5){break a}j[b>>2]=16372;i[b+8>>1]=h[a+3|0]-48}c=1}return c}function Cga(a){a=a|0;var b=0,c=0,d=0,e=0,f=q(0),g=0,h=0;c=Za-32|0;Za=c;a:{b=j[a+20>>2];b:{if(!b){break b}j[b+148>>2]=-1;g=c,h=bb[j[j[a>>2]+40>>2]](a)|0,j[g+16>>2]=h;j[c+8>>2]=1073741822;e=j[Pd(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=j[a+20>>2];j[114626]=0;F(507,d+4|0,b+4|0);b=j[114626];j[114626]=0;c:{d:{e:{f:{if((b|0)!=1){b=j[a+20>>2];j[114626]=0;F(1731,c+8|0,b+4|0);b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;j[c>>2]=0;j[c+4>>2]=0;I(1732,c+16|0,c+8|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break f}j[114626]=0;E(1733,c+16|0,0)|0;b=j[114626];j[114626]=0;g:{if((b|0)==1){break g}b=j[j[a>>2]+176>>2];j[114626]=0;F(b|0,a|0,-1);b=j[114626];j[114626]=0;if((b|0)==1){break g}if((e|0)>=1){b=0;while(1){d=j[j[a>>2]+48>>2];j[114626]=0;f=q(da(d|0,a|0,b|0));d=j[114626];j[114626]=0;if((d|0)==1){break e}j[114626]=0;n[c+8>>2]=f;E(1734,c+16|0,c+8|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break e}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=j[j[a>>2]+180>>2];j[114626]=0;N(b|0,a|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(71396)|0;break c}b=J(71396)|0;break c}b=J(71396)|0;break c}b=J(71396)|0;break c}b=J(71396)|0}if((C()|0)!=(W(71396)|0)){break a}O(b|0)|0;_r(j[a+20>>2]+4|0);Q()}Za=c+32|0;return}G(b|0);z()}function cIa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,m=0,n=0;f=Za-16|0;Za=f;md(b,32);e=a+4|0;e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);j[b>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=a+10|0;e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);j[b+4>>2]=e;g=e;e=a+14|0;e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);j[b+8>>2]=g+(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24));e=b;if(!(d?0:c)){c=a+46|0;c=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}j[e+24>>2]=c;c=k[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;if(!(k[d|0]|k[d+1|0]<<8)|(k[d|0]|k[d+1|0]<<8)==12288){break a}e=c;c=k[d|0]|k[d+1|0]<<8;c=(e-((c<<24|c<<8&16711680)>>>9|0)|0)+6144|0}ls(b,+(c|0)*.0006510416666666666);h[f+15|0]=k[a+9|0];h[f+14|0]=64;m=b,n=k[Yb(f+15|0,f+14|0)|0]<<2,i[m+30>>1]=n;if(h[a+40|0]&1){i[b+34>>1]=l[b+34>>1]|64;j[b>>2]=j[b>>2]>>>1;j[b+4>>2]=j[b+4>>2]>>>1;j[b+8>>2]=j[b+8>>2]>>>1}b:{if(k[a+41|0]<=8){a=j[b+4>>2];c=j[b+8>>2];break b}i[b+34>>1]=l[b+34>>1]|1;j[b>>2]=j[b>>2]>>>1;a=j[b+4>>2]>>>1|0;j[b+4>>2]=a;c=j[b+8>>2]>>>1|0;j[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){i[b+34>>1]=l[b+34>>1]|2;break c}j[b+4>>2]=0;j[b+8>>2]=0}Za=f+16|0}function to(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=Za-16|0;Za=c;a:{b:{c:{d:{e:{f:{g:{h:{b=j[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=j[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(l[a+480192>>1]){break a}a=a+484344|0;f=c,g=Lb(a),j[f+8>>2]=g;f=c,g=Mb(a),j[f>>2]=g;a=1;j:{if(!rb(c+8|0,c)){break j}while(1){b=j[c+8>>2];if(!(!th(b)|j[b+12>>2]==64)){a=4;break j}Hx(c+8|0);if(rb(c+8|0,c)){continue}break}}Za=c+16|0;return a}d=32;if(l[a+480188>>1]>16){break a}if(!l[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(h[e+480281|0]&1|l[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<l[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}Za=c+16|0;return d}function BP(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;a:{d=k[a|0];b:{if(d>>>0>21){break b}h[a|0]=k[d+14784|0];c:{switch(d-8|0){case 0:h[b|0]=k[b|0]<<1;break b;case 4:h[b|0]=k[b|0]+1>>>1;break b;case 5:a=k[b|0];h[b|0]=p(a>>>4|0,10)+(a&15);break b;case 6:d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=k[b|0];switch((d>>>4|0)-1|0){case 10:break e;case 9:break f;case 8:break g;case 6:break h;case 5:break i;case 3:break j;case 1:break k;case 0:break l;case 11:case 12:case 13:break b;case 14:break d;default:break m}}h[a|0]=0;break b}h[a|0]=29;h[c+15|0]=k[b|0]&15;h[c+14|0]=14;e=b,f=k[Yb(c+15|0,c+14|0)|0]<<4|15,h[e|0]=f;break b}h[a|0]=29;h[c+13|0]=k[b|0]&15;h[c+12|0]=14;e=b,f=k[Yb(c+13|0,c+12|0)|0]|240,h[e|0]=f;break b}h[b|0]=d&15|48;break b}h[b|0]=d&15|176;break b}h[b|0]=d&15|64;break b}h[a|0]=15;h[b|0]=k[b|0]&15;break b}h[a|0]=24;h[b|0]=(k[b|0]<<3&120)+8&240;break b}h[a|0]=24;h[b|0]=(k[b|0]&15)+1>>>1;break b}h[a|0]=10;break b;case 8:a=k[b|0];if(a>>>0<=223){h[b|0]=a>>>0>63?-16:a<<2&240;break b}if(a>>>0<=239){h[b|0]=a<<2&48|15;break b}h[b|0]=a<<4|15;break b;case 9:break c;default:break b}}a=k[b|0];if(a>>>0<=223){break a}if(a>>>0>239){break b}h[b|0]=a>>>2&3|240}Za=c+16|0;return}h[b|0]=a>>>0>63?15:a>>>2|0;Za=c+16|0}function rva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=Za-16|0;Za=g;f=j[a+48>>2];o=j[a+40>>2];q=j[a+36>>2];e=j[a+44>>2];t=j[a+16>>2];m=j[a+4>>2];k=j[a>>2];j[g+8>>2]=k;j[g+12>>2]=m;b=j[a+12>>2];j[g>>2]=j[a+8>>2];j[g+4>>2]=b;a:{if(!d){l=o>>12;r=q>>12;break a}while(1){b=m+t|0;l=h[b+2|0];r=h[b+1|0];u=h[b|0];v=h[b-1|0];b=j[a+60>>2];w=b;x=b>>31;b=e;e=Gb(e,-16777216,16776704);n=j[a+64>>2];f=Gb(f,-16777216,16776704);y=j[a+72>>2];z=j[a+32>>2];m=c;A=j[c>>2];e=OMa(n,n>>31,e,e>>31);n=ab;B=e;e=j[a+68>>2];s=OMa(e,e>>31,f,f>>31);e=B+s|0;f=ab+n|0;f=e>>>0<s>>>0?f+1|0:f;n=e;e=(k>>>21&2040)+27888|0;k=(((p(u,i[e+2>>1])+p(i[e>>1],v)|0)+p(r,i[e+4>>1])|0)+p(l,i[e+6>>1])<<8)/16384<<8;e=k;l=OMa(w,x,e,e>>31);e=n+l|0;f=ab+f|0;f=e>>>0<l>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;q=j[a+28>>2]+q|0;r=q>>12;j[m>>2]=p(f,r)+A;o=o+z|0;l=o>>12;j[c+4>>2]=j[c+4>>2]+p(f,l);e=e-(k&y)|0;Bb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=j[g+8>>2];m=j[g+12>>2];f=b;continue}break}k=j[g+8>>2];m=j[g+12>>2];f=b}j[a+40>>2]=o;j[a+20>>2]=r;j[a+36>>2]=q;j[a+48>>2]=f;j[a+44>>2]=e;j[a+24>>2]=l;j[a>>2]=k;j[a+4>>2]=m;Za=g+16|0}function Rza(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0;f=Za-16|0;Za=f;e=ei(c,b);j[f+12>>2]=e;a:{if((e|0)<1){break a}c=j[b+4>>2];b:{if(!c){c=j[d+4>>2];break b}c=32-c|0;j[f+8>>2]=c;e=j[Pd(f+8|0,f+12|0)>>2];j[f+12>>2]=j[f+12>>2]-e;h=j[d+4>>2];i=j[j[b>>2]>>2];k=j[b+4>>2];j[f+8>>2]=e;l=32-h|0;j[f+4>>2]=l;m=tb(f+8|0,f+4|0);g=j[d>>2];i=i&(-1<<k&-1>>>c-e);c=j[d+4>>2];h=j[b+4>>2];k=c>>>0>h>>>0?i<<c-h:i>>>h-c|0;h=j[m>>2];j[g>>2]=k|j[g>>2]&(-1<<c&-1>>>l-h^-1);k=c+h|0;c=k&31;j[d+4>>2]=c;g=g+(k>>>3&536870908)|0;j[d>>2]=g;e=e-h|0;if((e|0)>=1){j[g>>2]=j[g>>2]&(-1>>>32-e^-1)|i>>>h+j[b+4>>2];j[d+4>>2]=e;c=e}j[b>>2]=j[b>>2]+4;e=j[f+12>>2]}h=32-c|0;if((e|0)>=32){i=-1<<c;k=i^-1;g=j[b>>2];while(1){e=j[d>>2];g=j[g>>2];j[e>>2]=k&j[e>>2]|g<<c;j[d>>2]=e+4;j[e+4>>2]=i&j[e+4>>2]|g>>>h;l=j[f+12>>2];e=l-32|0;j[f+12>>2]=e;g=j[b>>2]+4|0;j[b>>2]=g;if((l|0)>63){continue}break}}if((e|0)<1){break a}i=j[j[b>>2]>>2];j[f+8>>2]=h;b=Pd(f+12|0,f+8|0);c=j[d>>2];g=j[d+4>>2];b=j[b>>2];k=j[c>>2]&(-1<<g&-1>>>h-b^-1);h=i&-1>>>32-e;j[c>>2]=k|h<<g;e=b+g|0;j[d+4>>2]=e&31;c=c+(e>>>3&536870908)|0;j[d>>2]=c;e=j[f+12>>2]-b|0;j[f+12>>2]=e;if((e|0)<1){break a}j[c>>2]=j[c>>2]&(-1>>>32-e^-1)|h>>>b;j[d+4>>2]=j[f+12>>2]}vd(a,d);Za=f+16|0}function nea(a,b,c){var d=0,e=0,f=0,g=0,h=q(0),k=0,o=q(0),r=0,s=0;e=Za-144|0;Za=e;d=j[a+4>>2];if(d>>>0>=29){j[a+4>>2]=0;d=0}d=p(d,44)+82240|0;if(!(b?0:(d|0)==j[a+4112>>2])){j[a+4112>>2]=d;h=q(c>>>0);mea(d,e+8|0,h);j[a+4124>>2]=j[e+40>>2];d=JG(KG(j[e+16>>2]),h);i[a+4190>>1]=d;i[a+4188>>1]=d;d=l[e+24>>1]<<1;i[a+4198>>1]=d;i[a+4196>>1]=d;while(1){d=(g<<4)+a|0;f=(e+8|0)+p(g,12)|0;k=j[f+44>>2];j[d+4204>>2]=k;j[d+4208>>2]=k;i[d+4212>>1]=l[f+36>>1];i[d+4214>>1]=l[f+42>>1];i[d+4216>>1]=l[f+40>>1];i[d+4218>>1]=l[f+38>>1];g=g+1|0;if((g|0)!=8){continue}break}j[a+53996>>2]=j[e+32>>2];f=a+4184|0;d=j[e+12>>2];if((d|0)>-9e3){d=IG(d)}else{d=0}j[f>>2]=d;f=a+54052|0;d=j[e+8>>2];if((d|0)>=-8999){d=IG(d)}else{d=0}j[f>>2]=d;d=j[e+28>>2];f=a+54036|0;j[f>>2]=268464128;j[f+4>>2]=1879052288;d=d>>>0<32512?d:32512;i[a+54010>>1]=d;i[a+54008>>1]=d;i[a+54006>>1]=d;i[a+54004>>1]=d;j[e+4>>2]=j[e+20>>2];Md(e+4|0,0,32752);d=l[e+4>>1];i[a+54018>>1]=d;f=a+54014|0;i[f>>1]=0;i[f+2>>1]=0;i[a+54012>>1]=d;o=n[e+36>>2];r=e,s=JG(q(o*o),h),j[r>>2]=s;Md(e,256,32512);d=l[e>>1];i[a+54026>>1]=d;f=a+54022|0;i[f>>1]=0;i[f+2>>1]=0;i[a+54020>>1]=d}if(b){j[a+4120>>2]=0;MG(a)}b=p(c,5);if(b>>>0>m[a+4124>>2]){j[a+4124>>2]=b}Za=e+144|0}function Vza(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0;f=Za-16|0;Za=f;g=ei(c,b);j[f+12>>2]=g;a:{if((g|0)<1){break a}c=j[b+4>>2];b:{if(!c){e=j[d+4>>2];break b}e=32-c|0;j[f+8>>2]=e;c=j[Pd(f+8|0,f+12|0)>>2];j[f+12>>2]=j[f+12>>2]-c;g=j[d+4>>2];h=j[j[b>>2]>>2];k=j[b+4>>2];j[f+8>>2]=c;l=32-g|0;j[f+4>>2]=l;m=tb(f+8|0,f+4|0);i=j[d>>2];k=h&(-1<<k&-1>>>e-c);e=j[d+4>>2];g=j[b+4>>2];h=j[m>>2];j[i>>2]=(e>>>0>g>>>0?k<<e-g:k>>>g-e|0)|j[i>>2]&(-1<<e&-1>>>l-h^-1);l=e+h|0;e=l&31;j[d+4>>2]=e;i=i+(l>>>3&536870908)|0;j[d>>2]=i;c=c-h|0;if((c|0)>=1){j[i>>2]=j[i>>2]&(-1>>>32-c^-1)|k>>>g+h;j[d+4>>2]=c;e=c}j[b>>2]=j[b>>2]+4;g=j[f+12>>2]}i=32-e|0;if((g|0)>=32){l=-1<<e;m=l^-1;h=j[b>>2];c=j[d>>2];k=j[c>>2];while(1){g=j[h>>2];j[c>>2]=k&m|g<<e;k=l&j[c+4>>2]|g>>>i;j[c+4>>2]=k;n=j[f+12>>2];g=n-32|0;j[f+12>>2]=g;h=h+4|0;c=c+4|0;if((n|0)>63){continue}break}j[b>>2]=h;j[d>>2]=c}if((g|0)<1){break a}h=j[j[b>>2]>>2];j[f+8>>2]=i;b=Pd(f+12|0,f+8|0);c=j[d>>2];e=j[d+4>>2];b=j[b>>2];g=h&-1>>>32-g;j[c>>2]=j[c>>2]&(-1<<e&-1>>>i-b^-1)|g<<e;e=b+e|0;j[d+4>>2]=e&31;c=c+(e>>>3&536870908)|0;j[d>>2]=c;e=j[f+12>>2]-b|0;j[f+12>>2]=e;if((e|0)<1){break a}j[c>>2]=j[c>>2]&(-1>>>32-e^-1)|g>>>b;j[d+4>>2]=j[f+12>>2]}vd(a,d);Za=f+16|0}function kva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=Za-32|0;Za=g;a:{b:{c:{h=j[a+8>>2];e=j[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}k=b+196648|0;break a}k=b+131112|0;break a}k=b+262184|0}l=j[a+16>>2];m=j[a+24>>2];n=j[a+20>>2];b=j[a+4>>2];f=j[a>>2];j[g+24>>2]=f;j[g+28>>2]=b;j[g+16>>2]=h;j[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;b=(f>>>16&65520)+k|0;o=i[b+14>>1];q=i[b+12>>1];r=i[b+10>>1];s=i[b+8>>1];t=i[b+6>>1];u=i[b+4>>1];v=i[b+2>>1];w=i[b>>1];h=0;b=1;while(1){f=h<<1;j[(g+8|0)+(h<<2)>>2]=(((((((p(i[(f|-8)+e>>1],v)+p(i[(f|-12)+e>>1],w)|0)+p(i[(f|-4)+e>>1],u)|0)+p(i[e+f>>1],t)|0)+p(i[(f|4)+e>>1],s)|0)+p(i[(f|8)+e>>1],r)|0)+p(i[(f|12)+e>>1],q)|0)+p(i[(f|16)+e>>1],o)|0)/32768;f=b;b=0;h=1;if(f){continue}break}j[c>>2]=j[c>>2]+p(j[g+8>>2],n);j[c+4>>2]=j[c+4>>2]+p(j[g+12>>2],m);Bb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;f=j[g+24>>2];b=j[g+28>>2];continue}break}f=j[g+24>>2];b=j[g+28>>2]}j[a>>2]=f;j[a+4>>2]=b;Za=g+32|0}function qva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=Za-16|0;Za=g;e=j[a+48>>2];n=j[a+40>>2];o=j[a+36>>2];f=j[a+44>>2];s=j[a+16>>2];m=j[a+4>>2];l=j[a>>2];j[g+8>>2]=l;j[g+12>>2]=m;b=j[a+12>>2];j[g>>2]=j[a+8>>2];j[g+4>>2]=b;a:{if(!d){k=n>>12;h=o>>12;break a}while(1){b=(m<<1)+s|0;h=i[b>>1];t=i[b-2>>1];u=i[b+2>>1];v=i[b+4>>1];r=j[a+60>>2];b=f;f=Gb(f,-16777216,16776704);q=j[a+64>>2];k=Gb(e,-16777216,16776704);w=j[a+72>>2];x=j[a+32>>2];m=c;y=j[c>>2];e=OMa(q,q>>31,f,f>>31);q=ab;f=e;e=(l>>>21&2040)+27888|0;l=(((p(i[e+2>>1],h)+p(i[e>>1],t)|0)+p(u,i[e+4>>1])|0)+p(v,i[e+6>>1])|0)/16384<<8;e=l;h=OMa(r,r>>31,e,e>>31);f=f+h|0;e=ab+q|0;e=f>>>0<h>>>0?e+1|0:e;h=f;f=j[a+68>>2];k=OMa(f,f>>31,k,k>>31);f=h+k|0;e=ab+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;o=j[a+28>>2]+o|0;h=o>>12;j[m>>2]=p(e,h)+y;n=n+x|0;k=n>>12;j[c+4>>2]=j[c+4>>2]+p(e,k);f=f-(l&w)|0;Bb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;l=j[g+8>>2];m=j[g+12>>2];e=b;continue}break}l=j[g+8>>2];m=j[g+12>>2];e=b}j[a+40>>2]=n;j[a+20>>2]=h;j[a+36>>2]=o;j[a+48>>2]=e;j[a+44>>2]=f;j[a+24>>2]=k;j[a>>2]=l;j[a+4>>2]=m;Za=g+16|0}function gja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,k=q(0),o=q(0),p=0,s=0,t=0,u=q(0);h=Za-16|0;Za=h;a:{if(i[d>>1]>i[d+2>>1]){break a}if(!sb(b)){break a}g=i[e>>1];if((g|0)<i[d>>1]){break a}p=i[d+2>>1];if((g|0)>(p|0)){break a}if((sb(b)-1&65535)>>>0>(p-g&65535)>>>0|m[a+36>>2]>65535){break a}b:{if(!sb(b)){break b}while(1){if(!(n[xb(b,f)>>2]<q(0))){f=f+1|0;if(sb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(n[c>>2]<=q(0)){break a}i[a>>1]=1;i[a+28>>1]=l[d>>1];s=a,t=dI(sb(b)),i[s+30>>1]=t;n[a+32>>2]=r(n[c>>2]);g=a+4|0;Sk(g,(i[d+2>>1]-i[d>>1]|0)+1|0);c=Lb(b);b=Mb(b);s=h,t=Lb(g),j[s+8>>2]=t;fja(c,b,So(h+8|0,i[e>>1]-i[d>>1]|0));c=i[a+28>>1];f=i[e>>1];c:{if((c|0)>=(f|0)){b=f;break c}while(1){f=f-1|0;k=n[xb(g,i[a+30>>1]+(f-c|0)|0)>>2];o=n[a+32>>2];s=xb(g,f-i[a+28>>1]|0),u=q(k/o),n[s>>2]=u;b=i[e>>1];c=i[a+28>>1];if((f|0)<=(c|0)){break c}if((b|0)!=-32768){continue}break}}c=i[a+30>>1];f=c+b|0;d:{if((f|0)>i[d+2>>1]|(32767-c|0)<(b|0)){break d}while(1){k=n[a+32>>2];o=n[xb(g,(f-c|0)-i[a+28>>1]|0)>>2];s=xb(g,f-i[a+28>>1]|0),u=q(o*k),n[s>>2]=u;if(i[d+2>>1]<=(f|0)){break d}f=f+1|0;c=i[a+30>>1];if(i[e>>1]<=(32767-c|0)){continue}break}}io(a);f=1}Za=h+16|0;return f|0}function P$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,l=0;a=Za-160|0;Za=a;j[a+144>>2]=c;j[a+152>>2]=b;j[a+20>>2]=2474;b=yd(a+24|0,a+32|0,a+20|0);j[114626]=0;hc(a+16|0,e);i=j[114626];j[114626]=0;a:{b:{c:{d:{if((i|0)!=1){j[114626]=0;i=H(21,a+16|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break b}h[a+15|0]=0;e=j[e+4>>2];j[114626]=0;c=ha(2475,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,i|0,b|0,a+20|0,a+132|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}if(!c){break c}De(g);if(!k[a+15|0]){break d}j[114626]=0;c=E(22,i|0,45)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}j[114626]=0;F(110,g|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){break d}break b}e=D()|0;C()|0;break a}j[114626]=0;i=E(22,i|0,48)|0;c=j[114626];j[114626]=0;if((c|0)!=1){e=j[b>>2];l=j[a+20>>2];c=l-1|0;d=c>>>0<e>>>0?e:c;i=i&255;while(1){e:{if(c>>>0>e>>>0){if((i|0)==k[e|0]){break e}d=e}j[114626]=0;K(2483,g|0,d|0,l|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break c}break b}e=e+1|0;continue}}break b}j[114626]=0;c=E(2415,a+152|0,a+144|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}if(c){j[f>>2]=j[f>>2]|2}c=j[a+152>>2];wb(a+16|0);mc(b);Za=a+160|0;return c|0}e=D()|0;C()|0;wb(a+16|0)}mc(b);G(e|0);z()}function Eua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=Za-48|0;Za=e;l=j[a+16>>2];f=wf(e+16|0);j[f+8>>2]=a+112;j[f+16>>2]=j[a+128>>2];q=f,r=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[q+12>>2]=r;b=j[f+16>>2];if(b){q=f,r=vf(a+8|0,b),j[q>>2]=r;j[f+4>>2]=ab}m=j[a+24>>2];n=j[a+20>>2];b=j[a+4>>2];g=j[a>>2];j[e+8>>2]=g;j[e+12>>2]=b;h=j[a+12>>2];j[e>>2]=j[a+8>>2];j[e+4>>2]=h;if(d){while(1){h=0;k=g;j[e+40>>2]=g;j[e+44>>2]=o;g=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a:{b=j[f+16>>2];if((b|0)<=0){break a}while(1){h=(h&2147483647)<<1|k>>>31;id(j[f+8>>2],(i[(h<<1|2)+g>>1]+i[g+((h&2147483646)<<1)>>1]|0)/8<<16>>16);hd(j[f+8>>2],4);Bb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;k=j[e+40>>2];h=j[e+44>>2];continue}}d=d-1|0;b=j[f+8>>2];Bb(b,b+8|0);b=j[f+8>>2];h=j[b+4>>2];if(h){k=b;b=(j[e+44>>2]&2147483647)<<1|j[e+40>>2]>>>31;id(k,(i[(b<<1|2)+g>>1]+i[g+((b&2147483646)<<1)>>1]|0)/8<<16>>16);hd(j[f+8>>2],h);b=j[f+8>>2];h=j[b>>2];j[b>>2]=h;j[b+4>>2]=0}b=qf(b,j[f+12>>2]);j[c>>2]=j[c>>2]+p(b,n);j[c+4>>2]=j[c+4>>2]+p(b,m);Bb(e+8|0,e);if(d){c=c+8|0;g=j[e+8>>2];b=j[e+12>>2];continue}break}g=j[e+8>>2];b=j[e+12>>2]}j[a>>2]=g;j[a+4>>2]=b;Za=e+48|0}function Eo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,n=0;e=Za-16|0;Za=e;f=a+1074308|0;mb(e+8|0,f,96);d=kb(e+8|0);j[b+660>>2]=(d?0:j[b+660>>2])+c;a:{if(!(k[b+88|0]&2)|(!(j[a+480180>>2]&18)|m[b+84>>2]>c>>>0)){break a}d=j[b+84>>2];if(!d){break a}g=c;c=j[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(j[a+480180>>2]==16384?j[b+88>>2]&1:0)|0;b:{if(Lf(b+810|0)){d=j[b+656>>2];if(d){d=l[Oc(d+236|0,k[b+810|0]-1|0)>>1];if(!d|d>>>0>l[a+480190>>1]){break b}}if(k[a+480210|0]&32){d=c;c=j[b+660>>2];j[b+660>>2]=d+c}j[b>>2]=0;j[b+4>>2]=c;if(!(k[b+88|0]&2)|m[b+84>>2]>c>>>0?m[b+76>>2]>c>>>0:0){break b}mb(e+8|0,f,57);if(!(h=!kb(e+8|0),i=0,n=j[a+480180>>2]!=16,n?h:i)){j[b+700>>2]=0;j[b+88>>2]=j[b+88>>2]|2097152;break b}if(!(j[a+480180>>2]&1048581)){mb(e+8|0,f,27);if(kb(e+8|0)){if(k[a+480208|0]&4){d=j[b+76>>2];j[b>>2]=0;j[b+4>>2]=d;break b}j[b>>2]=0;j[b+4>>2]=0;break b}d=j[b+80>>2];j[b>>2]=0;j[b+4>>2]=d;if(!(k[a+480208|0]&4)){break b}a=j[b+76>>2];if(a>>>0<5){break b}j[b>>2]=0;j[b+4>>2]=a-2;break b}if(!(k[b+88|0]&2)|j[a+480180>>2]!=1){break b}a=j[b+80>>2];j[b>>2]=0;j[b+4>>2]=a;break b}if(!(j[a+480180>>2]&268582928)|m[b+76>>2]<=c>>>0){break b}j[b>>2]=0;j[b+4>>2]=c}Za=e+16|0}function Epa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,l=0,m=0,n=0,q=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0;h=Za-16|0;Za=h;x=h,y=p(j[a>>2],be(a)),j[x+4>>2]=y;kc(h+4|0,c);c=lb(b);m=o[e+8>>3];l=j[h+4>>2];a:{if(!l){break a}e=l;while(1){n=0;f=c;q=k[f+4|0]|k[f+5|0]<<8|(k[f+6|0]<<16|k[f+7|0]<<24);g=k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24);v=g<<24|g<<8&16711680;s=n;n=q<<24|g>>>8;f=q<<8|g>>>24;s=s|0;n=n&65280|f&255|v;f=q;WMa(0,((f&255)<<24|g>>>8)&-16777216|((f&16777215)<<8|g>>>24)&16711680|(f>>>8&65280|f>>>24)|s);WMa(1,n&2147483647);m=u(+XMa(),m);c=c+8|0;e=e-1|0;if(e){continue}break}if(!l|m==0){break a}w=1/m;c=j[a+20>>2];while(1){e=b;a=k[e+4|0]|k[e+5|0]<<8|(k[e+6|0]<<16|k[e+7|0]<<24);g=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);f=g<<24;v=0;q=g<<8&16711680|f;s=a<<24|g>>>8;f=a<<8|g>>>24;e=a;WMa(0,((e&255)<<24|g>>>8)&-16777216|((e&16777215)<<8|g>>>24)&16711680|(e>>>8&65280|e>>>24)|v);WMa(1,q|(s&65280|f&255));x=h,z=+XMa()*w,o[x+8>>3]=z;pf(h+8|0,-1,1);t=o[h+8>>3]*32768;o[h+8>>3]=t;a=c;t=zd(t);b:{if(r(t)<2147483648){e=~~t;break b}e=-2147483648}x=a,y=Dc(e),i[x>>1]=y;b=b+8|0;c=c+2|0;l=l-1|0;if(l){continue}break}}if(d){o[d>>3]=m}Za=h+16|0;return j[h+4>>2]}function lva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=Za-32|0;Za=e;a:{b:{c:{f=j[a+8>>2];g=j[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?f>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?f>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?f>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?f>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=j[a+16>>2];n=j[a+24>>2];o=j[a+20>>2];b=j[a+4>>2];k=j[a>>2];j[e+24>>2]=k;j[e+28>>2]=b;j[e+16>>2]=f;j[e+20>>2]=g;g=a;if(d){while(1){f=(((b&2147483647)<<1|k>>>31)&-2)+m|0;a=(k>>>16&65520)+l|0;q=i[a+14>>1];r=i[a+12>>1];s=i[a+10>>1];t=i[a+8>>1];u=i[a+6>>1];v=i[a+4>>1];w=i[a+2>>1];x=i[a>>1];b=0;a=1;while(1){j[(e+8|0)+(b<<2)>>2]=(((((((p(h[(b|-4)+f|0],w)+p(h[(b|-6)+f|0],x)|0)+p(h[(b|-2)+f|0],v)|0)+p(h[b+f|0],u)|0)+p(h[(b|2)+f|0],t)|0)+p(h[(b|4)+f|0],s)|0)+p(h[(b|6)+f|0],r)|0)+p(h[(b|8)+f|0],q)<<8)/32768;k=a;a=0;b=1;if(k){continue}break}j[c>>2]=j[c>>2]+p(j[e+8>>2],o);j[c+4>>2]=j[c+4>>2]+p(j[e+12>>2],n);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=j[e+24>>2];b=j[e+28>>2];continue}break}k=j[e+24>>2];b=j[e+28>>2]}j[g>>2]=k;j[g+4>>2]=b;Za=e+32|0}function baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;b=Za-2144|0;Za=b;Ab(b+96|0,0,2048);a:{b:{c:{f=j[c+4>>2];if(!f){a=R(8)|0;j[114626]=0;b=E(85,b+80|0,38648)|0;c=j[114626];j[114626]=0;if((c|0)==1){break c}Wb(a,b);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}c=D()|0;C()|0;gb(b);break b}g=j[c>>2];d=j[c+12>>2];e=j[c+8>>2];j[b+72>>2]=e;j[b+76>>2]=d;c=j[b+76>>2];j[b+24>>2]=j[b+72>>2];j[b+28>>2]=c;j[b+68>>2]=f;j[b+64>>2]=g;c=j[b+68>>2];j[b+16>>2]=j[b+64>>2];j[b+20>>2]=c;c=b;i=b;h=QP(b+16|0);if(h){j[b+48>>2]=e;j[b+52>>2]=d;d=j[b+52>>2];j[b+8>>2]=j[b+48>>2];j[b+12>>2]=d;j[b+44>>2]=f;j[b+40>>2]=g;d=j[b+44>>2];j[b>>2]=j[b+40>>2];j[b+4>>2]=d;d=LP(b)}else{d=0}j[i+56>>2]=d;j[c+60>>2]=0;d=0;c=2048;while(1){if(c){e=bb[f|0](g,(b+96|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}a=Jr(a,ml(b+32|0,lb(b+96|0),d),h?b+56|0:0);if(a+1>>>0>=3){a=R(8)|0;j[114626]=0;b=E(85,b+80|0,38633)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Wb(a,b);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}c=D()|0;C()|0;gb(b);break b}c=D()|0;C()|0;S(a|0);break b}Za=b+2144|0;return a|0}c=D()|0;C()|0;S(a|0)}G(c|0)}z()}function H$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,l=0;a=Za-448|0;Za=a;j[a+432>>2]=c;j[a+440>>2]=b;j[a+20>>2]=2474;b=yd(a+24|0,a+32|0,a+20|0);j[114626]=0;hc(a+16|0,e);i=j[114626];j[114626]=0;a:{b:{c:{d:{if((i|0)!=1){j[114626]=0;i=H(2441,a+16|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break b}h[a+15|0]=0;e=j[e+4>>2];j[114626]=0;c=ha(2485,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,i|0,b|0,a+20|0,a+432|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}if(!c){break c}G$(g);if(!k[a+15|0]){break d}j[114626]=0;c=E(2467,i|0,45)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}j[114626]=0;F(112,g|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){break d}break b}e=D()|0;C()|0;break a}j[114626]=0;c=E(2467,i|0,48)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}e=j[b>>2];d=j[a+20>>2];i=d-4|0;while(1){if(!((c|0)!=j[e>>2]|e>>>0>=i>>>0)){e=e+4|0;continue}break}j[114626]=0;K(2491,g|0,e|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break c}break b}j[114626]=0;c=E(2447,a+440|0,a+432|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}if(c){j[f>>2]=j[f>>2]|2}c=j[a+440>>2];wb(a+16|0);mc(b);Za=a+448|0;return c|0}e=D()|0;C()|0;wb(a+16|0)}mc(b);G(e|0);z()}function $za(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=Za+ -64|0;Za=d;t=d,u=ef(a)>>>5|0,i[t+32>>1]=u;i[d+16>>1]=3999;t=c,u=l[gf(d+32|0,d+16|0)>>1],i[t+480190>>1]=u;qy(b,l[c+480190>>1],0);a:{if(l[c+480190>>1]){h=d+62|0;p=d+58|0;q=d+56|0;s=d+52|0;r=d+60|0;n=1;o=1;while(1){f=Yo(c,o&65535);Ds(a,d+32|0);md(f,0);en(d,2,d+32|0);qc(d+16|0,d);j[114626]=0;E(369,((n<<5)+c|0)+946300|0,d+16|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break a}gb(d+16|0);i[f+32>>1]=64;j[f+24>>2]=8287;e=k[r|0]|k[r+1|0]<<8;i[d+16>>1]=(e<<24|e<<8&16711680)>>>16;i[d>>1]=64;t=f,u=l[gf(d+16|0,d)>>1]<<2,i[t+30>>1]=u;e=s;e=(k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))&-16777217;j[f>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=k[q|0]|k[q+1|0]<<8;g=k[p|0]|k[p+1|0]<<8;g=(g<<24|g<<8&16711680)>>>16|0;b:{if(g>>>0<2){break b}e=(e<<8&16711680|e<<24)>>>16|0;g=e+g<<1;if(g>>>0>m[f>>2]){break b}j[f+16>>2]=g;j[f+12>>2]=e<<1;i[f+34>>1]=l[f+34>>1]|8}if(k[h|0]|k[h+1|0]<<8){e=(k[h|0]|k[h+1|0]<<8)==512}else{e=1}Nd(d+16|0,b,n-1|0);Qd(d+16|0,e);o=o+1|0;n=o&65535;if(n>>>0<=l[c+480190>>1]){continue}break}}Za=d- -64|0;return}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function kCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,m=0;e=Za-16|0;Za=e;md(b,0);f=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);a:{if(c&34){if(d){j[b+24>>2]=f;break a}g=b,m=Yj(Bg(+(f+1408|0)*.0006510416666666666)*8363),j[g+24>>2]=m;break a}h[b+37|0]=(c|0)==16?f:f^128;h[b+36|0]=k[a+4|0]}h[e+15|0]=k[a+5|0];h[e+14|0]=64;g=b,m=k[Yb(e+15|0,e+14|0)|0]<<2,i[g+30>>1]=m;d=a+6|0;if((k[d|0]|k[d+1|0]<<8)>>>0<=256){i[b+28>>1]=k[d|0]|k[d+1|0]<<8;i[b+34>>1]=l[b+34>>1]|32}d=a+8|0;j[b>>2]=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=a+12|0;j[b+4>>2]=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=a+16|0;j[b+8>>2]=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=a+20|0;if(k[d|0]&16){i[b+34>>1]=l[b+34>>1]|2}if(k[d|0]&32){i[b+34>>1]=l[b+34>>1]|4}if(h[d+1|0]&1){i[b+34>>1]=l[b+34>>1]|8}if(k[d+1|0]&2){i[b+34>>1]=l[b+34>>1]|16}h[b+38|0]=k[(k[a+22|0]&7)+27872|0];h[b+39|0]=k[a+23|0];h[b+40|0]=k[a+24|0];h[b+41|0]=k[a+25|0];if((c|0)==32){h[e+13|0]=k[a+26|0];h[e+12|0]=64;g=b,m=k[Yb(e+13|0,e+12|0)|0],i[g+32>>1]=m}c=a+27|0;j[b+12>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);a=a+31|0;j[b+16>>2]=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);Za=e+16|0}function om(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;c=Za-80|0;Za=c;g=bw(a);e=b+24|0;a:{b:{if(rh(j[e>>2]+484360|0)){if(rh(j[e>>2]+484360|0)){a=0;while(1){f=j[e>>2];b=uG(zO(c+40|0,1),a&255,0,0);j[114626]=0;d=j[b+12>>2];j[c+8>>2]=j[b+8>>2];j[c+12>>2]=d;d=j[b+20>>2];j[c+16>>2]=j[b+16>>2];j[c+20>>2]=d;d=j[b+4>>2];j[c>>2]=j[b>>2];j[c+4>>2]=d;L(2121,c- -64|0,f|0,0,c|0);b=j[114626];j[114626]=0;c:{d:{if((b|0)!=1){i=c,k=Lb(c- -64|0),j[i+32>>2]=k;i=c,k=Mb(c- -64|0),j[i+24>>2]=k;if(rb(c+32|0,c+24|0)){break d}break c}a=D()|0;C()|0;break b}while(1){e:{b=j[c+32>>2];f=l[b+24>>1];h=o[b>>3];d=j[b+16>>2];b=c+40|0;j[b+16>>2]=a;j[b+12>>2]=f;j[b+8>>2]=d;o[b>>3]=h;j[114626]=0;F(2122,g|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break e}Qx(c+32|0);if(rb(c+32|0,c+24|0)){continue}break c}break}a=D()|0;C()|0;hl(c- -64|0);break b}hl(c- -64|0);a=a+1|0;if(rh(j[e>>2]+484360|0)>>>0>a>>>0){continue}break}}Za=c+80|0;return}b=R(8)|0;j[114626]=0;c=E(85,c+40|0,38586)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}a=D()|0;C()|0;S(b|0)}Ye(g);G(a|0)}z()}function GZ(a,b,c,d,e,f){var g=0,i=0;j[c>>2]=a;j[f>>2]=d;g=j[c>>2];a:{b:{while(1){if(b>>>0<=g>>>0){a=0;break a}a=2;d=l[g>>1];if(d>>>0>1114111){break a}c:{d:{if(d>>>0<=127){a=1;g=j[f>>2];if((e-g|0)<1){break a}j[f>>2]=g+1;h[g|0]=d;break d}if(d>>>0<=2047){a=j[f>>2];if((e-a|0)<2){break b}j[f>>2]=a+1;h[a|0]=d>>>6|192;a=j[f>>2];j[f>>2]=a+1;h[a|0]=d&63|128;break d}if(d>>>0<=55295){a=j[f>>2];if((e-a|0)<3){break b}j[f>>2]=a+1;h[a|0]=d>>>12|224;a=j[f>>2];j[f>>2]=a+1;h[a|0]=d>>>6&63|128;a=j[f>>2];j[f>>2]=a+1;h[a|0]=d&63|128;break d}if(d>>>0<=56319){a=1;if((b-g|0)<4){break a}i=l[g+2>>1];if((i&64512)!=56320){break c}if((e-j[f>>2]|0)<4){break a}a=d&960;if((i&1023|(d<<10&64512|a<<10))+65536>>>0>1114111){break c}j[c>>2]=g+2;g=j[f>>2];j[f>>2]=g+1;a=(a>>>6|0)+1|0;h[g|0]=a>>>2|240;g=j[f>>2];j[f>>2]=g+1;h[g|0]=a<<4&48|d>>>2&15|128;a=j[f>>2];j[f>>2]=a+1;h[a|0]=i>>>6&15|d<<4&48|128;a=j[f>>2];j[f>>2]=a+1;h[a|0]=i&63|128;break d}if(d>>>0<57344){break a}a=j[f>>2];if((e-a|0)<3){break b}j[f>>2]=a+1;h[a|0]=d>>>12|224;a=j[f>>2];j[f>>2]=a+1;h[a|0]=d>>>6&63|128;a=j[f>>2];j[f>>2]=a+1;h[a|0]=d&63|128}g=j[c>>2]+2|0;j[c>>2]=g;continue}break}return 2}return 1}return a}function CD(a,b){var c=0,d=0,e=0,f=0;a:{b:{c:{c=j[a+4>>2];d:{if(c>>>0<m[a+104>>2]){j[a+4>>2]=c+1;c=k[c|0];break d}c=Lc(a)}switch(c-43|0){case 0:case 2:break b;default:break c}}b=c-48|0;break a}f=(c|0)==45;e=!b;b=j[a+4>>2];e:{if(b>>>0<m[a+104>>2]){j[a+4>>2]=b+1;c=k[b|0];break e}c=Lc(a)}b=c-48|0;if(!(e|b>>>0<10|!j[a+104>>2])){j[a+4>>2]=j[a+4>>2]-1}}f:{if(b>>>0<10){b=0;while(1){d=p(b,10)+c|0;b=j[a+4>>2];g:{if(b>>>0<m[a+104>>2]){j[a+4>>2]=b+1;c=k[b|0];break g}c=Lc(a)}e=c-48|0;b=d-48|0;if((b|0)<214748364?e>>>0<=9:0){continue}break}d=b;b=b>>31;h:{if(e>>>0>=10){break h}while(1){d=OMa(d,b,10,0);c=d+c|0;b=ab;b=c>>>0<d>>>0?b+1|0:b;d=c-48|0;b=b-(c>>>0<48)|0;c=j[a+4>>2];i:{if(c>>>0<m[a+104>>2]){j[a+4>>2]=c+1;c=k[c|0];break i}c=Lc(a)}e=c-48|0;if(e>>>0>9){break h}if((b|0)<21474836?1:(b|0)<=21474836?d>>>0<2061584302:0){continue}break}}if(e>>>0<10){while(1){c=j[a+4>>2];j:{if(c>>>0<m[a+104>>2]){j[a+4>>2]=c+1;c=k[c|0];break j}c=Lc(a)}if(c-48>>>0<10){continue}break}}if(j[a+104>>2]){j[a+4>>2]=j[a+4>>2]-1}a=d;d=f?0-a|0:a;b=f?0-(((a|0)!=0)+b|0)|0:b;break f}b=-2147483648;if(!j[a+104>>2]){break f}j[a+4>>2]=j[a+4>>2]-1;ab=-2147483648;return 0}ab=b;return d}function nga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,i=0,l=0;c=Za+ -64|0;Za=c;gga(a);j[114626]=0;l=a;F(1747,a|0,11);b=j[114626];j[114626]=0;a:{if((b|0)!=1){b=80080;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){d=lg(44);if(d){g=j[b>>2];f=j[b+4>>2];j[114626]=0;f=E(85,c+32|0,f|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break k}j[114626]=0;F(1748,c+48|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break j}e=j[b+8>>2];j[114626]=0;e=E(85,c|0,e|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break i}j[114626]=0;F(1748,c+16|0,e|0);i=j[114626];j[114626]=0;if((i|0)==1){break h}j[114626]=0;U(1749,d|0,g|0,1,c+48|0,c+16|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break g}qb(c+16|0);gb(e);qb(c+48|0);gb(f);j[114626]=0;j[c+60>>2]=d;F(1750,l|0,c+60|0);d=j[114626];j[114626]=0;if((d|0)==1){break b}d=j[c+60>>2];j[d+32>>2]=j[b+12>>2];j[d+36>>2]=j[b+16>>2];h[d+40|0]=k[b+20|0];h[d+41|0]=k[d+41|0]&253|k[b+21|0]<<1}b=b+24|0;if((b|0)!=80344){continue}break}Za=c- -64|0;return a|0}b=D()|0;C()|0;break c}b=D()|0;C()|0;break d}b=D()|0;C()|0;break e}b=D()|0;C()|0;break f}b=D()|0;C()|0;qb(c+16|0)}gb(e)}qb(c+48|0)}gb(f)}Cb(d);break a}b=D()|0;C()|0;break a}b=D()|0;C()|0}ow(l);G(b|0);z()}function pX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,l=0,m=0,n=0;if(Rf(a,j[b+8>>2],e)){Au(b,c,d);return}a:{if(Rf(a,j[b>>2],e)){if(!(j[b+20>>2]!=(c|0)?j[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}j[b+32>>2]=1;return}j[b+32>>2]=d;if(j[b+44>>2]!=4){f=a+16|0;m=f+(j[a+12>>2]<<3)|0;n=b;b:{c:{while(1){d:{if(f>>>0>=m>>>0){break d}i[b+52>>1]=0;zu(f,b,c,c,1,e);if(k[b+54|0]){break d}e:{if(!k[b+53|0]){break e}if(k[b+52|0]){d=1;if(j[b+24>>2]==1){break c}l=1;g=1;if(k[a+8|0]&2){break e}break c}l=1;d=g;if(!(h[a+8|0]&1)){break c}}f=f+8|0;continue}break}d=g;a=4;if(!l){break b}}a=3}j[n+44>>2]=a;if(d&1){break a}}j[b+20>>2]=c;j[b+40>>2]=j[b+40>>2]+1;if(j[b+36>>2]!=1|j[b+24>>2]!=2){break a}h[b+54|0]=1;return}g=j[a+12>>2];f=a+16|0;hq(f,b,c,d,e);if((g|0)<2){break a}g=f+(g<<3)|0;f=a+24|0;a=j[a+8>>2];if(!(j[b+36>>2]!=1?!(a&2):0)){while(1){if(k[b+54|0]){break a}hq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(k[b+54|0]|j[b+36>>2]==1){break a}hq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(k[b+54|0]|(j[b+24>>2]==1?j[b+36>>2]==1:0)){break a}hq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function oga(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,l=0,m=0,n=0;d=Za-80|0;Za=d;f=Eb(d+48|0,BJ(b));j[114626]=0;F(1596,d- -64|0,f|0);e=j[114626];j[114626]=0;a:{b:{c:{if((e|0)!=1){gb(f);m=d,n=Lb(a),j[m+40>>2]=n;m=d,n=Mb(a),j[m+32>>2]=n;if(!rb(d+40|0,d+32|0)){a=0;break a}i=b+20|0;l=b+16|0;f=0;while(1){a=0;g=j[d+40>>2];e=l;if(j[j[g>>2]+32>>2]==(k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))){a=i;a=j[j[g>>2]+36>>2]==(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))}e=j[g>>2];j[114626]=0;F(1746,d|0,e+8|0);e=j[114626];j[114626]=0;d:{e:{f:{g:{if((e|0)!=1){j[114626]=0;F(1596,d+16|0,d|0);e=j[114626];j[114626]=0;if((e|0)==1){break g}e=Ze(d+16|0,d- -64|0);gb(d+16|0);gb(d);if((a&e)!=1){break e}f=j[g>>2];h=3;break d}a=D()|0;C()|0;break f}a=D()|0;C()|0;gb(d)}f=d- -64|0;break b}if(!(a^1|(h|0)>1)){f=j[g>>2];h=2;break d}a=e&(h|0)<1;f=a?j[g>>2]:f;h=a?1:h}Id(d+40|0);if(rb(d+40|0,d+32|0)){continue}break}break c}a=D()|0;C()|0;break b}a=0;if(!f){break a}e=j[f+4>>2];if(!e){break a}j[114626]=0;a=K(e|0,f|0,c|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){a=(a|0)!=0;break a}a=D()|0;f=d- -64|0;C()|0}gb(f);G(a|0);z()}gb(d- -64|0);Za=d+80|0;return a}function bha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,l=0,m=0,p=0,s=0;h=Za-16|0;Za=h;if(!k[a+4242|0]){uw(a);a:{if(!k[a+4240|0]){break a}e=zJ(j[a+16>>2]);if(e==o[a+4288>>3]){break a}o[a+4288>>3]=e;xr(a)}g=a+4256|0;b:{if(k[a+4244|0]){if(!(o[g>>3]<=1)){o[g>>3]=1}break b}i=(j[a+4232>>2]&-2)!=4;e=o[g>>3];c:{if(r(e)<2147483648){f=~~e;break c}f=-2147483648}if(!(i|(f|0)<1)){sw(a);e=o[a+4256>>3]}o[g>>3]=e- +(f|0)}e=0;d:{e:{switch(j[a+4232>>2]){case 0:e=Kh(o[a+4256>>3]*6.283185307179586);break d;case 1:e=r(o[a+4256>>3]+ -.5)*-4+1;break d;case 2:e=o[a+4256>>3];e=e+e+ -1;break d;case 3:e=o[a+4256>>3]<.5?-1:1;break d;case 4:e=o[a+4272>>3];break d;case 5:break e;default:break d}}e=o[a+4256>>3];l=e*e*e*((e*6+ -15)*e+10);e=o[a+4272>>3];e=l*(o[a+4280>>3]-e)+e}o[h+8>>3]=(k[a+4241|0]?-e:e)*+n[a+4220>>2]+ +n[a+4224>>2];pf(h+8|0,0,1);f=Ki(a);f:{if(!f){break f}g=j[a+4236>>2];if(k[a+4243|0]){p=f,s=g>>>8&15|176|(g&127)<<8|Ls(o[h+8>>3]*127)<<16,m=j[j[f>>2]+68>>2],bb[m](p|0,s|0)|0;break f}bb[j[j[f>>2]+44>>2]](f,g,q(o[h+8>>3]))}o[a+4256>>3]=o[a+4256>>3]+o[a+4264>>3]*+(d>>>0)}f=a;a=a+44|0;Th(f,b,c,wd(a,0),wd(a,1),d);Za=h+16|0}function Cua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0;e=Za-48|0;Za=e;n=j[a+16>>2];f=wf(e+16|0);j[f+8>>2]=a+112;j[f+16>>2]=j[a+128>>2];o=f,q=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[o+12>>2]=q;b=j[f+16>>2];if(b){o=f,q=vf(a+8|0,b),j[o>>2]=q;j[f+4>>2]=ab}l=j[a+40>>2];m=j[a+36>>2];g=j[a+4>>2];h=j[a>>2];j[e+8>>2]=h;j[e+12>>2]=g;b=j[a+12>>2];j[e>>2]=j[a+8>>2];j[e+4>>2]=b;a:{if(!d){b=l>>12;k=m>>12;break a}while(1){b=0;k=b;j[e+40>>2]=h;j[e+44>>2]=b;g=(g<<1)+n|0;b:{b=j[f+16>>2];if((b|0)<=0){break b}while(1){id(j[f+8>>2],i[(k<<1)+g>>1]/4<<16>>16);hd(j[f+8>>2],4);Bb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;k=j[e+44>>2];continue}}d=d-1|0;b=j[f+8>>2];Bb(b,b+8|0);b=j[f+8>>2];h=j[b+4>>2];if(h){id(b,i[g+(j[e+44>>2]<<1)>>1]/4<<16>>16);hd(j[f+8>>2],h);b=j[f+8>>2];h=j[b>>2];j[b>>2]=h;j[b+4>>2]=0}g=qf(b,j[f+12>>2]);b=j[a+32>>2];m=j[a+28>>2]+m|0;k=m>>12;j[c>>2]=j[c>>2]+p(g,k);l=b+l|0;b=l>>12;j[c+4>>2]=j[c+4>>2]+p(g,b);Bb(e+8|0,e);if(d){c=c+8|0;h=j[e+8>>2];g=j[e+12>>2];continue}break}h=j[e+8>>2];g=j[e+12>>2]}j[a+40>>2]=l;j[a+20>>2]=k;j[a+36>>2]=m;j[a+24>>2]=b;j[a>>2]=h;j[a+4>>2]=g;Za=e+48|0}function V5(a,b,c,d,e,f){var g=0,i=0,j=0,m=0,o=0,r=0,s=0,t=0,u=0,v=q(0),w=0,x=q(0);j=Za-48|0;Za=j;o=!k[d+13|0]+(k[d+14|0]!=0)|0;r=k[d+25|0];s=j;t=b;u=j+44|0;a:{if(k[a+1|0]&8){f=k[d+27|0];g=k[l[d+8>>1]+43504|0];i=g&3;h[j+47|0]=i;h[j+46|0]=i;i=g>>>2|0;h[j+45|0]=i;h[j+44|0]=i;b=p(o,28)+43408|0;break a}f=(k[a+3|0]&16)>>>4&(f|0)!=0;b=f?12:0;g=l[d+8>>1]>>>f|0;while(1){m=1;f=3;while(1){i=f;f=k[(f+b|0)+43520|0];h[i+(j+44|0)|0]=((g|0)/(m|0)|0)%(f|0);m=p(f,m);f=i-1|0;if(i){continue}break}b=b+4|0;g=g-m|0;if((g|0)>-1){continue}break}f=-16;b=(p(o,28)+43408|0)+b|0}K5(s,t,u,b,c,f);i=k[d+14|0];b:{if(i){b=2-r|0;o=k[d+23|0]<<b;f=k[d+22|0]<<b;c=k[d+21|0]<<b;b=k[d+13|0];m=0;while(1){g=(b+m|0)+j|0;h[g|0]=c+k[g|0];h[g+1|0]=f+k[g+1|0];h[g+2|0]=o+k[g+2|0];m=m+3|0;if(i>>>0>m>>>0){continue}break}break b}if(!k[d+24|0]){break b}f=0;while(1){b=f+j|0;h[b+11|0]=k[b+11|0]+k[f+43544|0];f=f+1|0;if((f|0)!=10){continue}break}}v=Iv(q(2048),((((k[a+3|0]&224)==96)<<1)-k[d+10|0]|0)+258|0);f=0;if((i|0)!=(0-k[d+13|0]|0)){a=r+1|0;while(1){w=(f<<2)+e|0,x=Iv(v,k[f+j|0]<<a),n[w>>2]=x;f=f+1|0;if(f>>>0<k[d+14|0]+k[d+13|0]>>>0){continue}break}}Za=j+48|0}function Fua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=Za-48|0;Za=e;l=j[a+16>>2];f=wf(e+16|0);j[f+8>>2]=a+112;j[f+16>>2]=j[a+128>>2];q=f,r=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[q+12>>2]=r;b=j[f+16>>2];if(b){q=f,r=vf(a+8|0,b),j[q>>2]=r;j[f+4>>2]=ab}m=j[a+24>>2];n=j[a+20>>2];b=j[a+4>>2];g=j[a>>2];j[e+8>>2]=g;j[e+12>>2]=b;i=j[a+12>>2];j[e>>2]=j[a+8>>2];j[e+4>>2]=i;if(d){while(1){i=0;k=g;j[e+40>>2]=g;j[e+44>>2]=o;g=(((b&2147483647)<<1|g>>>31)&-2)+l|0;a:{b=j[f+16>>2];if((b|0)<=0){break a}while(1){i=(i&2147483647)<<1|k>>>31;id(j[f+8>>2],h[(i|1)+g|0]+h[g+(i&-2)|0]<<5);hd(j[f+8>>2],4);Bb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;k=j[e+40>>2];i=j[e+44>>2];continue}}d=d-1|0;b=j[f+8>>2];Bb(b,b+8|0);b=j[f+8>>2];i=j[b+4>>2];if(i){k=b;b=(j[e+44>>2]&2147483647)<<1|j[e+40>>2]>>>31;id(k,h[(b|1)+g|0]+h[g+(b&-2)|0]<<5);hd(j[f+8>>2],i);b=j[f+8>>2];i=j[b>>2];j[b>>2]=i;j[b+4>>2]=0}b=qf(b,j[f+12>>2]);j[c>>2]=j[c>>2]+p(b,n);j[c+4>>2]=j[c+4>>2]+p(b,m);Bb(e+8|0,e);if(d){c=c+8|0;g=j[e+8>>2];b=j[e+12>>2];continue}break}g=j[e+8>>2];b=j[e+12>>2]}j[a>>2]=g;j[a+4>>2]=b;Za=e+48|0}function Jva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=Za-16|0;Za=g;f=j[a+48>>2];n=j[a+40>>2];o=j[a+36>>2];e=j[a+44>>2];s=j[a+16>>2];l=j[a+4>>2];k=j[a>>2];j[g+8>>2]=k;j[g+12>>2]=l;b=j[a+12>>2];j[g>>2]=j[a+8>>2];j[g+4>>2]=b;a:{if(!d){i=n>>12;q=o>>12;break a}while(1){b=l+s|0;q=h[b+1|0];i=h[b|0];b=j[a+60>>2];t=b;u=b>>31;b=e;e=Gb(e,-16777216,16776704);m=j[a+64>>2];f=Gb(f,-16777216,16776704);v=j[a+72>>2];w=j[a+32>>2];l=c;x=j[c>>2];e=OMa(m,m>>31,e,e>>31);m=ab;y=e;e=j[a+68>>2];r=OMa(e,e>>31,f,f>>31);e=y+r|0;f=ab+m|0;f=e>>>0<r>>>0?f+1|0:f;m=e;k=((p(q-i|0,k>>>10&4194048)|0)/16384|0)+(i<<8)<<8;e=k;i=OMa(t,u,e,e>>31);e=m+i|0;f=ab+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;o=j[a+28>>2]+o|0;q=o>>12;j[l>>2]=p(f,q)+x;n=n+w|0;i=n>>12;j[c+4>>2]=j[c+4>>2]+p(f,i);e=e-(k&v)|0;Bb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=j[g+8>>2];l=j[g+12>>2];f=b;continue}break}k=j[g+8>>2];l=j[g+12>>2];f=b}j[a+40>>2]=n;j[a+20>>2]=q;j[a+36>>2]=o;j[a+48>>2]=f;j[a+44>>2]=e;j[a+24>>2]=i;j[a>>2]=k;j[a+4>>2]=l;Za=g+16|0}function Npa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,l=0,m=0,n=0,p=0,q=0,s=0;f=Za-16|0;Za=f;j[f+8>>2]=c>>>4;j[f+4>>2]=j[a>>2];d=j[tb(f+8|0,f+4|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){e=b;g=k[e+4|0]|k[e+5|0]<<8|(k[e+6|0]<<16|k[e+7|0]<<24);h=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);e=g;m=h<<8&16711680|h<<24;n=e<<24|h>>>8;g=e<<8|h>>>24;m=n&65280|g&255|m;j[f+8>>2]=((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|p;j[f+12>>2]=m;pf(f+8|0,-1,1);l=o[f+8>>3]*32768;o[f+8>>3]=l;e=a;l=zd(l);a:{if(r(l)<2147483648){g=~~l;break a}g=-2147483648}q=e,s=Dc(g),i[q>>1]=s;e=b;g=k[e+12|0]|k[e+13|0]<<8|(k[e+14|0]<<16|k[e+15|0]<<24);h=k[e+8|0]|k[e+9|0]<<8|(k[e+10|0]<<16|k[e+11|0]<<24);e=g;m=h<<8&16711680|h<<24;n=e<<24|h>>>8;g=e<<8|h>>>24;m=n&65280|g&255|m;j[f+8>>2]=((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|p;j[f+12>>2]=m;pf(f+8|0,-1,1);l=o[f+8>>3]*32768;o[f+8>>3]=l;e=a;l=zd(l);b:{if(r(l)<2147483648){g=~~l;break b}g=-2147483648}q=e,s=Dc(g),i[q+2>>1]=s;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}Za=f+16|0;return d<<4}function io(a){a=a|0;var b=0,c=0,d=0,e=0,f=q(0),g=0,h=q(0),k=0,o=0,r=0,s=q(0);c=j[a+36>>2];if(!c){Xh(a+16|0);return}a:{b:{c:{switch(l[a>>1]){case 3:d=a+16|0;if(c>>>0>=1001){Xh(d);return}Sk(d,c);c=l[a+28>>1];b=a+4|0;sb(b);f=Tk(a,(c<<16)+65536>>16);c=i[a+28>>1];sb(b);b=1;f=Yd(q(f/Tk(a,c)),q(q(1)/q(j[a+36>>2]+1>>>0)));if(!j[a+36>>2]){break b}while(1){h=Yd(f,q(b>>>0));r=xb(d,b-1|0),s=h,n[r>>2]=s;b=b+1|0;if(b>>>0<=m[a+36>>2]){continue}break}break b;case 1:d=a+16|0;g=l[a+30>>1];if(g>>>0>1e3/(c>>>0)>>>0){Xh(d);return}Sk(d,p(c,g));c=i[a+28>>1];sb(a+4|0);b=l[a+30>>1];if((c|0)>=0){c=(c|0)%(b|0)|0}else{c=((c^-1)%(b|0)^-1)+b|0}if(!g){break b}while(1){b=b&65535;e=c+k<<16>>16;d:{if((e|0)>=0){b=(e|0)%(b|0)|0;break d}b=b+((e^-1)%(b|0)^-1)|0}e=1;b=b<<16;o=b>>16;f=Yd(q(Tk(a,b+65536>>16)/Tk(a,o)),q(q(1)/q(j[a+36>>2]+1>>>0)));b=1;if(j[a+36>>2]){while(1){h=Yd(f,q((b&65535)>>>0));r=xb(d,(p(j[a+36>>2],o)+e|0)-1|0),s=h,n[r>>2]=s;b=b+1|0;e=b&65535;if(e>>>0<=m[a+36>>2]){continue}break}}k=k+1|0;if(g>>>0<=(k&65535)>>>0){break b}b=l[a+30>>1];continue};case 0:break a;default:break c}}Xh(a+16|0);j[a+36>>2]=0}return}Xh(a+16|0)}function Iva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=Za-16|0;Za=g;f=j[a+48>>2];n=j[a+40>>2];o=j[a+36>>2];e=j[a+44>>2];s=j[a+16>>2];l=j[a+4>>2];k=j[a>>2];j[g+8>>2]=k;j[g+12>>2]=l;b=j[a+12>>2];j[g>>2]=j[a+8>>2];j[g+4>>2]=b;a:{if(!d){h=n>>12;q=o>>12;break a}while(1){b=(l<<1)+s|0;q=i[b+2>>1];h=i[b>>1];b=j[a+60>>2];t=b;u=b>>31;b=e;e=Gb(e,-16777216,16776704);m=j[a+64>>2];f=Gb(f,-16777216,16776704);v=j[a+72>>2];w=j[a+32>>2];l=c;x=j[c>>2];e=OMa(m,m>>31,e,e>>31);m=ab;y=e;e=j[a+68>>2];r=OMa(e,e>>31,f,f>>31);e=y+r|0;f=ab+m|0;f=e>>>0<r>>>0?f+1|0:f;m=e;k=h+((p(q-h|0,k>>>18|0)|0)/16384|0)<<8;e=k;h=OMa(t,u,e,e>>31);e=m+h|0;f=ab+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;o=j[a+28>>2]+o|0;q=o>>12;j[l>>2]=p(f,q)+x;n=n+w|0;h=n>>12;j[c+4>>2]=j[c+4>>2]+p(f,h);e=e-(k&v)|0;Bb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=j[g+8>>2];l=j[g+12>>2];f=b;continue}break}k=j[g+8>>2];l=j[g+12>>2];f=b}j[a+40>>2]=n;j[a+20>>2]=q;j[a+36>>2]=o;j[a+48>>2]=f;j[a+44>>2]=e;j[a+24>>2]=h;j[a>>2]=k;j[a+4>>2]=l;Za=g+16|0}function xZ(a,b,c,d,e,f){var g=0,i=0,l=0,m=0,n=0,o=0;j[c>>2]=a;j[f>>2]=d;a:{b:{while(1){c:{g=j[c>>2];if(g>>>0>=b>>>0){break c}m=j[f>>2];if(m>>>0>=e>>>0){break c}a=h[g|0];d=a&255;d:{if((a|0)>=0){if(d>>>0<=1114111){a=1;break d}return 2}n=2;if(d>>>0<194){break b}if(d>>>0<=223){if((b-g|0)<2){break a}i=k[g+1|0];if((i&192)!=128){break b}a=2;d=i&63|d<<6&1984;if(d>>>0<=1114111){break d}break b}if(d>>>0<=239){if((b-g|0)<3){break a}l=k[g+2|0];i=k[g+1|0];e:{f:{if((d|0)!=237){if((d|0)!=224){break f}if((i&224)==160){break e}break b}if((i&224)==128){break e}break b}if((i&192)!=128){break b}}if((l&192)!=128){break b}a=3;d=l&63|(d<<12&61440|(i&63)<<6);if(d>>>0<=1114111){break d}break b}if(d>>>0>244){break b}if((b-g|0)<4){break a}l=k[g+3|0];o=k[g+2|0];i=k[g+1|0];g:{h:{switch(d-240|0){case 0:if((i+112&255)>>>0<48){break g}break b;case 4:if((i&240)==128){break g}break b;default:break h}}if((i&192)!=128){break b}}if((o&192)!=128|(l&192)!=128){break b}a=4;d=l&63|(o<<6&4032|(d<<18&1835008|(i&63)<<12));if(d>>>0>1114111){break b}}j[m>>2]=d;j[c>>2]=a+g;j[f>>2]=j[f>>2]+4;continue}break}n=b>>>0>g>>>0}return n}return 1}function Vb(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){Da(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if((c|0)<1){c=a;break b}if(!(a&3)){c=a;break b}c=a;while(1){h[c|0]=k[b|0];b=b+1|0;c=c+1|0;if(e>>>0<=c>>>0){break b}if(c&3){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+ -64|0;if(f>>>0<c>>>0){break c}while(1){j[c>>2]=j[b>>2];j[c+4>>2]=j[b+4>>2];j[c+8>>2]=j[b+8>>2];j[c+12>>2]=j[b+12>>2];j[c+16>>2]=j[b+16>>2];j[c+20>>2]=j[b+20>>2];j[c+24>>2]=j[b+24>>2];j[c+28>>2]=j[b+28>>2];j[c+32>>2]=j[b+32>>2];j[c+36>>2]=j[b+36>>2];j[c+40>>2]=j[b+40>>2];j[c+44>>2]=j[b+44>>2];j[c+48>>2]=j[b+48>>2];j[c+52>>2]=j[b+52>>2];j[c+56>>2]=j[b+56>>2];j[c+60>>2]=j[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){j[c>>2]=j[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){h[c|0]=k[b|0];h[c+1|0]=k[b+1|0];h[c+2|0]=k[b+2|0];h[c+3|0]=k[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){h[c|0]=k[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function Dua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0;e=Za-48|0;Za=e;n=j[a+16>>2];f=wf(e+16|0);j[f+8>>2]=a+112;j[f+16>>2]=j[a+128>>2];o=f,q=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[o+12>>2]=q;b=j[f+16>>2];if(b){o=f,q=vf(a+8|0,b),j[o>>2]=q;j[f+4>>2]=ab}l=j[a+40>>2];m=j[a+36>>2];g=j[a+4>>2];i=j[a>>2];j[e+8>>2]=i;j[e+12>>2]=g;b=j[a+12>>2];j[e>>2]=j[a+8>>2];j[e+4>>2]=b;a:{if(!d){b=l>>12;k=m>>12;break a}while(1){b=0;k=b;j[e+40>>2]=i;j[e+44>>2]=b;g=g+n|0;b:{b=j[f+16>>2];if((b|0)<=0){break b}while(1){id(j[f+8>>2],h[g+k|0]<<6);hd(j[f+8>>2],4);Bb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;k=j[e+44>>2];continue}}d=d-1|0;b=j[f+8>>2];Bb(b,b+8|0);b=j[f+8>>2];i=j[b+4>>2];if(i){id(b,h[g+j[e+44>>2]|0]<<6);hd(j[f+8>>2],i);b=j[f+8>>2];i=j[b>>2];j[b>>2]=i;j[b+4>>2]=0}g=qf(b,j[f+12>>2]);b=j[a+32>>2];m=j[a+28>>2]+m|0;k=m>>12;j[c>>2]=j[c>>2]+p(g,k);l=b+l|0;b=l>>12;j[c+4>>2]=j[c+4>>2]+p(g,b);Bb(e+8|0,e);if(d){c=c+8|0;i=j[e+8>>2];g=j[e+12>>2];continue}break}i=j[e+8>>2];g=j[e+12>>2]}j[a+40>>2]=l;j[a+20>>2]=k;j[a+36>>2]=m;j[a+24>>2]=b;j[a>>2]=i;j[a+4>>2]=g;Za=e+48|0}function Hk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=Za-16|0;Za=f;j[a+4>>2]=0;if(k[Ji(f+8|0,a,1)|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=j[j[a>>2]-12>>2];j[114626]=0;b=j[(a+b|0)+24>>2];d=j[114626];j[114626]=0;if((d|0)==1){break c}j[114626]=0;b=H(2315,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}if(ce(b,-1)){break b}j[a+4>>2]=j[a+4>>2]+1;if(!ce(b,c)){continue}break}d=0;break a}while(1){if(j[a+4>>2]>=(b|0)){break a}e=j[j[a>>2]-12>>2];j[114626]=0;e=j[(a+e|0)+24>>2];g=j[114626];j[114626]=0;d:{if((g|0)==1){break d}j[114626]=0;e=H(2315,e|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break d}if(ce(e,-1)){break b}j[a+4>>2]=j[a+4>>2]+1;if(!ce(e,c)){continue}break a}break}}b=J(0)|0;C()|0;O(b|0)|0;Hi(j[j[a>>2]-12>>2]+a|0,1);b=j[j[a>>2]-12>>2];j[114626]=0;b=j[(a+b|0)+20>>2];c=j[114626];j[114626]=0;e:{f:{g:{if((c|0)!=1){if(!(b&1)){break g}j[114626]=0;M(81);a=j[114626];j[114626]=0;if((a|0)!=1){break e}}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break f}G(a|0);z()}Q();d=1;break a}a=J(0)|0;C()|0;ib(a)}z()}d=2}eg(j[j[a>>2]-12>>2]+a|0,d)}Za=f+16|0;return a|0}function Mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=q(0),g=q(0),h=0,i=0,k=0,l=0,m=0,o=0,p=0,s=0,t=0,v=q(0),w=0,x=0,y=0,z=q(0);a:{if(!j[a+4272>>2]){break a}h=a+44|0;if(!Yg(h)){break a}l=wd(h,0);m=wd(h,1);o=Rc(h,0);p=Rc(h,1);if(d){k=a+4256|0;e=j[a+4268>>2];s=d;while(1){f=n[m>>2];g=n[l>>2];y=xb(k,e<<1),z=g,n[y>>2]=z;y=xb(k,j[a+4268>>2]<<1|1),z=f,n[y>>2]=z;f=q(r(bH(q(q(q(r(g))+q(r(f)))*q(536870912)),31,5)));g=n[a+4276>>2];f=q(f*q(4.656612873077393e-10));f=q(q(q(g-f)*n[(f<g?4240:4236)+a>>2])+f);n[a+4276>>2]=f;t=o;v=q(n[a+4232>>2]*q(4.656612873077393e-10));g=n[a+4244>>2];f=q(q(q(n[a+4248>>2]*q(2147483648))*q(g-q(u(f,g))))+q(2147483392));b:{if(f<q(4294967296)&f>=q(0)){i=~~f>>>0;break b}i=0}e=i<<5;w=e|-2147483648;x=e;e=i>>>26|0;f=q(v*q((e?w:x)>>>(e?32-e|0:31)>>>0));e=j[a+4272>>2];e=(((e+(j[a+4252>>2]+(j[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(e|0)<<1;y=t,z=q(f*n[xb(k,e)>>2]),n[y>>2]=z;y=p,z=q(f*n[xb(k,e|1)>>2]),n[y>>2]=z;i=j[a+4268>>2];e=i-1|0;j[a+4268>>2]=e;if(!i){e=j[a+4272>>2]+e|0;j[a+4268>>2]=e}p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;s=s-1|0;if(s){continue}break}}Th(a,b,c,Rc(h,0),Rc(h,1),d)}}function m5(a,b,c){var d=0,e=0,f=0,g=0,i=0,l=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a:{if(k[a+23|0]){d=j[a+2092>>2];if((d|0)<1){break a}while(1){f=e<<2;s=f+j[a+2084>>2]|0,t=Lk(j[f+j[a+32>>2]>>2]),j[s>>2]=t;e=e+1|0;d=j[a+2092>>2];if((e|0)<(d|0)){continue}break}break a}if(j[a+4>>2]>=1){while(1){if(GE(a,k[b+e|0])){s=j[a+2084>>2]+(d<<2)|0,t=Lk(j[j[a+32>>2]+(e<<2)>>2]),j[s>>2]=t;d=d+1|0}e=e+1|0;if((e|0)<j[a+4>>2]){continue}break}}if(j[a+2092>>2]==(d|0)){break a}X(52113,50496,1185,52136);z()}sE(j[a+2084>>2],d,2294);j[j[a+2084>>2]+(j[a+2092>>2]<<2)>>2]=-1;b:{c:{d=k[a+23|0];l=j[(d?2092:4)+a>>2];if((l|0)<1){break c}f=0;while(1){e=f;g=a;if(d&255){e=j[(f<<2)+c>>2]}n=k[b+e|0];d:{if(!GE(g,n)){break d}o=f<<2;g=Lk(j[o+j[a+32>>2]>>2]);p=j[a+2084>>2];e=0;d=j[a+2092>>2];if((d|0)>=2){while(1){i=d>>>1|0;q=i+e|0;r=m[(q<<2)+p>>2]>g>>>0;e=r?e:q;d=r?i:d-i|0;if((d|0)>1){continue}break}}d=g;g=e<<2;if((d|0)!=j[g+p>>2]){break b}if(k[a+23|0]){j[g+j[a+2088>>2]>>2]=j[c+o>>2];h[j[a+8>>2]+e|0]=n;break d}j[g+j[a+2088>>2]>>2]=f}f=f+1|0;if((l|0)==(f|0)){break c}d=k[a+23|0];continue}}return}X(52159,50496,1215,52136);z()}function iva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0;f=Za-16|0;Za=f;a:{b:{c:{g=j[a+8>>2];e=j[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=j[a+16>>2];k=j[a+40>>2];l=j[a+36>>2];b=j[a+4>>2];m=j[a>>2];j[f+8>>2]=m;j[f+12>>2]=b;j[f>>2]=g;j[f+4>>2]=e;e:{if(!d){g=k>>12;e=l>>12;break e}while(1){g=j[a+32>>2];l=j[a+28>>2]+l|0;e=l>>12;h=(b<<1)+o|0;b=(m>>>16&65520)+n|0;b=(((((((p(i[h-4>>1],i[b+2>>1])+p(i[h-6>>1],i[b>>1])|0)+p(i[h-2>>1],i[b+4>>1])|0)+p(i[h>>1],i[b+6>>1])|0)+p(i[h+2>>1],i[b+8>>1])|0)+p(i[h+4>>1],i[b+10>>1])|0)+p(i[h+6>>1],i[b+12>>1])|0)+p(i[h+8>>1],i[b+14>>1])|0)/32768|0;j[c>>2]=j[c>>2]+p(e,b);k=g+k|0;g=k>>12;j[c+4>>2]=j[c+4>>2]+p(b,g);Bb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;m=j[f+8>>2];b=j[f+12>>2];continue}break}m=j[f+8>>2];b=j[f+12>>2]}j[a+40>>2]=k;j[a+20>>2]=e;j[a+36>>2]=l;j[a+24>>2]=g;j[a>>2]=m;j[a+4>>2]=b;Za=f+16|0}function E9(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,m=0;d=Za-80|0;Za=d;a:{b:{c:{d:{e:{f:{g:{if(Qh(a)){eo(d+72|0);break g}om(d+32|0,a);j[114626]=0;F(2167,d+72|0,d+32|0);c=j[114626];j[114626]=0;if((c|0)==1){break f}Ye(d+32|0)}c=a+36|0;h:{if(Qh(a)){break h}c=j[d+72>>2]}e=j[a+8>>2];if((e|0)!=-1){break c}f=mt(c);if(pd(c)){break e}break d}e=D()|0;C()|0;Ye(d+32|0);break a}e=0;while(1){if(!(o[yc(c,e)>>3]+g<=b)){f=yc(c,e);break d}g=o[f>>3]+g;e=e+1|0;if(pd(c)>>>0>e>>>0){continue}break}}b=b-g;break b}f=yc(c,e)}e=a+24|0;h=j[e>>2];m=k[a+64|0];c=uG(yO(d+32|0,b),k[f+16|0],l[f+12>>1],j[f+8>>2]);j[114626]=0;f=j[c+12>>2];j[d+16>>2]=j[c+8>>2];j[d+20>>2]=f;f=j[c+20>>2];j[d+24>>2]=j[c+16>>2];j[d+28>>2]=f;f=j[c+4>>2];j[d+8>>2]=j[c>>2];j[d+12>>2]=f;L(2121,d+56|0,h|0,(m?7:1)|0,d+8|0);c=j[114626];j[114626]=0;if((c|0)!=1){i:{c=yg(d+56|0);f=j[c+8>>2];b=o[c>>3];c=l[c+20>>1];hl(d+56|0);i[j[e>>2]+1074438>>1]=c;h=j[e>>2];j[114626]=0;F(2170,h|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break i}j[j[e>>2]+1074428>>2]=f;b=b+g;o[a+16>>3]=b;Gj(d+72|0);Za=d+80|0;return+b}}e=D()|0;C()|0;Gj(d+72|0)}G(e|0);z()}function Qua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=Za-32|0;Za=f;m=j[a+40>>2];n=j[a+36>>2];o=j[a+16>>2];e=j[a+4>>2];g=e;h=j[a>>2];j[f+24>>2]=h;j[f+28>>2]=e;e=j[a+12>>2];j[f+16>>2]=j[a+8>>2];j[f+20>>2]=e;a:{if(!d){e=m>>12;l=n>>12;break a}while(1){k=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+o|0;e=(((h>>>16|0)+4&131064)<<1)+b|0;h=i[e+38>>1];q=i[e+36>>1];r=i[e+34>>1];s=i[e+32>>1];t=i[e+30>>1];u=i[e+28>>1];v=i[e+26>>1];w=i[e+24>>1];l=0;e=1;while(1){g=l<<1;j[(f+8|0)+(l<<2)>>2]=(((((p(i[(g|8)+k>>1],r)+p(i[(g|4)+k>>1],s)|0)+p(i[(g|12)+k>>1],q)|0)+p(i[(g|16)+k>>1],h)|0)/2|0)+((((p(i[(g|-8)+k>>1],v)+p(i[(g|-12)+k>>1],w)|0)+p(i[(g|-4)+k>>1],u)|0)+p(i[g+k>>1],t)|0)/2|0)|0)/16384;g=e;e=0;l=1;if(g){continue}break}e=j[a+32>>2];n=j[a+28>>2]+n|0;l=n>>12;j[c>>2]=j[c>>2]+p(l,j[f+8>>2]);m=e+m|0;e=m>>12;j[c+4>>2]=j[c+4>>2]+p(e,j[f+12>>2]);Bb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=j[f+24>>2];g=j[f+28>>2];continue}break}h=j[f+24>>2];g=j[f+28>>2]}j[a+40>>2]=m;j[a+20>>2]=l;j[a+36>>2]=n;j[a+24>>2]=e;j[a>>2]=h;j[a+4>>2]=g;Za=f+32|0}function Nw(a,b,c){var d=0,e=0,f=0,g=0,m=0,n=0,o=0,p=0,q=0;e=Za-16|0;Za=e;d=a+2|0;if(!(k[d|0]==255|!k[d|0])){j[e+12>>2]=k[d|0]+1;j[e+8>>2]=10;Nf(b,j[Pd(e+12|0,e+8|0)>>2]);d=k[a+3|0];h[b+15|0]=d;h[b+16|0]=d;h[b+13|0]=k[a+4|0];h[b+14|0]=k[a+5|0];d=0;f=511;a:{b:{switch(c-1|0){case 1:d=4096;f=128;break a;case 0:break b;default:break a}}d=32768;f=1024}if(sb(b)){n=f>>>1|d;d=0;while(1){g=(d<<2)+a|0;c=g+6|0;c=k[c|0]|k[c+1|0]<<8;p=xb(b,d),q=c>>>4|0,i[p>>1]=q;o=b;c:{d:{if(!d){m=0;c=0;break d}c=d-1|0;if(l[xb(b,d)>>1]>=l[xb(b,c)>>1]){break c}m=d;c=l[xb(b,c)>>1]+1|0}p=xb(o,m),q=c,i[p>>1]=q}c=g+8|0;j[e+12>>2]=(((k[c|0]|k[c+1|0]<<8)<<16>>16)+n|0)/(f|0);j[e+8>>2]=0;j[e+4>>2]=64;c=j[cs(e+12|0,e+8|0,e+4|0)>>2];p=xb(b,d),q=c,h[p+2|0]=q;d=d+1|0;if(sb(b)>>>0>d>>>0){continue}break}}h[b+12|0]=k[b+12|0]&254|h[a|0]&1;c=b;e:{f:{if(!(k[a|0]&2)){break f}d=k[b+15|0];if(sb(b)>>>0<d>>>0){break f}d=k[b+12|0]|4;break e}d=k[b+12|0]&-5}h[c+12|0]=d;c=b;g:{h:{if(!(k[a|0]&4)){break h}a=k[b+13|0];if(a>>>0>k[b+14|0]){break h}if(sb(b)>>>0<a>>>0){break h}a=k[b+12|0]|2;break g}a=k[b+12|0]&-3}h[c+12|0]=a}Za=e+16|0}function jva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0;f=Za-16|0;Za=f;a:{b:{c:{g=j[a+8>>2];e=j[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}q=j[a+16>>2];l=j[a+40>>2];m=j[a+36>>2];b=j[a+4>>2];n=j[a>>2];j[f+8>>2]=n;j[f+12>>2]=b;j[f>>2]=g;j[f+4>>2]=e;e:{if(!d){g=l>>12;e=m>>12;break e}while(1){g=j[a+32>>2];m=j[a+28>>2]+m|0;e=m>>12;k=b+q|0;b=(n>>>16&65520)+o|0;b=(((((((p(h[k-2|0],i[b+2>>1])+p(h[k-3|0],i[b>>1])|0)+p(h[k-1|0],i[b+4>>1])|0)+p(h[k|0],i[b+6>>1])|0)+p(h[k+1|0],i[b+8>>1])|0)+p(h[k+2|0],i[b+10>>1])|0)+p(h[k+3|0],i[b+12>>1])|0)+p(h[k+4|0],i[b+14>>1])<<8)/32768|0;j[c>>2]=j[c>>2]+p(e,b);l=g+l|0;g=l>>12;j[c+4>>2]=j[c+4>>2]+p(b,g);Bb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;n=j[f+8>>2];b=j[f+12>>2];continue}break}n=j[f+8>>2];b=j[f+12>>2]}j[a+40>>2]=l;j[a+20>>2]=e;j[a+36>>2]=m;j[a+24>>2]=g;j[a>>2]=n;j[a+4>>2]=b;Za=f+16|0}function LE(a,b,c,d,e,f,g,h){var l=0,m=0,o=0,r=0,s=0,t=q(0),u=0,v=0;a:{if(k[b+21|0]){r=j[f>>2];m=j[e>>2];u=1;b:{if((h|0)>=1){s=j[b>>2];v=p(d,g);while(1){if(j[a+1396>>2]<=9){Dj(a)}o=j[a+1392>>2];g=i[(((o&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){l=o;o=k[g+j[b+8>>2]|0];j[a+1392>>2]=l>>>o;l=j[a+1396>>2]-o|0;o=(l|0)<0;j[a+1396>>2]=o?0:l;g=o?-1:g;break c}g=Mk(a,b)}if((g|0)>=j[b+2092>>2]?k[b+23|0]:0){break a}if((g|0)<=-1){if(!k[a+1376|0]){u=0;if(j[a+1384>>2]){break b}}Nb(a,21);return 0}o=p(d,r);s=((o+s|0)+m|0)>(v|0)?(v-o|0)+m|0:s;o=p(g,j[b>>2]);d:{if(k[b+22|0]){g=0;t=q(0);if((s|0)<=0){break d}while(1){t=q(n[j[b+28>>2]+(g+o<<2)>>2]+t);l=j[(m<<2)+c>>2];if(l){l=l+(r<<2)|0;n[l>>2]=n[l>>2]+t}m=m+1|0;l=(m|0)==(d|0);m=l?0:m;r=l+r|0;g=g+1|0;if((s|0)!=(g|0)){continue}break}break d}g=0;if((s|0)<=0){break d}while(1){l=j[(m<<2)+c>>2];if(l){l=l+(r<<2)|0;n[l>>2]=n[l>>2]+n[j[b+28>>2]+(g+o<<2)>>2]}m=m+1|0;l=(m|0)==(d|0);m=l?0:m;r=l+r|0;g=g+1|0;if((s|0)!=(g|0)){continue}break}}h=h-s|0;if((h|0)>0){continue}break}}j[e>>2]=m;j[f>>2]=r}return u}Nb(a,21);return 0}X(50752,50496,1872,50788);z()}function oka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0;e=Za+ -64|0;Za=e;g=vm(a);a:{if(b-1>>>0>1023){break a}f=j[a+12>>2];if((f|0)==(b|0)){break a}if(c){c=j[g+8>>2];if(m[c+40>>2]<b>>>0|m[c+36>>2]>b>>>0){break a}f=j[a+12>>2]}f=p(Jj(a),b>>>0>f>>>0?b-f|0:f-b|0);b:{c:{if(m[a+12>>2]<b>>>0){c=e;d:{if(d){d=Mb(a);break d}d=Lb(a)}j[c+48>>2]=d;c=Cd(e+56|0,e+48|0);Ug(e+40|0);c=j[c>>2];j[114626]=0;P(1556,a|0,c|0,f|0,e+40|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}a=J(71396)|0;break c}if(d){i=e,k=Mb(a),j[i+48>>2]=k;i=e,k=wI(e+48|0,0-f|0),j[i+40>>2]=k;c=Cd(e+32|0,e+40|0);i=e,k=Mb(a),j[i+16>>2]=k;d=j[Cd(e+24|0,e+16|0)>>2];c=j[c>>2];j[114626]=0;K(1557,a|0,c|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}a=J(71396)|0;break c}i=e,k=Lb(a),j[i+40>>2]=k;c=Cd(e+8|0,e+40|0);i=e,k=Lb(a),j[i+16>>2]=k;i=e,k=wI(e+16|0,f),j[i+48>>2]=k;d=j[Cd(e,e+48|0)>>2];c=j[c>>2];j[114626]=0;K(1557,a|0,c|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}a=J(71396)|0}if((C()|0)==(W(71396)|0)){O(a|0)|0;Q();break a}G(a|0);z()}j[a+12>>2]=b;h=1}Za=e- -64|0;return h|0}function wva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=Za-16|0;Za=g;f=j[a+48>>2];o=j[a+24>>2];q=j[a+20>>2];b=j[a+44>>2];r=j[a+16>>2];k=j[a+4>>2];l=j[a>>2];j[g+8>>2]=l;j[g+12>>2]=k;e=j[a+12>>2];j[g>>2]=j[a+8>>2];j[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=k+r|0;k=h[e+2|0];s=h[e+1|0];t=h[e|0];u=h[e-1|0];e=j[a+60>>2];v=e;w=e>>31;e=Gb(b,-16777216,16776704);m=j[a+64>>2];f=Gb(f,-16777216,16776704);x=j[a+72>>2];y=j[c>>2];e=OMa(m,m>>31,e,e>>31);m=ab;z=e;e=j[a+68>>2];n=OMa(e,e>>31,f,f>>31);e=z+n|0;f=ab+m|0;f=e>>>0<n>>>0?f+1|0:f;m=e;e=(l>>>21&2040)+27888|0;k=(((p(i[e+2>>1],t)+p(u,i[e>>1])|0)+p(i[e+4>>1],s)|0)+p(k,i[e+6>>1])<<8)/16384<<8;e=k;l=OMa(v,w,e,e>>31);e=m+l|0;f=ab+f|0;f=e>>>0<l>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;j[c>>2]=p(e,q)+y;j[c+4>>2]=j[c+4>>2]+p(e,o);e=f-(k&x)|0;Bb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;l=j[g+8>>2];k=j[g+12>>2];f=b;b=e;continue}break}l=j[g+8>>2];k=j[g+12>>2]}j[a+48>>2]=b;j[a+44>>2]=e;j[a>>2]=l;j[a+4>>2]=k;Za=g+16|0}function vva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=Za-16|0;Za=g;f=j[a+48>>2];o=j[a+24>>2];q=j[a+20>>2];b=j[a+44>>2];r=j[a+16>>2];h=j[a+4>>2];k=j[a>>2];j[g+8>>2]=k;j[g+12>>2]=h;e=j[a+12>>2];j[g>>2]=j[a+8>>2];j[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(h<<1)+r|0;l=i[e>>1];s=i[e-2>>1];t=i[e+2>>1];u=i[e+4>>1];n=j[a+60>>2];e=Gb(b,-16777216,16776704);m=j[a+64>>2];h=Gb(f,-16777216,16776704);v=j[a+72>>2];f=j[c>>2];e=OMa(m,m>>31,e,e>>31);m=ab;w=c;x=f;f=(k>>>21&2040)+27888|0;k=(((p(l,i[f+2>>1])+p(i[f>>1],s)|0)+p(i[f+4>>1],t)|0)+p(u,i[f+6>>1])|0)/16384<<8;f=k;l=OMa(n,n>>31,f,f>>31);e=l+e|0;f=ab+m|0;f=e>>>0<l>>>0?f+1|0:f;l=e;e=j[a+68>>2];h=OMa(e,e>>31,h,h>>31);e=l+h|0;f=ab+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;j[w>>2]=x+p(e,q);j[c+4>>2]=j[c+4>>2]+p(e,o);e=f-(k&v)|0;Bb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=j[g+8>>2];h=j[g+12>>2];f=b;b=e;continue}break}k=j[g+8>>2];h=j[g+12>>2]}j[a+48>>2]=b;j[a+44>>2]=e;j[a>>2]=k;j[a+4>>2]=h;Za=g+16|0}function wH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=q(0);c=Za+ -64|0;Za=c;d=Dn(c+48|0,vd(c+40|0,b),0);j[114626]=0;b=H(540,d|0)|0;e=j[114626];j[114626]=0;a:{if((e|0)==1){break a}j[114626]=0;b=K(1694,d|0,c|0,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break a}b:{if(!b|j[c>>2]!=542066252){break b}b=c|4;if(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24)){break b}b=c+8|0;f=a,g=Gm((WMa(2,k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24)),_Ma()),q(0),q(1)),n[f+4220>>2]=g;b=c+12|0;f=a,g=Gm((WMa(2,k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24)),_Ma()),q(0),q(1)),n[f+4224>>2]=g;b=c+16|0;f=a,g=Gm((WMa(2,k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24)),_Ma()),q(0),q(1)),n[f+4228>>2]=g;b=c+20|0;if((k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))>>>0<=5){j[a+4232>>2]=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24)}b=c+24|0;j[a+4236>>2]=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);h[a+4240|0]=k[c+28|0]!=0;h[a+4241|0]=k[c+29|0]!=0;h[a+4242|0]=k[c+30|0]!=0;h[a+4243|0]=k[c+31|0]!=0;h[a+4244|0]=k[c+32|0]!=0}jb(d);Za=c- -64|0;return}a=D()|0;C()|0;jb(d);G(a|0);z()}function Rua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=Za-32|0;Za=f;n=j[a+40>>2];o=j[a+36>>2];q=j[a+16>>2];e=j[a+4>>2];k=e;l=j[a>>2];j[f+24>>2]=l;j[f+28>>2]=e;e=j[a+12>>2];j[f+16>>2]=j[a+8>>2];j[f+20>>2]=e;a:{if(!d){g=n>>12;e=o>>12;break a}while(1){m=(((k&2147483647)<<1|l>>>31)&-2)+q|0;e=(((l>>>16|0)+4&131064)<<1)+b|0;l=i[e+38>>1];r=i[e+36>>1];s=i[e+34>>1];t=i[e+32>>1];u=i[e+30>>1];v=i[e+28>>1];w=i[e+26>>1];x=i[e+24>>1];g=0;e=1;while(1){j[(f+8|0)+(g<<2)>>2]=(((((p(h[(g|4)+m|0],s)+p(h[(g|2)+m|0],t)|0)+p(h[(g|6)+m|0],r)|0)+p(h[(g|8)+m|0],l)<<8)/2|0)+((((p(h[(g|-4)+m|0],w)+p(h[(g|-6)+m|0],x)|0)+p(h[(g|-2)+m|0],v)|0)+p(h[g+m|0],u)<<8)/2|0)|0)/16384;k=e;e=0;g=1;if(k){continue}break}k=j[a+32>>2];o=j[a+28>>2]+o|0;e=o>>12;j[c>>2]=j[c>>2]+p(e,j[f+8>>2]);n=k+n|0;g=n>>12;j[c+4>>2]=j[c+4>>2]+p(g,j[f+12>>2]);Bb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;l=j[f+24>>2];k=j[f+28>>2];continue}break}l=j[f+24>>2];k=j[f+28>>2]}j[a+40>>2]=n;j[a+20>>2]=e;j[a+36>>2]=o;j[a+24>>2]=g;j[a>>2]=l;j[a+4>>2]=k;Za=f+32|0}function D5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-32|0;Za=d;a=Av(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((Vq(b,c,0)|0)!=-1){while(1){f=Vq(b,c,e);j[114626]=0;L(199,d|0,b|0,e|0,f-e|0);f=j[114626];j[114626]=0;if((f|0)==1){break j}j[114626]=0;F(200,d+16|0,d|0);f=j[114626];j[114626]=0;if((f|0)==1){break i}j[114626]=0;F(201,a|0,d+16|0);f=j[114626];j[114626]=0;if((f|0)==1){break h}gb(d+16|0);gb(d);e=Vq(b,c,e)+nb(c)|0;if((Vq(b,c,e)|0)!=-1){continue}break}}k:{if(ad(a)){j[114626]=0;L(199,d+16|0,b|0,e|0,-1);c=j[114626];j[114626]=0;if((c|0)==1){break f}c=nb(d+16|0);gb(d+16|0);if(!c){break k}}j[114626]=0;L(199,d|0,b|0,e|0,-1);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;F(200,d+16|0,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;F(201,a|0,d+16|0);b=j[114626];j[114626]=0;if((b|0)==1){break c}gb(d+16|0);gb(d)}Za=d+32|0;return}e=D()|0;C()|0;break a}e=D()|0;C()|0;break g}e=D()|0;C()|0;gb(d+16|0)}gb(d);break a}e=D()|0;C()|0;break a}e=D()|0;C()|0;break a}e=D()|0;C()|0;break b}e=D()|0;C()|0;gb(d+16|0)}gb(d)}Ok(a);G(e|0);z()}function C3(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,l=0,m=0;c=Za-32|0;Za=c;j[114626]=0;h=E(15,c+24|0,a|0)|0;d=j[114626];j[114626]=0;a:{b:{c:{if((d|0)!=1){d:{if(!k[h|0]){break d}d=j[(j[j[a>>2]-12>>2]+a|0)+4>>2];hc(c+16|0,j[j[a>>2]-12>>2]+a|0);j[114626]=0;f=H(2323,c+16|0)|0;e=j[114626];j[114626]=0;e:{f:{if((e|0)!=1){wb(c+16|0);e=sk(c+8|0,a);g=j[j[a>>2]-12>>2];j[114626]=0;g=a+g|0;l=H(16,g|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break f}e=j[e>>2];j[114626]=0;i=f;f=b&65535;m=b;b=d&74;b=U(2324,i|0,e|0,g|0,l|0,((b|0)==64?f:(b|0)==8?f:m)|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}j[c+16>>2]=b;if(!rk(c+16|0)){break d}b=j[j[a>>2]-12>>2];j[114626]=0;F(18,a+b|0,5);b=j[114626];j[114626]=0;if((b|0)!=1){break d}b=J(0)|0;C()|0;break e}b=J(0)|0;C()|0;wb(c+16|0);break e}b=J(0)|0;C()|0}nf(h);break c}nf(h);break b}b=J(0)|0;C()|0}O(b|0)|0;b=j[j[a>>2]-12>>2];j[114626]=0;N(19,a+b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=c+32|0;return}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function n5(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,l=0,m=0,n=0;e=Za-128|0;Za=e;l=Ab(e,0,128);a:{b:{c:{d:{if((c|0)<1){break d}while(1){if(k[b+h|0]!=255){break d}h=h+1|0;if((h|0)!=(c|0)){continue}break}break c}if((c|0)!=(h|0)){break b}}f=1;if(!j[a+2092>>2]){break a}X(52010,50496,1088,52033);z()}e=b+h|0;HE(a,0,h,0,k[e|0],d);e=k[e|0];if(e){g=e>>>0>1?e:1;f=1;while(1){j[(f<<2)+l>>2]=1<<32-f;e=(f|0)==(g|0);f=f+1|0;if(!e){continue}break}}m=1;i=h+1|0;if((i|0)>=(c|0)){f=1;break a}e:{f:{g:{while(1){h:{h=b+i|0;e=k[h|0];i:{if((e|0)==255){break i}f=e;if(!e){break e}while(1){g=(f<<2)+l|0;n=j[g>>2];if(!n){g=(f|0)>1;f=f-1|0;if(g){continue}break e}break}if(f>>>0>=32){break h}j[g>>2]=0;HE(a,Lk(n),i,m,e,d);m=m+1|0;g=k[h|0];if((g|0)==(f|0)){break i}if(g>>>0>31){break g}if((f|0)>=(g|0)){break i}while(1){e=(g<<2)+l|0;if(j[e>>2]){break f}j[e>>2]=(1<<32-g)+n;g=g-1|0;if((g|0)>(f|0)){continue}break}}f=1;i=i+1|0;if((i|0)!=(c|0)){continue}break a}break}X(52051,50496,1111,52033);z()}X(52068,50496,1116,52033);z()}X(52095,50496,1118,52033);z()}f=0}Za=l+128|0;return f}function jea(a,b,c){var d=0,e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0;a:{if(!j[a+4116>>2]){if(!j[a+4120>>2]){break a}Rm(a+8|0,c,a+4104|0,a+4108|0)}f=j[a>>2];g=j[a+4184>>2];d=p(f,g)>>>4|0;d=d>>>0<32767?d:32767;i[a+4202>>1]=d;i[a+4200>>1]=d;e=j[a+54052>>2];d=p(e,f)>>>4|0;d=d>>>0<65536?d:65536;l=d+127>>>3|0;i[a+54050>>1]=l;d=d+255>>>4|0;i[a+54048>>1]=d;i[a+54046>>1]=d;i[a+54044>>1]=l;d=a+8|0;g=(e|0)<(g|0)?g:e;f=36-f>>>1|0;f=f>>>0>8?f:8;iea(b,d,16-(p((g|0)<32768?g:32768,(f|0)<16?16-f|0:0)>>15)|0,c);l=a+4172|0;c=hea(a,d,c);b:{if(!c){k=j[l>>2];break b}n=a+53996|0;gea(l,d,c);h=j[a+4180>>2];m=a+37612|0;f=d;g=c;while(1){k=h&4095;h=h-j[a+53996>>2]&4095;e=4096-(h>>>0<k>>>0?k:h)|0;e=e>>>0<g>>>0?e:g;e=e>>>0<64?e:64;fea(l,(k<<2)+m|0,f,e);eea(n,(h<<2)+m|0,f,e);h=e+j[a+4180>>2]&4095;j[a+4180>>2]=h;k=e+j[a+4172>>2]&8191;j[a+4172>>2]=k;f=(e<<3)+f|0;g=g-e|0;if(g){continue}break}}j[a+4172>>2]=k&8191;dea(a,d,b,c);c:{if(j[a+4116>>2]){j[a+4120>>2]=j[a+4124>>2];break c}b=j[a+4120>>2];if(b>>>0>c>>>0){j[a+4120>>2]=b-c;break c}MG(a);j[a+4120>>2]=0}j[a+4116>>2]=0}}function SZ(a,b,c,d,e,f,g,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;var l=0,m=0,n=0,o=0;n=Za-16|0;Za=n;l=c;while(1){a:{if((d|0)==(l|0)){l=d;break a}if(!j[l>>2]){break a}l=l+4|0;continue}break}j[i>>2]=f;j[e>>2]=c;while(1){b:{c:{if(!((f|0)==(g|0)|(c|0)==(d|0))){m=j[b+4>>2];j[n+8>>2]=j[b>>2];j[n+12>>2]=m;m=1;d:{e:{f:{g:{h:{o=RZ(f,e,l-c>>2,g-f|0,b,j[a+8>>2]);switch(o+1|0){case 0:break h;case 1:break c;default:break g}}j[i>>2]=f;while(1){i:{if(j[e>>2]==(c|0)){break i}b=Pu(f,j[c>>2],n+8|0,j[a+8>>2]);if((b|0)==-1){break i}f=b+j[i>>2]|0;j[i>>2]=f;c=c+4|0;continue}break}j[e>>2]=c;break f}f=j[i>>2]+o|0;j[i>>2]=f;if((f|0)==(g|0)){break d}if((d|0)==(l|0)){c=j[e>>2];l=d;continue}l=Pu(n+4|0,0,b,j[a+8>>2]);if((l|0)!=-1){break e}}m=2;break c}c=n+4|0;if(g-j[i>>2]>>>0<l>>>0){break c}while(1){if(l){f=k[c|0];m=j[i>>2];j[i>>2]=m+1;h[m|0]=f;l=l-1|0;c=c+1|0;continue}break}c=j[e>>2]+4|0;j[e>>2]=c;l=c;while(1){if((d|0)==(l|0)){l=d;break b}if(!j[l>>2]){break b}l=l+4|0;continue}}c=j[e>>2]}m=(c|0)!=(d|0)}Za=n+16|0;return m|0}f=j[i>>2];continue}}function KE(a,b,c,d,e){var f=q(0),g=q(0),h=0,i=q(0),j=q(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d-4|0;g=n[b>>2];i=n[d>>2];j=n[a>>2];n[a>>2]=i+j;c=a-4|0;f=n[c>>2];n[c>>2]=n[b>>2]+f;i=q(j-i);f=q(f-g);n[d>>2]=q(n[e>>2]*i)-q(n[e+4>>2]*f);n[b>>2]=q(n[e+4>>2]*i)+q(n[e>>2]*f);b=d-12|0;i=n[b>>2];c=a-8|0;f=n[c>>2];h=c;c=d-8|0;j=n[c>>2];n[h>>2]=j+f;h=a-12|0;g=n[h>>2];n[h>>2]=n[b>>2]+g;f=q(f-j);g=q(g-i);n[c>>2]=q(n[e+32>>2]*f)-q(n[e+36>>2]*g);n[b>>2]=q(n[e+36>>2]*f)+q(n[e+32>>2]*g);b=d-20|0;i=n[b>>2];c=a-16|0;f=n[c>>2];h=c;c=d-16|0;j=n[c>>2];n[h>>2]=j+f;h=a-20|0;g=n[h>>2];n[h>>2]=n[b>>2]+g;f=q(f-j);g=q(g-i);n[c>>2]=q(n[e+64>>2]*f)-q(n[e+68>>2]*g);n[b>>2]=q(n[e+68>>2]*f)+q(n[e+64>>2]*g);b=d-28|0;i=n[b>>2];c=a-24|0;f=n[c>>2];h=c;c=d-24|0;j=n[c>>2];n[h>>2]=j+f;h=a-28|0;g=n[h>>2];n[h>>2]=n[b>>2]+g;f=q(f-j);g=q(g-i);n[c>>2]=q(n[e+96>>2]*f)-q(n[e+100>>2]*g);n[b>>2]=q(n[e+100>>2]*f)+q(n[e+96>>2]*g);d=d-32|0;a=a-32|0;e=e+128|0;b=(k|0)>1;k=k-1|0;if(b){continue}break}}return}X(51904,50496,2408,51917);z()}function vG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,k=q(0);d=Za-48|0;Za=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==j[j[a>>2]+24604>>2]){break d}Vb(d+8|0,j[a>>2]+24604|0,40);j[d+8>>2]=b;ax(j[a>>2],d+8|0);break d;case 2:b=a+24|0;a=j[b>>2];e=a+24664|0;f=j[e+4>>2];j[d+24>>2]=j[e>>2];j[d+28>>2]=f;e=a+24656|0;f=j[e+4>>2];j[d+16>>2]=j[e>>2];j[d+20>>2]=f;e=j[a+24652>>2];j[d+8>>2]=j[a+24648>>2];j[d+12>>2]=e;g=d,i=Naa(c),h[g+8|0]=i;if(!cw(d+8|0,j[b>>2]+24648|0)){break d}$w(j[b>>2],d+8|0);break d;case 3:a=a+24|0;Vb(d+8|0,j[a>>2]+24604|0,40);Maa(d+8|0,c);if(j[j[a>>2]+24640>>2]==j[d+44>>2]?j[j[a>>2]+24636>>2]==j[d+40>>2]:0){break d}ax(j[a>>2],d+8|0);break d;default:a=R(8)|0;j[114626]=0;c=E(85,d+8|0,38669)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;gb(c);break b;case 0:break e}}g=a,k=Yd(q(10),q(q(c|0)*q(.0005000000237487257))),n[g+48>>2]=k}Za=d+48|0;return}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function TR(a){var b=0,c=0,d=0,e=0,f=0,g=0,i=0;a:{if((k[a|0]-1&255)>>>0>14){break a}g=a+1954|0;d=a+1698|0;while(1){if(h[d|0]<=-2){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}d=0;while(1){g=f;f=0;c=p(d,13)+a|0;if(k[c+14|0]){break a}e=(d<<4)+a|0;b=e+418|0;if(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24)){break a}b=e+422|0;if(k[c+942|0]|(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))>>>0>1048575){break a}c=p(d,11)+a|0;i=c+1346|0;if(k[i|0]>15|k[c+1351|0]>3|k[c+1356|0]>3){break a}b:{if(!(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))){break b}c=e+430|0;if((k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))>>>0>1048574){break b}if((k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))>>>0>(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))>>>0){break a}e=e+426|0;if((k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))>>>0>(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))>>>0){break a}}f=1;c:{if(g&1|(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))){break c}if(Yc(i,12323,11)){break c}f=0}d=d+1|0;if((d|0)!=32){continue}break}}return f}function iya(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Za-48|0;Za=b;a:{b:{c:{f=a+24|0;d:{if(bd(f)){break d}d=a+4|0;c=nb(d);a=sxa();e=ab;if(c){c=Sm(b+32|0);j[114626]=0;j[b+16>>2]=e;F(87,c|0,b+16|0);e=j[114626];j[114626]=0;e:{f:{g:{if((e|0)!=1){j[114626]=0;j[b+16>>2]=a;F(87,c|0,b+16|0);a=j[114626];j[114626]=0;if((a|0)==1){break g}if(nb(d)){a=0;while(1){e=k[Ub(d,a)|0];j[114626]=0;j[b+16>>2]=e;F(87,c|0,b+16|0);e=j[114626];j[114626]=0;if((e|0)==1){break b}a=a+1|0;if(nb(d)>>>0>a>>>0){continue}break}}a=Lb(c);d=Mb(c);j[114626]=0;d=K(88,b+16|0,a|0,d|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break f}j[114626]=0;F(89,b+8|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break e}ps(f,b+8|0);bf(b+8|0);Ud(d);Ud(c);break d}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;Ud(d);break a}ab=a;j[b+16>>2]=e;j[b+20>>2]=ab;c=nwa(b+32|0,b+16|0,b+24|0);j[114626]=0;F(89,b+8|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}ps(f,b+8|0);bf(b+8|0);Ud(c)}Za=b+48|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0}Ud(c);G(a|0);z()}function lwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,l=0,m=0;i=lb(b);a:{b:{c:{d:{e:{while(1){b=c;if(!c){break e}c=b-1|0;if(!k[i+c|0]){continue}break}if((d|0)!=4){break c}d=0;c=0;while(1){f:{g:{h:{e=k[c+i|0];switch(e-10|0){case 3:break h;case 0:break g;default:break f}}f=f+1|0;break f}g=g+1|0}j=((d&255)==13&(c|0)!=0&(e|0)==10)+j|0;d=e;c=c+1|0;if((c|0)!=(b|0)){continue}break}break d}b=0;if((d|0)!=4){break b}}i:{if((f|0)==(g|0)){d=2;if((f|0)==(j|0)){break i}}if(f){d=0;if(!g){break i}}d=f?3:g?1:3}if(!b){break b}}c=0;f=(d|0)!=2;e=0;while(1){e=(f|k[c+i|0]!=10)+e|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}qm(a,e);f=(d|0)==1?32:13;g=(d|0)==2;j=d&-3;c=0;e=0;while(1){j:{k:{l:{m:{n:{o:{d=h[c+i|0];switch(d-10|0){case 1:case 2:break l;case 0:break n;case 3:break o;default:break m}}l=Ol(a,e),m=f,h[l|0]=m;c=c+g|0;break j}d=Ol(a,e);if(j){h[d|0]=13;break j}h[d|0]=32;break j}if(!d){break k}}l=Ol(a,e),m=d,h[l|0]=m;break j}l=Ol(a,e),m=32,h[l|0]=m}e=e+1|0;c=c+1|0;if(c>>>0<b>>>0){continue}break}break a}qm(a,0)}return 1}function _4(a,b,c,d,e,f,g){var h=q(0),i=q(0),j=q(0),k=q(0),l=0,m=q(0),o=0,r=q(0),s=q(0),t=q(0),u=q(0),v=q(0),w=q(0),x=q(0);if((a|0)>=1){l=p(f,12)+e|0;m=n[l>>2];o=f<<3;r=n[o+e>>2];f=(f<<2)+e|0;s=n[f>>2];t=n[l+4>>2];u=n[(o|4)+e>>2];v=n[f+4>>2];w=n[e+4>>2];x=n[e>>2];e=(c<<2)+b|0;f=e+(d<<2)|0;b=0-g<<2;while(1){c=f-4|0;i=n[c>>2];k=n[f>>2];j=n[e>>2];n[e>>2]=k+j;d=e-4|0;h=n[d>>2];n[d>>2]=n[c>>2]+h;h=q(h-i);i=q(j-k);n[c>>2]=q(h*x)+q(i*w);n[f>>2]=q(i*x)-q(h*w);c=f-12|0;k=n[c>>2];d=e-8|0;h=n[d>>2];g=d;d=f-8|0;j=n[d>>2];n[g>>2]=j+h;g=e-12|0;i=n[g>>2];n[g>>2]=n[c>>2]+i;i=q(i-k);h=q(h-j);n[c>>2]=q(i*s)+q(h*v);n[d>>2]=q(h*s)-q(i*v);c=f-20|0;k=n[c>>2];d=e-16|0;h=n[d>>2];g=d;d=f-16|0;j=n[d>>2];n[g>>2]=j+h;g=e-20|0;i=n[g>>2];n[g>>2]=n[c>>2]+i;i=q(i-k);h=q(h-j);n[c>>2]=q(i*r)+q(h*u);n[d>>2]=q(h*r)-q(i*u);c=f-28|0;k=n[c>>2];d=e-24|0;h=n[d>>2];g=d;d=f-24|0;j=n[d>>2];n[g>>2]=j+h;g=e-28|0;i=n[g>>2];n[g>>2]=n[c>>2]+i;i=q(i-k);h=q(h-j);n[c>>2]=q(i*m)+q(h*t);n[d>>2]=q(h*m)-q(i*t);f=b+f|0;e=b+e|0;c=(a|0)>1;a=a-1|0;if(c){continue}break}}}function Zva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;h=Za-16|0;Za=h;e=j[a+48>>2];n=j[a+40>>2];o=j[a+36>>2];f=j[a+44>>2];s=j[a+16>>2];l=j[a+4>>2];k=j[a>>2];j[h+8>>2]=k;j[h+12>>2]=l;b=j[a+12>>2];j[h>>2]=j[a+8>>2];j[h+4>>2]=b;a:{if(!d){m=n>>12;g=o>>12;break a}while(1){m=i[(l<<1)+s>>1];g=j[a+60>>2];b=f;f=Gb(f,-16777216,16776704);q=j[a+64>>2];k=Gb(e,-16777216,16776704);t=j[a+72>>2];u=j[a+32>>2];l=c;v=j[c>>2];r=m<<8;e=r;e=OMa(g,g>>31,e,e>>31);m=ab;g=OMa(q,q>>31,f,f>>31);f=g+e|0;e=ab+m|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=j[a+68>>2];k=OMa(f,f>>31,k,k>>31);f=g+k|0;e=ab+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;o=j[a+28>>2]+o|0;g=o>>12;j[l>>2]=p(e,g)+v;n=n+u|0;m=n>>12;j[c+4>>2]=j[c+4>>2]+p(e,m);f=f-(r&t)|0;Bb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;l=j[h+12>>2];e=b;continue}break}k=j[h+8>>2];l=j[h+12>>2];e=b}j[a+40>>2]=n;j[a+20>>2]=g;j[a+36>>2]=o;j[a+48>>2]=e;j[a+44>>2]=f;j[a+24>>2]=m;j[a>>2]=k;j[a+4>>2]=l;Za=h+16|0}function tv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=Za-32|0;Za=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;i=c;a:{if((f|0)==(e|0)&c>>>0>c>>>0|e>>>0>f>>>0){f=c<<4|b>>>28;c=d<<4|c>>>28;b=b&268435455;h=b;if((b|0)==134217728&a>>>0>=1|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}e=c+1073741824|0;if(a|h^134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a;break a}if(!(!i&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){f=c;c=d<<4|c>>>28;f=f<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;We(g+16|0,a,b,c,e,h-15233|0);fm(g,a,b,c,e,15361-h|0);e=j[g+4>>2];h=e;a=j[g+8>>2];c=j[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;c=a;b=j[g>>2]|((j[g+16>>2]|j[g+24>>2])!=0|(j[g+20>>2]|j[g+28>>2])!=0);if((a|0)==134217728&b>>>0>=1|a>>>0>134217728){a=f+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}if(b|c^134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}Za=g+32|0;WMa(0,f|0);WMa(1,d&-2147483648|e);return+XMa()}function C1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Za-32|0;Za=g;j[g+24>>2]=b;a:{b:{if(!(j[d+4>>2]&1)){j[g>>2]=-1;b=bb[j[j[a>>2]+16>>2]](a,b,c,d,e,g)|0;j[g+24>>2]=b;c:{switch(j[g>>2]){case 1:h[f|0]=1;break a;case 0:break b;default:break c}}h[f|0]=1;j[e>>2]=4;break a}hc(g,d);j[114626]=0;b=H(2441,g|0)|0;a=j[114626];j[114626]=0;d:{e:{f:{g:{if((a|0)!=1){wb(g);hc(g,d);j[114626]=0;a=H(2442,g|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}wb(g);j[114626]=0;F(2443,g|0,a|0);d=j[114626];j[114626]=0;if((d|0)==1){b=D()|0;C()|0;break d}j[114626]=0;F(2444,g|12,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break f}j[114626]=0;d=g+24|0;a=ia(2445,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}h[f|0]=(a|0)==(g|0);b=j[g+24>>2];while(1){d=pc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=D()|0;C()|0;wb(g);break d}b=D()|0;C()|0;wb(g);break d}b=D()|0;C()|0;pc(g);break d}b=D()|0;C()|0;while(1){d=pc(d-12|0);if((g|0)!=(d|0)){continue}break}}G(b|0);z()}h[f|0]=0}Za=g+32|0;return b|0}function tq(a,b,c,d,e,f,g,i,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0;p=Za-16|0;Za=p;j[p+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!k[b|0]){break b}a=0;h[b|0]=0;b=j[e>>2];j[e>>2]=b+1;h[b|0]=46;if(!nb(i)){break a}b=j[m>>2];if((b-l|0)>159){break a}c=j[n>>2];j[m>>2]=b+4;j[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!nb(i)){break c}if(!k[b|0]){break b}a=0;b=j[m>>2];if((b-l|0)>159){break a}a=j[n>>2];j[m>>2]=b+4;j[b>>2]=a;a=0;j[n>>2]=0;break a}a=-1;f=Tu(o,o+128|0,p+12|0)-o|0;if((f|0)>124){break a}g=k[(f>>2)+62160|0];d:{e:{switch(TMa(f-88|0,30)|0){case 2:case 3:b=j[e>>2];if((k[b-1|0]&95)!=(k[c|0]&127)?(b|0)!=(d|0):0){break a}j[e>>2]=b+1;h[b|0]=g;a=0;break a;case 0:case 1:h[c|0]=80;break d;default:break e}}a=h[c|0];if((a|0)!=(g&95)){break d}h[c|0]=a|128;if(!k[b|0]){break d}h[b|0]=0;if(!nb(i)){break d}a=j[m>>2];if((a-l|0)>159){break d}b=j[n>>2];j[m>>2]=a+4;j[a>>2]=b}a=j[e>>2];j[e>>2]=a+1;h[a|0]=g;a=0;if((f|0)>84){break a}j[n>>2]=j[n>>2]+1;break a}a=-1}Za=p+16|0;return a|0}function tJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Za-16|0;Za=d;a:{b:{switch(j[a+480224>>2]-1|0){default:c=j[a+24620>>2];j[d+12>>2]=1;j[d+8>>2]=j[b+44>>2]<<1;c=OMa(c,c>>31,5e4,0);f=ab;b=j[Gc(d+12|0,d+8|0)>>2];c=ic(PMa(c,f,b,b>>31),ab);break a;case 0:c=j[a+24620>>2];j[d+12>>2]=1;j[d+8>>2]=j[b+44>>2];c=OMa(c,c>>31,1e4,0);f=ab;b=j[Gc(d+12|0,d+8|0)>>2];c=ic(PMa(c,f,b,b>>31),ab);break a;case 1:break b}}e=+m[a+24620>>2]*60/(+m[b+44>>2]*1e-4*(+(OMa(j[b+32>>2],0,j[b+40>>2],0)>>>0)+ +(ab>>>0)*4294967296));c:{d:{c=a+484344|0;if(!tg(c,l[b+60>>1])){break d}if(!(ad(Ib(c,l[b+60>>1])+24|0)^1)){break d}c=Ib(c,l[b+60>>1])+24|0;break c}c=a+480248|0}if(!ad(c)){e=e*5.960464477539063e-8*+m[xb(c,m[b+48>>2]%(sb(c)>>>0)|0)>>2]}e:{if(r(e)<2147483648){c=~~e;break e}c=-2147483648}e=e- +(c>>>0)+o[b+8>>3];o[b+8>>3]=e;if(!(e<1)){o[b+8>>3]=e+ -1;c=c+1|0;break a}if(o[a+1074384>>3]>-1){break a}o[b+8>>3]=e+1;c=c-1|0}b=OMa(j[a+480244>>2],0,c,0)+32768|0;a=ab;a=b>>>0<32768?a+1|0:a;a=Wc((a&65535)<<16|b>>>16,a>>>16|0);Za=d+16|0;return(a?a:1)|0}function f2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Za-32|0;Za=g;j[g+24>>2]=b;a:{b:{if(!(j[d+4>>2]&1)){j[g>>2]=-1;b=bb[j[j[a>>2]+16>>2]](a,b,c,d,e,g)|0;j[g+24>>2]=b;c:{switch(j[g>>2]){case 1:h[f|0]=1;break a;case 0:break b;default:break c}}h[f|0]=1;j[e>>2]=4;break a}hc(g,d);j[114626]=0;b=H(21,g|0)|0;a=j[114626];j[114626]=0;d:{e:{f:{g:{if((a|0)!=1){wb(g);hc(g,d);j[114626]=0;a=H(2408,g|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break g}wb(g);j[114626]=0;F(2409,g|0,a|0);d=j[114626];j[114626]=0;if((d|0)==1){b=D()|0;C()|0;break d}j[114626]=0;F(2410,g|12,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break f}j[114626]=0;d=g+24|0;a=ia(2411,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}h[f|0]=(a|0)==(g|0);b=j[g+24>>2];while(1){d=gb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=D()|0;C()|0;wb(g);break d}b=D()|0;C()|0;wb(g);break d}b=D()|0;C()|0;gb(g);break d}b=D()|0;C()|0;while(1){d=gb(d-12|0);if((g|0)!=(d|0)){continue}break}}G(b|0);z()}h[f|0]=0}Za=g+32|0;return b|0}function aH(a){var b=q(0),c=0,d=0,e=0,f=0,g=q(0),i=q(0),l=0,m=q(0);c=Za-16|0;Za=c;l=c,m=q(lw(n[a+4216>>2])/q(xe(j[a+16>>2])>>>0)),n[l+12>>2]=m;j[c+8>>2]=1056964608;b=q(y(q(q(_n(q(n[Rk(c+12|0,c+8|0)>>2]*q(6.2831854820251465)))*q(.4000000059604645))+q(.6000000238418579))));n[a+4236>>2]=b;n[a+4240>>2]=y(q(q(1)-q(b*b)));f=a;b=q(q(n[a+4212>>2]*q(29))+q(2));a:{if(b<q(4294967296)&b>=q(0)){d=~~b>>>0;break a}d=0}h[f+4272|0]=d;f=a;e=2;b:{if(d>>>0<4){break b}e=3;if(d>>>0<8){break b}e=d>>>0<16?4:5}h[f+4273|0]=e;g=Yd(q(10),q(q(q(n[a+4208>>2]*q(60))+q(-60))*q(.05000000074505806)));l=c,m=q(lw(n[a+4220>>2])/q(xe(j[a+16>>2])>>>0)),n[l+12>>2]=m;j[c+8>>2]=1056964608;i=n[Rk(c+12|0,c+8|0)>>2];l=c,m=q(lw(n[a+4224>>2])/q(xe(j[a+16>>2])>>>0)),n[l+12>>2]=m;j[c+8>>2]=1056964608;b=I4(q(n[Rk(c+12|0,c+8|0)>>2]*q(3.1415927410125732)));n[a+4268>>2]=q(q(1)-b)/q(b+q(1));b=_n(q(i*q(6.2831854820251465)));n[a+4264>>2]=-b;g=q(g*q(y(q(q(1)-q(b*b)))));b=n[a+4268>>2];n[a+4260>>2]=q(g*q(y(q(q(1)-q(b*b)))))*n[(k[a+4272|0]<<2)+33376>>2];Za=c+16|0}function _va(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;i=Za-16|0;Za=i;e=j[a+48>>2];n=j[a+40>>2];o=j[a+36>>2];f=j[a+44>>2];s=j[a+16>>2];l=j[a+4>>2];k=j[a>>2];j[i+8>>2]=k;j[i+12>>2]=l;b=j[a+12>>2];j[i>>2]=j[a+8>>2];j[i+4>>2]=b;a:{if(!d){m=n>>12;g=o>>12;break a}while(1){m=h[l+s|0];g=j[a+60>>2];b=f;f=Gb(f,-16777216,16776704);q=j[a+64>>2];k=Gb(e,-16777216,16776704);t=j[a+72>>2];u=j[a+32>>2];l=c;v=j[c>>2];r=m<<16;e=r;e=OMa(g,g>>31,e,e>>31);m=ab;g=OMa(q,q>>31,f,f>>31);f=g+e|0;e=ab+m|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=j[a+68>>2];k=OMa(f,f>>31,k,k>>31);f=g+k|0;e=ab+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;o=j[a+28>>2]+o|0;g=o>>12;j[l>>2]=p(e,g)+v;n=n+u|0;m=n>>12;j[c+4>>2]=j[c+4>>2]+p(e,m);f=f-(r&t)|0;Bb(i+8|0,i);d=d-1|0;if(d){c=c+8|0;l=j[i+12>>2];e=b;continue}break}k=j[i+8>>2];l=j[i+12>>2];e=b}j[a+40>>2]=n;j[a+20>>2]=g;j[a+36>>2]=o;j[a+48>>2]=e;j[a+44>>2]=f;j[a+24>>2]=m;j[a>>2]=k;j[a+4>>2]=l;Za=i+16|0}function IO(a,b,c,d,e){var f=0,g=0;f=Za-16|0;Za=f;g=l[c>>1];a:{if(k[d|0]<=4){while(1){d=g<<1;i[c>>1]=d;h[b|0]=(d&65534)>>>0>255;d=k[c|0];i[c>>1]=d;if(!d){if(!re(a,f+15|0)){break a}d=k[f+15|0];i[c>>1]=d<<1|1;h[b|0]=d>>>7;i[c>>1]=k[c|0]}i[e>>1]=h[b|0]+(l[e>>1]<<1);d=l[c>>1]<<1;i[c>>1]=d;h[b|0]=(d&65534)>>>0>255;d=k[c|0];i[c>>1]=d;if(!d){if(!re(a,f+14|0)){break a}d=k[f+14|0];i[c>>1]=d<<1|1;h[b|0]=d>>>7;i[c>>1]=k[c|0]}i[e>>1]=h[b|0]+(l[e>>1]<<1);d=l[c>>1]<<1;i[c>>1]=d;h[b|0]=(d&65534)>>>0>255;g=k[c|0];i[c>>1]=g;if(!g){if(!re(a,f+13|0)){break a}d=k[f+13|0];i[c>>1]=d<<1|1;h[b|0]=d>>>7;g=k[c|0];i[c>>1]=g}if(k[b|0]){continue}break a}}while(1){d=g<<1;i[c>>1]=d;h[b|0]=(d&65534)>>>0>255;d=k[c|0];i[c>>1]=d;if(!d){if(!re(a,f+12|0)){break a}d=k[f+12|0];i[c>>1]=d<<1|1;h[b|0]=d>>>7;i[c>>1]=k[c|0]}i[e>>1]=h[b|0]+(l[e>>1]<<1);d=l[c>>1]<<1;i[c>>1]=d;h[b|0]=(d&65534)>>>0>255;g=k[c|0];i[c>>1]=g;if(!g){if(!re(a,f+11|0)){break a}d=k[f+11|0];i[c>>1]=d<<1|1;h[b|0]=d>>>7;g=k[c|0];i[c>>1]=g}if(k[b|0]){continue}break}}Za=f+16|0}function iKa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=Za-144|0;Za=g;p=tp(a);if(p){u=g+8|4;v=g+8|6;w=g+8|5;n=g+8|2;q=g+8|3;while(1){QJa(a,g+8|0);e=k[g+8|0]|k[g+9|0]<<8;a:{if(!e){break a}e=(e<<24|e<<8)>>>16|0;if(e>>>0>l[c+480192>>1]){break a}e=j[((e<<2)+c|0)+900380>>2];if(!e){break a}e=Ht(e,b);b:{if(!k[q|0]){break b}if(h[n|0]&1){h[e+12|0]=k[e+12|0]|1}if(k[n|0]&2){h[e+12|0]=k[e+12|0]|4}if(!(k[n|0]&4)){break b}h[e+12|0]=k[e+12|0]|2}h[g+4|0]=k[q|0];h[g+7|0]=31;f=k[Yb(g+4|0,g+7|0)|0]+1|0;o=f&255;Nf(e,o);h[e+13|0]=k[w|0];h[e+14|0]=k[v|0];m=k[u|0];h[e+15|0]=m;h[e+16|0]=m;m=0;if((f|0)!=(o|0)){break a}while(1){r=g+16|0;s=m<<2;f=r+s|0;f=k[f|0]|k[f+1|0]<<8;x=xb(e,m),y=(f<<8&16711680|f<<24)>>>16|0,i[x>>1]=y;f=(s|2)+r|0;f=k[f|0]|k[f+1|0]<<8;f=(f<<24|f<<8&16711680)>>>16|0;i[g+4>>1]=d?f+128>>>2|0:f;Sf(g+4|0,64);f=k[g+4|0];x=xb(e,m),y=f,h[x+2|0]=y;m=m+1|0;if((o|0)!=(m|0)){continue}break}}t=t+1|0;if((t&65535)>>>0<p>>>0){continue}break}}Za=g+144|0}function vq(a,b,c,d,e,f,g,i,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0;p=Za-16|0;Za=p;h[p+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!k[b|0]){break b}a=0;h[b|0]=0;b=j[e>>2];j[e>>2]=b+1;h[b|0]=46;if(!nb(i)){break a}b=j[m>>2];if((b-l|0)>159){break a}c=j[n>>2];j[m>>2]=b+4;j[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!nb(i)){break c}if(!k[b|0]){break b}a=0;b=j[m>>2];if((b-l|0)>159){break a}a=j[n>>2];j[m>>2]=b+4;j[b>>2]=a;a=0;j[n>>2]=0;break a}a=-1;f=xm(o,o+32|0,p+15|0)-o|0;if((f|0)>31){break a}g=k[f+62160|0];d:{e:{switch(f-22|0){case 2:case 3:b=j[e>>2];if((k[b-1|0]&95)!=(k[c|0]&127)?(b|0)!=(d|0):0){break a}j[e>>2]=b+1;h[b|0]=g;a=0;break a;case 0:case 1:h[c|0]=80;break d;default:break e}}a=h[c|0];if((a|0)!=(g&95)){break d}h[c|0]=a|128;if(!k[b|0]){break d}h[b|0]=0;if(!nb(i)){break d}a=j[m>>2];if((a-l|0)>159){break d}b=j[n>>2];j[m>>2]=a+4;j[a>>2]=b}a=j[e>>2];j[e>>2]=a+1;h[a|0]=g;a=0;if((f|0)>21){break a}j[n>>2]=j[n>>2]+1;break a}a=-1}Za=p+16|0;return a|0}function $n(a,b,c,d,e,f){var g=q(0),h=q(0),i=0,j=q(0),k=q(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d-4|0;h=n[c>>2];j=n[d>>2];k=n[a>>2];n[a>>2]=j+k;f=a-4|0;g=n[f>>2];n[f>>2]=n[c>>2]+g;j=q(k-j);g=q(g-h);n[d>>2]=q(n[e>>2]*j)-q(n[e+4>>2]*g);n[c>>2]=q(n[e+4>>2]*j)+q(n[e>>2]*g);f=d-12|0;j=n[f>>2];c=a-8|0;g=n[c>>2];i=c;c=d-8|0;k=n[c>>2];n[i>>2]=k+g;i=a-12|0;h=n[i>>2];n[i>>2]=n[f>>2]+h;i=c;c=b+e|0;g=q(g-k);h=q(h-j);n[i>>2]=q(n[c>>2]*g)-q(n[c+4>>2]*h);n[f>>2]=q(n[c+4>>2]*g)+q(n[c>>2]*h);e=d-20|0;j=n[e>>2];f=a-16|0;g=n[f>>2];i=f;f=d-16|0;k=n[f>>2];n[i>>2]=k+g;i=a-20|0;h=n[i>>2];n[i>>2]=n[e>>2]+h;c=b+c|0;g=q(g-k);h=q(h-j);n[f>>2]=q(n[c>>2]*g)-q(n[c+4>>2]*h);n[e>>2]=q(n[c+4>>2]*g)+q(n[c>>2]*h);e=d-28|0;j=n[e>>2];f=a-24|0;g=n[f>>2];i=f;f=d-24|0;k=n[f>>2];n[i>>2]=k+g;i=a-28|0;h=n[i>>2];n[i>>2]=n[e>>2]+h;c=b+c|0;g=q(g-k);h=q(h-j);n[f>>2]=q(n[c>>2]*g)-q(n[c+4>>2]*h);n[e>>2]=q(n[c+4>>2]*g)+q(n[c>>2]*h);e=b+c|0;d=d-32|0;a=a-32|0;c=(l|0)>1;l=l-1|0;if(c){continue}break}}}function Gua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0;e=Za-48|0;Za=e;k=j[a+16>>2];f=wf(e+16|0);j[f+8>>2]=a+112;j[f+16>>2]=j[a+128>>2];o=f,q=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[o+12>>2]=q;b=j[f+16>>2];if(b){o=f,q=vf(a+8|0,b),j[o>>2]=q;j[f+4>>2]=ab}l=j[a+24>>2];m=j[a+20>>2];b=j[a+4>>2];h=j[a>>2];j[e+8>>2]=h;j[e+12>>2]=b;g=j[a+12>>2];j[e>>2]=j[a+8>>2];j[e+4>>2]=g;if(d){while(1){g=0;j[e+40>>2]=h;j[e+44>>2]=n;h=(b<<1)+k|0;a:{b=j[f+16>>2];if((b|0)<=0){break a}while(1){id(j[f+8>>2],i[(g<<1)+h>>1]/4<<16>>16);hd(j[f+8>>2],4);Bb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;g=j[e+44>>2];continue}}d=d-1|0;b=j[f+8>>2];Bb(b,b+8|0);b=j[f+8>>2];g=j[b+4>>2];if(g){id(b,i[h+(j[e+44>>2]<<1)>>1]/4<<16>>16);hd(j[f+8>>2],g);b=j[f+8>>2];g=j[b>>2];j[b>>2]=g;j[b+4>>2]=0}b=qf(b,j[f+12>>2]);j[c>>2]=j[c>>2]+p(b,m);j[c+4>>2]=j[c+4>>2]+p(b,l);Bb(e+8|0,e);if(d){c=c+8|0;h=j[e+8>>2];b=j[e+12>>2];continue}break}h=j[e+8>>2];b=j[e+12>>2]}j[a>>2]=h;j[a+4>>2]=b;Za=e+48|0}function gW(a){a=a|0;var b=0,c=0,d=0,e=0;c=Za+ -64|0;Za=c;a=Qc(a);j[114626]=0;b=T(228)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}j[114626]=0;d=E(2,c+32|0,10984)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}j[114626]=0;b=T(228)|0;e=j[114626];j[114626]=0;e:{f:{g:{h:{if((e|0)==1){break h}j[114626]=0;j[c+12>>2]=b;F(234,c+16|0,c+12|0);b=j[114626];j[114626]=0;if((b|0)==1){break h}j[114626]=0;I(3,c+48|0,d|0,c+16|0);b=j[114626];j[114626]=0;if((b|0)==1){break g}ob(a,c+48|0);gb(c+48|0);gb(c+16|0);gb(d);j[114626]=0;b=T(230)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}if(!b){break e}j[114626]=0;E(235,a|0,10987)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break e}break b}b=D()|0;C()|0;break f}b=D()|0;C()|0;gb(c+16|0)}gb(d);break a}j[114626]=0;b=T(229)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}if(!b){break d}j[114626]=0;E(235,a|0,10989)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}}Za=c- -64|0;return}b=D()|0;C()|0;break a}b=D()|0;C()|0}gb(a);G(b|0);z()}function _F(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Za-32|0;Za=d;a:{b:{c:{d:{e:{f:{g:{if(Qh(a)){eo(d+24|0);break g}om(d+8|0,a);j[114626]=0;F(2167,d+24|0,d+8|0);c=j[114626];j[114626]=0;if((c|0)==1){break f}Ye(d+8|0)}c=a+36|0;h:{if(Qh(a)){break h}c=j[d+24>>2]}if((b|0)==-1){e=4194304;break d}if((b|0)>=0){f=b;if((pd(c)|0)>(b|0)){break d}}b=R(8)|0;j[114626]=0;c=E(85,d+8|0,38703)|0;a=j[114626];j[114626]=0;if((a|0)==1){break e}Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break c}a=D()|0;C()|0;Ye(d+8|0);break b}a=D()|0;C()|0;S(b|0);break c}j[a+8>>2]=b;b=a+24|0;g=j[b>>2];j[g+480208>>2]=j[g+480208>>2]&-4194305|e;b=j[b>>2];e=k[yc(c,f)+16|0];j[114626]=0;F(488,b+484360|0,e|0);b=j[114626];j[114626]=0;i:{if((b|0)==1){break i}b=j[yc(c,f)+12>>2];c=j[yc(c,f)+8>>2];j[114626]=0;+ca(2018,a|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break i}j[a+16>>2]=0;j[a+20>>2]=0;Gj(d+24|0);Za=d+32|0;return}a=D()|0;C()|0}Gj(d+24|0)}G(a|0)}z()}function oK(a,b,c,d){var e=0,f=0,g=0,i=0,l=0,m=0;e=Za-16|0;Za=e;g=p(b,896)+a|0;a:{if(c){mb(e+8|0,a+1074308|0,90);if(!kb(e+8|0)){h[(p(b,896)+a|0)+1075815|0]=c}h[(p(b,896)+a|0)+1075816|0]=c;break a}c=k[g+1075816|0]}f=g+1074984|0;i=c&255;m=0-i|0;l=d?l:!(j[a+480180>>2]&204473357);jK(a,b,m,l);b:{c:{if(j[a+480180>>2]!=16777216){break c}g=j[(p(b,896)+a|0)+1075640>>2];if(!g|!j[g+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){iK(a,f,240-i|0);break b}if(!(b>>>0<224|d)){hK(f,224-i|0);break b}gK(f,m);break b}if(j[a+480180>>2]==268435456){j[(p(b,896)+a|0)+1075692>>2]=65535}if(!(l^1|(c&255)>>>0<224)){d:{d=i&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}dK(a,f,d);break b}if(j[a+480180>>2]==524288){break d}lK(a,f,d);break b}if(j[a+480180>>2]!=524288){break b}}e:{if(!(h[(p(b,896)+a|0)+1075856|0]&1)){break e}if(j[a+1074416>>2]==1){mb(e+8|0,a+1074308|0,6);if(kb(e+8|0)){break e}}if(j[a+480180>>2]==64){break e}if(!(j[a+480208>>2]&2)|j[a+480180>>2]!=8){break b}}eK(a,f,i<<2)}Za=e+16|0}function xsa(a,b,c){var d=0,e=0,f=0,g=0,h=0,m=0;if(!k[a+40|0]){i[c>>1]=0;i[b>>1]=0;return}f=j[a+16>>2];e=l[f+3840>>1];d=0;a:{if(!(e&3)){break a}d=(l[a+20>>1]>>>7&7)>>>(k[f+3844|0]^1)>>>(e&1)|0;d=(e&4?0-d|0:d)<<16>>16}d=d<<l[a+22>>1];h=b;e=j[a+36>>2];b:{if(e){m=l[e+32>>1];g=l[a+32>>1];e=tf(j[a>>2],j[a+24>>2],d<<16>>16,0,i[a+30>>1]);f=j[a+24>>2];b=j[a+4>>2];if(!m){if(!g){d=d<<16>>16;e=tf(b,f,d,e,0);e=tf(j[a+8>>2],j[a+24>>2],d,e,0);d=tf(j[a+12>>2],j[a+24>>2],d,e,0);break b}d=d<<16>>16;f=tf(b,f,d,0,0);f=tf(j[a+8>>2],j[a+24>>2],d,f,0);d=tf(j[a+12>>2],j[a+24>>2],d,f,0)+e|0;break b}if(!g){d=d<<16>>16;e=tf(b,f,d,e,0);f=tf(j[a+8>>2],j[a+24>>2],d,0,0);d=tf(j[a+12>>2],j[a+24>>2],d,f,0)+e|0;break b}d=d<<16>>16;f=tf(b,f,d,0,0);d=(tf(j[a+8>>2],j[a+24>>2],d,f,0)+e|0)+tf(j[a+12>>2],j[a+24>>2],d,0,0)|0;break b}g=l[a+32>>1];d=d<<16>>16;e=tf(j[a>>2],j[a+24>>2],d,0,i[a+30>>1]);f=j[a+24>>2];b=j[a+4>>2];if(!g){d=tf(b,f,d,e,0);break b}d=tf(b,f,d,0,0)+e|0}i[h>>1]=k[a+41|0]?d:0;i[c>>1]=k[a+42|0]?d:0}function QIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,l=0,m=0,n=0,o=0;f=Za-2608|0;Za=f;d=f+8|0;Jl(d,a);j[d+1056>>2]=0;j[d+1060>>2]=0;Ab(d+1064|0,0,1536);j[114626]=0;N(565,d|0);a=j[114626];j[114626]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!c){break d}f:{while(1){j[114626]=0;n=E(260,d|0,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break f}a=0;g:{while(1){j[114626]=0;e=E(260,d|0,1)|0;o=j[114626];j[114626]=0;if((o|0)==1){break g}a=p(a,6)+d|0;a=i[(e?a+1066|0:a+1064|0)>>1];h:{if((a|0)>255){break h}e=p(a,6)+d|0;g=k[e+1068|0];if(i[e+1064>>1]<0){break h}if(i[e+1066>>1]>-1){continue}}break}g=(n?-1:0)^g;m=(m&255)+(g&255)|0;h[b+l|0]=m;l=l+1|0;if((l|0)!=(c|0)){continue}break d}break}b=J(77072)|0;break e}b=J(77072)|0;break e}b=J(77072)|0}if((C()|0)!=(W(77072)|0)){break a}O(b|0)|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)==1){break c}}j[114626]=0;a=H(566,d|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}jb(d);Za=f+2608|0;return a|0}b=D()|0;C()|0;break a}b=D()|0;C()|0}jb(d);G(b|0);z()}function vZ(a,b,c){var d=0,e=0,f=0,g=0,i=0,j=0,l=0;d=a;while(1){a:{if(c>>>0<=j>>>0|b>>>0<=d>>>0){break a}g=h[d|0];f=g&255;b:{if((g|0)>=0){g=1;if(f>>>0<=1114111){break b}break a}if(f>>>0<194){break a}if(f>>>0<=223){if((b-d|0)<2){break a}e=k[d+1|0];if((e&192)!=128){break a}g=2;if((e&63|f<<6&1984)>>>0<=1114111){break b}break a}c:{d:{if(f>>>0<=239){if((b-d|0)<3){break a}i=k[d+2|0];e=k[d+1|0];if((f|0)==237){break d}if((f|0)==224){if((e&224)==160){break c}break a}if((e&192)!=128){break a}break c}if((b-d|0)<4|f>>>0>244){break a}i=k[d+3|0];l=k[d+2|0];e=k[d+1|0];e:{f:{switch(f-240|0){case 0:if((e+112&255)>>>0<48){break e}break a;case 4:if((e&240)==128){break e}break a;default:break f}}if((e&192)!=128){break a}}if((l&192)!=128|(i&192)!=128){break a}g=4;if((i&63|(l<<6&4032|(f<<18&1835008|(e&63)<<12)))>>>0>1114111){break a}break b}if((e&224)!=128){break a}}if((i&192)!=128){break a}g=3;if((i&63|(f<<12&61440|(e&63)<<6))>>>0>1114111){break a}}j=j+1|0;d=d+g|0;continue}break}return d-a|0}function gxa(a,b){var c=0,d=0,e=0,f=0,g=0;d=Za-32|0;Za=d;md(b,0);dk(d,2,a+32|0);qc(d+16|0,d);j[114626]=0;E(370,b+43|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){gb(d+16|0);e=a+56|0;c=a+52|0;a:{if((k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))>>>0<=(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))>>>0){break a}j[b>>2]=(k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24))-(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24));c=a+44|0;j[b+12>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+48|0;j[d+16>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);f=b,g=j[tb(d+16|0,b)>>2],j[f+16>>2]=g;i[b+30>>1]=k[a+60|0];c=a+62|0;j[b+24>>2]=k[c|0]|k[c+1|0]<<8;c=a- -64|0;if(k[c|0]|k[c+1|0]<<8){ls(b,+((k[c|0]|k[c+1|0]<<8)<<16>>16)*25431315104166665e-22)}a=a+61|0;if(k[a|0]&8){i[b+34>>1]=l[b+34>>1]|8}if(k[a|0]&16){i[b+34>>1]=l[b+34>>1]|16}if(!(k[a|0]&4)){break a}i[b+34>>1]=l[b+34>>1]|1;j[b+12>>2]=j[b+12>>2]>>>1;j[b+16>>2]=j[b+16>>2]>>>1}Za=d+32|0;return}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function Nva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;i=Za-16|0;Za=i;g=j[a+48>>2];o=j[a+24>>2];q=j[a+20>>2];b=j[a+44>>2];r=j[a+16>>2];f=j[a+4>>2];k=j[a>>2];j[i+8>>2]=k;j[i+12>>2]=f;e=j[a+12>>2];j[i>>2]=j[a+8>>2];j[i+4>>2]=e;a:{if(!d){e=b;b=g;break a}while(1){e=f+r|0;s=h[e+1|0];e=h[e|0];f=j[a+60>>2];t=f;u=f>>31;f=Gb(b,-16777216,16776704);l=j[a+64>>2];g=Gb(g,-16777216,16776704);v=j[a+72>>2];w=j[c>>2];f=OMa(l,l>>31,f,f>>31);l=ab;m=f;f=j[a+68>>2];n=OMa(f,f>>31,g,g>>31);f=m+n|0;g=ab+l|0;g=f>>>0<n>>>0?g+1|0:g;m=f;f=((p(s-e|0,k>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=f;k=OMa(t,u,e,e>>31);e=m+k|0;g=ab+g|0;g=e>>>0<k>>>0?g+1|0:g;e=e+8388608|0;if(e>>>0<8388608){g=g+1|0}g=(g&16777215)<<8|e>>>24;e=(g|0)/256|0;j[c>>2]=p(e,q)+w;j[c+4>>2]=j[c+4>>2]+p(e,o);e=g-(f&v)|0;Bb(i+8|0,i);d=d-1|0;if(d){c=c+8|0;k=j[i+8>>2];f=j[i+12>>2];g=b;b=e;continue}break}k=j[i+8>>2];f=j[i+12>>2]}j[a+48>>2]=b;j[a+44>>2]=e;j[a>>2]=k;j[a+4>>2]=f;Za=i+16|0}function pK(a,b,c,d){var e=0,f=0,g=0,i=0,l=0;e=Za-16|0;Za=e;i=p(b,896)+a|0;a:{if(c){mb(e+8|0,a+1074308|0,90);if(!kb(e+8|0)){h[(p(b,896)+a|0)+1075816|0]=c}h[(p(b,896)+a|0)+1075815|0]=c;break a}c=k[i+1075815|0]}f=i+1074984|0;g=c&255;l=d?l:!(j[a+480180>>2]&204473357);jK(a,b,g,l);b:{c:{if(j[a+480180>>2]!=16777216){break c}i=j[(p(b,896)+a|0)+1075640>>2];if(!i|!j[i+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){iK(a,f,g-240|0);break b}if(!(b>>>0<224|d)){hK(f,g-224|0);break b}gK(f,g);break b}if(j[a+480180>>2]==268435456){j[(p(b,896)+a|0)+1075692>>2]=1}if(!(l^1|(c&255)>>>0<224)){d:{d=g&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}fK(a,f,d);break b}if(j[a+480180>>2]==524288){break d}kK(a,f,d);break b}if(j[a+480180>>2]!=524288){break b}}e:{if(!(h[(p(b,896)+a|0)+1075856|0]&1)){break e}if(j[a+1074416>>2]==1){mb(e+8|0,a+1074308|0,6);if(kb(e+8|0)){break e}}if(j[a+480180>>2]==64){break e}if(!(j[a+480208>>2]&2)|j[a+480180>>2]!=8){break b}}eK(a,f,0-(g<<2)|0)}Za=e+16|0}function Mva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=Za-16|0;Za=h;g=j[a+48>>2];o=j[a+24>>2];q=j[a+20>>2];b=j[a+44>>2];r=j[a+16>>2];f=j[a+4>>2];k=j[a>>2];j[h+8>>2]=k;j[h+12>>2]=f;e=j[a+12>>2];j[h>>2]=j[a+8>>2];j[h+4>>2]=e;a:{if(!d){e=b;b=g;break a}while(1){e=(f<<1)+r|0;s=i[e+2>>1];e=i[e>>1];f=j[a+60>>2];t=f;u=f>>31;f=Gb(b,-16777216,16776704);l=j[a+64>>2];g=Gb(g,-16777216,16776704);v=j[a+72>>2];w=j[c>>2];f=OMa(l,l>>31,f,f>>31);l=ab;m=f;f=j[a+68>>2];n=OMa(f,f>>31,g,g>>31);f=m+n|0;g=ab+l|0;g=f>>>0<n>>>0?g+1|0:g;m=f;f=e+((p(s-e|0,k>>>18|0)|0)/16384|0)<<8;e=f;k=OMa(t,u,e,e>>31);e=m+k|0;g=ab+g|0;g=e>>>0<k>>>0?g+1|0:g;e=e+8388608|0;if(e>>>0<8388608){g=g+1|0}g=(g&16777215)<<8|e>>>24;e=(g|0)/256|0;j[c>>2]=p(e,q)+w;j[c+4>>2]=j[c+4>>2]+p(e,o);e=g-(f&v)|0;Bb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;k=j[h+8>>2];f=j[h+12>>2];g=b;b=e;continue}break}k=j[h+8>>2];f=j[h+12>>2]}j[a+48>>2]=b;j[a+44>>2]=e;j[a>>2]=k;j[a+4>>2]=f;Za=h+16|0}function QZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,l=0,m=0;l=Za-16|0;Za=l;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!k[i|0]){break a}i=i+1|0;continue}break}j[h>>2]=f;j[e>>2]=c;while(1){b:{c:{d:{if((f|0)==(g|0)|(c|0)==(d|0)){break d}m=j[b+4>>2];j[l+8>>2]=j[b>>2];j[l+12>>2]=m;e:{f:{g:{m=PZ(f,e,i-c|0,g-f>>2,b,j[a+8>>2]);h:{if((m|0)==-1){while(1){i:{j[h>>2]=f;if(j[e>>2]==(c|0)){break i}g=1;j:{k:{l:{b=nC(f,c,i-c|0,l+8|0,j[a+8>>2]);switch(b+2|0){case 2:break j;case 1:break l;case 0:break f;default:break k}}j[e>>2]=c;break h}g=b}c=c+g|0;f=j[h>>2]+4|0;continue}break}j[e>>2]=c;break d}f=j[h>>2]+(m<<2)|0;j[h>>2]=f;if((f|0)==(g|0)){break e}c=j[e>>2];if((d|0)==(i|0)){i=d;continue}if(!nC(f,c,1,b,j[a+8>>2])){break g}}a=2;break c}j[h>>2]=j[h>>2]+4;c=j[e>>2]+1|0;j[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!k[i|0]){break b}i=i+1|0;continue}}j[e>>2]=c;a=1;break c}c=j[e>>2]}a=(c|0)!=(d|0)}Za=l+16|0;return a|0}f=j[h>>2];continue}}function Nka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=Za-16|0;Za=e;md(c,0);d=a+36|0;i[e+14>>1]=k[d|0]|k[d+1|0]<<8;i[e+12>>1]=32767;f=c,g=(l[gf(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,i[f+28>>1]=g;d=a+38|0;i[e+10>>1]=k[d|0]|k[d+1|0]<<8;i[e+8>>1]=32767;f=c,g=(l[gf(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,i[f+30>>1]=g;i[c+32>>1]=64;d=a+44|0;j[c>>2]=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=a+48|0;j[c+4>>2]=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=a+52|0;j[c+8>>2]=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=a+56|0;j[c+24>>2]=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=b+166|0;if(k[d|0]<=4){h[c+38|0]=k[k[d|0]+31850|0]}h[c+39|0]=k[b+167|0];d=b+171|0;h[c+41|0]=(k[d|0]|k[d+1|0]<<8)>>>4;b=b+169|0;b=(k[b|0]|k[b+1|0]<<8)>>>2|0;h[c+40|0]=b;if(k[c+41|0]|b&255){h[c+39|0]=k[c+39|0]^-1}a=a+40|0;if(k[a|0]&4){i[c+34>>1]=l[c+34>>1]|1}if(k[a|0]&8){i[c+34>>1]=l[c+34>>1]|2}if(k[a|0]&16){i[c+34>>1]=l[c+34>>1]|4}if(k[a|0]&32){i[c+34>>1]=l[c+34>>1]|32}Za=e+16|0}function CZ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=a;while(1){a:{if(c>>>0<=g>>>0|b>>>0<=e>>>0){break a}f=k[e|0];if(f>>>0>1114111){break a}d=e+1|0;b:{if(f<<24>>24>=0){break b}if(f>>>0<194){break a}if(f>>>0<=223){if((b-e|0)<2){break a}d=k[e+1|0];if((d&192)!=128|(d&63|f<<6&1984)>>>0>1114111){break a}d=e+2|0;break b}c:{d:{if(f>>>0<=239){if((b-e|0)<3){break a}h=k[e+2|0];d=k[e+1|0];if((f|0)==237){break d}if((f|0)==224){if((d&224)==160){break c}break a}if((d&192)!=128){break a}break c}if(c-g>>>0<2|f>>>0>244|(b-e|0)<4){break a}h=k[e+3|0];i=k[e+2|0];d=k[e+1|0];e:{f:{switch(f-240|0){case 0:if((d+112&255)>>>0<48){break e}break a;case 4:if((d&240)==128){break e}break a;default:break f}}if((d&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(h&63|(i<<6&4032|(f<<18&1835008|(d&63)<<12)))>>>0>1114111){break a}g=g+1|0;d=e+4|0;break b}if((d&224)!=128){break a}}if((h&192)!=128|(h&63|(f<<12&61440|(d&63)<<6))>>>0>1114111){break a}d=e+3|0}e=d;g=g+1|0;continue}break}return e-a|0}function sE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Za-208|0;Za=d;j[d+8>>2]=1;j[d+12>>2]=0;a:{h=b<<2;if(!h){break a}j[d+16>>2]=4;j[d+20>>2]=4;b=4;g=4;e=2;while(1){f=b;b=(g+4|0)+b|0;j[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;g=f;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){e=1;b=1;break b}e=1;b=1;while(1){c:{if((e&3)==3){vv(a,c,b,d+16|0);Rq(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(m[(d+16|0)+(g<<2)>>2]>=f-a>>>0){Qq(a,c,d+8|0,b,0,d+16|0);break d}vv(a,c,b,d+16|0)}if((b|0)==1){Pq(d+8|0,1);b=0;break c}Pq(d+8|0,g);b=1}e=j[d+8>>2]|1;j[d+8>>2]=e;a=a+4|0;if(f>>>0>a>>>0){continue}break}}Qq(a,c,d+8|0,b,0,d+16|0);while(1){e:{f:{g:{if(!((b|0)!=1|(e|0)!=1)){if(j[d+12>>2]){break g}break a}if((b|0)>1){break f}}f=rE(d+8|0);Rq(d+8|0,f);e=j[d+8>>2];b=b+f|0;break e}Pq(d+8|0,2);j[d+8>>2]=j[d+8>>2]^7;Rq(d+8|0,1);g=a-4|0;f=b-2|0;Qq(g-j[(d+16|0)+(f<<2)>>2]|0,c,d+8|0,b-1|0,1,d+16|0);Pq(d+8|0,1);e=j[d+8>>2]|1;j[d+8>>2]=e;Qq(g,c,d+8|0,f,1,d+16|0);b=f}a=a-4|0;continue}}Za=d+208|0}function y3(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,l=0;d=Za-32|0;Za=d;j[114626]=0;g=E(15,d+24|0,a|0)|0;h=j[114626];j[114626]=0;a:{b:{c:{if((h|0)!=1){d:{if(!k[g|0]){break d}hc(d+16|0,j[j[a>>2]-12>>2]+a|0);j[114626]=0;h=H(2323,d+16|0)|0;e=j[114626];j[114626]=0;e:{f:{if((e|0)!=1){wb(d+16|0);e=sk(d+8|0,a);f=j[j[a>>2]-12>>2];j[114626]=0;f=a+f|0;i=H(16,f|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break f}e=j[e>>2];j[114626]=0;b=ra(2326,h|0,e|0,f|0,i|0,b|0,c|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break f}j[d+16>>2]=b;if(!rk(d+16|0)){break d}b=j[j[a>>2]-12>>2];j[114626]=0;F(18,a+b|0,5);b=j[114626];j[114626]=0;if((b|0)!=1){break d}b=J(0)|0;C()|0;break e}b=J(0)|0;C()|0;wb(d+16|0);break e}b=J(0)|0;C()|0}nf(g);break c}nf(g);break b}b=J(0)|0;C()|0}O(b|0)|0;b=j[j[a>>2]-12>>2];j[114626]=0;N(19,a+b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=d+32|0;return}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Hua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0;e=Za-48|0;Za=e;k=j[a+16>>2];f=wf(e+16|0);j[f+8>>2]=a+112;j[f+16>>2]=j[a+128>>2];o=f,q=rf(b+327720|0,j[b+20>>2],(j[a+88>>2]&16384)>>>14|0),j[o+12>>2]=q;b=j[f+16>>2];if(b){o=f,q=vf(a+8|0,b),j[o>>2]=q;j[f+4>>2]=ab}l=j[a+24>>2];m=j[a+20>>2];b=j[a+4>>2];i=j[a>>2];j[e+8>>2]=i;j[e+12>>2]=b;g=j[a+12>>2];j[e>>2]=j[a+8>>2];j[e+4>>2]=g;if(d){while(1){g=0;j[e+40>>2]=i;j[e+44>>2]=n;i=b+k|0;a:{b=j[f+16>>2];if((b|0)<=0){break a}while(1){id(j[f+8>>2],h[i+g|0]<<6);hd(j[f+8>>2],4);Bb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;g=j[e+44>>2];continue}}d=d-1|0;b=j[f+8>>2];Bb(b,b+8|0);b=j[f+8>>2];g=j[b+4>>2];if(g){id(b,h[i+j[e+44>>2]|0]<<6);hd(j[f+8>>2],g);b=j[f+8>>2];g=j[b>>2];j[b>>2]=g;j[b+4>>2]=0}b=qf(b,j[f+12>>2]);j[c>>2]=j[c>>2]+p(b,m);j[c+4>>2]=j[c+4>>2]+p(b,l);Bb(e+8|0,e);if(d){c=c+8|0;i=j[e+8>>2];b=j[e+12>>2];continue}break}i=j[e+8>>2];b=j[e+12>>2]}j[a>>2]=i;j[a+4>>2]=b;Za=e+48|0}function Ei(a,b,c,d,e,f,g,h){var i=0,k=0,l=0,m=0,n=0;i=Za-32|0;Za=i;j[i+16>>2]=c;j[i+24>>2]=b;hc(i+8|0,d);j[114626]=0;k=H(2441,i+8|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){wb(i+8|0);j[e>>2]=0;c=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(yj(i+24|0,i+16|0)){break b}c:{if((Tl(k,j[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}l=0;b=Tl(k,j[c>>2]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+8|0)==(h|0)){break b}l=b;b=Tl(k,j[g+8>>2])}m=i,n=bb[j[j[a>>2]+36>>2]](a,j[i+24>>2],j[i+16>>2],d,e,f,b,l)|0,j[m+24>>2]=n;g=c+8|0;break c}if(zj(k,8192,j[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if(zj(k,8192,j[g>>2])){continue}}break}while(1){if(!Hq(i+24|0,i+16|0)){break c}if(!zj(k,8192,Gk(i+24|0))){break c}cm(i+24|0);continue}}if((qk(k,Gk(i+24|0))|0)==(qk(k,j[g>>2])|0)){g=g+4|0;cm(i+24|0);break c}j[e>>2]=4}c=j[e>>2];continue}break}j[e>>2]=4}if(yj(i+24|0,i+16|0)){j[e>>2]=j[e>>2]|2}Za=i+32|0;return j[i+24>>2]}a=D()|0;C()|0;wb(i+8|0);G(a|0);z()}function z3(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Za-32|0;Za=c;j[114626]=0;g=E(15,c+24|0,a|0)|0;d=j[114626];j[114626]=0;a:{b:{c:{if((d|0)!=1){d:{if(!k[g|0]){break d}hc(c+16|0,j[j[a>>2]-12>>2]+a|0);j[114626]=0;d=H(2323,c+16|0)|0;e=j[114626];j[114626]=0;e:{f:{if((e|0)!=1){wb(c+16|0);e=sk(c+8|0,a);f=j[j[a>>2]-12>>2];j[114626]=0;f=a+f|0;h=H(16,f|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break f}e=j[e>>2];j[114626]=0;b=U(2324,d|0,e|0,f|0,h|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}j[c+16>>2]=b;if(!rk(c+16|0)){break d}b=j[j[a>>2]-12>>2];j[114626]=0;F(18,a+b|0,5);b=j[114626];j[114626]=0;if((b|0)!=1){break d}b=J(0)|0;C()|0;break e}b=J(0)|0;C()|0;wb(c+16|0);break e}b=J(0)|0;C()|0}nf(g);break c}nf(g);break b}b=J(0)|0;C()|0}O(b|0)|0;b=j[j[a>>2]-12>>2];j[114626]=0;N(19,a+b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=c+32|0;return}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function v3(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=Za-32|0;Za=d;j[114626]=0;g=E(15,d+24|0,a|0)|0;c=j[114626];j[114626]=0;a:{b:{c:{if((c|0)!=1){d:{if(!k[g|0]){break d}hc(d+16|0,j[j[a>>2]-12>>2]+a|0);j[114626]=0;c=H(2323,d+16|0)|0;e=j[114626];j[114626]=0;e:{f:{if((e|0)!=1){wb(d+16|0);e=sk(d+8|0,a);f=j[j[a>>2]-12>>2];j[114626]=0;f=a+f|0;h=H(16,f|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break f}e=j[e>>2];j[114626]=0;c=La(2327,c|0,e|0,f|0,h|0,+b)|0;e=j[114626];j[114626]=0;if((e|0)==1){break f}j[d+16>>2]=c;if(!rk(d+16|0)){break d}c=j[j[a>>2]-12>>2];j[114626]=0;F(18,a+c|0,5);c=j[114626];j[114626]=0;if((c|0)!=1){break d}c=J(0)|0;C()|0;break e}c=J(0)|0;C()|0;wb(d+16|0);break e}c=J(0)|0;C()|0}nf(g);break c}nf(g);break b}c=J(0)|0;C()|0}O(c|0)|0;c=j[j[a>>2]-12>>2];j[114626]=0;N(19,a+c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=d+32|0;return}a=D()|0;C()|0;j[114626]=0;M(20);d=j[114626];j[114626]=0;if((d|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function lv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Za-32|0;Za=c;j[114626]=0;g=E(15,c+24|0,a|0)|0;d=j[114626];j[114626]=0;a:{b:{c:{if((d|0)!=1){d:{if(!k[g|0]){break d}hc(c+16|0,j[j[a>>2]-12>>2]+a|0);j[114626]=0;d=H(2323,c+16|0)|0;e=j[114626];j[114626]=0;e:{f:{if((e|0)!=1){wb(c+16|0);e=sk(c+8|0,a);f=j[j[a>>2]-12>>2];j[114626]=0;f=a+f|0;h=H(16,f|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break f}e=j[e>>2];j[114626]=0;b=U(2325,d|0,e|0,f|0,h|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}j[c+16>>2]=b;if(!rk(c+16|0)){break d}b=j[j[a>>2]-12>>2];j[114626]=0;F(18,a+b|0,5);b=j[114626];j[114626]=0;if((b|0)!=1){break d}b=J(0)|0;C()|0;break e}b=J(0)|0;C()|0;wb(c+16|0);break e}b=J(0)|0;C()|0}nf(g);break c}nf(g);break b}b=J(0)|0;C()|0}O(b|0)|0;b=j[j[a>>2]-12>>2];j[114626]=0;N(19,a+b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=c+32|0;return}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function gy(a,b){a=a|0;b=b|0;a:{b:{switch((k[a+3|0]|64)+ -64|0){case 0:h[a+3|0]=k[a+5|0]?42:0;return;case 1:h[a+3|0]=16;return;case 2:h[a+3|0]=12;return;case 3:h[a+3|0]=14;if(b){break a}b=a;a=k[a+5|0];h[b+5|0]=p(a>>>4|0,10)+(a&15);return;case 4:h[a+3|0]=11;return;case 5:h[a+3|0]=3;return;case 6:h[a+3|0]=2;return;case 7:h[a+3|0]=4;return;case 8:h[a+3|0]=5;return;case 9:h[a+3|0]=18;return;case 10:h[a+3|0]=1;return;case 11:h[a+3|0]=7;return;case 12:h[a+3|0]=6;return;case 13:h[a+3|0]=21;return;case 14:h[a+3|0]=22;return;case 15:h[a+3|0]=10;return;case 16:h[a+3|0]=29;return;case 17:h[a+3|0]=15;return;case 18:h[a+3|0]=8;return;case 19:h[a+3|0]=20;return;case 20:h[a+3|0]=17;return;case 21:h[a+3|0]=26;return;case 22:h[a+3|0]=23;return;case 23:h[a+3|0]=24;return;case 24:h[a+3|0]=9;return;case 25:h[a+3|0]=27;return;case 26:h[a+3|0]=31;return;case 28:h[a+3|0]=b?32:31;return;case 29:h[a+3|0]=33;return;case 27:h[a+3|0]=34;return;default:break b}}h[a+3|0]=0}}function Uua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=Za-32|0;Za=f;l=j[a+24>>2];m=j[a+20>>2];n=j[a+16>>2];k=j[a+4>>2];e=k;g=j[a>>2];j[f+24>>2]=g;j[f+28>>2]=e;k=j[a+12>>2];j[f+16>>2]=j[a+8>>2];j[f+20>>2]=k;k=a;if(d){while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+n|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;o=i[a+38>>1];q=i[a+36>>1];r=i[a+34>>1];s=i[a+32>>1];t=i[a+30>>1];u=i[a+28>>1];v=i[a+26>>1];w=i[a+24>>1];g=0;a=1;while(1){e=g<<1;j[(f+8|0)+(g<<2)>>2]=(((((p(i[(e|8)+h>>1],r)+p(i[(e|4)+h>>1],s)|0)+p(i[(e|12)+h>>1],q)|0)+p(i[(e|16)+h>>1],o)|0)/2|0)+((((p(i[(e|-8)+h>>1],v)+p(i[(e|-12)+h>>1],w)|0)+p(i[(e|-4)+h>>1],u)|0)+p(i[e+h>>1],t)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}j[c>>2]=j[c>>2]+p(j[f+8>>2],m);j[c+4>>2]=j[c+4>>2]+p(j[f+12>>2],l);Bb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;g=j[f+24>>2];e=j[f+28>>2];continue}break}g=j[f+24>>2];e=j[f+28>>2]}j[k>>2]=g;j[k+4>>2]=e;Za=f+32|0}function Fi(a,b,c,d,e,f,g,i){var k=0,l=0,m=0,n=0,o=0;k=Za-32|0;Za=k;j[k+16>>2]=c;j[k+24>>2]=b;hc(k+8|0,d);j[114626]=0;l=H(21,k+8|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){wb(k+8|0);j[e>>2]=0;c=0;a:{while(1){if((g|0)==(i|0)|c){break a}b:{if(Ii(k+24|0,k+16|0)){break b}c:{if((Vl(l,h[g|0])|0)==37){c=g+1|0;if((i|0)==(c|0)){break b}m=0;b=Vl(l,h[c|0]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+2|0)==(i|0)){break b}m=b;b=Vl(l,h[g+2|0])}n=k,o=bb[j[j[a>>2]+36>>2]](a,j[k+24>>2],j[k+16>>2],d,e,f,b,m)|0,j[n+24>>2]=o;g=c+2|0;break c}if(ng(l,8192,h[g|0])){while(1){e:{g=g+1|0;if((i|0)==(g|0)){g=i;break e}if(ng(l,8192,h[g|0])){continue}}break}while(1){if(!Tn(k+24|0,k+16|0)){break c}if(!ng(l,8192,Bj(k+24|0))){break c}Ik(k+24|0);continue}}if((Xu(l,Bj(k+24|0))|0)==(Xu(l,h[g|0])|0)){g=g+1|0;Ik(k+24|0);break c}j[e>>2]=4}c=j[e>>2];continue}break}j[e>>2]=4}if(Ii(k+24|0,k+16|0)){j[e>>2]=j[e>>2]|2}Za=k+32|0;return j[k+24>>2]}a=D()|0;C()|0;wb(k+8|0);G(a|0);z()}function mva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0;f=Za-16|0;Za=f;a:{b:{c:{h=j[a+8>>2];g=j[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}k=b+196648|0;break a}k=b+131112|0;break a}k=b+262184|0}l=j[a+16>>2];m=j[a+24>>2];n=j[a+20>>2];b=j[a+4>>2];e=j[a>>2];j[f+8>>2]=e;j[f+12>>2]=b;j[f>>2]=h;j[f+4>>2]=g;if(d){while(1){b=(b<<1)+l|0;e=(e>>>16&65520)+k|0;b=(((((((p(i[b-4>>1],i[e+2>>1])+p(i[b-6>>1],i[e>>1])|0)+p(i[b-2>>1],i[e+4>>1])|0)+p(i[b>>1],i[e+6>>1])|0)+p(i[b+2>>1],i[e+8>>1])|0)+p(i[b+4>>1],i[e+10>>1])|0)+p(i[b+6>>1],i[e+12>>1])|0)+p(i[b+8>>1],i[e+14>>1])|0)/32768|0;j[c>>2]=j[c>>2]+p(b,n);j[c+4>>2]=j[c+4>>2]+p(b,m);Bb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=j[f+8>>2];b=j[f+12>>2];continue}break}e=j[f+8>>2];b=j[f+12>>2]}j[a>>2]=e;j[a+4>>2]=b;Za=f+16|0}function kj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;c=Za-80|0;Za=c;d=j[a+28>>2];jn(j[j[d>>2]-12>>2]+d|0,0);if(!gd(a,4)){Nu(a)}a:{if(!j[a+4>>2]){break a}if(gd(a,6)){break a}if(gd(a,7)){break a}h=j[a+28>>2];f=j[a+84>>2];g=p(j[a+20>>2],j[a+4>>2]);e=g+j[a+80>>2]|0;e=sg(c- -64|0,e,e>>>0<g>>>0?f+1|0:f);g=j[e+12>>2];j[c+24>>2]=j[e+8>>2];j[c+28>>2]=g;d=j[e+4>>2];j[c+16>>2]=j[e>>2];j[c+20>>2]=d;Gi(h,c+16|0)}b:{if(!gd(a,5)){break b}i=a+44|0;e=Xc(i);if(!e){break b}h=a+32|0;while(1){c:{f=(j[a+96>>2]+k>>>0)%(e>>>0)|0;if(m[_b(i,f)>>2]>=tc(h)>>>0){break c}g=Rl(c+48|0,fc(h,j[_b(i,f)>>2]),l[_b(i,f)+12>>1]);d=Ru(b,g);qb(g);if(!d){break c}j[a+96>>2]=(f+1>>>0)%(e>>>0);if(j[_b(i,f)+4>>2]){g=j[a+28>>2];d=j[a+12>>2];b=j[a+8>>2];a=j[_b(i,f)+4>>2];h=b+a|0;d=sg(c+32|0,h,a>>>0>h>>>0?d+1|0:d);a=j[d+12>>2];j[c+8>>2]=j[d+8>>2];j[c+12>>2]=a;a=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=a;Gi(g,c)}k=_b(i,f);break b}k=k+1|0;if((e|0)!=(k|0)){continue}break}k=0}Za=c+80|0;return k}function Yi(a){a=a|0;var b=0;a:{b:{switch(k[a+3|0]){case 0:if(!k[a+5|0]){break a}h[a+3|0]=1;return;case 1:h[a+3|0]=2;return;case 2:h[a+3|0]=3;return;case 3:h[a+3|0]=4;return;case 4:h[a+3|0]=5;return;case 5:h[a+3|0]=6;return;case 6:h[a+3|0]=7;return;case 7:h[a+3|0]=8;return;case 8:h[a+3|0]=9;return;case 9:h[a+3|0]=10;return;case 10:h[a+3|0]=11;return;case 11:h[a+3|0]=12;return;case 12:h[a+3|0]=13;return;case 13:h[a+3|0]=14;b=a;a=k[a+5|0];h[b+5|0]=p(a>>>4|0,10)+(a&15);return;case 14:h[a+3|0]=19;return;case 15:if(k[a+5|0]<=31){h[a+3|0]=16;return}h[a+3|0]=17;return;case 16:h[a+3|0]=23;return;case 17:h[a+3|0]=24;return;case 20:h[a+3|0]=25;return;case 21:h[a+3|0]=30;return;case 25:h[a+3|0]=29;return;case 27:h[a+3|0]=15;return;case 29:h[a+3|0]=18;return;case 32:h[a+3|0]=42;return;case 33:h[a+3|0]=28;return;case 34:h[a+3|0]=27;return;case 35:h[a+3|0]=31;return;case 36:h[a+3|0]=32;return;case 38:h[a+3|0]=34;return;default:break b}}h[a+3|0]=0}}function fU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-80|0;Za=d;rc(b);aq(a);a:{if(!_t(b,d+40|0)){break a}if(!FA(d+40|0)){break a}b:{if(!c){break b}c=d+40|4;e=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);if(!yb(b,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))-28|0)){break a}tu(a);su(d+24|0);ru(yg(a)+28|0,d+24|0);$p(d+24|0);e=j[yg(a)+28>>2];j[114626]=0;f=H(350,b|0)|0;b=j[114626];j[114626]=0;c:{if((b|0)==1){break c}c=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);b=k[d+52|0]|k[d+53|0]<<8|(k[d+54|0]<<16|k[d+55|0]<<24);j[114626]=0;c=P(351,f|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))-28|0,e|0,b<<8&16711680|b<<24|(b>>>8&65280|b>>>24))|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}f=0;if(!c){break a}xi(d+8|0,e);ou(d+16|0,d+8|0);b=Dn(d+24|0,d+16|0,0);Ed(yg(a)+12|0,b);jb(b);break b}b=qa(71396,77416)|0;a=C()|0;d:{if((W(71396)|0)==(a|0)){break d}if((W(77416)|0)==(a|0)){break d}G(b|0);z()}O(b|0)|0;Q();f=0;break a}f=1}Za=d+80|0;return f|0}function nva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0;f=Za-16|0;Za=f;a:{b:{c:{k=j[a+8>>2];g=j[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?k>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?k>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?k>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?k>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=j[a+16>>2];n=j[a+24>>2];o=j[a+20>>2];b=j[a+4>>2];e=j[a>>2];j[f+8>>2]=e;j[f+12>>2]=b;j[f>>2]=k;j[f+4>>2]=g;if(d){while(1){b=b+m|0;e=(e>>>16&65520)+l|0;b=(((((((p(h[b-2|0],i[e+2>>1])+p(h[b-3|0],i[e>>1])|0)+p(h[b-1|0],i[e+4>>1])|0)+p(h[b|0],i[e+6>>1])|0)+p(h[b+1|0],i[e+8>>1])|0)+p(h[b+2|0],i[e+10>>1])|0)+p(h[b+3|0],i[e+12>>1])|0)+p(h[b+4|0],i[e+14>>1])<<8)/32768|0;j[c>>2]=j[c>>2]+p(b,o);j[c+4>>2]=j[c+4>>2]+p(b,n);Bb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=j[f+8>>2];b=j[f+12>>2];continue}break}e=j[f+8>>2];b=j[f+12>>2]}j[a>>2]=e;j[a+4>>2]=b;Za=f+16|0}function gCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=Za-16|0;Za=e;h[e+15|0]=8;i[e+12>>1]=0;j[e+8>>2]=0;if(d){q=p(c,d);while(1){if((q|0)>=1){m=(o<<1)+b|0;t=m+(q<<1)|0;while(1){i[e+6>>1]=0;IO(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{b:{g=k[e+15|0];if(!g){break b}c=l[e+12>>1];while(1){f=c<<1;c=f&254;i[e+12>>1]=c;f=(f&65534)>>>0>255;h[e+14|0]=f;if(!c){if(!re(a,e+5|0)){break b}c=k[e+5|0];f=c>>>7|0;h[e+14|0]=f;c=c<<1&254|1;i[e+12>>1]=c}n=l[e+6>>1]<<1|f;i[e+6>>1]=n;g=g-1|0;if(g&255){continue}break}break a}n=l[e+6>>1]}c=1;g=n&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;r=c&255;if(r>>>0<2){break c}f=c-1|0;if(!(g&1<<r)){continue}break}}h[e+15|0]=(k[e+15|0]+c&254)>>>1;c=n&1;h[e+14|0]=c;c=c-1^(n&65534)>>>1;f=c+l[e+8>>1]|0;i[e+6>>1]=f;i[m>>1]=f;c=(c>>1)-s|0;s=i[e+6>>1];j[e+8>>2]=c+(s<<1);Md(e+8|0,-32768,32767);m=(d<<1)+m|0;if(t>>>0>m>>>0){continue}break}}o=o+1|0;if((o|0)!=(d|0)){continue}break}}Za=e+16|0}function SE(a){var b=0,c=0,d=0,e=0,f=0,g=0,i=0,l=0;b=j[a+32>>2];a:{b:{c:{c=j[a+1380>>2];d:{if((c|0)==-1){i=1;c=-1;break d}d=j[a+1116>>2];e:{if((d|0)<=(c|0)){break e}while(1){e=k[(a+c|0)+1120|0];b=e+b|0;if((e|0)!=255){break e}c=c+1|0;if((d|0)>(c|0)){continue}break}}if(m[a+40>>2]<b>>>0){break c}c=(c|0)==(d|0)?-1:c}while(1){if((c|0)!=-1){return 1}g=j[a+40>>2];if(g>>>0<=b+26>>>0){Nb(a,1);break a}if((k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))!=(k[84672]|k[84673]<<8|(k[84674]<<16|k[84675]<<24))){Nb(a,21);break a}if(k[b+4|0]){Nb(a,21);break a}f:{if(i){if(!j[a+992>>2]|!(h[b+5|0]&1)){break f}Nb(a,21);break a}if(h[b+5|0]&1){break f}Nb(a,21);break a}d=b+27|0;e=k[b+26|0];b=d+e|0;if(g>>>0<b>>>0){break b}i=0;c=0;f=0;g:{if(!e){break g}while(1){l=k[c+d|0];b=l+b|0;f=c;if((l|0)!=255){break g}c=c+1|0;if((e|0)!=(c|0)){continue}break}f=e}d=f;c=(d|0)==(e|0)?-1:d;if(b>>>0<=g>>>0){continue}break}Nb(a,1);break a}Nb(a,1);break a}Nb(a,1)}return 0}function Pm(a,b,c){var d=0,e=0;e=Za-16|0;Za=e;h[a+861|0]=0;j[a+708>>2]=0;j[a+656>>2]=0;j[a+104>>2]=0;h[a+819|0]=0;j[a+804>>2]=0;j[a+824>>2]=0;j[a+696>>2]=0;j[a+668>>2]=0;j[a+88>>2]=j[a+88>>2]|6144;mb(e+8|0,b+1074308|0,23);if(kb(e+8|0)){i[a+798>>1]=0;i[a+800>>1]=1}h[a+866|0]=0;h[a+859|0]=0;h[a+871|0]=255;j[a+660>>2]=0;h[a+872|0]=k[a+872|0]&252;As(a+810|0);j[a+84>>2]=0;j[a+76>>2]=0;j[a+80>>2]=0;j[a+700>>2]=0;j[a+656>>2]=0;j[a+104>>2]=0;j[a+92>>2]=0;j[a+96>>2]=0;j[a>>2]=0;j[a+4>>2]=0;h[a+865|0]=0;h[a+858|0]=0;j[a+688>>2]=0;j[a+672>>2]=0;j[a+676>>2]=0;i[a+840>>1]=0;h[a+839|0]=0;i[a+856>>1]=32512;i[a+862>>1]=0;j[a+20>>2]=0;j[a+24>>2]=0;j[a+8>>2]=0;j[a+12>>2]=0;j[a+28>>2]=0;j[a+32>>2]=0;j[a+876>>2]=0;j[a+880>>2]=0;h[a+872|0]=k[a+872|0]&243;a:{if(c>>>0>126){c=64;b=128;d=0;break a}d=(c<<5)+b|0;c=l[d+480286>>1];b=l[d+480284>>1];d=j[d+480280>>2]}i[a+796>>1]=0;j[a+760>>2]=c;j[a+692>>2]=b;j[a+88>>2]=d;h[a+817|0]=0;h[a+818|0]=0;Za=e+16|0}function dL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,n=0,o=0,p=0;e=Za-96|0;Za=e;h[e+95|0]=d;d=0;n=Jo(a);o=Ui(n);i[b>>1]=0;a:{if(o){while(1){p=l[ac(n,d&65535)>>1];b:{if(!tg(j[a+24>>2]+484344|0,p)){break b}d=l[b>>1];if(cc(a)>>>0<=d>>>0){j[c>>2]=0;a=1;break a}f=Zc(a,l[b>>1]);Xi(e+72|0,f);Wj(e- -64|0,f);d=j[e+76>>2];j[e+32>>2]=j[e+72>>2];j[e+36>>2]=d;d=j[e+68>>2];j[e+24>>2]=j[e+64>>2];j[e+28>>2]=d;qra(e+80|0,e+32|0,e+24|0,e+95|0);d=c;c:{if(k[e+95|0]){Wj(e+56|0,f);g=0;if(cL(e+80|0,e+56|0)){break c}if(k[e+95|0]){break b}}Wj(e+56|0,f);if(cL(e+80|0,e+56|0)^1){Xi(e+48|0,f);a=j[e+84>>2];b=j[e+80>>2];j[e+40>>2]=b;j[e+44>>2]=a;c=j[e+52>>2];j[e+16>>2]=j[e+48>>2];j[e+20>>2]=c;j[e+8>>2]=b;j[e+12>>2]=a;g=nN(e+16|0,e+8|0);break c}if(m[f+4>>2]>=m[Ib(j[a+24>>2]+484344|0,p)+12>>2]){break b}g=j[f+4>>2]}j[d>>2]=g;a=1;break a}d=l[b>>1]+1|0;i[b>>1]=d;if((d&65535)>>>0<o>>>0){continue}break}}i[b>>1]=65535;j[c>>2]=-1;a=0}Za=e+96|0;return a|0}function kia(a,b,c,d){var e=0,f=0,g=0,h=0,k=0;e=Za-48|0;Za=e;j[e+44>>2]=0;ii(b,e+44|0);a:{b:{if(j[e+44>>2]!=(nk(32545)|0)){break b}j[e+40>>2]=0;ii(b,e+40|0);k=-1;f=j[e+40>>2];if(f-1>>>0>1){break b}c:{d:{e:{if((f|0)<=1){f=Db(e+24|0);j[114626]=0;g=K(721,b|0,f|0,256)|0;h=j[114626];j[114626]=0;if((h|0)==1){break a}if(!g){break d}j[114626]=0;I(13,e+8|0,d|0,f|0);g=j[114626];j[114626]=0;if((g|0)!=1){break e}break a}f=Db(e+24|0);j[114626]=0;g=K(723,b|0,f|0,255)|0;h=j[114626];j[114626]=0;if((h|0)==1){break a}if(!g){break c}j[114626]=0;I(13,e+8|0,d|0,f|0);g=j[114626];j[114626]=0;if((g|0)==1){break a}}ob(c,e+8|0);gb(e+8|0);gb(f);c=0;i[e+8>>1]=0;cf(b,e+8|0);j[e+24>>2]=0;ii(b,e+24|0);f=j[e+24>>2];if(f>>>0>50){break b}if(f){while(1){if(!SH(a,b,d)){break b}c=c+1|0;if(c>>>0<m[e+24>>2]){continue}break}}j[e+24>>2]=0;ii(b,e+24|0);k=j[e+24>>2]==(nk(32550)|0)?1:-1;break b}gb(f);break b}gb(f)}Za=e+48|0;return k}a=D()|0;C()|0;gb(f);G(a|0);z()}function Vua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=Za-32|0;Za=f;m=j[a+24>>2];n=j[a+20>>2];o=j[a+16>>2];k=j[a+4>>2];l=k;e=j[a>>2];j[f+24>>2]=e;j[f+28>>2]=k;k=j[a+12>>2];j[f+16>>2]=j[a+8>>2];j[f+20>>2]=k;k=a;if(d){while(1){g=(((l&2147483647)<<1|e>>>31)&-2)+o|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;q=i[a+38>>1];r=i[a+36>>1];s=i[a+34>>1];t=i[a+32>>1];u=i[a+30>>1];v=i[a+28>>1];w=i[a+26>>1];x=i[a+24>>1];e=0;a=1;while(1){j[(f+8|0)+(e<<2)>>2]=(((((p(h[(e|4)+g|0],s)+p(h[(e|2)+g|0],t)|0)+p(h[(e|6)+g|0],r)|0)+p(h[(e|8)+g|0],q)<<8)/2|0)+((((p(h[(e|-4)+g|0],w)+p(h[(e|-6)+g|0],x)|0)+p(h[(e|-2)+g|0],v)|0)+p(h[e+g|0],u)<<8)/2|0)|0)/16384;l=a;a=0;e=1;if(l){continue}break}j[c>>2]=j[c>>2]+p(j[f+8>>2],n);j[c+4>>2]=j[c+4>>2]+p(j[f+12>>2],m);Bb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;e=j[f+24>>2];l=j[f+28>>2];continue}break}e=j[f+24>>2];l=j[f+28>>2]}j[k>>2]=e;j[k+4>>2]=l;Za=f+32|0}function Lea(a){var b=q(0),c=q(0),d=q(0),e=0,f=q(0),g=q(0),i=q(0),k=q(0),l=q(0),m=q(0),o=q(0),p=0,r=q(0);e=Za-16|0;Za=e;c=qg(a,5);f=qg(a,11);d=q(c*qg(a,4));k=q(q(d*q(.03999999910593033))+q(c*q(.02250000089406967)));c=q(f*qg(a,10));f=q(q(c*q(.03999999910593033))+q(f*q(.02250000089406967)));if(h[a+4264|0]&1){b=qg(a,3);g=qg(a,9);b=q(b*d);d=q(qg(a,2)*b);k=q(q(q(b*q(.12250000238418579))+k)+q(d*q(.1444000005722046)));b=q(g*c);c=q(qg(a,8)*b);f=q(q(q(b*q(.12250000238418579))+f)+q(c*q(.1444000005722046)))}qg(a,12);b=n[a+4496>>2];g=qg(a,1);i=qg(a,7);m=qg(a,0);o=qg(a,6);p=e,r=Yd(q(10),q(q(VG(a)+q(q(n[a+4236>>2]*q(12e3))+q(-1e4)))*q(.0005000000237487257))),n[p+12>>2]=r;j[e+8>>2]=1065353216;l=n[Rk(e+12|0,e+8|0)>>2];b=q(b*b);c=q(i*q(b*c));i=q(o*c);d=q(g*q(b*d));b=q(m*d);g=q(q(q(i+b)*q(-.5))+q(1));n[a+4284>>2]=l*q(y(q(g/q(q(q(b+c)*q(.1444000005722046))+k))));n[a+4288>>2]=l*q(y(q(g/q(q(q(i+d)*q(.1444000005722046))+f))));Za=e+16|0}function Mha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=q(0),h=0,i=0,k=0,l=0,m=0,o=0,p=q(0),s=q(0),t=q(0),u=q(0),v=q(0),w=q(0),x=q(0),y=q(0),z=0,A=0,B=q(0);if(j[a+4220>>2]){f=a+44|0;i=wd(f,0);k=wd(f,1);l=Rc(f,0);m=Rc(f,1);if(d){h=a+4208|0;e=j[a+4224>>2];o=d;while(1){p=n[k>>2];s=n[i>>2];z=h;e=e-j[a+4228>>2]|0;if((e|0)<=-1){e=e+j[a+4220>>2]|0}e=e<<1;t=n[xb(z,e)>>2];e=xb(h,e|1);v=n[a+4248>>2];w=n[a+4256>>2];x=n[a+4252>>2];y=n[a+4244>>2];u=n[e>>2];g=q(q(q(q(p*v)+q(s*w))+q(t*x))+q(y*u));A=xb(h,j[a+4224>>2]<<1),B=q(r(g))<q(1.0000000195414814e-24)?q(0):g,n[A>>2]=B;g=q(q(q(q(v*s)+q(w*p))+q(x*u))+q(y*t));A=xb(h,j[a+4224>>2]<<1|1),B=q(r(g))<q(1.0000000195414814e-24)?q(0):g,n[A>>2]=B;e=j[a+4224>>2]+1|0;e=(e|0)==j[a+4220>>2]?0:e;j[a+4224>>2]=e;n[l>>2]=q(t*n[a+4236>>2])+q(s*n[a+4240>>2]);n[m>>2]=q(u*n[a+4236>>2])+q(p*n[a+4240>>2]);m=m+4|0;l=l+4|0;k=k+4|0;i=i+4|0;o=o-1|0;if(o){continue}break}}Th(a,b,c,Rc(f,0),Rc(f,1),d)}}function Gi(a,b){var c=0,d=0,e=0,f=0;c=Za+ -64|0;Za=c;d=j[(j[j[a>>2]-12>>2]+a|0)+16>>2]&-3;jn(j[j[a>>2]-12>>2]+a|0,d);a:{b:{if(k[Ji(c+56|0,a,1)|0]){e=j[j[a>>2]-12>>2];j[114626]=0;e=j[(a+e|0)+24>>2];f=j[114626];j[114626]=0;c:{d:{if((f|0)==1){break d}j[114626]=0;f=j[b+12>>2];j[c+16>>2]=j[b+8>>2];j[c+20>>2]=f;f=j[b+4>>2];j[c+8>>2]=j[b>>2];j[c+12>>2]=f;L(2318,c+40|0,e|0,c+8|0,8);b=j[114626];j[114626]=0;if((b|0)==1){break d}b=sg(c+24|0,-1,-1);j[114626]=0;b=OR(c+40|0,b);e=j[114626];j[114626]=0;if((e|0)==1){break d}b=b?d|4:d;break c}b=J(0)|0;C()|0;O(b|0)|0;b=d|1;Hi(j[j[a>>2]-12>>2]+a|0,b);d=j[j[a>>2]-12>>2];j[114626]=0;d=j[(a+d|0)+20>>2];e=j[114626];j[114626]=0;e:{if((e|0)!=1){if(!(d&1)){break e}j[114626]=0;M(81);a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}Q()}eg(j[j[a>>2]-12>>2]+a|0,b)}Za=c- -64|0;return}a=J(0)|0;C()|0;ib(a)}z()}function sca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Za-48|0;Za=b;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((c|0)!=1){d=Db(b+32|0);c=j[a+24>>2];j[114626]=0;F(2068,b+16|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break h}e=b,f=Lb(b+16|0),j[e+8>>2]=f;e=b,f=Mb(b+16|0),j[e>>2]=f;if(!rb(b+8|0,b)){break f}break g}c=J(0)|0;C()|0;break c}c=J(0)|0;C()|0;break d}while(1){c=j[b+8>>2];j[114626]=0;E(1245,d|0,c|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}_m(b+8|0);e=b,f=Mb(b+16|0),j[e>>2]=f;if(!rb(b+8|0,b)){break f}j[114626]=0;E(1988,d|0,34201)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}break e}c=Gd(zb(d));Uc(b+16|0);gb(d);break b}c=J(0)|0;C()|0;Uc(b+16|0)}gb(d)}O(c|0)|0;c=0;j[114626]=0;L(1982,36905,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=b+48|0;return c|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function ada(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Za-48|0;Za=b;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((c|0)!=1){d=Db(b+32|0);c=j[a+24>>2];j[114626]=0;F(2033,b+16|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break h}e=b,f=Lb(b+16|0),j[e+8>>2]=f;e=b,f=Mb(b+16|0),j[e>>2]=f;if(!rb(b+8|0,b)){break f}break g}c=J(0)|0;C()|0;break c}c=J(0)|0;C()|0;break d}while(1){c=j[b+8>>2];j[114626]=0;E(1245,d|0,c|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break e}_m(b+8|0);e=b,f=Mb(b+16|0),j[e>>2]=f;if(!rb(b+8|0,b)){break f}j[114626]=0;E(1988,d|0,34201)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}break e}c=Gd(zb(d));Uc(b+16|0);gb(d);break b}c=J(0)|0;C()|0;Uc(b+16|0)}gb(d)}O(c|0)|0;c=0;j[114626]=0;L(1982,35662,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=b+48|0;return c|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function wla(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=Za-16|0;Za=f;g=Mg(a);a=c+16|0;a=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);j[114626]=0;a=E(256,b|0,a|0)|0;d=j[114626];j[114626]=0;a:{b:{c:{if((d|0)==1){break c}d:{e:{f:{if(!a){break f}a=c+12|0;d=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);j[114626]=0;F(1525,g|0,d|0);d=j[114626];j[114626]=0;if((d|0)==1){break c}if(!(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))){break f}d=c+4|0;c=0;while(1){j[114626]=0;e=E(258,b|0,4)|0;h=j[114626];j[114626]=0;if((h|0)==1){break b}if(!e){break f}e=k[d|0]|k[d+1|0]<<8;j[114626]=0;I(1526,f|0,b|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break e}j[114626]=0;F(1527,g|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break d}gb(f);c=c+1|0;if(c>>>0<(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))>>>0){continue}break}}Za=f+16|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(f);break a}a=D()|0;C()|0;break a}a=D()|0;C()|0}Uc(g);G(a|0);z()}function AD(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0;g=Za-32|0;Za=g;f=d&2147483647;h=f;e=f-1065418752|0;i=f-1082064896|0;f=c;a:{if((e|0)==(i|0)&f>>>0<f>>>0|e>>>0<i>>>0){h=(d&33554431)<<7|c>>>25;f=0;k=f;i=c&33554431;if(!(!f&(i|0)==16777216?!(a|b):!f&i>>>0<16777216)){e=h+1073741825|0;break a}e=h+1073741824|0;if(i^16777216|a|(b|k)){break a}e=(e&1)+e|0;break a}if(!(!f&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(h>>>0>1082064895){break a}e=0;f=h>>>16|0;if(f>>>0<16145){break a}h=c;e=d&65535|65536;We(g+16|0,a,b,h,e,f-16129|0);fm(g,a,b,h,e,16257-f|0);b=j[g+8>>2];e=(j[g+12>>2]&33554431)<<7|b>>>25;h=j[g+4>>2];f=h;a=0;i=a;k=j[g>>2]|((j[g+16>>2]|j[g+24>>2])!=0|(j[g+20>>2]|j[g+28>>2])!=0);b=b&33554431;if(!(!a&(b|0)==16777216?!(f|k):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|k|(f|i)){break a}e=(e&1)+e|0}Za=g+32|0;return WMa(2,d&-2147483648|e),_Ma()}function bwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;h=Za-16|0;Za=h;f=j[a+48>>2];q=j[a+24>>2];r=j[a+20>>2];b=j[a+44>>2];s=j[a+16>>2];k=j[a+4>>2];l=j[a>>2];j[h+8>>2]=l;j[h+12>>2]=k;e=j[a+12>>2];j[h>>2]=j[a+8>>2];j[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){l=i[(k<<1)+s>>1];g=j[a+60>>2];m=g;e=Gb(b,-16777216,16776704);o=j[a+64>>2];k=Gb(f,-16777216,16776704);t=j[a+72>>2];f=j[c>>2];n=g>>31;l=l<<8;g=l;g=OMa(m,n,g,g>>31);m=ab;n=c;u=f;f=g;g=OMa(o,o>>31,e,e>>31);e=f+g|0;f=ab+m|0;f=e>>>0<g>>>0?f+1|0:f;g=e;e=j[a+68>>2];k=OMa(e,e>>31,k,k>>31);e=g+k|0;f=ab+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;j[n>>2]=u+p(e,r);j[c+4>>2]=j[c+4>>2]+p(e,q);e=f-(l&t)|0;Bb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;k=j[h+12>>2];f=b;b=e;continue}break}l=j[h+8>>2];k=j[h+12>>2]}j[a+48>>2]=b;j[a+44>>2]=e;j[a>>2]=l;j[a+4>>2]=k;Za=h+16|0}function Q6(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0;g=a;l=a>>31;e=OMa(a,l,1e4,0)+14780|0;a=ab;h=e;a=e>>>0<14780?a+1|0:a;f=a;e=PMa(e,a,-14609700,-1);a=g;i=e+a|0;e=l+ab|0;e=a>>>0>i>>>0?e+1|0:e;k=PMa(h,f,365242500,0);i=k+i|0;a=ab+e|0;a=i>>>0<k>>>0?a+1|0:a;k=PMa(h,f,-146097e4,-1);i=k+i|0;e=ab+a|0;e=i>>>0<k>>>0?e+1|0:e;a=PMa(h,f,3652425,0);f=ab;k=f;h=i;i=OMa(a,f,-365,-1);h=h+i|0;f=ab+e|0;f=h>>>0<i>>>0?f+1|0:f;e=f;if(!((e|0)>0?1:(e|0)>=0)){e=k-(a>>>0<1)|0;a=a-1|0;f=OMa(a,e,-365,-1)+g|0;e=l+ab|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=(a|0)/-4|0;h=f;g=g+f|0;f=(f>>31)+e|0;f=h>>>0>g>>>0?f+1|0:f;e=g;g=(a|0)/100|0;h=g;e=e+g|0;g=(g>>31)+f|0;g=e>>>0<h>>>0?g+1|0:g;f=e;e=(a|0)/-400|0;h=e;f=f+e|0;e=(e>>31)+g|0;e=f>>>0<h>>>0?e+1|0:e;h=f}k=b;f=a;b=OMa(h,e,100,0)+52|0;a=ab;a=PMa(b,b>>>0<52?a+1|0:a,3060,0);b=a+2|0;g=(b|0)/12|0;j[k>>2]=f+g;j[c>>2]=(b-p(g,12)|0)+1;a=OMa(a,ab,306,0)+5|0;e=ab;a=PMa(a,a>>>0<5?e+1|0:e,-10,-1)+h|0;j[d>>2]=a+1}function cwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;i=Za-16|0;Za=i;f=j[a+48>>2];q=j[a+24>>2];r=j[a+20>>2];b=j[a+44>>2];s=j[a+16>>2];k=j[a+4>>2];l=j[a>>2];j[i+8>>2]=l;j[i+12>>2]=k;e=j[a+12>>2];j[i>>2]=j[a+8>>2];j[i+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){l=h[k+s|0];g=j[a+60>>2];m=g;e=Gb(b,-16777216,16776704);o=j[a+64>>2];k=Gb(f,-16777216,16776704);t=j[a+72>>2];f=j[c>>2];n=g>>31;l=l<<16;g=l;g=OMa(m,n,g,g>>31);m=ab;n=c;u=f;f=g;g=OMa(o,o>>31,e,e>>31);e=f+g|0;f=ab+m|0;f=e>>>0<g>>>0?f+1|0:f;g=e;e=j[a+68>>2];k=OMa(e,e>>31,k,k>>31);e=g+k|0;f=ab+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;j[n>>2]=u+p(e,r);j[c+4>>2]=j[c+4>>2]+p(e,q);e=f-(l&t)|0;Bb(i+8|0,i);d=d-1|0;if(d){c=c+8|0;k=j[i+12>>2];f=b;b=e;continue}break}l=j[i+8>>2];k=j[i+12>>2]}j[a+48>>2]=b;j[a+44>>2]=e;j[a>>2]=l;j[a+4>>2]=k;Za=i+16|0}function Pxa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,k=0,m=0,n=0;m=Za-112|0;Za=m;a:{b:{if(!ke(a)){break b}if(cc(b)>>>0<2){break b}f=by(m+8|0,a);j[f+20>>2]=0;j[f>>2]=0;c:{d=cc(b);if(d){d:{while(1){c=Zc(b,g);e=j[a>>2];h=j[c>>2];if(e>>>0<=h>>>0){break d}c=j[c+4>>2];if(c>>>0>e-h>>>0){break d}e=j[f>>2];if(e>>>0>268435456-c>>>0){break d}j[f>>2]=c+e;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(!Qo(f)){break b}if(!g){break c}d=0;c=0;while(1){e=Zc(b,d);h=j[f+20>>2];j[114626]=0;h=H(466,h|0)|0;k=j[114626];j[114626]=0;if((k|0)==1){break a}k=j[a+20>>2];j[114626]=0;k=H(466,k|0)|0;n=j[114626];j[114626]=0;if((n|0)==1){break a}Vb(c+h|0,k+j[e>>2]|0,j[e+4>>2]);j[e>>2]=c;if(!(!d|d>>>0>9)){j[((d<<2)+f|0)- -64>>2]=c}c=j[e+4>>2]+c|0;d=d+1|0;if((g|0)!=(d|0)){continue}break}break c}if(Qo(f)){break c}break b}Om(a);by(a,f);j[a+4>>2]=0;j[a+8>>2]=j[a>>2];i[a+34>>1]=l[a+34>>1]|2}Za=m+112|0;return}a=J(0)|0;C()|0;ib(a);z()}function LI(a,b,c,d,e,f,g,j){var m=0,n=0,o=0,p=0,q=0,r=0,s=0;o=Za-16|0;Za=o;h[o+15|0]=c;h[o+14|0]=12;Nf(b,k[Yb(o+15|0,o+14|0)|0]);if(sb(b)){c=0;p=a+96|0;a=a+144|0;while(1){a:{b:{c:{switch(j|0){case 0:m=c<<2;n=m+p|0;n=k[n|0]|k[n+1|0]<<8;r=xb(b,c),s=n,i[r>>1]=s;m=(m|2)+p|0;break b;case 1:break c;default:break a}}m=c<<2;n=m+a|0;n=k[n|0]|k[n+1|0]<<8;r=xb(b,c),s=n,i[r>>1]=s;m=a+(m|2)|0}m=k[m|0];r=xb(b,c),s=m,h[r+2|0]=s}d:{if(!c){break d}m=c-1|0;if(l[xb(b,c)>>1]>=l[xb(b,m)>>1]){break d}if(l[xb(b,c)>>1]>255){break d}n=k[xb(b,m)+1|0];q=xb(b,c);i[q>>1]=l[q>>1]|n<<8;if(l[xb(b,c)>>1]>=l[xb(b,m)>>1]){break d}m=xb(b,c);i[m>>1]=l[m>>1]+256}c=c+1|0;if(sb(b)>>>0>c>>>0){continue}break}}h[b+12|0]=0;e:{if(!(d&1)){break e}if(ad(b)){break e}h[b+12|0]=k[b+12|0]|1}if(e>>>0<=11){if(d&2){h[b+12|0]=k[b+12|0]|4}h[b+15|0]=e;h[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){h[b+12|0]=k[b+12|0]|2}h[b+14|0]=g;h[b+13|0]=f}Za=o+16|0}function MM(a,b,c){var d=0;d=k[a|0]&15;h[a|0]=k[d+17520|0];a:{b:{c:{switch(d|0){case 0:if(k[b|0]?c>>>0>=51:0){break b}h[a|0]=0;return;case 5:d=k[b|0];if(!((d&240)!=32?(d&15)!=2:0)){h[a|0]=20;h[b|0]=159;d=159}if(!((d&15)==12|(d&240)==192)|c>>>0<51){break b}h[a|0]=25;h[b|0]=0;return;case 7:if(c>>>0>51){break b}h[a|0]=0;return;case 10:a=k[b|0]&240;if(!a){break b}h[b|0]=a;return;case 11:h[b|0]=p(k[b|0]&15,17);return;case 12:h[b|0]=k[b|0]>>>2;return;case 13:a=k[b|0];h[b|0]=p(a>>>4|0,10)+(a&15);return;case 14:d:{switch((k[b|0]>>>4|0)-1|0){case 0:h[a|0]=2;break a;case 1:h[a|0]=3;break a;case 7:if(c>>>0<52){break b}h[a|0]=20;h[b|0]=k[b|0]&15|96;return;case 8:h[a|0]=15;h[b|0]=k[b|0]&15;return;case 9:h[a|0]=11;h[b|0]=k[b|0]<<4|15;return;case 10:h[a|0]=11;break a;case 11:case 12:break d;default:break b}}h[a|0]=20;return;case 15:break c;default:break b}}if(k[b|0]<48){break b}h[a|0]=17}return}h[b|0]=k[b|0]|240}function z5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0;g=Za-16|0;Za=g;a:{if(j[a+1420>>2]>=0){j[f>>2]=0;a=y5(a,b,c);break a}j[a+100>>2]=0;j[a+32>>2]=b;j[a+40>>2]=b+c;if(!SE(a)){j[f>>2]=0;a=0;break a}if(!x5(a,g+12|0,g+4|0,g+8|0)){b:{c:{d:{c=j[a+100>>2];switch(c-32|0){case 0:break c;case 3:break d;default:break b}}j[a+100>>2]=0;while(1){if(m=0,n=(pg(a)|0)!=-1,o=j[a+96>>2],o?m:n){continue}break}j[f>>2]=0;a=j[a+32>>2]-b|0;break a}if(j[a+992>>2]){break b}j[a+100>>2]=0;while(1){if(m=0,n=(pg(a)|0)!=-1,o=j[a+96>>2],o?m:n){continue}break}j[f>>2]=0;a=j[a+32>>2]-b|0;break a}A5(a);j[a+100>>2]=c;j[f>>2]=0;a=1;break a}i=j[g+4>>2];k=w5(a,j[g+12>>2],i,j[g+8>>2]);j[g+12>>2]=k;h=j[a+4>>2];if((h|0)>=1){c=0;while(1){l=(c<<2)+a|0;j[l+864>>2]=j[l+800>>2]+(i<<2);c=c+1|0;if((h|0)!=(c|0)){continue}break}}if(d){j[d>>2]=h}j[f>>2]=k;j[e>>2]=a+864;a=j[a+32>>2]-b|0}Za=g+16|0;return a|0}function od(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Za+ -64|0;Za=c;j[a+480180>>2]=b;b=to(a);DJ(c,b);e=j[c+12>>2];d=a+1074316|0;j[d>>2]=j[c+8>>2];j[d+4>>2]=e;d=j[c+4>>2];j[a+1074308>>2]=j[c>>2];j[a+1074312>>2]=d;Kr(a+8|0,b);d=l[a+480192>>1];if(d){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=j[e>>2];if(f){Cb(Ns(f));d=l[a+480192>>1]}j[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=d>>>0){continue}break}}j[a+480184>>2]=0;j[a+480188>>2]=0;j[a+480236>>2]=65536;j[a+480228>>2]=48;j[a+480232>>2]=48;h[a+480268|0]=5;j[a+480260>>2]=16;j[a+480264>>2]=32767;j[a+480204>>2]=125e4;j[a+480208>>2]=0;j[a+480196>>2]=6;j[a+480200>>2]=256;j[a+1074300>>2]=0;j[a+1074304>>2]=0;i[a+480192>>1]=0;jx(a,4);Oja(a+484344|0);XL(a+484360|0);De(a+1304400|0);De(a+1304412|0);De(a+1304424|0);b=Ab(c,0,64);c=LJ(b);Kna(a+1304436|0,c);Nr(c);yz(a+1304500|0);es(a+480248|0);if(j[a+480180>>2]&738230281){j[a+480208>>2]=j[a+480208>>2]|8388608}Za=b- -64|0}function fCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=Za-16|0;Za=e;h[e+15|0]=4;i[e+12>>1]=0;j[e+8>>2]=0;if(d){q=p(c,d);t=(q|0)<1;while(1){if(!t){m=b+o|0;u=q+m|0;while(1){h[e+7|0]=0;HO(a,e+14|0,e+12|0,e+7|0);a:{b:{g=k[e+15|0];if(!g){break b}c=l[e+12>>1];while(1){f=c<<1;c=f&254;i[e+12>>1]=c;f=(f&65534)>>>0>255;h[e+14|0]=f;if(!c){if(!re(a,e+6|0)){break b}c=k[e+6|0];f=c>>>7|0;h[e+14|0]=f;c=c<<1&254|1;i[e+12>>1]=c}n=k[e+7|0]<<1|f;h[e+7|0]=n;g=g-1|0;if(g&255){continue}break}break a}n=k[e+7|0]}c=1;g=n&255;c:{if(g>>>0<4){break c}f=7;while(1){c=f;r=c&255;if(r>>>0<2){break c}f=c-1|0;if(!(g&1<<r)){continue}break}}h[e+15|0]=(k[e+15|0]+c&254)>>>1;c=n&1;h[e+14|0]=c;c=c-1^(n&254)>>>1;f=c+k[e+8|0]|0;h[e+7|0]=f;h[m|0]=f;c=(c>>1)-s|0;s=h[e+7|0];j[e+8>>2]=c+(s<<1);Md(e+8|0,-128,127);m=d+m|0;if(u>>>0>m>>>0){continue}break}}o=o+1|0;if((o|0)!=(d|0)){continue}break}}Za=e+16|0}function Lla(a,b){var c=0,d=0,e=0,f=0,g=0,i=0,l=0;d=Za-16|0;Za=d;f=Qc(a);a:{if(nb(b)){while(1){e=j[Li(b,l)>>2];b:{if(e>>>0>=2097152){j[114626]=0;F(118,f|0,63);a=j[114626];j[114626]=0;if((a|0)!=1){break b}break a}a=0;c:{d:{while(1){i=e&63;h[(d+10|0)+a|0]=i;c=a+1|0;e=e>>>6|0;if(!e){break d}a=c;if((a|0)!=6){continue}break}c=7;a=6;break c}e:{if(!a){j[114626]=0;F(118,f|0,h[d+10|0]);break e}if((c|0)!=2){break c}a=1;c=2;if((i|0)!=1){break c}j[114626]=0;F(118,f|0,h[d+10|0]|64)}a=j[114626];j[114626]=0;if((a|0)!=1){break b}break a}e=(-1<<c^-1)<<7-a;i=c+d|0;a=c;while(1){f:{if((a|0)==(c|0)){g=k[i+9|0];j[114626]=0;F(118,f|0,(e|g)<<24>>24);g=j[114626];j[114626]=0;if((g|0)==1){break a}a=a-1|0;break f}j[114626]=0;a=a-1|0;F(118,f|0,h[a+(d+10|0)|0]|-128);g=j[114626];j[114626]=0;if((g|0)==1){break a}}if(a){continue}break}}l=l+1|0;if(nb(b)>>>0>l>>>0){continue}break}}Za=d+16|0;return}a=D()|0;C()|0;gb(f);G(a|0);z()}function Coa(a,b){var c=0,d=0,e=0,f=0,g=0,i=0,l=0;d=Za-16|0;Za=d;f=Db(a);a:{if(nb(b)){while(1){e=j[Li(b,l)>>2];b:{if(e>>>0>=2097152){j[114626]=0;F(110,f|0,63);a=j[114626];j[114626]=0;if((a|0)!=1){break b}break a}a=0;c:{d:{while(1){i=e&63;h[(d+10|0)+a|0]=i;c=a+1|0;e=e>>>6|0;if(!e){break d}a=c;if((a|0)!=6){continue}break}c=7;a=6;break c}e:{if(!a){j[114626]=0;F(110,f|0,h[d+10|0]);break e}if((c|0)!=2){break c}a=1;c=2;if((i|0)!=1){break c}j[114626]=0;F(110,f|0,h[d+10|0]|64)}a=j[114626];j[114626]=0;if((a|0)!=1){break b}break a}e=(-1<<c^-1)<<7-a;i=c+d|0;a=c;while(1){f:{if((a|0)==(c|0)){g=k[i+9|0];j[114626]=0;F(110,f|0,(e|g)<<24>>24);g=j[114626];j[114626]=0;if((g|0)==1){break a}a=a-1|0;break f}j[114626]=0;a=a-1|0;F(110,f|0,h[a+(d+10|0)|0]|-128);g=j[114626];j[114626]=0;if((g|0)==1){break a}}if(a){continue}break}}l=l+1|0;if(nb(b)>>>0>l>>>0){continue}break}}Za=d+16|0;return}a=D()|0;C()|0;gb(f);G(a|0);z()}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;j[114626]=0;N(2081,a|0);e=j[114626];j[114626]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}j[114626]=0;N(2034,b|0);e=j[114626];j[114626]=0;if((e|0)==1){break e}e=0;j[114626]=0;N(2082,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break e}a=Ab(c,0,d);if(!k[b|0]){break b}if(Mh(b,37350)|(d|0)!=8){break d}j[a+4>>2]=2083;j[a>>2]=2084;break c}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37374,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();return 0}if(Mh(b,37362)|(d|0)!=64){break b}j[a+60>>2]=2085;j[a+56>>2]=2086;j[a+52>>2]=2087;j[a+48>>2]=2088;j[a+44>>2]=2089;j[a+40>>2]=2090;j[a+36>>2]=2091;j[a+32>>2]=2092;j[a+28>>2]=2093;j[a+24>>2]=2094;j[a+20>>2]=2095;j[a+16>>2]=2096;j[a+12>>2]=2097;j[a+8>>2]=2098;j[a+4>>2]=2099;j[a>>2]=2100}e=1}return e|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function fea(a,b,c,d){var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=Za-32|0;Za=l;g=j[a>>2];while(1){j[(e<<2)+l>>2]=g+(j[((e<<4)+a|0)+32>>2]^-1);e=e+1|0;if((e|0)!=7){continue}break}if(d){q=i[a+28>>1]/8<<16>>16;while(1){g=0;f=0;e=0;while(1){h=(e<<2)+l|0;k=j[h>>2]+1&8191;j[h>>2]=k;o=f;f=(k<<2)+a|0;k=i[f+160>>1];h=(e<<4)+a|0;n=i[f+162>>1];f=(o+p(k,i[h+44>>1])|0)+p(n,i[h+46>>1])|0;g=(p(k,i[h+40>>1])+g|0)+p(n,i[h+42>>1])|0;e=e+1|0;if((e|0)!=4){continue}break}h=0;e=4;k=Dc((g|0)/32768|0);n=Dc((f|0)/32768|0);g=0;while(1){m=(e<<2)+l|0;f=j[m>>2]+1&8191;j[m>>2]=f;o=g;g=(f<<2)+a|0;m=i[g+160>>1];f=(e<<4)+a|0;r=i[g+162>>1];g=(o+p(m,i[f+44>>1])|0)+p(r,i[f+46>>1])|0;h=(p(i[f+40>>1],m)+h|0)+p(i[f+42>>1],r)|0;e=e+1|0;if((e|0)!=7){continue}break}e=Dc(k+((h|0)/32768|0)|0);i[b>>1]=e;j[c>>2]=p(e,q);e=Dc(n+((g|0)/32768|0)|0);i[b+2>>1]=e;j[c+4>>2]=p(e,q);c=c+8|0;b=b+4|0;d=d-1|0;if(d){continue}break}}Za=l+32|0}function sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,l=0,m=0,o=q(0),p=0,s=0,t=0,u=0,v=0,w=q(0),x=q(0),y=q(0),z=0,A=0,B=q(0);f=Za-16|0;Za=f;a:{if(!j[a+4240>>2]){break a}g=a+44|0;if(!Yg(g)){break a}y=n[a+4220>>2];z=f,A=wd(g,0),j[z+8>>2]=A;z=f,A=wd(g,1),j[z+12>>2]=A;z=f,A=Rc(g,0),j[z>>2]=A;z=f,A=Rc(g,1),j[z+4>>2]=A;if(d){p=a+4208|0;l=d;while(1){h=0;i=1;m=0;while(1){s=(k[a+4264|0]?1-m|0:h)&255;e=j[a+4244>>2]-j[((s<<2)+a|0)+4248>>2]|0;if((e|0)<=-1){e=j[a+4240>>2]+e|0}t=h<<2;u=t+(f+8|0)|0;v=j[u>>2];j[u>>2]=v+4;o=n[v>>2];w=n[xb(p,(e<<1)+s|0)>>2];x=q(q(n[a+4224>>2]*w)+q(o*n[a+4260>>2]));z=xb(p,j[a+4244>>2]<<1|h),B=q(r(x))<q(1.0000000195414814e-24)?q(0):x,n[z>>2]=B;h=f+t|0;e=j[h>>2];j[h>>2]=e+4;n[e>>2]=o+q(q(w-o)*y);m=m+1|0;e=i;i=0;h=1;if(e){continue}break}i=j[a+4244>>2]+1|0;j[a+4244>>2]=(i|0)==j[a+4240>>2]?0:i;l=l-1|0;if(l){continue}break}}Th(a,b,c,Rc(g,0),Rc(g,1),d)}Za=f+16|0}function MD(a,b){var c=0,d=0,e=0,f=0,g=0,i=0,l=0,m=0,n=0;c=Za-32|0;Za=c;a:{if(k[a+52|0]){d=j[a+48>>2];if(!b){break a}h[a+52|0]=0;j[a+48>>2]=-1;break a}j[c+24>>2]=1;e=j[zf(c+24|0,a+44|0)>>2];i=(e|0)>0?e:0;b:{while(1){if((d|0)!=(i|0)){f=Cq(j[a+32>>2]);if((f|0)==-1){break b}h[(c+24|0)+d|0]=f;d=d+1|0;continue}break}c:{if(k[a+53|0]){h[c+23|0]=k[c+24|0];break c}i=c+24|0;while(1){d:{d=j[a+40>>2];f=j[d>>2];l=j[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(LD(j[a+36>>2],g,c+24|0,d,c+16|0,c+23|0,i,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=j[a+40>>2];j[g>>2]=f;j[g+4>>2]=l;if((e|0)==8){break b}f=Cq(j[a+32>>2]);if((f|0)==-1){break b}h[d|0]=f;e=e+1|0;continue}break}h[c+23|0]=k[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((Dq(gg(h[e+(c+24|0)|0]),j[a+32>>2])|0)!=-1){continue}break b}}m=a,n=gg(h[c+23|0]),j[m+48>>2]=n}d=gg(h[c+23|0]);break a}d=-1}Za=c+32|0;return d}function HG(a,b,c,d,e,f,g,h,i){var k=0,l=0,m=0,n=0;k=Za-48|0;Za=k;j[k+44>>2]=0;if(!(i?0:!(d|g|h))){l=Kba(g?k+44|0:0)}if(d){m=bb[d|0](l,e)|0}else{m=3}if(!(!(m&2)|!g)){j[g+16>>2]=l;n=g;g=j[k+44>>2];a:{if(g){g=Gd(g);break a}g=Gd(34181)}j[n+20>>2]=g}if(h){j[h>>2]=l}if(i){g=j[k+44>>2];b:{if(g){g=Gd(g);break b}g=Gd(34181)}j[i>>2]=g}g=j[k+44>>2];if(g){Cb(g);j[k+44>>2]=0}c:{if(!(m&1)){break c}j[114626]=0;F(1983,k+32|0,a|0);g=j[114626];j[114626]=0;d:{e:{if((g|0)!=1){f:{if(f){j[114626]=0;F(1984,f|0,k+32|0);g=j[114626];j[114626]=0;if((g|0)!=1){break f}break e}g=zb(k+32|0);if(b){j[114626]=0;F(b|0,g|0,c|0);g=j[114626];j[114626]=0;if((g|0)==1){break e}break f}mr(g,k)}gb(k+32|0);break c}g=J(0)|0;C()|0;break d}g=J(0)|0;C()|0;gb(k+32|0)}O(g|0)|0;j[k+28>>2]=f;j[k+24>>2]=e;j[k+20>>2]=d;j[k+16>>2]=c;j[k+12>>2]=b;j[k+4>>2]=248;j[k>>2]=37537;j[k+8>>2]=a?a:34181;a=j[13922];tE(a,37407,k);Sq(a);Q()}Za=k+48|0}function _J(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;j[e+12>>2]=b;f=0;a:{if(!b){break a}if(j[a+480180>>2]&20){b=a+1074308|0;mb(e,b,73);if(kb(e)){j[e+12>>2]=l[e+12>>1]}if(k[a+480208|0]&16){mb(e,b,73);b=kb(e);a=j[e+12>>2];f=j[((a>>>0)%768<<2)+22112>>2]<<6>>>(b?14-((9983-a>>>0)/768|0)&31:((a>>>0)/768|0)+2|0)|0;break a}a=j[e+12>>2];if(!a){j[e+12>>2]=1;a=1}f=229079296/(a>>>0)|0;break a}f=227001280/(b>>>0)|0;if(Zs(a)){break a}f=(b+c<<4)-133808|0;if(j[a+480180>>2]==64){break a}b=j[a+480180>>2];kc(e+12|0,16777215);if(b&17408){f=Wc(RMa(OMa(c?c:8363,0,3506176,0),ab,(j[e+12>>2]<<8)+d|0,0),ab);break a}if(k[a+480208|0]&16){mb(e,a+1074308|0,7);if(kb(e)){c=d>>31;b=d;a=j[e+12>>2];d=a>>>24|0;f=a<<8;b=b+f|0;a=c+d|0;a=b>>>0<f>>>0?a+1|0:a;f=(a&15)<<28|b>>>4;break a}f=Wc(RMa(OMa(c?c:8363,0,7012352,0),ab,(j[e+12>>2]<<8)+d|0,0),ab);break a}f=Wc(RMa(-1485242368,13,(j[e+12>>2]<<8)+d|0,0),ab)}Za=e+16|0;return f}function OJ(a,b){var c=0,d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;e=Me(a);f=d,g=nd(b),j[f+8>>2]=g;f=d,g=_e(b),j[f>>2]=g;a:{b:{if(!rb(d+8|0,d)){break b}a=0;b=0;while(1){c=k[j[d+8>>2]];c:{if(!a){if(!(c&128)){a=0;j[114626]=0;F(112,e|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){break c}break a}if((c&224)==192){b=c&31;a=1;break c}if((c&240)==224){b=c&15;a=2;break c}if((c&248)==240){b=c&7;a=3;break c}b=0;j[114626]=0;F(112,e|0,65533);c=j[114626];j[114626]=0;a=0;if((c|0)==1){break a}break c}if((c&192)!=128){j[114626]=0;F(112,e|0,65533);a=j[114626];j[114626]=0;if((a|0)==1){break a}b=c&63;a=-1;break c}c=c&63|b<<6;a=a-1|0;if(a){b=c;break c}b=0;j[114626]=0;F(112,e|0,c|0);c=j[114626];j[114626]=0;a=0;if((c|0)==1){break a}}Xf(d+8|0);if(rb(d+8|0,d)){continue}break}if(!a){break b}j[114626]=0;F(112,e|0,65533);a=j[114626];j[114626]=0;if((a|0)!=1){break b}break a}Za=d+16|0;return}a=D()|0;C()|0;pc(e);G(a|0);z()}function xva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=Za-32|0;Za=e;k=j[a+40>>2];l=j[a+36>>2];n=j[a+16>>2];b=j[a+4>>2];f=b;g=j[a>>2];j[e+24>>2]=g;j[e+28>>2]=b;b=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=b;a:{if(!d){b=k>>12;h=l>>12;break a}while(1){m=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+n|0;b=(g>>>21&2040)+27888|0;g=i[b+6>>1];o=i[b+4>>1];q=i[b+2>>1];r=i[b>>1];h=0;b=1;while(1){f=h<<1;j[(e+8|0)+(h<<2)>>2]=(((p(i[f+m>>1],q)+p(i[(f|-4)+m>>1],r)|0)+p(i[(f|4)+m>>1],o)|0)+p(i[(f|8)+m>>1],g)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=j[a+32>>2];l=j[a+28>>2]+l|0;h=l>>12;j[c>>2]=j[c>>2]+p(h,j[e+8>>2]);k=b+k|0;b=k>>12;j[c+4>>2]=j[c+4>>2]+p(b,j[e+12>>2]);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=j[e+24>>2];f=j[e+28>>2];continue}break}g=j[e+24>>2];f=j[e+28>>2]}j[a+40>>2]=k;j[a+20>>2]=h;j[a+36>>2]=l;j[a+24>>2]=b;j[a>>2]=g;j[a+4>>2]=f;Za=e+32|0}function iCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,m=0,n=0,o=0,q=0,r=0,s=0;e=Za-16|0;Za=e;h[e+15|0]=8;h[e+14|0]=0;i[e+12>>1]=0;if(d){o=p(c,d);while(1){if((o|0)>=1){j=(n<<1)+b|0;r=j+(o<<1)|0;while(1){i[e+10>>1]=0;IO(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{b:{g=k[e+15|0];if(!g){break b}c=l[e+12>>1];while(1){f=c<<1;c=f&254;i[e+12>>1]=c;f=(f&65534)>>>0>255;h[e+14|0]=f;if(!c){if(!re(a,e+9|0)){break b}c=k[e+9|0];f=c>>>7|0;h[e+14|0]=f;c=c<<1&254|1;i[e+12>>1]=c}m=l[e+10>>1]<<1|f;i[e+10>>1]=m;g=g-1|0;if(g&255){continue}break}break a}m=l[e+10>>1]}c=1;g=m&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;q=c&255;if(q>>>0<2){break c}f=c-1|0;if(!(g&1<<q)){continue}break}}h[e+15|0]=(k[e+15|0]+c&254)>>>1;c=m&1;h[e+14|0]=c;c=(c-1^(m&65534)>>>1)+s|0;i[e+10>>1]=c;i[j>>1]=c;s=l[e+10>>1];j=(d<<1)+j|0;if(r>>>0>j>>>0){continue}break}}n=n+1|0;if((n|0)!=(d|0)){continue}break}}Za=e+16|0}function vW(){var a=0,b=0,c=0,d=0;c=Za-32|0;Za=c;a:{a=Eb(c+16|0,10940);if(!nb(a)){break a}b:{if((Ff(a,10946)|0)!=-1){b=Ff(a,10946);j[114626]=0;L(232,c|0,a|0,b+1|0,-1);b=j[114626];j[114626]=0;if((b|0)==1){break b}ob(a,c);gb(c)}if((Ff(a,10948)|0)!=-1){b=Ff(a,10948);j[114626]=0;L(232,c|0,a|0,b+1|0,-1);b=j[114626];j[114626]=0;if((b|0)==1){break b}ob(a,c);gb(c)}if((Ff(a,10950)|0)!=-1){b=Ff(a,10950);j[114626]=0;L(232,c|0,a|0,0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}ob(a,c);gb(c)}if((Ff(a,10952)|0)!=-1){b=Ff(a,10952);j[114626]=0;L(232,c|0,a|0,0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}ob(a,c);gb(c)}if((Ff(a,10954)|0)!=-1){b=Ff(a,10954);j[114626]=0;L(232,c|0,a|0,0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}ob(a,c);gb(c)}j[114626]=0;b=H(233,a|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break a}}c=D()|0;C()|0;gb(a);G(c|0);z()}gb(a);Za=c+32|0;return b|0}function THa(a,b,c){var d=0,e=0,f=0,g=0,i=0,k=0;d=Za-80|0;Za=d;De(b);a:{if(yb(a,1)){b:{c:{d:{e:{f:{g:{while(1){j[114626]=0;e=K(602,a|0,d+16|0,64)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}j[d+8>>2]=e;e=nb(b);j[114626]=0;j[d+4>>2]=c-e;e=E(33,d+8|0,d+4|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break g}e=j[e>>2];if(!e){break b}h[d+8|0]=0;f=e+(d+16|0)|0;e=xm(d+16|0,f,d+8|0);i=d,k=_e(b),j[i+8>>2]=k;Cd(d,d+8|0);j[114626]=0;P(603,b|0,j[d>>2],d+16|0,e|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break f}j[114626]=0;E(338,a|0,e-(d+16|0)|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break e}if(e>>>0>=f>>>0){continue}break}j[114626]=0;E(338,a|0,1)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break b}a=J(71396)|0;break c}a=J(71396)|0;break c}a=J(71396)|0;break c}a=J(71396)|0;break c}a=J(71396)|0}if((C()|0)!=(W(71396)|0)){break a}O(a|0)|0;Q()}e=(nb(b)|0)!=0}Za=d+80|0;return e}G(a|0);z()}function Mk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,l=0;Dj(a);a:{b:{c:{g=j[b+32>>2];d:{if(!g){d=j[b+2084>>2];if(d){break d}break b}f=j[b+4>>2];if((f|0)<9){break c}d=j[b+2084>>2];if(!d){break c}}h=j[a+1392>>2];l=Lk(h);e=j[b+2092>>2];if((e|0)>=2){while(1){f=e>>>1|0;i=f+c|0;g=l>>>0<m[(i<<2)+d>>2];c=g?c:i;e=g?f:e-f|0;if((e|0)>1){continue}break}}e=a;d=j[a+1396>>2];c=k[b+23|0]?c:j[j[b+2088>>2]+(c<<2)>>2];b=k[c+j[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;a=0;break e}j[a+1392>>2]=h>>>b;a=d-b|0}j[e+1396>>2]=a;return c}if(k[b+23|0]){break a}if((f|0)>=1){d=j[b+8>>2];while(1){f:{e=k[c+d|0];if((e|0)==255){break f}h=j[a+1392>>2];if(j[g+(c<<2)>>2]!=(h&(-1<<e^-1))){break f}d=j[a+1396>>2];if((d|0)>=(e|0)){j[a+1392>>2]=h>>>e;j[a+1396>>2]=d-k[j[b+8>>2]+c|0];return c}j[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}Nb(a,21);j[a+1396>>2]=0}return-1}X(50714,50496,1690,50725);z()}function JD(a,b){var c=0,d=0,e=0,f=0,g=0,i=0,l=0;c=Za-32|0;Za=c;a:{if(k[a+52|0]){d=j[a+48>>2];if(!b){break a}h[a+52|0]=0;j[a+48>>2]=-1;break a}j[c+24>>2]=1;e=j[zf(c+24|0,a+44|0)>>2];i=(e|0)>0?e:0;b:{while(1){if((d|0)!=(i|0)){f=Cq(j[a+32>>2]);if((f|0)==-1){break b}h[(c+24|0)+d|0]=f;d=d+1|0;continue}break}c:{if(k[a+53|0]){j[c+20>>2]=h[c+24|0];break c}i=c+24|0;while(1){d:{d=j[a+40>>2];f=j[d>>2];l=j[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(LD(j[a+36>>2],g,c+24|0,d,c+16|0,c+20|0,i,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=j[a+40>>2];j[g>>2]=f;j[g+4>>2]=l;if((e|0)==8){break b}f=Cq(j[a+32>>2]);if((f|0)==-1){break b}h[d|0]=f;e=e+1|0;continue}break}j[c+20>>2]=h[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((Dq(h[e+(c+24|0)|0],j[a+32>>2])|0)!=-1){continue}break b}}j[a+48>>2]=j[c+20>>2]}d=j[c+20>>2];break a}d=-1}Za=c+32|0;return d}function yva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=Za-32|0;Za=e;l=j[a+40>>2];m=j[a+36>>2];o=j[a+16>>2];b=j[a+4>>2];g=b;k=j[a>>2];j[e+24>>2]=k;j[e+28>>2]=b;b=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=b;a:{if(!d){f=l>>12;b=m>>12;break a}while(1){n=(((g&2147483647)<<1|k>>>31)&-2)+o|0;b=(k>>>21&2040)+27888|0;k=i[b+6>>1];q=i[b+4>>1];r=i[b+2>>1];s=i[b>>1];f=0;b=1;while(1){j[(e+8|0)+(f<<2)>>2]=(((p(h[f+n|0],r)+p(h[(f|-2)+n|0],s)|0)+p(h[(f|2)+n|0],q)|0)+p(h[(f|4)+n|0],k)<<8)/16384;g=b;b=0;f=1;if(g){continue}break}g=j[a+32>>2];m=j[a+28>>2]+m|0;b=m>>12;j[c>>2]=j[c>>2]+p(b,j[e+8>>2]);l=g+l|0;f=l>>12;j[c+4>>2]=j[c+4>>2]+p(f,j[e+12>>2]);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=j[e+24>>2];g=j[e+28>>2];continue}break}k=j[e+24>>2];g=j[e+28>>2]}j[a+40>>2]=l;j[a+20>>2]=b;j[a+36>>2]=m;j[a+24>>2]=f;j[a>>2]=k;j[a+4>>2]=g;Za=e+32|0}function qka(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;n=Za-16|0;Za=n;if(ke(a)){d=l[a+34>>1];h=j[a+8>>2];o=j[a+4>>2];k=j[a>>2];r=!(d&2)|(h>>>0<=o>>>0|k>>>0<h>>>0);i=j[a+16>>2];p=j[a+12>>2];s=!(d&8)|(i>>>0<=p>>>0|i>>>0>k>>>0);t=b+1304360|0;b=b+1074984|0;u=d&4;v=d&16;while(1){a:{if(j[b+104>>2]!=(a|0)){break a}d=j[b+76>>2];if(!d){break a}b:{c:{d:{e=b;e:{f:{if(s){break f}c=j[b+88>>2];if(c&2048){break f}j[b+84>>2]=i;j[b+80>>2]=p;g=v;d=i;break e}if(r){break d}j[b+84>>2]=h;j[b+80>>2]=o;c=j[b+88>>2];g=u;d=h}j[e+76>>2]=d;f=c|2;j[b+88>>2]=f;q=b+88|0;e=1;if(!g){break c}c=c|6;e=1;g=1;break b}f=j[b+88>>2]&-3;j[b+88>>2]=f;q=b+88|0;e=0}c=f&-5;g=0}j[b+88>>2]=c;if(m[b+4>>2]>d>>>0){c=c&-129;j[b+88>>2]=c;f=j[b+80>>2];j[b>>2]=0;j[b+4>>2]=f}if(!g){j[q>>2]=c&-129}if(e){break a}j[b+76>>2]=k}b=b+896|0;if((t|0)!=(b|0)){continue}break}}Za=n+16|0}function Kba(a){var b=0,c=0,d=0,e=0;a:{if(!a){break a}c=j[a>>2];if(!c){break a}Cb(c);j[a>>2]=0}j[114626]=0;M(81);c=j[114626];j[114626]=0;e=a;b:{c:{d:{if((c|0)==1){d=Qa(71396,83516,83528,83632,71552,71656,71604,71496,71484,71800,71768,71736,71724,71372,0)|0;a=277;b=C()|0;if((b|0)==(W(71396)|0)){break d}a=358;if((W(83516)|0)==(b|0)){break d}a=359;if((W(83528)|0)==(b|0)){break d}a=357;if((W(83632)|0)==(b|0)){break d}a=300;if((W(71552)|0)==(b|0)){break d}a=299;if((W(71656)|0)==(b|0)){break d}a=298;if((W(71604)|0)==(b|0)){break d}a=297;if((W(71496)|0)==(b|0)){break d}a=296;if((W(71484)|0)==(b|0)){break d}a=289;if((W(71800)|0)==(b|0)){break d}a=288;if((W(71768)|0)==(b|0)){break d}a=287;if((W(71736)|0)==(b|0)){break d}a=286;if((W(71724)|0)==(b|0)){break d}c=257;a=267;b=(W(71372)|0)==(b|0);d=O(d|0)|0;if(b){break c}break b}z()}d=O(d|0)|0}Iba(e,d);c=a}Q();return c}function lM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;h[a+15|0]=0;h[a+16|0]=0;h[a+17|0]=0;h[a+18|0]=0;h[a+19|0]=0;h[a+20|0]=0;h[a+21|0]=0;h[a+22|0]=0;h[a+14|0]=5;i[a+12>>1]=0;j[a+8>>2]=128;j[a>>2]=256;j[a+4>>2]=64;j[a+28>>2]=0;h[a+27|0]=60;j[a+40>>2]=0;j[a+44>>2]=0;h[a+33|0]=2;h[a+34|0]=0;h[a+35|0]=0;h[a+36|0]=2;h[a+23|0]=0;h[a+24|0]=0;h[a+25|0]=255;h[a+26|0]=0;h[a+32|0]=0;d=Tx(a+48|0);e=Tx(a+68|0);f=Tx(a+88|0);j[114626]=0;H(1157,a+492|0)|0;c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;H(1157,a+524|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}j[114626]=0;I(905,a|0,0,0);c=j[114626];j[114626]=0;if((c|0)==1){break a}j[114626]=0;I(906,a|0,0,0);c=j[114626];j[114626]=0;if((c|0)==1){break a}j[a+40>>2]=0;j[a+44>>2]=0;j[114626]=0;F(776,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}Zta(a);return a|0}a=D()|0;C()|0;Um(f);Um(e);Um(d);G(a|0);z()}function wK(a,b){var c=0,d=0,e=0,f=0,g=0;d=l[a+480188>>1];a:{if(d>>>0<=255){f=a+1304392|0;while(1){e=p(d,896)+a|0;c=e+1075060|0;b:{if(j[c>>2]){break b}if(!Qi(e+1074984|0)){break a}if(j[c>>2]){break b}if(k[e+1075073|0]&24){break a}}if(k[e+1075073|0]&2){if(!bd(f)){break a}if(!vK(j[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=p(b,896)+a|0;if(!j[b+1075680>>2]){d=65535;if(j[b+1075060>>2]){break a}}g=j[b+1075672>>2]|j[b+1075664>>2]<<9}d=65535;b=l[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=p(b,896)+a|0;if(!(j[c+1075680>>2]?0:j[c+1075060>>2])){f=(j[c+1075672>>2]|j[c+1075664>>2]<<9)>>>(j[c+1075072>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=j[c+1075712>>2];break d}if((f|0)!=(g|0)){break c}c=j[c+1075712>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function zv(a){var b=0,c=0,d=0,e=0,f=0,g=0;YMa(+a);e=VMa(1)|0;VMa(0)|0;b=e;e=b>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=b&2147483647;g:{if(b>>>0>=1082532651){YMa(+a);b=VMa(1)|0;b=b&2147483647;if((b|0)==2146435072&(VMa(0)|0)!=0|b>>>0>2146435072){return a}if(!(a>709.782712893384^1)){return a*8.98846567431158e+307}if(!(a<-745.1332191019411)|a<-708.3964185322641^1){break g}break b}if(b>>>0<1071001155){break d}if(b>>>0<1072734898){break f}}a=a*1.4426950408889634+o[(e<<3)+52256>>3];if(r(a)<2147483648){b=~~a;break e}b=-2147483648;break e}b=(e^1)-e|0}c=+(b|0);a=d+c*-.6931471803691238;f=c*1.9082149292705877e-10;d=a-f;break c}if(b>>>0<=1043333120){break a}b=0;d=a}c=d;g=a;c=c*c;a=d-c*(c*(c*(c*(c*4.1381367970572385e-8+ -16533902205465252e-22)+6613756321437934e-20)+ -.0027777777777015593)+.16666666666666602);c=g+(d*a/(2-a)-f)+1;if(!b){break b}c=Bh(c,b)}return c}return a+1}function Jq(a){a=a|0;var b=0,c=0,d=0,e=0;d=Za-16|0;Za=d;c=j[j[a>>2]-12>>2];j[114626]=0;c=j[(a+c|0)+24>>2];b=j[114626];j[114626]=0;a:{b:{c:{d:{e:{if((b|0)!=1){if(!c){break b}j[114626]=0;c=E(15,d+8|0,a|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}if(!k[c|0]){break e}b=j[j[a>>2]-12>>2];j[114626]=0;b=j[(a+b|0)+24>>2];e=j[114626];j[114626]=0;f:{if((e|0)==1){break f}j[114626]=0;b=H(2307,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break f}if((b|0)!=-1){break e}b=j[j[a>>2]-12>>2];j[114626]=0;F(18,a+b|0,1);b=j[114626];j[114626]=0;if((b|0)!=1){break e}}b=J(0)|0;C()|0;nf(c);break c}b=J(0)|0;C()|0;break c}nf(c);break b}b=J(0)|0;C()|0}O(b|0)|0;c=j[j[a>>2]-12>>2];j[114626]=0;N(19,a+c|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}Q()}Za=d+16|0;return a|0}a=D()|0;C()|0;j[114626]=0;M(20);c=j[114626];j[114626]=0;if((c|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function lca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-32|0;Za=e;j[114626]=0;N(2008,a|0);d=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}j[114626]=0;N(2034,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break g}j[114626]=0;N(2034,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break g}d=j[a+24>>2];j[114626]=0;b=E(85,e+16|0,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break g}j[114626]=0;c=E(85,e|0,c|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break f}j[114626]=0;L(2074,d|0,b|0,c|0,1);d=j[114626];j[114626]=0;if((d|0)==1){break e}gb(c);gb(b);b=1;break b}d=J(0)|0;C()|0;break c}d=J(0)|0;C()|0;break d}d=J(0)|0;C()|0;gb(c)}gb(b)}O(d|0)|0;b=0;j[114626]=0;L(1982,37079,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=e+32|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function fxa(a,b,c){var d=0,e=0,f=0,g=0,i=0,j=0;d=Za-16|0;Za=d;g=1;f=a;e=dd(b);if((e|0)==252){g=dd(b);e=dd(b)}h[f|0]=(e-1&255)>>>0<60?e+36|0:0;nn(d+8|0,b);b=Pc(d+8|0);f=Bf(d+8|0);e=pi(d+8|0);h[a+1|0]=k[d+8|0];h[d+7|0]=k[b|0]&15;h[d+6|0]=k[b|0]>>>4;h[d+5|0]=k[f|0];h[d+4|0]=k[e|0];MM(d+7|0,d+5|0,c);MM(d+6|0,d+4|0,c);a:{b:{c:{d:{e=k[d+7|0];c=(e|0)!=10;b=k[d+6|0];if(!(c|(b|0)!=10)){h[d+7|0]=0;i=d,j=Vm((k[d+4|0]|k[d+5|0]<<8)>>>6|0),h[i+5|0]=j;break d}if(!c){i=d,j=Vm(k[d+5|0]<<2),h[i+5|0]=j;break d}if((b|0)==10){i=d,j=Vm(k[d+4|0]<<2),h[i+4|0]=j;break d}if((b|0)!=(e|0)){break d}h[d+6|0]=0;break c}b=k[d+6|0];if((b|0)==13){break b}if(b){break a}e=k[d+7|0]}if((e&255)==13){break a}}Tg(d+7|0,d+6|0);Tg(d+5|0,d+4|0)}Jw(d+6|0,d+4|0,d+7|0,d+5|0);Iw(d,d+7|0,d+5|0,d+6|0,d+4|0);h[a+2|0]=k[d+7|0];h[a+4|0]=k[d+5|0];h[a+3|0]=k[d+6|0];h[a+5|0]=k[d+4|0];Za=d+16|0;return g}function S3(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-32|0;Za=c;j[c+28>>2]=0;a:{b:{if(k[Ji(c+24|0,a,0)|0]){hc(c+16|0,j[j[a>>2]-12>>2]+a|0);j[114626]=0;d=H(2308,c+16|0)|0;e=j[114626];j[114626]=0;c:{d:{e:{f:{if((e|0)==1){break f}e=dm(c+8|0,a);f=ck(c);g=j[j[a>>2]-12>>2];f=j[f>>2];e=j[e>>2];j[114626]=0;_(2311,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break f}wb(c+16|0);break e}b=J(0)|0;C()|0;wb(c+16|0);O(b|0)|0;b=j[c+28>>2]|1;j[c+28>>2]=b;Hi(j[j[a>>2]-12>>2]+a|0,b);b=j[j[a>>2]-12>>2];j[114626]=0;b=j[(a+b|0)+20>>2];d=j[114626];j[114626]=0;if((d|0)!=1){if(!(b&1)){break d}j[114626]=0;M(81);a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}d=j[c+20>>2];j[b>>2]=d;break c}Q()}eg(j[j[a>>2]-12>>2]+a|0,j[c+28>>2])}Za=c+32|0;return a}a=J(0)|0;C()|0;ib(a)}z()}function Gca(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-16|0;Za=d;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;F(2054,d|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break i}if(cc(d)>>>0<2147483647){break h}c=R(8)|0;j[114626]=0;E(2055,c|0,36392)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;I(2002,c|0,71724,265);b=j[114626];j[114626]=0;if((b|0)!=1){break b}b=J(0)|0;C()|0;break f}b=J(0)|0;C()|0;break e}b=J(0)|0;C()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((cc(d)|0)<=(b|0)){break j}a=zb(Zc(d,b))}b=Gd(a);Uc(d);break d}b=J(0)|0;C()|0;S(c|0)}Uc(d)}O(b|0)|0;b=0;j[114626]=0;L(1982,36407,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Q()}Za=d+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){break a}a=J(0)|0;C()|0;ib(a)}z()}G(a|0);z()}function Fca(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-16|0;Za=d;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;F(2056,d|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break i}if(cc(d)>>>0<2147483647){break h}c=R(8)|0;j[114626]=0;E(2055,c|0,36392)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;I(2002,c|0,71724,265);b=j[114626];j[114626]=0;if((b|0)!=1){break b}b=J(0)|0;C()|0;break f}b=J(0)|0;C()|0;break e}b=J(0)|0;C()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((cc(d)|0)<=(b|0)){break j}a=zb(Zc(d,b))}b=Gd(a);Uc(d);break d}b=J(0)|0;C()|0;S(c|0)}Uc(d)}O(b|0)|0;b=0;j[114626]=0;L(1982,36439,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Q()}Za=d+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){break a}a=J(0)|0;C()|0;ib(a)}z()}G(a|0);z()}function Eca(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-16|0;Za=d;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;F(2057,d|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break i}if(cc(d)>>>0<2147483647){break h}c=R(8)|0;j[114626]=0;E(2055,c|0,36392)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;I(2002,c|0,71724,265);b=j[114626];j[114626]=0;if((b|0)!=1){break b}b=J(0)|0;C()|0;break f}b=J(0)|0;C()|0;break e}b=J(0)|0;C()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((cc(d)|0)<=(b|0)){break j}a=zb(Zc(d,b))}b=Gd(a);Uc(d);break d}b=J(0)|0;C()|0;S(c|0)}Uc(d)}O(b|0)|0;b=0;j[114626]=0;L(1982,36471,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Q()}Za=d+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){break a}a=J(0)|0;C()|0;ib(a)}z()}G(a|0);z()}function Dca(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-16|0;Za=d;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;F(2058,d|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break i}if(cc(d)>>>0<2147483647){break h}c=R(8)|0;j[114626]=0;E(2055,c|0,36392)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;I(2002,c|0,71724,265);b=j[114626];j[114626]=0;if((b|0)!=1){break b}b=J(0)|0;C()|0;break f}b=J(0)|0;C()|0;break e}b=J(0)|0;C()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((cc(d)|0)<=(b|0)){break j}a=zb(Zc(d,b))}b=Gd(a);Uc(d);break d}b=J(0)|0;C()|0;S(c|0)}Uc(d)}O(b|0)|0;b=0;j[114626]=0;L(1982,36501,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Q()}Za=d+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){break a}a=J(0)|0;C()|0;ib(a)}z()}G(a|0);z()}function Bca(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-16|0;Za=d;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;F(2059,d|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break i}if(cc(d)>>>0<2147483647){break h}c=R(8)|0;j[114626]=0;E(2055,c|0,36392)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;I(2002,c|0,71724,265);b=j[114626];j[114626]=0;if((b|0)!=1){break b}b=J(0)|0;C()|0;break f}b=J(0)|0;C()|0;break e}b=J(0)|0;C()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((cc(d)|0)<=(b|0)){break j}a=zb(Zc(d,b))}b=Gd(a);Uc(d);break d}b=J(0)|0;C()|0;S(c|0)}Uc(d)}O(b|0)|0;b=0;j[114626]=0;L(1982,36533,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Q()}Za=d+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){break a}a=J(0)|0;C()|0;ib(a)}z()}G(a|0);z()}function Aca(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-16|0;Za=d;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;F(2060,d|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break i}if(cc(d)>>>0<2147483647){break h}c=R(8)|0;j[114626]=0;E(2055,c|0,36392)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;I(2002,c|0,71724,265);b=j[114626];j[114626]=0;if((b|0)!=1){break b}b=J(0)|0;C()|0;break f}b=J(0)|0;C()|0;break e}b=J(0)|0;C()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((cc(d)|0)<=(b|0)){break j}a=zb(Zc(d,b))}b=Gd(a);Uc(d);break d}b=J(0)|0;C()|0;S(c|0)}Uc(d)}O(b|0)|0;b=0;j[114626]=0;L(1982,36568,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Q()}Za=d+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){break a}a=J(0)|0;C()|0;ib(a)}z()}G(a|0);z()}function fI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,l=0;d=Za-32|0;Za=d;j[114626]=0;g=E(15,d+24|0,a|0)|0;e=j[114626];j[114626]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!k[g|0]){break e}e=sk(d+8|0,a);h=j[(j[j[a>>2]-12>>2]+a|0)+4>>2];f=j[j[a>>2]-12>>2];j[114626]=0;f=a+f|0;i=H(16,f|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break d}e=j[e>>2];j[114626]=0;c=b+c|0;b=_(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break d}j[d+16>>2]=b;if(!rk(d+16|0)){break e}b=j[j[a>>2]-12>>2];j[114626]=0;F(18,a+b|0,5);b=j[114626];j[114626]=0;if((b|0)!=1){break e}break d}nf(g);break b}b=J(0)|0;C()|0;nf(g);break c}b=J(0)|0;C()|0}O(b|0)|0;b=j[j[a>>2]-12>>2];j[114626]=0;N(19,a+b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}Q()}Za=d+32|0;return a}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){a=J(0)|0;C()|0;ib(a);z()}G(a|0);z()}function WE(a,b,c,d){var e=0,f=0,g=0,h=q(0),i=0,j=q(0),k=0,l=q(0),m=q(0),o=q(0),p=0;e=Za-96|0;Za=e;if((d|0)>=1){while(1){n[e+48>>2]=-n[a>>2];n[e>>2]=n[a+68>>2];f=0;while(1){g=f<<3;i=f<<4;j=n[(i|8)+a>>2];h=n[(i|4)+a>>2];n[(e+48|0)+(g|4)>>2]=j+h;k=f<<1;n[(8-k<<2)+e>>2]=h-j;j=n[(a+i|0)+16>>2];h=n[(i|12)+a>>2];n[(7-k<<2)+e>>2]=j-h;n[(e+g|0)+56>>2]=-q(h+j);f=f+1|0;if((f|0)!=4){continue}break}VE(e+48|0);VE(e);n[e+4>>2]=-n[e+4>>2];n[e+12>>2]=-n[e+12>>2];n[e+20>>2]=-n[e+20>>2];n[e+28>>2]=-n[e+28>>2];i=0;while(1){f=i<<2;g=f+b|0;j=n[g>>2];k=g;h=n[f+48928>>2];l=n[f+(e+48|0)>>2];m=n[e+f>>2];g=f+36|0;o=n[g+48928>>2];n[k>>2]=q(h*l)-q(m*o);k=a+f|0;f=c+f|0;g=c+g|0;h=q(q(h*m)+q(o*l));n[k>>2]=q(j*n[f>>2])-q(n[g>>2]*h);n[(17-i<<2)+a>>2]=q(n[f>>2]*h)+q(j*n[g>>2]);i=i+1|0;if((i|0)!=9){continue}break}b=b+36|0;a=a+72|0;p=p+1|0;if((p|0)!=(d|0)){continue}break}}Za=e+96|0}function hCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=Za-16|0;Za=e;h[e+15|0]=4;h[e+14|0]=0;i[e+12>>1]=0;if(d){o=p(c,d);r=(o|0)<1;while(1){if(!r){j=b+n|0;s=o+j|0;while(1){h[e+11|0]=0;HO(a,e+14|0,e+12|0,e+11|0);a:{b:{g=k[e+15|0];if(!g){break b}c=l[e+12>>1];while(1){f=c<<1;c=f&254;i[e+12>>1]=c;f=(f&65534)>>>0>255;h[e+14|0]=f;if(!c){if(!re(a,e+10|0)){break b}c=k[e+10|0];f=c>>>7|0;h[e+14|0]=f;c=c<<1&254|1;i[e+12>>1]=c}m=k[e+11|0]<<1|f;h[e+11|0]=m;g=g-1|0;if(g&255){continue}break}break a}m=k[e+11|0]}c=1;g=m&255;c:{if(g>>>0<4){break c}f=7;while(1){c=f;q=c&255;if(q>>>0<2){break c}f=c-1|0;if(!(g&1<<q)){continue}break}}h[e+15|0]=(k[e+15|0]+c&254)>>>1;c=m&1;h[e+14|0]=c;c=(c-1^(m&254)>>>1)+t|0;h[e+11|0]=c;h[j|0]=c;t=k[e+11|0];j=d+j|0;if(s>>>0>j>>>0){continue}break}}n=n+1|0;if((n|0)!=(d|0)){continue}break}}Za=e+16|0}function oH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=q(0);b=Za-32|0;Za=b;e=j[a+20>>2];a:{if(!e){break a}if(tc(e+4|0)>>>0<4){break a}xi(b+8|0,j[a+20>>2]+4|0);e=xga(b+16|0,b+8|0);j[114626]=0;d=H(390,e|0)|0;c=j[114626];j[114626]=0;b:{if((c|0)!=1){if(d){break b}d=j[j[a>>2]+40>>2];j[114626]=0;d=H(d|0,a|0)|0;c=j[114626];j[114626]=0;c:{if((c|0)==1){break c}if(tc(j[a+20>>2]+4|0)-4>>>0<d<<2>>>0){break b}c=j[j[a>>2]+168>>2];j[114626]=0;F(c|0,a|0,-1);c=j[114626];j[114626]=0;if((c|0)==1){break c}if(d){c=0;while(1){j[114626]=0;g=q(oa(700,e|0));f=j[114626];j[114626]=0;if((f|0)==1){break c}f=j[j[a>>2]+44>>2];j[114626]=0;ma(f|0,a|0,c|0,q(g));f=j[114626];j[114626]=0;if((f|0)==1){break c}c=c+1|0;if((d|0)!=(c|0)){continue}break}}d=j[j[a>>2]+172>>2];j[114626]=0;N(d|0,a|0);a=j[114626];j[114626]=0;if((a|0)!=1){break b}}}a=D()|0;C()|0;jb(e);G(a|0);z()}jb(e)}Za=b+32|0}function fK(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{if(j[a+480180>>2]==4){d=k[b+833|0];if(c){h[b+833|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(j[a+480180>>2]!=1048576){break a}if(c){h[b+833|0]=c;break a}c=k[b+833|0]}b:{if(!(h[b+872|0]&1)|!(c&255)){break b}d=j[b+700>>2];if(!d){break b}c:{if(!(k[a+480208|0]&16)){break c}d=j[b+700>>2];if(j[a+480180>>2]==4){break c}c=qx(a,c&15);f=OMa(c,c>>31,d,d>>31)+32768|0;c=ab;c=ic(PMa(f,f>>>0<32768?c+1|0:c,65536,0),ab);j[b+700>>2]=c;if((c|0)!=(d|0)){break b}a=a+1074308|0;mb(e+8|0,a,7);if(!(!kb(e+8|0)|j[b+700>>2]==2147483647)){j[b+700>>2]=j[b+700>>2]+1;break b}mb(e+8|0,a,7);if(kb(e+8|0)){break b}a=j[b+700>>2];if((a|0)<2){break b}j[b+700>>2]=a-1;break b}c=d-((c&255)<<2)|0;j[b+700>>2]=c;if((c|0)>0){break b}j[b+700>>2]=1;if(j[a+480180>>2]!=2){break b}j[b+696>>2]=0;j[b+88>>2]=j[b+88>>2]|2101248}Za=e+16|0}function Ela(a,b,c,d){var e=0;e=Za-48|0;Za=e;a=Db(a);a:{b:{b=b-1|0;switch(b|0){case 0:case 3:break b;default:break a}}d=d?d-1|0:0}c:{d:{e:{f:{g:{h:{i:{j:{switch(b|0){case 0:case 1:h[e+32|0]=0;b=xm(c,c+d|0,e+32|0);j[114626]=0;K(119,a|0,c|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break i}b=D()|0;C()|0;break c;case 2:case 3:break j;default:break i}}j[114626]=0;K(119,a|0,c|0,c+d|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break h}ela(nd(a),_e(a),nd(a));j[114626]=0;c=E(120,e+16|0,a|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break g}j[114626]=0;d=E(85,e|0,6640)|0;b=j[114626];j[114626]=0;if((b|0)==1){break f}j[114626]=0;I(121,e+32|0,c|0,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break e}ob(a,e+32|0);gb(e+32|0);gb(d);gb(c)}Za=e+48|0;return}b=D()|0;C()|0;break c}b=D()|0;C()|0;break c}b=D()|0;C()|0;break d}b=D()|0;C()|0;gb(d)}gb(c)}gb(a);G(b|0);z()}function AU(a,b,c,d){var e=0,f=0,g=0,i=0,l=0,n=0,o=0,p=0;e=Za-32|0;Za=e;h[e+24|0]=k[a|0];h[e+25|0]=k[a+1|0];h[e+26|0]=k[a+2|0];h[e+27|0]=k[a+3|0];f=LA(e+8|0);b=a+b|0;j[f+12>>2]=b-4;j[f+8>>2]=a;vi(f,k[b-1|0]);a:{if(!d){break a}a=d;while(1){if(!vi(f,1)){j[e+4>>2]=1;while(1){b=vi(f,2);j[e+4>>2]=b+j[e+4>>2];if((b|0)==3){continue}break}kc(e+4|0,a);b=0;if(j[e+4>>2]){while(1){a=a-1|0;o=c+a|0,p=vi(f,8),h[o|0]=p;b=b+1|0;if(b>>>0<m[e+4>>2]){continue}break}}if(!a){break a}}b=vi(f,2);j[e+4>>2]=b+2;b:{if((b|0)==3){b=f;i=b;g=7;c:{if(!vi(b,1)){break c}g=k[Pb(e+24|0,3)|0]}g=vi(i,g);while(1){b=vi(f,3);j[e+4>>2]=b+j[e+4>>2];if((b|0)==7){continue}break}break b}g=vi(f,k[Pb(e+24|0,b)|0])}kc(e+4|0,a);i=0;l=j[e+4>>2];if(l){while(1){b=0;n=a+g|0;if(n>>>0<d>>>0){b=k[c+n|0]}a=a-1|0;h[c+a|0]=b;i=i+1|0;if((l|0)!=(i|0)){continue}break}}if(a){continue}break}}Za=e+32|0}function DJ(a,b){var c=0;c=Za-16|0;Za=c;a=mx(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}vb(a,7,1);vb(a,9,1);vb(a,10,1);vb(a,13,1);vb(a,15,1);vb(a,16,1);vb(a,17,1);vb(a,18,1);vb(a,20,1);vb(a,21,1);vb(a,24,1);vb(a,25,1);vb(a,26,1);vb(a,28,1);vb(a,30,1);vb(a,31,1);vb(a,33,1);vb(a,34,1);vb(a,39,1);vb(a,41,1);vb(a,44,1);vb(a,46,1);vb(a,45,1);vb(a,47,1);vb(a,48,1);vb(a,50,1);vb(a,99,1);vb(a,102,1);vb(a,104,1);vb(a,105,1);vb(a,108,1);break a;case 1:ix(c,2);b=j[c+12>>2];j[a+8>>2]=j[c+8>>2];j[a+12>>2]=b;b=j[c+4>>2];j[a>>2]=j[c>>2];j[a+4>>2]=b;rg(a,107);break a;case 3:ix(c,4);b=j[c+12>>2];j[a+8>>2]=j[c+8>>2];j[a+12>>2]=b;b=j[c+4>>2];j[a>>2]=j[c>>2];j[a+4>>2]=b;rg(a,4);break a;case 2:break b;case 0:break c}}vb(a,88,1);break a}ix(c,b);b=j[c+12>>2];j[a+8>>2]=j[c+8>>2];j[a+12>>2]=b;b=j[c+4>>2];j[a>>2]=j[c>>2];j[a+4>>2]=b}Za=c+16|0}function Sua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0;g=Za-16|0;Za=g;k=j[a+40>>2];l=j[a+36>>2];n=j[a+16>>2];h=j[a+4>>2];e=h;f=j[a>>2];j[g+8>>2]=f;j[g+12>>2]=e;h=j[a+12>>2];j[g>>2]=j[a+8>>2];j[g+4>>2]=h;a:{if(!d){h=k>>12;m=l>>12;break a}while(1){h=j[a+32>>2];l=j[a+28>>2]+l|0;m=l>>12;e=(e<<1)+n|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((p(i[e+4>>1],i[f+34>>1])+p(i[e+2>>1],i[f+32>>1])|0)+p(i[e+6>>1],i[f+36>>1])|0)+p(i[e+8>>1],i[f+38>>1])|0)/2|0)+((((p(i[e-4>>1],i[f+26>>1])+p(i[e-6>>1],i[f+24>>1])|0)+p(i[e-2>>1],i[f+28>>1])|0)+p(i[e>>1],i[f+30>>1])|0)/2|0)|0)/16384|0;j[c>>2]=j[c>>2]+p(m,e);k=h+k|0;h=k>>12;j[c+4>>2]=j[c+4>>2]+p(e,h);Bb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=j[g+8>>2];e=j[g+12>>2];continue}break}f=j[g+8>>2];e=j[g+12>>2]}j[a+40>>2]=k;j[a+20>>2]=m;j[a+36>>2]=l;j[a+24>>2]=h;j[a>>2]=f;j[a+4>>2]=e;Za=g+16|0}function qy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Za-80|0;Za=d;a:{b:{e=j[a+4>>2];if(e>>>0<b>>>0){g=wf(d+72|0);f=b-e|0;b=zs(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){Wj(d+56|0,a);b=j[d+60>>2];j[d+72>>2]=j[d+56>>2];j[d+76>>2]=b;j[a+4>>2]=j[a+4>>2]+f;break b}hb(a);b=py(d+56|0);e=j[a+4>>2];j[114626]=0;e=E(928,a|0,e+f|0)|0;h=j[114626];j[114626]=0;c:{if((h|0)==1){break c}j[114626]=0;F(929,b|0,e|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[b+4>>2]=j[a+4>>2]+f;Xi(d+40|0,a);Wj(d+32|0,a);Xi(d+24|0,b);j[114626]=0;e=j[d+44>>2];j[d+8>>2]=j[d+40>>2];j[d+12>>2]=e;e=j[d+36>>2];j[d>>2]=j[d+32>>2];j[d+4>>2]=e;L(930,d+48|0,d+8|0,d|0,d+24|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}e=j[d+52>>2];j[d+72>>2]=j[d+48>>2];j[d+76>>2]=e;oy(a,b);Vd(b);break b}a=D()|0;C()|0;Vd(b);G(a|0);z()}j[a+4>>2]=b;break a}Fp(vd(d+16|0,g),f,c)}Za=d+80|0}function EG(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var k=0,l=0;k=Za+ -64|0;Za=k;j[k+60>>2]=e;e=j[a+4>>2];l=j[a>>2];a=j[a+8>>2];j[114626]=0;j[k+40>>2]=b;j[k+52>>2]=a;j[k+44>>2]=l;j[k+48>>2]=e;j[k+20>>2]=d?d:1990;I(1991,k+24|0,k+20|0,k+60|0);a=j[114626];j[114626]=0;a:{b:{c:{d:{if((a|0)!=1){b=go(k+32|0,k+24|0);j[114626]=0;a=j[k+52>>2];j[k+8>>2]=j[k+48>>2];j[k+12>>2]=a;a=j[k+44>>2];j[k>>2]=j[k+40>>2];j[k+4>>2]=a;c=+la(1992,k|0,+c,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}Hc(b);Hc(k+24|0);break b}a=J(0)|0;C()|0;break c}a=J(0)|0;C()|0;Hc(b);Hc(k+24|0)}O(a|0)|0;j[114626]=0;Z(1993,34536,d|0,j[k+60>>2],f|0,g|0,h|0,i|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();c=0}Za=k- -64|0;return+c}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function c9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Za-32|0;Za=d;e=Mg(a);f=b+24|0;a=j[f>>2];j[114626]=0;a=H(2186,a+484344|0)|0;c=j[114626];j[114626]=0;a:{b:{c:{if((c|0)==1){break c}j[114626]=0;F(1525,e|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=j[f>>2];j[114626]=0;c=H(2186,c+484344|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=Ib(j[f>>2]+484344|0,a);j[114626]=0;F(2183,d|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){j[114626]=0;I(2177,d+16|0,b|0,d|0);c=j[114626];j[114626]=0;if((c|0)==1){break g}j[114626]=0;F(1527,e|0,d+16|0);c=j[114626];j[114626]=0;if((c|0)==1){break f}a=a+1|0;gb(d+16|0);gb(d);continue}break}a=D()|0;C()|0;break a}a=D()|0;C()|0;break e}a=D()|0;C()|0;gb(d+16|0)}gb(d);break a}Za=d+32|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0}Uc(e);G(a|0);z()}function Tua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0;g=Za-16|0;Za=g;l=j[a+40>>2];m=j[a+36>>2];o=j[a+16>>2];k=j[a+4>>2];e=k;f=j[a>>2];j[g+8>>2]=f;j[g+12>>2]=e;k=j[a+12>>2];j[g>>2]=j[a+8>>2];j[g+4>>2]=k;a:{if(!d){k=l>>12;n=m>>12;break a}while(1){k=j[a+32>>2];m=j[a+28>>2]+m|0;n=m>>12;e=e+o|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((p(h[e+2|0],i[f+34>>1])+p(h[e+1|0],i[f+32>>1])|0)+p(h[e+3|0],i[f+36>>1])|0)+p(h[e+4|0],i[f+38>>1])<<8)/2|0)+((((p(h[e-2|0],i[f+26>>1])+p(h[e-3|0],i[f+24>>1])|0)+p(h[e-1|0],i[f+28>>1])|0)+p(h[e|0],i[f+30>>1])<<8)/2|0)|0)/16384|0;j[c>>2]=j[c>>2]+p(n,e);l=k+l|0;k=l>>12;j[c+4>>2]=j[c+4>>2]+p(e,k);Bb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=j[g+8>>2];e=j[g+12>>2];continue}break}f=j[g+8>>2];e=j[g+12>>2]}j[a+40>>2]=l;j[a+20>>2]=n;j[a+36>>2]=m;j[a+24>>2]=k;j[a>>2]=f;j[a+4>>2]=e;Za=g+16|0}function Aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=q(0),o=0,p=q(0),r=q(0),s=q(0),t=q(0),u=q(0),v=q(0),w=q(0),x=q(0),y=q(0);i=Za-16|0;Za=i;k=a+44|0;if(Yg(k)){h=wd(k,0);j[i+8>>2]=h;l=wd(k,1);j[i+12>>2]=l;e=Rc(k,0);j[i>>2]=e;f=Rc(k,1);j[i+4>>2]=f;a:{if(n[a+4216>>2]!=q(.5)){if(!d){break a}h=d;while(1){f=0;l=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=j[e>>2];j[e>>2]=g+4;e=a+f|0;o=e+4248|0;s=n[o>>2];m=n[g>>2];t=n[a+4228>>2];u=n[a+4224>>2];v=n[a+4220>>2];w=n[a+4236>>2];x=n[a+4232>>2];g=e+4240|0;p=n[g>>2];n[o>>2]=p;n[g>>2]=m;g=e+4264|0;y=n[g>>2];e=e+4256|0;r=n[e>>2];n[g>>2]=r;m=q(q(q(q(p*u)+q(v*m))+q(s*t))-q(q(y*w)+q(r*x)));n[e>>2]=m;f=f+i|0;e=j[f>>2];j[f>>2]=e+4;n[e>>2]=m;e=l;l=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;Vb(e,g,h);Vb(f,l,h)}Th(a,b,c,Rc(k,0),Rc(k,1),d)}Za=i+16|0}function rma(a,b,c){var d=0,e=0,f=0,g=0,i=0;d=Za-16|0;Za=d;a:{if(!(k[b+90|0]&4)|(j[a+480208>>2]&2101248)==2101248){break a}b:{if(j[c>>2]<=0){mb(d+8|0,a+1074308|0,21);if(!kb(d+8|0)){break b}}g=5;if(!(j[a+480180>>2]&5)){mb(d+8|0,a+1074308|0,21);g=kb(d+8|0)?5:6}f=Zw(a,k[b+845|0],k[b+840|0]);c:{if((k[b+845|0]&3)!=1){break c}mb(d+8|0,a+1074308|0,89);if(!kb(d+8|0)){break c}f=k[b+839|0];i=k[b+840|0];e=i<<2&124;e=(!(k[b+90|0]&2)|k[a+480209|0]&16?f:k[b+843|0]+f|0)&32?e^127:e;f=i&32?0-e|0:e}e=c;if(j[a+480180>>2]!=131072){c=j[c>>2]+((p(k[b+847|0],f)|0)/(1<<g)|0)|0}else{c=j[c>>2];c=((p(k[b+847|0],p(c,64-f|0))|0)/-8192|0)+c|0}j[e>>2]=c}if(!(j[a+480180>>2]&16777248)|k[a+480208|0]&4?k[a+480209|0]&16:0){break a}mb(d+8|0,a+1074308|0,21);c=kb(d+8|0);a=k[b+846|0];if(c){h[b+840|0]=k[b+840|0]+(a<<2);break a}h[b+840|0]=a+k[b+840|0]}Za=d+16|0}function HR(a,b){var c=0,d=0;d=k[a|0];if(d>>>0>=36){h[a|0]=0;return}c=k[d+12560|0];h[a|0]=c;a:{b:{c:{d:{e:{f:{if(c>>>0<=16){if(c-6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=k[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}h[b|0]=a;return}switch(c-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(k[b|0]){break a}h[a|0]=0;return}a=k[b|0];if(a>>>0<=64){h[b|0]=a<<1;return}h[b|0]=128;return}g:{h:{i:{j:{c=k[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}h[a|0]=20;h[b|0]=159;return}h[a|0]=20;h[b|0]=192;return}if(c&14){break a}h[a|0]=21;h[b|0]=(k[b|0]!=80)<<6;return}h[a|0]=20;h[b|0]=k[b|0]&15|160;return}if(k[b|0]>31){break a}h[a|0]=16;return}if((c|0)!=31){break a}h[b|0]=(d<<5|k[b|0]<<24>>>27)^128}}function Pha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,k=0;a:{b:{if((Te(a)|0)==(b|0)){if((Te(a+12|0)|0)==(c|0)){break b}}j[114626]=0;F(1634,a|0,b|0);d=j[114626];j[114626]=0;c:{d:{if((d|0)==1){break d}j[114626]=0;e=a+12|0;F(1634,e|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break d}j[114626]=0;f=a+24|0;F(1635,f|0,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break d}j[114626]=0;g=a+36|0;F(1635,g|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=xl(a,d);i=xb(f,d),k=h,j[i>>2]=k;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=J(71396)|0;if((C()|0)!=(W(71396)|0)){break a}O(b|0)|0;OH(a);NH(a);b=a+12|0;OH(b);NH(b);b=a+24|0;MH(b);LH(b);a=a+36|0;MH(a);LH(a);Q();return 0}a=0;while(1){b=xl(e,a);i=xb(g,a),k=b,j[i>>2]=k;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}G(b|0);z()}function AM(a){a=a|0;var b=0;Ab(a,0,288);Zx(a+288|0);Vo(a+800|0);h[a+2|0]=k[18178];b=k[18176]|k[18177]<<8;h[a|0]=b;h[a+1|0]=b>>>8;h[a+34|0]=k[18181];b=k[18179]|k[18180]<<8;h[a+32|0]=b;h[a+33|0]=b>>>8;b=k[18185]|k[18186]<<8|(k[18187]<<16|k[18188]<<24);h[a+99|0]=b;h[a+100|0]=b>>>8;h[a+101|0]=b>>>16;h[a+102|0]=b>>>24;b=k[18182]|k[18183]<<8|(k[18184]<<16|k[18185]<<24);h[a+96|0]=b;h[a+97|0]=b>>>8;h[a+98|0]=b>>>16;h[a+99|0]=b>>>24;b=k[18189]|k[18190]<<8|(k[18191]<<16|k[18192]<<24);h[a+128|0]=b;h[a+129|0]=b>>>8;h[a+130|0]=b>>>16;h[a+131|0]=b>>>24;b=k[18192]|k[18193]<<8|(k[18194]<<16|k[18195]<<24);h[a+131|0]=b;h[a+132|0]=b>>>8;h[a+133|0]=b>>>16;h[a+134|0]=b>>>24;h[a+260|0]=k[18200];b=k[18196]|k[18197]<<8|(k[18198]<<16|k[18199]<<24);h[a+256|0]=b;h[a+257|0]=b>>>8;h[a+258|0]=b>>>16;h[a+259|0]=b>>>24;xwa(a+288|0);wwa(a+800|0)}function q2(a,b,c){var d=0,e=0,f=0,g=0,i=0;i=Za-16|0;Za=i;a:{b:{c:{d:{if(a){if(c>>>0>=4){break d}d=c;break c}c=0;a=j[b>>2];d=j[a>>2];if(!d){break a}while(1){f=1;if(d>>>0>=128){g=-1;f=Cj(i+12|0,d,0);if((f|0)==-1){break a}}d=j[a+4>>2];a=a+4|0;c=c+f|0;g=c;if(d){continue}break}break a}f=j[b>>2];d=c;while(1){e=j[f>>2];e:{if(e-1>>>0>=127){if(!e){h[a|0]=0;j[b>>2]=0;break b}g=-1;e=Cj(a,e,0);if((e|0)==-1){break a}d=d-e|0;a=a+e|0;break e}h[a|0]=e;d=d-1|0;f=j[b>>2];a=a+1|0}f=f+4|0;j[b>>2]=f;if(d>>>0>3){continue}break}}if(d){f=j[b>>2];while(1){e=j[f>>2];f:{if(e-1>>>0>=127){if(!e){h[a|0]=0;j[b>>2]=0;break b}g=-1;e=Cj(i+12|0,e,0);if((e|0)==-1){break a}if(d>>>0<e>>>0){break b}Cj(a,j[f>>2],0);d=d-e|0;a=a+e|0;break f}h[a|0]=e;d=d-1|0;f=j[b>>2];a=a+1|0}f=f+4|0;j[b>>2]=f;if(d){continue}break}}g=c;break a}g=c-d|0}Za=i+16|0;return g}function V3(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-32|0;Za=c;j[c+28>>2]=0;a:{b:{if(k[Ji(c+24|0,a,0)|0]){hc(c+16|0,j[j[a>>2]-12>>2]+a|0);j[114626]=0;e=H(2308,c+16|0)|0;d=j[114626];j[114626]=0;c:{d:{if((d|0)==1){break d}d=dm(c+8|0,a);f=ck(c);g=j[j[a>>2]-12>>2];f=j[f>>2];d=j[d>>2];j[114626]=0;_(2309,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}wb(c+16|0);break c}b=J(0)|0;C()|0;wb(c+16|0);O(b|0)|0;b=j[c+28>>2]|1;j[c+28>>2]=b;Hi(j[j[a>>2]-12>>2]+a|0,b);b=j[j[a>>2]-12>>2];j[114626]=0;b=j[(a+b|0)+20>>2];e=j[114626];j[114626]=0;e:{if((e|0)!=1){if(!(b&1)){break e}j[114626]=0;M(81);a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}Q()}eg(j[j[a>>2]-12>>2]+a|0,j[c+28>>2])}Za=c+32|0;return a}a=J(0)|0;C()|0;ib(a)}z()}function Q3(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-32|0;Za=c;j[c+28>>2]=0;a:{b:{if(k[Ji(c+24|0,a,0)|0]){hc(c+16|0,j[j[a>>2]-12>>2]+a|0);j[114626]=0;e=H(2308,c+16|0)|0;d=j[114626];j[114626]=0;c:{d:{if((d|0)==1){break d}d=dm(c+8|0,a);f=ck(c);g=j[j[a>>2]-12>>2];f=j[f>>2];d=j[d>>2];j[114626]=0;_(2312,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}wb(c+16|0);break c}b=J(0)|0;C()|0;wb(c+16|0);O(b|0)|0;b=j[c+28>>2]|1;j[c+28>>2]=b;Hi(j[j[a>>2]-12>>2]+a|0,b);b=j[j[a>>2]-12>>2];j[114626]=0;b=j[(a+b|0)+20>>2];e=j[114626];j[114626]=0;e:{if((e|0)!=1){if(!(b&1)){break e}j[114626]=0;M(81);a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}Q()}eg(j[j[a>>2]-12>>2]+a|0,j[c+28>>2])}Za=c+32|0;return a}a=J(0)|0;C()|0;ib(a)}z()}function N3(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-32|0;Za=c;j[c+28>>2]=0;a:{b:{if(k[Ji(c+24|0,a,0)|0]){hc(c+16|0,j[j[a>>2]-12>>2]+a|0);j[114626]=0;e=H(2308,c+16|0)|0;d=j[114626];j[114626]=0;c:{d:{if((d|0)==1){break d}d=dm(c+8|0,a);f=ck(c);g=j[j[a>>2]-12>>2];f=j[f>>2];d=j[d>>2];j[114626]=0;_(2313,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}wb(c+16|0);break c}b=J(0)|0;C()|0;wb(c+16|0);O(b|0)|0;b=j[c+28>>2]|1;j[c+28>>2]=b;Hi(j[j[a>>2]-12>>2]+a|0,b);b=j[j[a>>2]-12>>2];j[114626]=0;b=j[(a+b|0)+20>>2];e=j[114626];j[114626]=0;e:{if((e|0)!=1){if(!(b&1)){break e}j[114626]=0;M(81);a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}Q()}eg(j[j[a>>2]-12>>2]+a|0,j[c+28>>2])}Za=c+32|0;return a}a=J(0)|0;C()|0;ib(a)}z()}function L3(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-32|0;Za=c;j[c+28>>2]=0;a:{b:{if(k[Ji(c+24|0,a,0)|0]){hc(c+16|0,j[j[a>>2]-12>>2]+a|0);j[114626]=0;e=H(2308,c+16|0)|0;d=j[114626];j[114626]=0;c:{d:{if((d|0)==1){break d}d=dm(c+8|0,a);f=ck(c);g=j[j[a>>2]-12>>2];f=j[f>>2];d=j[d>>2];j[114626]=0;_(2314,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}wb(c+16|0);break c}b=J(0)|0;C()|0;wb(c+16|0);O(b|0)|0;b=j[c+28>>2]|1;j[c+28>>2]=b;Hi(j[j[a>>2]-12>>2]+a|0,b);b=j[j[a>>2]-12>>2];j[114626]=0;b=j[(a+b|0)+20>>2];e=j[114626];j[114626]=0;e:{if((e|0)!=1){if(!(b&1)){break e}j[114626]=0;M(81);a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}Q()}eg(j[j[a>>2]-12>>2]+a|0,j[c+28>>2])}Za=c+32|0;return a}a=J(0)|0;C()|0;ib(a)}z()}function sD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,k=0,l=0;g=Za-1040|0;Za=g;h=j[b>>2];j[g+12>>2]=h;k=a?a:g+16|0;a:{b:{c:{d=a?d:256;if(!d|!h){break c}f=c>>>2|0;l=f>>>0<d>>>0;if(d>>>0>f>>>0?c>>>0<=131:0){break b}while(1){f=l?f:d;c=c-f|0;f=av(k,g+12|0,f,e);if((f|0)==-1){d=0;h=j[g+12>>2];i=-1;break c}h=(g+16|0)==(k|0);k=h?k:(f<<2)+k|0;i=f+i|0;d=d-(h?0:f)|0;h=j[g+12>>2];if(!d|!h){break c}f=c>>>2|0;l=f>>>0<d>>>0;if(d>>>0<=f>>>0|c>>>0>131){continue}break}break b}if(!h){break a}}if(!d|!c){break a}f=i;while(1){d:{i=Qn(k,h,c,e);e:{if(i+2>>>0<=2){f:{switch(i+1|0){case 1:j[g+12>>2]=0;break e;case 0:break a;default:break f}}j[e>>2]=0;break e}h=j[g+12>>2]+i|0;j[g+12>>2]=h;f=f+1|0;d=d-1|0;if(d){break d}}i=f;break a}k=k+4|0;c=c-i|0;i=f;if(c){continue}break}}if(a){j[b>>2]=j[g+12>>2]}Za=g+1040|0;return i|0}function vya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-32|0;Za=d;md(c,2);h[d+16|0]=k[b+13|0];h[d|0]=64;f=c,g=k[Yb(d+16|0,d)|0]<<2,i[f+30>>1]=g;e=b+14|0;j[c+24>>2]=(k[e|0]|k[e+1|0]<<8)<<1;dk(d,2,b+1|0);qc(d+16|0,d);j[114626]=0;E(370,c+43|0,d+16|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){gb(d+16|0);e=Mc(a,8,1,0,2);a:{if((k[b|0]&3)!=1){break a}a=b+22|0;j[c>>2]=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);a=b+26|0;j[c+4>>2]=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);a=b+30|0;a=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);j[c+8>>2]=a;if(a>>>0>m[c+4>>2]){j[c+8>>2]=a-1}if(k[b|0]&4){i[c+34>>1]=l[c+34>>1]|2}if(k[b|0]&8){i[c+34>>1]=l[c+34>>1]|4}if(!(k[b|0]&16)){break a}rz(e);dj(e,9);j[c>>2]=j[c>>2]>>>1;j[c+4>>2]=j[c+4>>2]>>>1;j[c+8>>2]=j[c+8>>2]>>>1}Za=d+32|0;return}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function yJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b:{d=a+484360|0;if(bc(Fb(d))>>>0<=b>>>0){break b}if(Po(Fb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(bc(Fb(d))>>>0<=c>>>0){break a}if(!Po(Fb(d),b&65535)){continue}break}break a}c=b}if(bc(Fb(d))>>>0>c>>>0){d=a+1074308|0;f=a+1304360|0;c=a+1074984|0;while(1){h[c+819|0]=0;j[c+700>>2]=0;h[c+861|0]=0;h[c+827|0]=0;j[c+708>>2]=0;h[c+841|0]=0;j[c+804>>2]=0;h[c+839|0]=0;h[c+840|0]=0;mb(e+8|0,d,23);if(kb(e+8|0)){i[c+798>>1]=0;i[c+800>>1]=1}h[c+859|0]=0;c=c+896|0;if((f|0)!=(c|0)){continue}break}xJ(a);c:{if(!(b&65535)){sna(a);break c}i[a+1074440>>1]=b;i[a+1074436>>1]=0;b=a+1074424|0;j[b>>2]=0;j[b+4>>2]=0;j[a+1074432>>2]=0;b=a+1074396|0;j[b>>2]=0;j[b+4>>2]=0;j[a+1074380>>2]=0;j[a+1074392>>2]=j[a+1074416>>2]}j[a+480208>>2]=j[a+480208>>2]&-769}Za=e+16|0}function TKa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Za-16|0;Za=d;md(b,0);j[b>>2]=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);c=wt(a+4|0,a);j[b+4>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=wt(a+8|0,a);j[b+8>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+15|0;j[b+24>>2]=(k[c|0]|k[c+1|0]<<8)<<1;if(!(k[c|0]|k[c+1|0]<<8)){j[b+24>>2]=16726}c=a+14|0;e=b,f=(p(ms(h[a+17|0],k[c|0]<<28>>24),j[b+24>>2])>>>0)/8363|0,j[e+24>>2]=f;h[d+15|0]=k[a+18|0];h[d+14|0]=127;e=b,f=(((k[Yb(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,i[e+30>>1]=f;if(k[c|0]>=16){c=k[c|0];i[b+34>>1]=32;i[b+28>>1]=c&240}a=a+19|0;if(k[a|0]&4){i[b+34>>1]=l[b+34>>1]|1}a:{if(!(k[a|0]&8)|m[b+4>>2]>=m[b+8>>2]){break a}i[b+34>>1]=l[b+34>>1]|2;if(k[a|0]&16){i[b+34>>1]=l[b+34>>1]|4}if(!(k[a|0]&64)){break a}i[b+34>>1]=l[b+34>>1]|128}Za=d+16|0}function nM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0;e=Za-32|0;Za=e;d=c&4;a:{if(!(b&4)){if(!d){break a}h[a+15|0]=k[a+16|0];b=k[a+12|0];h[a+12|0]=b&247;if(!(b&2)){break a}b=k[a+14|0];if(b>>>0<=k[a+13|0]){break a}if(sb(a)>>>0<=b>>>0){break a}while(1){d=jc(a,b);i[d>>1]=l[d>>1]+1;b=b+1|0;if(sb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=k[a+14|0];b:{if(b>>>0>=k[a+15|0]){break b}d=k[a+12|0];if(!(d&2)){break b}h[a+12|0]=d&251}if(!(k[a+12|0]&2)|b>>>0<=k[a+13|0]){break a}if(sb(a)>>>0<=b>>>0){break a}d=l[jc(a,k[a+14|0])>>1];f=jc(a,k[a+14|0]-1|0);b=k[a+14|0];if(l[f>>1]<(d-1|0)){b=l[jc(a,b)>>1]-1&65535;d=To(a,b,64,64);g=e,m=Lb(a),j[g+8>>2]=m;g=e,m=So(e+8|0,k[a+14|0]),j[g+16>>2]=m;f=Cd(e+24|0,e+16|0);b=ep(e,b,d&255);cua(a,j[f>>2],b);break a}h[a+14|0]=b-1}if((c|0)!=16777216){h[a+17|0]=255}Za=e+32|0}function eta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,k=0;c=Za+ -64|0;Za=c;cf(a,c+62|0);a:{b:{c:{d:{e:{f:{g:{e=j[19859];if(l[c+62>>1]>l[e+12>>1]){f=j[b+12>>2];Hz(c+16|0,18533);j[114626]=0;L(1176,c+32|0,c+16|0,c+62|0,e+12|0);d=j[114626];j[114626]=0;if((d|0)==1){break g}j[114626]=0;d=E(650,c+48|0,c+32|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break f}j[114626]=0;F(624,f|0,d|0);f=j[114626];j[114626]=0;if((f|0)==1){break e}gb(d);gb(c+32|0);qb(c+16|0);i[c+62>>1]=l[e+12>>1]}bg(gi(b,0),l[c+62>>1]);b=gi(b,0);h=c,k=Lb(b),j[h+48>>2]=k;h=c,k=Mb(b),j[h+16>>2]=k;if(rb(c+48|0,c+16|0)){break b}break a}b=D()|0;C()|0;break c}b=D()|0;C()|0;break d}b=D()|0;C()|0;gb(d)}gb(c+32|0)}qb(c+16|0);G(b|0);z()}while(1){b=j[c+48>>2];cf(a,c+14|0);i[b>>1]=l[c+14>>1];je(c+48|0);if(rb(c+48|0,c+16|0)){continue}break}}Za=c- -64|0}function Fpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,l=0,m=0,n=0,q=0,s=0,t=0;f=Za-16|0;Za=f;q=f,s=p(j[a>>2],be(a)),j[q+4>>2]=s;kc(f+4|0,c);c=lb(b);h=o[e+8>>3];g=j[f+4>>2];a:{if(!g){break a}e=g;while(1){m=(k[c+4|0]|k[c+5|0]<<8|(k[c+6|0]<<16|k[c+7|0]<<24))&2147483647;WMa(0,k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24));WMa(1,m|0);h=u(+XMa(),h);c=c+8|0;e=e-1|0;if(e){continue}break}if(!g|h==0){break a}n=1/h;c=j[a+20>>2];while(1){a=b;e=k[a+4|0]|k[a+5|0]<<8|(k[a+6|0]<<16|k[a+7|0]<<24);WMa(0,k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24));WMa(1,e|0);q=f,t=+XMa()*n,o[q+8>>3]=t;pf(f+8|0,-1,1);l=o[f+8>>3]*32768;o[f+8>>3]=l;a=c;l=zd(l);b:{if(r(l)<2147483648){e=~~l;break b}e=-2147483648}q=a,s=Dc(e),i[q>>1]=s;b=b+8|0;c=c+2|0;g=g-1|0;if(g){continue}break}}if(d){o[d>>3]=h}Za=f+16|0;return j[f+4>>2]}function dX(a){var b=0,c=q(0),d=q(0),e=q(0),f=q(0),g=0,h=q(0),i=q(0);b=(ZMa(a),VMa(2));a:{b:{if(!((b|0)>-1?b>>>0>=8388608:0)){if(!(b&2147483647)){return q(q(-1)/q(a*a))}if((b|0)<=-1){return q(q(a-a)/q(0))}b=(ZMa(q(a*q(33554432))),VMa(2));g=-152;break b}if(b>>>0>2139095039){break a}g=-127;a=q(0);if((b|0)==1065353216){break a}}b=b+4913933|0;h=q((b>>>23|0)+g|0);a=q((WMa(2,(b&8388607)+1060439283|0),_Ma())+q(-1));c=q(a*q(a*q(.5)));d=q(a/q(a+q(2)));e=q(d*d);f=q(e*e);i=a;a=(WMa(2,(ZMa(q(a-c)),VMa(2))&-4096),_Ma());c=q(q(q(i-a)-c)+q(d*q(c+q(q(e*q(q(f*q(.2849878668785095))+q(.6666666269302368)))+q(f*q(q(f*q(.24279078841209412))+q(.40000972151756287)))))));a=q(q(h*q(.3010292053222656))+q(q(a*q(.434326171875))+q(q(c*q(.434326171875))+q(q(h*q(7.903415166765626e-7))+q(q(c+a)*q(-3168997136526741e-20))))))}return a}function xD(a,b){var c=0,d=0,e=0;a:{if(k[b|0]){break a}b=ev(58016);if(k[b|0]?b:0){break a}b=ev(p(a,12)+58032|0);if(k[b|0]?b:0){break a}b=ev(58104);if(k[b|0]?b:0){break a}b=58109}b:{while(1){e=k[b+c|0];if(!(!e|(e|0)==47)){e=15;c=c+1|0;if((c|0)!=15){continue}break b}break}e=c}d=58109;c:{d:{c=k[b|0];e:{f:{if(!(k[b+e|0]|(c|0)==46)){d=b;if((c|0)!=67){break f}}if(!k[d+1|0]){break e}}if(!Mh(d,58109)){break e}if(Mh(d,58117)){break d}}if(!a){c=57940;if(k[d+1|0]==46){break c}}return 0}c=j[115415];if(c){while(1){if(!Mh(d,c+8|0)){break c}c=j[c+24>>2];if(c){continue}break}}c=j[115415];if(c){while(1){if(!Mh(d,c+8|0)){return c}c=j[c+24>>2];if(c){continue}break}}c=_c(28);g:{if(!c){c=0;break g}b=j[14486];j[c>>2]=j[14485];j[c+4>>2]=b;b=c+8|0;Vb(b,d,e);h[b+e|0]=0;j[c+24>>2]=j[115415];j[115415]=c}c=a|c?c:57940}return c}function Hpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=q(0),l=q(0),m=q(0),o=0,s=0;f=Za-16|0;Za=f;o=f,s=p(j[a>>2],be(a)),j[o+8>>2]=s;kc(f+8|0,c);c=lb(b);h=n[e+4>>2];e=j[f+8>>2];if(e){while(1){g=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);h=q(u(q(r((WMa(2,g<<24|g<<8&16711680|(g>>>8&65280|g>>>24)),_Ma()))),h));c=c+4|0;e=e-1|0;if(e){continue}break}}c=h==q(0);a:{if(c){break a}e=j[f+8>>2];if(!e){break a}m=c?q(1):q(q(1)/h);c=j[a+20>>2];while(1){a=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);n[f+12>>2]=m*(WMa(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),_Ma());Kd(f+12|0,q(-1));l=q(n[f+12>>2]*q(32768));n[f+12>>2]=l;a=c;l=Sd(l);b:{if(q(r(l))<q(2147483648)){g=~~l;break b}g=-2147483648}o=a,s=Dc(g),i[o>>1]=s;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){n[d>>2]=h}Za=f+16|0;return j[f+8>>2]}function dla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;md(b,4);i[b+30>>1]=k[a+12|0]<<2;Sf(b+30|0,256);c=k[a+15|0];i[b+34>>1]=32;i[b+28>>1]=c;h[b+37|0]=k[a+13|0];h[b+36|0]=k[a+16|0];j[b>>2]=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);c=a+4|0;e=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[b+4>>2]=e;c=a+8|0;j[b+8>>2]=e+(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24));a=a+14|0;if(k[a|0]&16){j[b>>2]=j[b>>2]>>>1;j[b+4>>2]=j[b+4>>2]>>>1;j[b+8>>2]=j[b+8>>2]>>>1}if(k[a|0]&32){j[b>>2]=j[b>>2]>>>1;j[b+4>>2]=j[b+4>>2]>>>1;j[b+8>>2]=j[b+8>>2]>>>1}a:{if(!(k[a|0]&3)|m[b+8>>2]<=m[b+4>>2]){break a}i[b+34>>1]=l[b+34>>1]|2;if(!(k[a|0]&2)){break a}i[b+34>>1]=l[b+34>>1]|4}a=Eb(d,31680);j[114626]=0;E(370,b+43|0,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){gb(a);Za=d+16|0;return}b=D()|0;C()|0;gb(a);G(b|0);z()}function ypa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=q(0),g=0,h=0,l=q(0),m=0,o=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>3;j[e+8>>2]=j[a>>2];h=j[tb(e+12|0,e+8|0)>>2];l=n[d>>2];b=lb(b);if(h){a=j[a+20>>2];c=h;while(1){d=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);n[e+12>>2]=l*(WMa(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),_Ma());Kd(e+12|0,q(-1));f=q(n[e+12>>2]*q(32768));n[e+12>>2]=f;d=a;f=Sd(f);a:{if(q(r(f))<q(2147483648)){g=~~f;break a}g=-2147483648}m=d,o=Dc(g),i[m>>1]=o;d=k[b+4|0]|k[b+5|0]<<8|(k[b+6|0]<<16|k[b+7|0]<<24);n[e+12>>2]=l*(WMa(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),_Ma());Kd(e+12|0,q(-1));f=q(n[e+12>>2]*q(32768));n[e+12>>2]=f;d=a;f=Sd(f);b:{if(q(r(f))<q(2147483648)){g=~~f;break b}g=-2147483648}m=d,o=Dc(g),i[m+2>>1]=o;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return h<<3}function owa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,j=0,m=0;e=Za-48|0;Za=e;i[a>>1]=0;i[a+2>>1]=0;i[a+4>>1]=0;$m(b,e+44|0);a:{if(!yM(e+44|0)){break a}d=k[e+46|0];g=k[e+47|0];f=k[e+45|0];h[a+4|0]=1;j=f>>>3&3;c=(j|0)!=3;m=f>>>1&3;f=m^3;g=g>>>0<192;i[a+2>>1]=l[(p(c,6)+18424|0)+(f<<1)>>1]<<g;f=p(p(k[f+(p(c,3)+18201|0)|0],l[((p(c,90)+18208|0)+p(f,30)|0)+(d>>>3&30)>>1]),1e3);d=d>>>1|0;d=p(((f>>>0)/l[(p(j,6)+18400|0)+(d&6)>>1]|0)+(d&1)|0,(m|0)==3?4:1);i[a>>1]=d;c=k[g+((c<<1)+18436|0)|0];if(c+8>>>0>(d&65535)>>>0){break a}mwa(b,e,c+4|0);b=2;if(c>>>0>2){while(1){if(k[b+e|0]){break a}b=b+1|0;if((c|0)!=(b|0)){continue}break}}b=a;c=c+e|0;d=1;b:{if((k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))==1868983881){break b}d=(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))==1735289176}h[b+5|0]=d}Za=e+48|0;return a|0}function aaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0;e=Za-48|0;Za=e;h=fo(a,c);i=dG(a+4|0);k=bG(a+24|0);l=aG(a+32|0);m=bw(a+36|0);j[a+56>>2]=3;n=Mg(a+68|0);j[114626]=0;F(2157,a|0,d|0);c=j[114626];j[114626]=0;a:{b:{c:{d:{if((c|0)!=1){c=j[b>>2];f=j[b+4>>2];g=j[b+12>>2];b=j[b+8>>2];j[e+8>>2]=b;j[e+12>>2]=g;j[114626]=0;j[e+24>>2]=b;j[e+28>>2]=g;j[e+16>>2]=c;j[e+20>>2]=f;j[e>>2]=c;j[e+4>>2]=f;I(2158,e+32|0,e|0,0);b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;I(2159,a|0,e+32|0,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break c}jb(e+32|0);j[114626]=0;N(2160,a|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}Za=e+48|0;return a|0}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;jb(e+32|0);break a}a=D()|0;C()|0}Uc(n);Ye(m);bf(l);kh(k);Hc(i);Hc(h);G(a|0);z()}function lpa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=Za-32|0;Za=e;yoa(a+8|0);j[a+32>>2]=0;j[a+36>>2]=0;c=a+4|0;j[j[c>>2]>>2]=0;j[j[c>>2]+40>>2]=j[j[a>>2]+480196>>2];j[j[c>>2]+44>>2]=j[j[a>>2]+480204>>2];j[j[c>>2]+68>>2]=j[j[a>>2]+480200>>2];f=l[j[a>>2]+480188>>1];b=e;j[b+24>>2]=0;j[b+28>>2]=0;j[b+16>>2]=0;j[b+20>>2]=0;j[b+8>>2]=0;j[b+12>>2]=0;b=b+8|0;j[b>>2]=0;j[b+4>>2]=0;h[b+21|0]=255;h[b+13|0]=0;h[b+14|0]=0;h[b+15|0]=0;h[b+16|0]=0;h[b+17|0]=0;h[b+18|0]=0;h[b+19|0]=0;h[b+20|0]=0;j[b+8>>2]=0;j[b+12>>2]=0;Zoa(a+20|0,f,b);if(l[j[a>>2]+480188>>1]){while(1){b=p(d,896);Pm((b+j[c>>2]|0)+608|0,j[a>>2],d&65535);h[(b+j[c>>2]|0)+1445|0]=0;h[(b+j[c>>2]|0)+1444|0]=0;h[(b+j[c>>2]|0)+1429|0]=0;h[(b+j[c>>2]|0)+1432|0]=0;h[(b+j[c>>2]|0)+1427|0]=0;d=d+1|0;if(d>>>0<l[j[a>>2]+480188>>1]){continue}break}}Za=e+32|0}function Zda(){var a=0,b=0,c=0,d=0,e=0;a=Za-48|0;Za=a;c=Db(a+32|0);j[114626]=0;N(1987,a+16|0);b=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{if((b|0)!=1){d=a,e=Lb(a+16|0),j[d+8>>2]=e;d=a,e=Mb(a+16|0),j[d>>2]=e;if(!rb(a+8|0,a)){break e}break f}b=J(0)|0;C()|0;break c}while(1){b=j[a+8>>2];j[114626]=0;E(1245,c|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break d}_m(a+8|0);d=a,e=Mb(a+16|0),j[d>>2]=e;if(!rb(a+8|0,a)){break e}j[114626]=0;E(1988,c|0,34201)|0;b=j[114626];j[114626]=0;if((b|0)!=1){continue}break}break d}b=Gd(zb(c));Uc(a+16|0);gb(c);break b}b=J(0)|0;C()|0;Uc(a+16|0)}gb(c);O(b|0)|0;b=0;j[114626]=0;L(1982,34203,0,0,0);c=j[114626];j[114626]=0;if((c|0)==1){break a}Q()}Za=a+48|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);c=j[114626];j[114626]=0;if((c|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function K4(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=Za-32|0;Za=d;YMa(+a);g=VMa(1)|0;e=VMa(0)|0;YMa(+b);f=VMa(1)|0;h=VMa(0)|0;i=g&2147483647;c=i;f=f&2147483647;j=(c|0)==(f|0)&e>>>0<h>>>0|c>>>0<f>>>0;g=j?e:h;c=j?c:f;j=c;WMa(0,g|0);WMa(1,c|0);a=+XMa();c=c>>>20|0;a:{if((c|0)==2047){break a}l=e;e=(f|0)==(i|0)&e>>>0>h>>>0|f>>>0<i>>>0;h=e?l:h;i=e?i:f;e=i;WMa(0,h|0);WMa(1,e|0);b=+XMa();b:{if(!(g|j)){break b}g=e>>>20|0;if((g|0)==2047){break b}if((g-c|0)>=65){a=b+a;break a}c:{if(g>>>0>=1534){a=a*1.90109156629516e-211;b=b*1.90109156629516e-211;k=5.260135901548374e+210;break c}k=1;if(c>>>0>572){break c}a=a*5.260135901548374e+210;b=b*5.260135901548374e+210;k=1.90109156629516e-211}BE(d+24|0,d+16|0,b);BE(d+8|0,d,a);a=k*y(o[d>>3]+o[d+16>>3]+o[d+8>>3]+o[d+24>>3]);break a}a=b}Za=d+32|0;return a}function wr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Za-176|0;Za=d;e=Lg(d+40|0);f=j[j[e>>2]-12>>2];j[114626]=0;g=T(122)|0;h=j[114626];j[114626]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}j[114626]=0;I(123,d+32|0,f+(d+40|0)|0,g|0);f=j[114626];j[114626]=0;if((f|0)==1){break e}wb(d+32|0);j[114626]=0;F(142,e|0,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break e}j[114626]=0;F(133,e|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;F(125,d|0,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;I(140,d+16|0,d|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;I(141,a|0,d+16|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}gb(d+16|0);gb(d);Hd(e);Za=d+176|0;return}c=D()|0;C()|0;break a}c=D()|0;C()|0;break b}c=D()|0;C()|0;gb(d+16|0)}gb(d)}Hd(e);G(c|0);z()}function dH(a){var b=0,c=q(0),d=0,e=0,f=q(0);b=Za-16|0;Za=b;d=xe(j[a+16>>2]);e=a,f=Yd(q(10),q(q(q(n[a+4208>>2]*q(120))+q(-60))*q(.05000000074505806))),n[e+4232>>2]=f;c=q(q(d>>>0)*q(.0010000000474974513));e=a,f=Yd(q(10),q(q(-1)/q(q(q(n[a+4212>>2]*q(499.989990234375))+q(.009999999776482582))*c))),n[e+4236>>2]=f;e=a,f=Yd(q(10),q(q(-1)/q(q(q(n[a+4216>>2]*q(2950))+q(50))*c))),n[e+4240>>2]=f;j[b+12>>2]=1325400064;e=b,f=q(q(O4(q(Yd(q(10),q(q(q(n[a+4220>>2]*q(60))+q(-60))*q(.05000000074505806)))*q(2147483648)))*q(96817624))+q(67108864)),n[e+8>>2]=f;e=a,f=q(n[Rk(b+12|0,b+8|0)>>2]*q(4.656612873077393e-10)),n[e+4244>>2]=f;n[a+4248>>2]=q(q(-1)/q(q(n[a+4224>>2]*q(99))+q(1)))+q(1);d=a;c=q(q(q(n[a+4228>>2]*q(4))*c)+q(2));a:{if(q(r(c))<q(2147483648)){a=~~c;break a}a=-2147483648}j[d+4252>>2]=a;Za=b+16|0}function nY(a,b){var c=0;while(1){if(j[a>>2]==1){continue}break}a:{b:{if(!j[a>>2]){c:{lf(a,1);j[114626]=0;c=j[114626];j[114626]=0;d:{if((c|0)==1){break d}j[114626]=0;N(2559,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;b=j[114626];j[114626]=0;if((b|0)==1){break d}j[a>>2]=-1;j[114626]=0;b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;b=j[114626];j[114626]=0;if((b|0)!=1){break c}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;b=j[114626];j[114626]=0;e:{if((b|0)==1){break e}lf(a,0);j[114626]=0;a=j[114626];j[114626]=0;if((a|0)==1){break e}j[114626]=0;a=j[114626];j[114626]=0;if((a|0)==1){break e}j[114626]=0;M(81);a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}}return}a=J(0)|0;C()|0;ib(a)}z()}function wEa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Za-16|0;Za=g;h[g+14|0]=d;h[g+15|0]=c;h[g+13|0]=e;h[g+12|0]=f;if((d-1&255)>>>0<=5){h[g+14|0]=d+15}BP(g+15|0,g+13|0);BP(g+14|0,g+12|0);a:{if(k[g+15|0]==10){h[g+13|0]=k[g+13|0]&15?-1:k[g+12|0];if(k[g+14|0]!=10){break a}h[g+14|0]=0;break a}if(k[g+14|0]!=10){break a}h[g+12|0]=k[g+12|0]&15?-1:0}if(b){h[a+2|0]=1;h[a+4|0]=b+2>>>2}Jw(g+15|0,g+13|0,g+14|0,g+12|0);c=k[g+15|0];b:{if(!c){break b}d=k[g+14|0];if(!d){h[g+14|0]=c;h[g+12|0]=k[g+13|0];h[g+15|0]=0;break b}if(!((c|0)==20|(c|0)!=(d|0))){h[g+15|0]=0;break b}if(!b){Iw(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);h[a+2|0]=k[g+15|0];h[a+4|0]=k[g+13|0];break b}if(wm(c)>>>0<=wm(k[g+14|0])>>>0){break b}Tg(g+15|0,g+14|0);Tg(g+13|0,g+12|0)}h[a+3|0]=k[g+14|0];h[a+5|0]=k[g+12|0];Za=g+16|0}function _9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,k=0,l=0,m=0;f=Za-32|0;Za=f;d=fo(a,d);h=dG(a+4|0);i=bG(a+24|0);k=aG(a+32|0);l=bw(a+36|0);j[a+56>>2]=3;m=Mg(a+68|0);j[114626]=0;F(2157,a|0,e|0);g=j[114626];j[114626]=0;a:{b:{c:{d:{if((g|0)!=1){j[114626]=0;b=H(2164,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break d}j[114626]=0;I(2165,f+8|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;I(2166,f+16|0,f+8|0,0);b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;I(2159,a|0,f+16|0,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break c}jb(f+16|0);j[114626]=0;N(2160,a|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;break b}a=D()|0;C()|0;break b}a=D()|0;C()|0;jb(f+16|0)}Uc(m);Ye(l);bf(k);kh(i);Hc(h);Hc(d);G(a|0);z()}Za=f+32|0;return a|0}function qo(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=Za-16|0;Za=c;a:{b:{switch(j[a+480224>>2]-1|0){default:b=j[a+24620>>2];d=b>>31;j[c+8>>2]=1;j[c>>2]=j[a+1074420>>2]<<1;d=OMa(b,d,5e4,0);e=ab;b=j[Gc(c+8|0,c)>>2];b=ic(PMa(d,e,b,b>>31),ab);j[a+1074404>>2]=b;break a;case 1:b=j[a+24620>>2];j[c+8>>2]=1;j[c+12>>2]=0;f=c,g=OMa(j[a+1074420>>2],0,OMa(j[a+1074408>>2],0,j[a+1074416>>2],0),ab),j[f>>2]=g;j[c+4>>2]=ab;d=OMa(b,0,6e5,0);e=ab;b=Zma(c+8|0,c);b=RMa(d,e,j[b>>2],j[b+4>>2]);j[a+1074404>>2]=b;break a;case 0:break b}}b=j[a+24620>>2];d=b>>31;j[c+8>>2]=1;j[c>>2]=j[a+1074420>>2];d=OMa(b,d,1e4,0);e=ab;b=j[Gc(c+8|0,c)>>2];b=ic(PMa(d,e,b,b>>31),ab);j[a+1074404>>2]=b}d=a+1074404|0;a=j[a+480244>>2];b=OMa(a,a>>31,b,b>>31)+32768|0;a=ab;a=ic(PMa(b,b>>>0<32768?a+1|0:a,65536,0),ab);j[d>>2]=a?a:1;Za=c+16|0}function nP(a){var b=0,c=0,d=0,e=0;b=Za-48|0;Za=b;c=k[a+8|0]|k[a+9|0]<<8|(k[a+10|0]<<16|k[a+11|0]<<24);j[b+8>>2]=(c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))+788;j[b+12>>2]=0;c=k[a+16|0]|k[a+17|0]<<8|(k[a+18|0]<<16|k[a+19|0]<<24);j[b+16>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);j[b+20>>2]=0;c=b;e=b;if(k[a+24|0]|k[a+25|0]<<8|(k[a+26|0]<<16|k[a+27|0]<<24)){d=k[a+24|0]|k[a+25|0]<<8|(k[a+26|0]<<16|k[a+27|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)}else{d=52}j[e+24>>2]=d;j[c+28>>2]=0;c=k[a+32|0]|k[a+33|0]<<8|(k[a+34|0]<<16|k[a+35|0]<<24);j[b+44>>2]=4;j[b+40>>2]=b+8;a=j[b+44>>2];j[b>>2]=j[b+40>>2];j[b+4>>2]=a;j[b+32>>2]=(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+80;j[b+36>>2]=0;d=$Ca(j[b>>2],j[b>>2]+(j[b+4>>2]<<3)|0);a=j[d>>2];Za=b+48|0;ab=j[d+4>>2]-(a>>>0<52)|0;return a-52|0}function eK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=Za-16|0;Za=e;a:{if(!j[b+700>>2]){break a}f=j[a+480180>>2]==64?p(c,-20):c;b:{if(!(!(k[a+480208|0]&16)|j[a+480180>>2]==4)){g=j[b+700>>2];c=f>>31;j[e+12>>2]=(c+f^c)>>>2;kc(e+12|0,255);d=j[e+12>>2];c:{if(!d){break c}h=b;c=j[b+700>>2];i=c;c=c>>31;d:{if((f|0)<=-1){d=qx(a,d);break d}d=px(a,d)}d=OMa(i,c,d,d>>31)+32768|0;c=ab;c=ic(PMa(d,d>>>0<32768?c+1|0:c,65536,0),ab);j[h+700>>2]=c;if((c|0)!=(g|0)){break c}mb(e,a+1074308|0,7);d=kb(e);c=j[b+700>>2];if((d|0)==(f>>>31|0)){if((c|0)==2147483647){break c}j[b+700>>2]=j[b+700>>2]+1;break c}if((c|0)<2){break c}j[b+700>>2]=c-1}c=j[b+700>>2];break b}c=f+j[b+700>>2]|0;j[b+700>>2]=c}if((c|0)>0){break a}j[b+700>>2]=1;if(j[a+480180>>2]!=2){break a}j[b+696>>2]=0;j[b+88>>2]=j[b+88>>2]|2101248}Za=e+16|0}function WG(a){var b=q(0),c=0,d=q(0),e=q(0),f=q(0),g=0,i=0,k=0,l=q(0);c=Za-16|0;Za=c;i=a,k=di(q(n[a+4256>>2]*q(3))),j[i+4264>>2]=k;i=a,l=q(xe(j[a+16>>2])>>>((j[a+4264>>2]>>>1^-1)&1)>>>0),n[i+4268>>2]=l;n[a+4272>>2]=q(n[a+4244>>2]*q(100))*q(.0061803399585187435);i=c,l=Yd(q(10),q(q(VG(a)+q(q(n[a+4228>>2]*q(11e3))+q(-1e4)))*q(.0005000000237487257))),n[i+12>>2]=l;j[c+8>>2]=1065353216;i=a,l=q(n[Rk(c+12|0,c+8|0)>>2]*q(.7609999775886536)),n[i+4280>>2]=l;g=a;b=Yd(q(10),q(q(q(n[a+4212>>2]*q(1e4))+q(-1e4))*q(.0010000000474974513)));if(b!=q(1)){d=_n(q(q(UG(a)*q(6.2831854820251465))/n[a+4268>>2]));e=q(b+b);f=q(b*b);b=q(b*q(8));b=Gm(q(q(q(q(d*e)+q(-2))+q(y(q(q(q(f*q(-4))+b)+q(q(q(q(f*q(4))*d)-b)*d)))))/q(e+q(-2))),q(0),q(1))}else{b=q(0)}n[g+4276>>2]=b;Mea(a);Lea(a);h[a+5046|0]=0;Za=c+16|0}function ABa(a,b,c){var d=0,e=0,f=0,g=0,m=0,n=0;f=Za-16|0;Za=f;md(b,1);d=a+22|0;d=k[d|0]|k[d+1|0]<<8;j[b>>2]=(d<<24|d<<8&16711680)>>>15;h[b+37|0]=k[a+24|0]<<4;h[f+15|0]=k[a+25|0];h[f+14|0]=64;m=b,n=k[Yb(f+15|0,f+14|0)|0]<<2,i[m+30>>1]=n;d=a+26|0;d=k[d|0]|k[d+1|0]<<8;g=(d<<24|d<<8&16711680)>>>16|0;d=g<<1;a=a+28|0;a=k[a|0]|k[a+1|0]<<8;a=(a<<24|a<<8&16711680)>>>16|0;e=a<<1;a:{if(a>>>0<=1){a=j[b>>2];break a}a=j[b>>2];d=d+e>>>0<=a>>>0?d:a>>>0<e+g>>>0?d:g}b:{c:{switch(a|0){case 2:j[b>>2]=0;break b;case 0:break b;default:break c}}j[b+4>>2]=d;e=d+e|0;j[b+8>>2]=e;if(a>>>0<=d>>>0){d=a-1|0;j[b+4>>2]=d}if(!(e-d>>>0>3?!(e>>>0<4|d>>>0>e>>>0):0)){j[b+4>>2]=0;j[b+8>>2]=0;e=0;d=0}if(!(a>>>0<=e>>>0|e>>>0>8|(!c|d))){j[b+8>>2]=0;break b}if(d>>>0>=e>>>0){break b}i[b+34>>1]=l[b+34>>1]|2}Za=f+16|0}function Pva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0;e=Za-32|0;Za=e;k=j[a+40>>2];l=j[a+36>>2];n=j[a+16>>2];b=j[a+4>>2];g=b;f=j[a>>2];j[e+24>>2]=f;j[e+28>>2]=b;b=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=b;a:{if(!d){h=k>>12;b=l>>12;break a}while(1){o=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+n|0;h=0;b=1;while(1){m=h<<1;f=i[m+g>>1];j[(e+8|0)+(h<<2)>>2]=f+((p(i[(m|4)+g>>1]-f|0,o)|0)/16384|0);f=b;b=0;h=1;if(f){continue}break}f=j[a+32>>2];l=j[a+28>>2]+l|0;b=l>>12;j[c>>2]=j[c>>2]+p(b,j[e+8>>2]);k=f+k|0;h=k>>12;j[c+4>>2]=j[c+4>>2]+p(h,j[e+12>>2]);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=j[e+24>>2];g=j[e+28>>2];continue}break}f=j[e+24>>2];g=j[e+28>>2]}j[a+40>>2]=k;j[a+20>>2]=b;j[a+36>>2]=l;j[a+24>>2]=h;j[a>>2]=f;j[a+4>>2]=g;Za=e+32|0}function N4(a){var b=0,c=q(0),d=q(0),e=0,f=0,g=q(0),h=q(0);e=(ZMa(a),VMa(2));f=e>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=e&2147483647;g:{if(b>>>0>=1118743632){if(b>>>0>2139095040){return a}if(!((e|0)<0|b>>>0<1118925336)){return q(a*q(1.7014118346046923e+38))}if(b>>>0<=1120924084|(e|0)>-1){break g}break b}if(b>>>0<1051816473){break d}if(b>>>0<1065686419){break f}}a=q(q(a*q(1.4426950216293335))+n[(f<<2)+52272>>2]);if(q(r(a))<q(2147483648)){b=~~a;break e}b=-2147483648;break e}b=(f^1)-f|0}c=q(b|0);a=q(d+q(c*q(-.693145751953125)));g=q(c*q(1428606765330187e-21));d=q(a-g);break c}if(b>>>0<=956301312){break a}b=0;d=a}c=d;h=a;c=q(c*c);a=q(d-q(c*q(q(c*q(-.0027667332906275988))+q(.16666625440120697))));c=q(q(h+q(q(q(d*a)/q(q(2)-a))-g))+q(1));if(!b){break b}c=FE(c,b)}return c}return q(a+q(1))}function _n(a){var b=q(0),c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;e=(ZMa(a),VMa(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=q(1);if(d>>>0<964689920){break a}b=gh(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=q(-gh(((e|0)>-1?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<=-1){b=hh(f+1.5707963267948966);break a}b=hh(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=gh(((e|0)>-1?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<=-1){b=hh(-4.71238898038469- +a);break a}b=hh(+a+ -4.71238898038469);break a}b=q(a-a);if(d>>>0>=2139095040){break a}b:{switch(yv(a,c+8|0)&3){case 0:b=gh(o[c+8>>3]);break a;case 1:b=hh(-o[c+8>>3]);break a;case 2:b=q(-gh(o[c+8>>3]));break a;default:break b}}b=hh(o[c+8>>3])}a=b;Za=c+16|0;return a}function kga(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Za-176|0;Za=d;e=Lg(d+40|0);f=j[j[e>>2]-12>>2];j[114626]=0;g=T(122)|0;h=j[114626];j[114626]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}j[114626]=0;I(123,d+32|0,f+(d+40|0)|0,g|0);f=j[114626];j[114626]=0;if((f|0)==1){break e}wb(d+32|0);j[114626]=0;F(148,e|0,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break e}j[114626]=0;F(132,e|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;F(125,d|0,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;I(140,d+16|0,d|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;I(141,a|0,d+16|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}gb(d+16|0);gb(d);Hd(e);Za=d+176|0;return}c=D()|0;C()|0;break a}c=D()|0;C()|0;break b}c=D()|0;C()|0;gb(d+16|0)}gb(d)}Hd(e);G(c|0);z()}function lH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Za-176|0;Za=d;e=Lg(d+40|0);f=j[j[e>>2]-12>>2];j[114626]=0;g=T(122)|0;h=j[114626];j[114626]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}j[114626]=0;I(123,d+32|0,f+(d+40|0)|0,g|0);f=j[114626];j[114626]=0;if((f|0)==1){break e}wb(d+32|0);j[114626]=0;F(147,e|0,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break e}j[114626]=0;F(130,e|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;F(125,d|0,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;I(140,d+16|0,d|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break d}j[114626]=0;I(141,a|0,d+16|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}gb(d+16|0);gb(d);Hd(e);Za=d+176|0;return}c=D()|0;C()|0;break a}c=D()|0;C()|0;break b}c=D()|0;C()|0;gb(d+16|0)}gb(d)}Hd(e);G(c|0);z()}function nf(a){var b=0,c=0;b=j[a+4>>2];c=j[j[b>>2]-12>>2];j[114626]=0;b=j[(b+c|0)+24>>2];c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=j[a+4>>2];c=j[j[b>>2]-12>>2];j[114626]=0;b=mf(b+c|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}if(!b){break b}b=j[a+4>>2];if(!(j[(j[j[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(kE()){break b}b=j[a+4>>2];c=j[j[b>>2]-12>>2];j[114626]=0;b=j[(b+c|0)+24>>2];c=j[114626];j[114626]=0;c:{if((c|0)==1){break c}j[114626]=0;b=H(2307,b|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=j[a+4>>2];b=j[j[a>>2]-12>>2];j[114626]=0;F(18,a+b|0,1);a=j[114626];j[114626]=0;if((a|0)!=1){break b}}a=J(0)|0;C()|0;O(a|0)|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)==1){break a}}return}a=J(0)|0;C()|0;ib(a);z()}function Xxa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=Za-16|0;Za=e;c=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);j[b>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);h[e+15|0]=k[a+4|0];h[e+14|0]=64;f=b,g=k[Yb(e+15|0,e+14|0)|0]<<2,i[f+30>>1]=g;c=a+6|0;d=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[b+4>>2]=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);a=a+10|0;a=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);d=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24);a=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);a=d+(a<<8&16711680|a<<24|(a>>>8&65280|a>>>24))|0;j[b+8>>2]=a;d=j[b+4>>2];c=j[b>>2];if(d>>>0>=c>>>0){d=c-1|0;j[b+4>>2]=d}if(a>>>0>c>>>0){j[b+8>>2]=c;a=c}a:{if(a>>>0<d>>>0){j[b+4>>2]=0;j[b+8>>2]=0;break a}if(a>>>0<=d>>>0){break a}j[b+68>>2]=d;i[b+34>>1]=l[b+34>>1]|2}Za=e+16|0}function s$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;b=Za-32|0;Za=b;d=Db(b+16|0);j[114626]=0;c=LC(b+8|0);e=j[114626];j[114626]=0;a:{b:{c:{if((e|0)!=1){j[114626]=0;e=Qe(d);g=j[114626];j[114626]=0;if((g|0)==1){break c}g=zb(f);h=zb(f);f=nb(f);j[114626]=0;P(2502,c|0,e|0,g|0,(f<<2)+h|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break c}c=zb(d);j[114626]=0;e=j[114626];j[114626]=0;if((e|0)!=1){break b}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}e=Me(a);j[114626]=0;a=KC(b+8|0);f=j[114626];j[114626]=0;if((f|0)!=1){d:{j[114626]=0;f=Qe(e);g=j[114626];j[114626]=0;if((g|0)==1){break d}g=ne(c);j[114626]=0;P(2505,a|0,f|0,c|0,c+g|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break d}gb(d);Za=b+32|0;return}}a=D()|0;C()|0;pc(e)}gb(d);G(a|0);z()}



function xj(a,b,c,d,e,f,g,i,l,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;l=l|0;m=m|0;var n=0,o=0,p=0;n=Za-16|0;Za=n;h[n+15|0]=a;a:{b:{c:{if(j[d>>2]!=(c|0)){break c}o=43;p=a&255;if((p|0)!=k[m+24|0]){o=45;if(k[m+25|0]!=(p|0)){break c}}j[d>>2]=c+1;h[c|0]=o;break b}if(!(!nb(g)|(a|0)!=(f|0))){a=0;b=j[l>>2];if((b-i|0)>159){break a}a=j[e>>2];j[l>>2]=b+4;j[b>>2]=a;break b}a=-1;f=xm(m,m+26|0,n+15|0)-m|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=j[d>>2];if((b|0)==(c|0)|(b-c|0)>2|k[b-1|0]!=48){break a}a=0;j[e>>2]=0;j[d>>2]=b+1;h[b|0]=k[f+62160|0];break a}a=j[d>>2];j[d>>2]=a+1;h[a|0]=k[f+62160|0];j[e>>2]=j[e>>2]+1;a=0;break a}a=0;j[e>>2]=0}Za=n+16|0;return a|0}function wj(a,b,c,d,e,f,g,i,l,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;l=l|0;m=m|0;var n=0,o=0;n=Za-16|0;Za=n;j[n+12>>2]=a;a:{b:{c:{if(j[d>>2]!=(c|0)){break c}o=43;if(j[m+96>>2]!=(a|0)){o=45;if(j[m+100>>2]!=(a|0)){break c}}j[d>>2]=c+1;h[c|0]=o;break b}if(!(!nb(g)|(a|0)!=(f|0))){a=0;b=j[l>>2];if((b-i|0)>159){break a}a=j[e>>2];j[l>>2]=b+4;j[b>>2]=a;break b}a=-1;g=Tu(m,m+104|0,n+12|0)-m|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=j[d>>2];if((b|0)==(c|0)|(b-c|0)>2|k[b-1|0]!=48){break a}a=0;j[e>>2]=0;j[d>>2]=b+1;h[b|0]=k[f+62160|0];break a}a=j[d>>2];j[d>>2]=a+1;h[a|0]=k[f+62160|0];j[e>>2]=j[e>>2]+1;a=0;break a}a=0;j[e>>2]=0}Za=n+16|0;return a|0}function cq(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-16|0;Za=d;a=Qc(a);a:{b:{c:{switch(b|0){case 0:j[114626]=0;b=E(2,d|0,7167)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}ob(a,b);gb(b);break b;case 1:j[114626]=0;b=E(2,d|0,7192)|0;c=j[114626];j[114626]=0;if((c|0)!=1){ob(a,b);gb(b);break b}break a;case 2:j[114626]=0;b=E(2,d|0,7237)|0;c=j[114626];j[114626]=0;if((c|0)!=1){ob(a,b);gb(b);break b}break a;case 3:j[114626]=0;b=E(2,d|0,7264)|0;c=j[114626];j[114626]=0;if((c|0)!=1){ob(a,b);gb(b);break b}break a;case 4:j[114626]=0;b=E(2,d|0,7290)|0;c=j[114626];j[114626]=0;if((c|0)!=1){ob(a,b);gb(b);break b}break a;case 5:break c;default:break b}}j[114626]=0;b=E(2,d|0,7319)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}ob(a,b);gb(b)}Za=d+16|0;return}b=D()|0;C()|0;gb(a);G(b|0);z()}function AZ(a,b,c,d,e,f){var g=0;j[c>>2]=a;j[f>>2]=d;d=j[c>>2];a:{while(1){if(b>>>0<=d>>>0){g=0;break a}g=2;a=j[d>>2];if(a>>>0>1114111|(a&-2048)==55296){break a}b:{c:{if(a>>>0<=127){g=1;d=j[f>>2];if((e-d|0)<1){break a}j[f>>2]=d+1;h[d|0]=a;break c}if(a>>>0<=2047){d=j[f>>2];if((e-d|0)<2){break b}j[f>>2]=d+1;h[d|0]=a>>>6|192;d=j[f>>2];j[f>>2]=d+1;h[d|0]=a&63|128;break c}d=j[f>>2];g=e-d|0;if(a>>>0<=65535){if((g|0)<3){break b}j[f>>2]=d+1;h[d|0]=a>>>12|224;d=j[f>>2];j[f>>2]=d+1;h[d|0]=a>>>6&63|128;d=j[f>>2];j[f>>2]=d+1;h[d|0]=a&63|128;break c}if((g|0)<4){break b}j[f>>2]=d+1;h[d|0]=a>>>18|240;d=j[f>>2];j[f>>2]=d+1;h[d|0]=a>>>12&63|128;d=j[f>>2];j[f>>2]=d+1;h[d|0]=a>>>6&63|128;d=j[f>>2];j[f>>2]=d+1;h[d|0]=a&63|128}d=j[c>>2]+4|0;j[c>>2]=d;continue}break}return 1}return g}function EE(a){var b=0,c=0,d=0,e=0;b=Za-16|0;Za=b;e=(ZMa(a),VMa(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=hh(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<=-1){a=q(-gh(d+1.5707963267948966));break a}a=gh(d+ -1.5707963267948966);break a}a=hh(-(((e|0)>-1?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<=-1){a=gh(d+4.71238898038469);break a}a=q(-gh(d+ -4.71238898038469));break a}a=hh(((e|0)>-1?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=q(a-a);break a}b:{switch(yv(a,b+8|0)&3){case 0:a=hh(o[b+8>>3]);break a;case 1:a=gh(o[b+8>>3]);break a;case 2:a=hh(-o[b+8>>3]);break a;default:break b}}a=q(-gh(o[b+8>>3]))}Za=b+16|0;return a}function z9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=Za-32|0;Za=e;h=Db(a);a=Db(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!l[j[f>>2]+480192>>1]){break d}b=1;while(1){c=j[f>>2];j[114626]=0;c=E(2175,c|0,b&65535)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}j[114626]=0;c=E(85,e|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}d=Ec(c);j[114626]=0;E(1245,a|0,c|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}j[114626]=0;E(1988,a|0,38845)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}i=d^1|i;gb(c);b=b+1|0;if(l[j[f>>2]+480192>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}j[114626]=0;E(448,h|0,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break d}b=D()|0;C()|0;break a}gb(a);Za=e+32|0;return}b=D()|0;C()|0;break a}b=D()|0;C()|0;gb(c)}gb(a);gb(h);G(b|0);z()}function y9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=Za-32|0;Za=e;h=Db(a);a=Db(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!l[j[f>>2]+480190>>1]){break d}b=1;while(1){c=j[f>>2];j[114626]=0;c=E(2176,c|0,b&65535)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}j[114626]=0;c=E(85,e|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}d=Ec(c);j[114626]=0;E(1245,a|0,c|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}j[114626]=0;E(1988,a|0,38845)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}i=d^1|i;gb(c);b=b+1|0;if(l[j[f>>2]+480190>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}j[114626]=0;E(448,h|0,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break d}b=D()|0;C()|0;break a}gb(a);Za=e+32|0;return}b=D()|0;C()|0;break a}b=D()|0;C()|0;gb(c)}gb(a);gb(h);G(b|0);z()}function w5(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,o=0;a:{h=j[a+992>>2];b:{if(!h){e=j[a+4>>2];i=0;break b}o=t5(a,h);if(!o){break a}e=j[a+4>>2];if((e|0)>=1){m=(h|0)<1;while(1){if(!m){g=(f<<2)+a|0;k=g;e=0;while(1){l=j[g+800>>2]+(c+e<<2)|0;i=e<<2;n[l>>2]=q(n[o+(h+(e^-1)<<2)>>2]*n[i+j[k+928>>2]>>2])+q(n[i+o>>2]*n[l>>2]);e=e+1|0;if((h|0)!=(e|0)){continue}break}e=j[a+4>>2]}f=f+1|0;if((f|0)<(e|0)){continue}break}}i=j[a+992>>2]}m=b-d|0;j[a+992>>2]=m;if((e|0)>=1){f=0;while(1){if((b|0)>(d|0)){g=(f<<2)+a|0;k=g;e=0;l=d;while(1){n[j[k+928>>2]+(e<<2)>>2]=n[j[g+800>>2]+(l<<2)>>2];e=e+1|0;l=e+d|0;if((e|0)!=(m|0)){continue}break}e=j[a+4>>2]}f=f+1|0;if((f|0)<(e|0)){continue}break}}if(!i){break a}g=a;k=j[a+1416>>2];a=((b|0)<(d|0)?b:d)-c|0;j[g+1416>>2]=k+a;return a}return 0}function Kpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,l=0,m=0,n=0,o=0,q=0,r=0;l=Za-16|0;Za=l;q=l,r=p(j[a>>2],be(a)),j[q+12>>2]=r;kc(l+12|0,c);c=lb(b);h=j[e+4>>2];f=j[l+12>>2];a:{if(!f){g=h;break a}while(1){e=lb(k[c|0])|lb(k[c+1|0])<<8|lb(k[c+2|0])<<16|lb(k[c+3|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>h>>>0?e:h}c=c+4|0;h=g;f=f-1|0;if(f){continue}break}}c:{if(!g){break c}e=j[l+12>>2];if(!e){break c}m=g-1|0;n=g>>>1|0;o=g;c=j[a+20>>2];while(1){a=lb(k[b|0])|lb(k[b+1|0])<<8|lb(k[b+2|0])<<16|lb(k[b+3|0])<<24;h=a>>31;f=a;a=h;h=a<<31|f>>>1;f=n|f<<31;a=m&a>>31;q=c,r=ic(PMa(f-a|0,h-(a>>>0>f>>>0)|0,o,0),ab)>>>16|0,i[q>>1]=r;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){j[d>>2]=g}Za=l+16|0;return j[l+12>>2]}function Jpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,l=0,m=0,n=0,o=0,q=0,r=0;l=Za-16|0;Za=l;q=l,r=p(j[a>>2],be(a)),j[q+12>>2]=r;kc(l+12|0,c);c=lb(b);h=j[e+4>>2];f=j[l+12>>2];a:{if(!f){g=h;break a}while(1){e=lb(k[c+3|0])|lb(k[c+2|0])<<8|lb(k[c+1|0])<<16|lb(k[c|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>h>>>0?e:h}c=c+4|0;h=g;f=f-1|0;if(f){continue}break}}c:{if(!g){break c}e=j[l+12>>2];if(!e){break c}m=g-1|0;n=g>>>1|0;o=g;c=j[a+20>>2];while(1){a=lb(k[b+3|0])|lb(k[b+2|0])<<8|lb(k[b+1|0])<<16|lb(k[b|0])<<24;h=a>>31;f=a;a=h;h=a<<31|f>>>1;f=n|f<<31;a=m&a>>31;q=c,r=ic(PMa(f-a|0,h-(a>>>0>f>>>0)|0,o,0),ab)>>>16|0,i[q>>1]=r;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){j[d>>2]=g}Za=l+16|0;return j[l+12>>2]}function Afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=q(0),l=0,m=0,o=0,p=0,r=q(0),s=q(0),t=0,u=0,v=0,w=0;g=Za-16|0;Za=g;l=a+44|0;if(Yg(l)){v=g,w=wd(l,0),j[v+8>>2]=w;v=g,w=wd(l,1),j[v+12>>2]=w;v=g,w=Rc(l,0),j[v>>2]=w;v=g,w=Rc(l,1),j[v+4>>2]=w;if(d){t=k[a+4273|0];u=k[a+4272|0];m=d;while(1){e=0;o=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=j[f>>2];j[f>>2]=e+4;f=a+h|0;p=f+4228|0;i=q(q(n[a+4236>>2]*n[p>>2])+q(n[a+4240>>2]*n[e>>2]));n[p>>2]=i;i=q(n[a+4260>>2]*bH(q(i*q(1073741824)),u,t));e=f+4244|0;r=n[a+4264>>2];f=f+4252|0;s=n[f>>2];i=q(i-q(q(n[a+4268>>2]*n[e>>2])+q(r*s)));n[f>>2]=i;n[e>>2]=s+q(i*r);e=g+h|0;h=j[e>>2];j[e>>2]=h+4;n[h>>2]=i*q(9.313225746154785e-10);h=o;o=0;e=1;if(h){continue}break}m=m-1|0;if(m){continue}break}}Th(a,b,c,Rc(l,0),Rc(l,1),d)}Za=g+16|0}function Qva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0;e=Za-32|0;Za=e;k=j[a+40>>2];l=j[a+36>>2];m=j[a+16>>2];b=j[a+4>>2];i=b;f=j[a>>2];j[e+24>>2]=f;j[e+28>>2]=b;b=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=b;a:{if(!d){g=k>>12;b=l>>12;break a}while(1){n=f>>>10&4194048;i=(((i&2147483647)<<1|f>>>31)&-2)+m|0;g=0;b=1;while(1){f=h[i+g|0];j[(e+8|0)+(g<<2)>>2]=((p(h[(g|2)+i|0]-f|0,n)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=j[a+32>>2];l=j[a+28>>2]+l|0;b=l>>12;j[c>>2]=j[c>>2]+p(b,j[e+8>>2]);k=f+k|0;g=k>>12;j[c+4>>2]=j[c+4>>2]+p(g,j[e+12>>2]);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=j[e+24>>2];i=j[e+28>>2];continue}break}f=j[e+24>>2];i=j[e+28>>2]}j[a+40>>2]=k;j[a+20>>2]=b;j[a+36>>2]=l;j[a+24>>2]=g;j[a>>2]=f;j[a+4>>2]=i;Za=e+32|0}function FI(a,b,c,d,e,f,g){var j=0,m=0,n=0;j=Za-16|0;Za=j;h[j+15|0]=b;h[j+14|0]=10;Nf(g,k[Yb(j+15|0,j+14|0)|0]);h[g+15|0]=c;h[g+16|0]=c;h[g+14|0]=e;h[g+13|0]=d;if(sb(g)){c=0;while(1){b=p(c,3)+f|0;d=k[b|0]|k[b+1|0]<<8;m=xb(g,c),n=d>>>4|0,i[m>>1]=n;a:{b:{if(!c){e=0;d=0;break b}d=c-1|0;if(l[xb(g,c)>>1]>=l[xb(g,d)>>1]){break a}e=c;d=l[xb(g,d)>>1]+1|0}m=xb(g,e),n=d,i[m>>1]=n}b=kd(k[b+2|0],0,64);m=xb(g,c),n=b,h[m+2|0]=n;c=c+1|0;if(sb(g)>>>0>c>>>0){continue}break}}c=k[g+12|0]&-2|a&1;h[g+12|0]=c;b=g;c:{d:{if(!(a&2)){break d}d=k[g+15|0];e=sb(g);c=k[g+12|0];if(d>>>0>e>>>0){break d}c=c|4;break c}c=c&251}h[b+12|0]=c;b=g;e:{f:{if(!(a&4)){break f}a=k[g+13|0];if(a>>>0>k[g+14|0]){break f}d=sb(g);c=k[g+12|0];if(a>>>0>d>>>0){break f}a=c|2;break e}a=c&253}h[b+12|0]=a;Za=j+16|0}function Ve(a,b){var c=0,d=0,e=0;d=Za-32|0;Za=d;a=sg(a,-1,-1);a:{b:{if(k[Ji(d+24|0,b,1)|0]){c=j[j[b>>2]-12>>2];j[114626]=0;c=j[(b+c|0)+24>>2];e=j[114626];j[114626]=0;c:{d:{if((e|0)==1){break d}j[114626]=0;Ca(2317,d+8|0,c|0,0,0,1,8);c=j[114626];j[114626]=0;if((c|0)==1){break d}c=j[d+12>>2];j[a>>2]=j[d+8>>2];j[a+4>>2]=c;c=j[d+20>>2];j[a+8>>2]=j[d+16>>2];j[a+12>>2]=c;a=0;break c}a=J(0)|0;C()|0;O(a|0)|0;Hi(j[j[b>>2]-12>>2]+b|0,1);a=j[j[b>>2]-12>>2];j[114626]=0;a=j[(a+b|0)+20>>2];c=j[114626];j[114626]=0;e:{if((c|0)!=1){if(!(a&1)){break e}j[114626]=0;M(81);a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}Q();a=1}eg(j[j[b>>2]-12>>2]+b|0,a)}Za=d+32|0;return}a=J(0)|0;C()|0;ib(a)}z()}function Opa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,l=0,m=0;e=Za-16|0;Za=e;j[e+8>>2]=c>>>4;j[e+4>>2]=j[a>>2];d=j[tb(e+8|0,e+4|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){g=k[b+4|0]|k[b+5|0]<<8|(k[b+6|0]<<16|k[b+7|0]<<24);j[e+8>>2]=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);j[e+12>>2]=g;pf(e+8|0,-1,1);f=o[e+8>>3]*32768;o[e+8>>3]=f;g=a;f=zd(f);a:{if(r(f)<2147483648){h=~~f;break a}h=-2147483648}l=g,m=Dc(h),i[l>>1]=m;g=k[b+12|0]|k[b+13|0]<<8|(k[b+14|0]<<16|k[b+15|0]<<24);j[e+8>>2]=k[b+8|0]|k[b+9|0]<<8|(k[b+10|0]<<16|k[b+11|0]<<24);j[e+12>>2]=g;pf(e+8|0,-1,1);f=o[e+8>>3]*32768;o[e+8>>3]=f;g=a;f=zd(f);b:{if(r(f)<2147483648){h=~~f;break b}h=-2147483648}l=g,m=Dc(h),i[l+2>>1]=m;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<4}function Pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=Uh(a,b,c,d);j[a+4260>>2]=0;j[a>>2]=81632;c=a+4960|0;e=a+4504|0;b=e;while(1){Ij(b);b=b+24|0;if((c|0)!=(b|0)){continue}break}h[a+5046|0]=1;i[a+5044>>1]=0;j[a+4208>>2]=1063675494;j[a+4212>>2]=1065185444;j[a+4256>>2]=1059760811;b=a+4248|0;j[b>>2]=1065353216;j[b+4>>2]=1048525618;b=a+4240|0;j[b>>2]=1038174126;j[b+4>>2]=1065353216;b=a+4232|0;j[b>>2]=1047457519;j[b+4>>2]=1062836634;b=a+4224|0;j[b>>2]=1053079357;j[b+4>>2]=1059859440;b=a+4216|0;j[b>>2]=0;j[b+4>>2]=1032805417;j[114626]=0;K(1632,a+44|0,2,2)|0;b=j[114626];j[114626]=0;a:{if((b|0)!=1){j[114626]=0;N(1633,d|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;while(1){c=c-24|0;xf(c);if((c|0)!=(e|0)){continue}break}we(d);G(a|0);z()}return a|0}function kla(a,b,c,d){var e=0,f=0;e=1;b=+(a|0)-b;f=b+ -3.5;if(!(r(f)<1e-8)){a:{b:{switch(d|0){case 0:e=.5-ge(b*.8975979010256552)*.5;break a;case 1:e=ge(b*.8975979010256552)*-.46+.54;break a;case 2:b=b*.8975979010256552;e=ge(b+b);e=ge(b)*-.5+.42+e*.08;break a;case 3:b=b*.8975979010256552;e=ge(b+b);e=ge(b)*-.49364+.44959+e*.05677;break a;case 4:b=b*.8975979010256552;e=ge(b+b);e=ge(b)*-.49755+.42323+e*.07922;break a;case 5:b=b*.8975979010256552;e=ge(b+b);e=ge(b)*-.48829+.35875+e*.14128+ge(b*3)*-.01168;break a;case 6:b=b*.8975979010256552;e=ge(b+b);e=ge(b)*-.49703+.40217+e*.09392+ge(b*3)*-.00183;break a;case 7:break b;default:break a}}b=b*.8975979010256552;e=ge(b+b);e=ge(b)*-.49804+.40243+e*.09831+ge(b*3)*-.00122}b=f*3.141592653589793;c=Kh(b*c)/b}return c*e}function Qt(a,b,c,d){var e=0,f=0,g=0,j=0,m=0,n=0,o=0;f=Za-16|0;Za=f;h[f+15|0]=d;h[b+12|0]=k[a|0]&15|k[b+12|0]&240;g=a+1|0;Nf(b,k[Yb(g,f+15|0)|0]);d=k[Yb(a+2|0,f+15|0)|0];h[b+13|0]=d;n=b,o=kd(k[a+3|0],d,k[f+15|0]),h[n+14|0]=o;d=k[Yb(a+4|0,f+15|0)|0];h[b+15|0]=d;n=b,o=kd(k[a+5|0],d,k[f+15|0]),h[n+16|0]=o;h[f+14|0]=25;if(k[Yb(f+14|0,g)|0]){d=0;while(1){e=p(d,3)+a|0;j=Gb(k[e+6|0]+c<<24>>24,0,64);n=xb(b,d),o=j,h[n+2|0]=o;e=e+7|0;e=k[e|0]|k[e+1|0]<<8;n=xb(b,d),o=e,i[n>>1]=o;a:{if(!d){break a}e=d-1|0;if(l[xb(b,d)>>1]>=l[xb(b,e)>>1]){break a}if(l[xb(b,d)>>1]>255){break a}j=k[xb(b,e)+1|0];m=xb(b,d);i[m>>1]=l[m>>1]|j<<8;if(l[xb(b,d)>>1]>=l[xb(b,e)>>1]){break a}e=xb(b,d);i[e>>1]=l[e>>1]+256}h[f+14|0]=25;d=d+1|0;if(d>>>0<k[Yb(f+14|0,g)|0]){continue}break}}Za=f+16|0}function fJ(a,b,c){var d=0,e=0,f=0,g=0,i=0,l=0,m=0;e=Za-16|0;Za=e;g=-1;a:{if(!Yw(a,b,2)){break a}i=j[b+656>>2];f=a+1074308|0;mb(e+8|0,f,31);b:{if(kb(e+8|0)){d=j[b+752>>2];if(d){break b}break a}d=j[b+752>>2]}mb(e+8|0,f,31);f=d-kb(e+8|0)|0;d=j[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=To(i+88|0,f,d,j[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(k[b+748|0]&16){g=Ho(a,b,!(j[b+88>>2]&32768),d);break a}if(Wi(b)){if((d|0)==j[b+768>>2]){break a}j[b+768>>2]=d;h[b+872|0]=k[b+872|0]|8;break a}b=zo(a);j[e+8>>2]=d;f=c;c:{if((d|0)<=-1){j[e+8>>2]=0-d;Zj(e+8|0,255);a=(j[e+8>>2]<<2)+(b?26336:25312)|0;break c}Zj(e+8|0,255);a=(j[e+8>>2]<<2)+(b?25312:26336)|0}a=j[a>>2];b=a;d=a>>31;a=j[c>>2];l=f,m=ic(PMa(OMa(b,d,a,a>>31),ab,65536,0),ab),j[l>>2]=m}Za=e+16|0;return g}function eAa(a,b){var c=0,d=0,e=0,f=0;d=Za-16|0;Za=d;md(b,0);i[d+14>>1]=k[a+35|0]<<2;i[d+12>>1]=256;e=b,f=l[gf(d+14|0,d+12|0)>>1],i[e+30>>1]=f;c=a+22|0;a:{if((k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))>>>0<3){break a}j[b>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+26|0;j[b+4>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+30|0;j[d+8>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[d+4>>2]=1;e=b,f=j[Gc(d+8|0,d+4|0)>>2]-1|0,j[e+8>>2]=f;kc(b+8|0,j[b>>2]);b:{if(m[b+8>>2]<=j[b+4>>2]+4>>>0){j[b+4>>2]=0;j[b+8>>2]=0;break b}i[b+34>>1]=l[b+34>>1]|2}c=a+34|0;h[b+37|0]=k[c|0];e=b,f=ms(0,h[c|0]<<4),j[e+24>>2]=f;if(!(h[a+36|0]&1)){break a}i[b+34>>1]=l[b+34>>1]|1;j[b>>2]=j[b>>2]>>>1;j[b+4>>2]=j[b+4>>2]>>>1;j[b+8>>2]=j[b+8>>2]>>>1}Za=d+16|0}function dK(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{if(j[a+480180>>2]==4){d=k[b+833|0];if(c){h[b+833|0]=d&240|c&15;break a}c=d&15;break a}if(j[a+480180>>2]!=1048576){break a}if(c){h[b+833|0]=c;break a}c=k[b+833|0]}b:{c:{if(!(h[b+872|0]&1)|!(c&255)){break c}d=j[b+700>>2];if(!d){break c}if(!(k[a+480208|0]&16)){break b}d=j[b+700>>2];if(j[a+480180>>2]==4){break b}c=px(a,c&15);f=OMa(c,c>>31,d,d>>31)+32768|0;c=ab;c=ic(PMa(f,f>>>0<32768?c+1|0:c,65536,0),ab);j[b+700>>2]=c;if((c|0)!=(d|0)){break c}a=a+1074308|0;mb(e+8|0,a,7);if(!(kb(e+8|0)|j[b+700>>2]==2147483647)){j[b+700>>2]=j[b+700>>2]+1;break c}mb(e+8|0,a,7);if(!kb(e+8|0)){break c}a=j[b+700>>2];if((a|0)<2){break c}j[b+700>>2]=a-1}Za=e+16|0;return}a=((c&255)<<2)+d|0;j[b+700>>2]=(a|0)<65535?a:65535;Za=e+16|0}function Z4(a,b,c,d,e){var f=q(0),g=q(0),h=0,i=q(0),j=q(0),k=q(0),l=0;if((0-(a<<4)|0)<=-1){b=(c<<2)+b|0;c=b-(a<<6)|0;k=n[(e>>3<<2)+d>>2];while(1){a=b-32|0;f=n[a>>2];i=n[b>>2];n[b>>2]=f+i;d=b-4|0;g=n[d>>2];e=d;d=b-36|0;j=n[d>>2];n[e>>2]=j+g;n[a>>2]=i-f;n[d>>2]=g-j;d=b-8|0;g=n[d>>2];e=d;d=b-40|0;i=n[d>>2];n[e>>2]=i+g;e=b-12|0;f=n[e>>2];h=e;e=b-44|0;j=n[e>>2];n[h>>2]=j+f;f=q(f-j);g=q(g-i);n[d>>2]=q(f+g)*k;n[e>>2]=q(f-g)*k;d=b-20|0;g=n[d>>2];e=b-52|0;f=n[e>>2];h=b-16|0;i=n[h>>2];l=h;h=b-48|0;j=n[h>>2];n[l>>2]=i+j;n[d>>2]=f+g;n[h>>2]=g-f;n[e>>2]=j-i;d=b-60|0;g=n[d>>2];e=b-28|0;f=n[e>>2];h=b-24|0;i=n[h>>2];l=h;h=b-56|0;j=n[h>>2];n[l>>2]=i+j;n[e>>2]=g+f;g=q(f-g);f=q(j-i);n[h>>2]=q(g+f)*k;n[d>>2]=q(f-g)*k;IE(b);IE(a);b=b+ -64|0;if(c>>>0<b>>>0){continue}break}}}function VE(a){var b=q(0),c=q(0),d=q(0),e=q(0),f=q(0),g=q(0),h=q(0),i=q(0),j=q(0),k=q(0),l=q(0),m=q(0),o=q(0),p=q(0);b=n[a+32>>2];c=n[a+8>>2];e=n[a+16>>2];f=q(q(b-c)+e);i=n[a>>2];j=n[a+24>>2];k=q(i-j);n[a+16>>2]=f+k;d=n[a+4>>2];g=n[a+20>>2];h=n[a+28>>2];l=q(q(d-q(g+h))*q(.8660253882408142));k=q(k-q(f*q(.5)));n[a+4>>2]=l+k;m=q(q(g+d)*q(.9848077297210693));f=q(n[a+12>>2]*q(.8660253882408142));o=q(q(h+d)*q(-.6427876353263855));p=q(q(m-f)+o);d=q(i+q(j*q(.5)));i=q(q(b+c)*q(.7660444378852844));b=q(q(e-b)*q(.1736481785774231));j=q(q(d-i)+b);n[a+12>>2]=p+j;n[a+20>>2]=j-p;n[a+28>>2]=k-l;g=q(q(g-h)*q(.3420201539993286));h=q(g-q(f+m));c=q(q(e+c)*q(.9396926164627075));b=q(q(d+c)-b);n[a+32>>2]=h+b;e=q(q(g+f)+o);c=q(q(d-c)+i);n[a+24>>2]=e+c;n[a+8>>2]=c-e;n[a>>2]=b-h}function Cm(a,b){var c=0,d=0,e=0,f=0,g=0,i=0,m=0;c=j[b+88>>2];d=c|2048;j[b+88>>2]=d;e=j[b+656>>2];if(!(!e|h[b+724|0]&1)){d=c|6144;j[b+88>>2]=d}a:{if(!j[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=j[b+104>>2];if(!c){break b}f=l[c+34>>1];if(f&2){j[b+88>>2]=(f&4?d|4:d&-135)|2;d=j[c>>2];j[b+76>>2]=d;f=j[c+4>>2];j[b+80>>2]=f;c=j[c+8>>2];j[b+84>>2]=c;if(c>>>0<d>>>0){j[b+76>>2]=c;g=c}else{g=d}d=j[b+4>>2];if(g>>>0>=d>>>0){break b}j[b>>2]=0;j[b+4>>2]=((d-f>>>0)%(c-f>>>0)|0)+f;break b}j[b+88>>2]=d&-135;j[b+76>>2]=j[c>>2]}if(!e){break a}if(!(!j[e>>2]|(j[a+480180>>2]&1064964?0:!(k[e+60|0]&2)))){j[b+88>>2]=j[b+88>>2]|4096}if(k[e+65|0]==255|j[b+732>>2]!=-1){break a}a=e+48|0;i=b,m=To(a,j[b+728>>2],256,64),j[i+732>>2]=m;i=b,m=l[xb(a,k[e+65|0])>>1],j[i+728>>2]=m}}function b9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Za-32|0;Za=c;g=Mg(a);f=b+24|0;a=l[j[f>>2]+480192>>1];j[114626]=0;F(1525,g|0,a|0);a=j[114626];j[114626]=0;a:{if((a|0)!=1){b:{c:{d:{e:{if(l[j[f>>2]+480192>>1]){a=1;while(1){d=j[f>>2];j[114626]=0;d=E(2175,d|0,a&65535)|0;e=j[114626];j[114626]=0;if((e|0)==1){break e}j[114626]=0;d=E(85,c|0,d|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break e}j[114626]=0;I(2177,c+16|0,b|0,d|0);e=j[114626];j[114626]=0;if((e|0)==1){break d}j[114626]=0;F(1527,g|0,c+16|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}gb(c+16|0);gb(d);a=a+1|0;if(l[j[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}Za=c+32|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;gb(c+16|0)}gb(d);break a}a=D()|0;C()|0}Uc(g);G(a|0);z()}function a9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Za-32|0;Za=c;g=Mg(a);f=b+24|0;a=l[j[f>>2]+480190>>1];j[114626]=0;F(1525,g|0,a|0);a=j[114626];j[114626]=0;a:{if((a|0)!=1){b:{c:{d:{e:{if(l[j[f>>2]+480190>>1]){a=1;while(1){d=j[f>>2];j[114626]=0;d=E(2176,d|0,a&65535)|0;e=j[114626];j[114626]=0;if((e|0)==1){break e}j[114626]=0;d=E(85,c|0,d|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break e}j[114626]=0;I(2177,c+16|0,b|0,d|0);e=j[114626];j[114626]=0;if((e|0)==1){break d}j[114626]=0;F(1527,g|0,c+16|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}gb(c+16|0);gb(d);a=a+1|0;if(l[j[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}Za=c+32|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;gb(c+16|0)}gb(d);break a}a=D()|0;C()|0}Uc(g);G(a|0);z()}function w$(a,b,c,d,e,f,g,i,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;k=k|0;l=l|0;var m=0,n=0,o=0;m=Za-16|0;Za=m;a:{if(a){a=RC(c);b:{if(b){pj(m,a);b=j[m>>2];h[d|0]=b;h[d+1|0]=b>>>8;h[d+2|0]=b>>>16;h[d+3|0]=b>>>24;oj(m,a);break b}pq(m,a);b=j[m>>2];h[d|0]=b;h[d+1|0]=b>>>8;h[d+2|0]=b>>>16;h[d+3|0]=b>>>24;Fg(m,a)}Dh(k,m);pc(m);n=e,o=Hh(a),j[n>>2]=o;n=f,o=Gh(a),j[n>>2]=o;Uf(m,a);ob(g,m);gb(m);Gg(m,a);Dh(i,m);pc(m);a=nj(a);break a}a=QC(c);c:{if(b){pj(m,a);b=j[m>>2];h[d|0]=b;h[d+1|0]=b>>>8;h[d+2|0]=b>>>16;h[d+3|0]=b>>>24;oj(m,a);break c}pq(m,a);b=j[m>>2];h[d|0]=b;h[d+1|0]=b>>>8;h[d+2|0]=b>>>16;h[d+3|0]=b>>>24;Fg(m,a)}Dh(k,m);pc(m);n=e,o=Hh(a),j[n>>2]=o;n=f,o=Gh(a),j[n>>2]=o;Uf(m,a);ob(g,m);gb(m);Gg(m,a);Dh(i,m);pc(m);a=nj(a)}j[l>>2]=a;Za=m+16|0}function Wla(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=Za-48|0;Za=e;c=78928;g=Vla(e+32|0);a=Qc(a);while(1){if(j[c>>2]==(b|0)){f=j[c+4>>2];j[114626]=0;f=E(2,e+16|0,f|0)|0;d=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{if((d|0)!=1){j[114626]=0;I(1513,e|0,g|0,f|0);d=j[114626];j[114626]=0;if((d|0)==1){break d}if(!k[e+4|0]){break a}if(!Ec(a)){j[114626]=0;d=E(2,e|0,20816)|0;h=j[114626];j[114626]=0;if((h|0)==1){break f}j[114626]=0;E(192,a|0,d|0)|0;h=j[114626];j[114626]=0;if((h|0)==1){break e}gb(d)}j[114626]=0;E(192,a|0,f|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break a}c=D()|0;C()|0;break c}c=D()|0;C()|0;break b}c=D()|0;C()|0;break c}c=D()|0;C()|0;gb(d);break c}c=D()|0;C()|0}gb(f)}gb(a);WI(g);G(c|0);z()}gb(f)}c=c+12|0;if((c|0)!=78976){continue}break}WI(g);Za=e+48|0}function Rpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=q(0),h=0,l=0,m=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>3;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){f=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);j[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);Kd(e+12|0,q(-1));g=q(n[e+12>>2]*q(32768));n[e+12>>2]=g;f=a;g=Sd(g);a:{if(q(r(g))<q(2147483648)){h=~~g;break a}h=-2147483648}l=f,m=Dc(h),i[l>>1]=m;f=k[b+4|0]|k[b+5|0]<<8|(k[b+6|0]<<16|k[b+7|0]<<24);j[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);Kd(e+12|0,q(-1));g=q(n[e+12>>2]*q(32768));n[e+12>>2]=g;f=a;g=Sd(g);b:{if(q(r(g))<q(2147483648)){h=~~g;break b}h=-2147483648}l=f,m=Dc(h),i[l+2>>1]=m;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<3}function Bva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=Za-32|0;Za=e;k=j[a+24>>2];l=j[a+20>>2];m=j[a+16>>2];g=j[a+4>>2];b=g;f=j[a>>2];j[e+24>>2]=f;j[e+28>>2]=b;g=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+m|0;b=(f>>>21&2040)+27888|0;n=i[b+6>>1];o=i[b+4>>1];q=i[b+2>>1];r=i[b>>1];h=0;b=1;while(1){f=h<<1;j[(e+8|0)+(h<<2)>>2]=(((p(i[f+g>>1],q)+p(i[(f|-4)+g>>1],r)|0)+p(i[(f|4)+g>>1],o)|0)+p(i[(f|8)+g>>1],n)|0)/16384;f=b;b=0;h=1;if(f){continue}break}j[c>>2]=j[c>>2]+p(j[e+8>>2],l);j[c+4>>2]=j[c+4>>2]+p(j[e+12>>2],k);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=j[e+24>>2];b=j[e+28>>2];continue}break}f=j[e+24>>2];b=j[e+28>>2]}j[a>>2]=f;j[a+4>>2]=b;Za=e+32|0}function oP(a){var b=0,c=0;a:{if(Yc(a,15083,3)){break a}b=a+3|0;if(k[b|0]<48|k[b|0]>51){break a}b=a+8|0;c=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<52){break a}b=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>4294966507){break a}b=a+16|0;b=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}b=a+24|0;if(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24)){b=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}}a=a+32|0;a=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);return(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0<4294967216}return 0}function Tka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;md(c,0);i[c+28>>1]=k[a+36|0]<<2;d=k[a+37|0];i[c+32>>1]=64;i[c+30>>1]=d<<2;d=a+40|0;j[c>>2]=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=a+44|0;j[c+4>>2]=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=a+48|0;j[c+8>>2]=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=a+52|0;j[c+24>>2]=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);d=b+151|0;if(k[d|0]<5){h[c+38|0]=k[k[d|0]+31850|0]}h[c+39|0]=k[b+152|0];d=b+156|0;h[c+41|0]=(k[d|0]|k[d+1|0]<<8)>>>4;b=b+154|0;b=(k[b|0]|k[b+1|0]<<8)>>>2|0;h[c+40|0]=b;if(k[c+41|0]|b&255){h[c+39|0]=k[c+39|0]^-1}a=a+38|0;if(k[a|0]&4){i[c+34>>1]=l[c+34>>1]|1}if(k[a|0]&8){i[c+34>>1]=l[c+34>>1]|2}if(k[a|0]&16){i[c+34>>1]=l[c+34>>1]|4}if(k[a|0]&32){i[c+34>>1]=l[c+34>>1]|32}}function QG(a){var b=0,c=0,d=0,e=0,f=0,g=q(0),h=0,i=0,k=0,l=0,o=0,p=0,r=q(0);c=xe(j[a+16>>2]);g=q(q(n[a+4220>>2]*q(.9980000257492065))+q(.0010000000474974513));d=-9965.784284662086/+q(q(q(n[a+4216>>2]*q(2999.9990234375))+q(.0010000000474974513))*q(c>>>0));p=a,r=q(Bg(d*+m[a+4288>>2])),n[p+4232>>2]=r;p=a+4236|0,r=q(Bg(d*+m[a+4292>>2])),n[p>>2]=r;o=d*(1/+g+ -1);c=0;h=a+4272|0;i=a+4232|0;while(1){k=j[(c<<2)+h>>2];e=c<<1&-4;f=Bg(o*+(k+j[(e+h|0)+16>>2]>>>0));b=Bg(d*+(k>>>0));g=n[e+i>>2];e=(c<<3)+i|0;f=f*.5;n[e+12>>2]=b*(.5-f);n[e+8>>2]=b*(f+.5);b=b*+g;b=(((b+1)*b+1)*b+1)*b+1;l=b*b+l;c=c+1|0;if((c|0)!=4){continue}break}d=Bg(+PG(n[a+4208>>2])*.16609640474436813);b=Bg(+PG(n[a+4212>>2])*.33219280948873625);n[a+4228>>2]=d*4*y(b)/y(l);n[a+4224>>2]=d*y(1-b)}function A$(a,b,c,d,e,f,g,i,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;k=k|0;l=l|0;var m=0,n=0,o=0;m=Za-16|0;Za=m;a:{if(a){a=VC(c);b:{if(b){pj(m,a);b=j[m>>2];h[d|0]=b;h[d+1|0]=b>>>8;h[d+2|0]=b>>>16;h[d+3|0]=b>>>24;oj(m,a);break b}pq(m,a);b=j[m>>2];h[d|0]=b;h[d+1|0]=b>>>8;h[d+2|0]=b>>>16;h[d+3|0]=b>>>24;Fg(m,a)}ob(k,m);gb(m);n=e,o=Hh(a),h[n|0]=o;n=f,o=Gh(a),h[n|0]=o;Uf(m,a);ob(g,m);gb(m);Gg(m,a);ob(i,m);gb(m);a=nj(a);break a}a=UC(c);c:{if(b){pj(m,a);b=j[m>>2];h[d|0]=b;h[d+1|0]=b>>>8;h[d+2|0]=b>>>16;h[d+3|0]=b>>>24;oj(m,a);break c}pq(m,a);b=j[m>>2];h[d|0]=b;h[d+1|0]=b>>>8;h[d+2|0]=b>>>16;h[d+3|0]=b>>>24;Fg(m,a)}ob(k,m);gb(m);n=e,o=Hh(a),h[n|0]=o;n=f,o=Gh(a),h[n|0]=o;Uf(m,a);ob(g,m);gb(m);Gg(m,a);ob(i,m);gb(m);a=nj(a)}j[l>>2]=a;Za=m+16|0}function Xn(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;YMa(+a);b=VMa(1)|0;e=VMa(0)|0;a:{b:{c:{d:{if((b|0)>0?1:(b|0)>=0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|e)){return-1/(a*a)}if((b|0)>-1){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(e){break b}return 0}YMa(+(a*0x40000000000000));b=VMa(1)|0;e=VMa(0)|0;g=-1077}b=b+614242|0;d=+((b>>>20|0)+g|0);WMa(0,e|0);WMa(1,(b&1048575)+1072079006|0);a=+XMa()+ -1;c=a/(a+2);h=d*.6931471803691238;i=a;j=d*1.9082149292705877e-10;k=c;d=a*(a*.5);c=c*c;a=c*c;a=h+(i+(j+k*(d+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))-d))}return a}function Mpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,l=0,m=0,n=0,o=0,q=0,r=0;l=Za-16|0;Za=l;q=l,r=p(j[a>>2],be(a)),j[q+12>>2]=r;kc(l+12|0,c);c=lb(b);h=j[e+4>>2];f=j[l+12>>2];a:{if(!f){g=h;break a}while(1){e=lb(k[c|0]);e=lb(k[c+1|0])<<16|e<<8|lb(k[c+2|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>h>>>0?e:h}c=c+3|0;h=g;f=f-1|0;if(f){continue}break}}c:{if(!g){break c}e=j[l+12>>2];if(!e){break c}m=g-1|0;n=g>>>1|0;o=g;c=j[a+20>>2];while(1){a=lb(k[b|0]);a=lb(k[b+1|0])<<16|a<<8|lb(k[b+2|0])<<24;h=a>>31;f=a;a=h;h=a<<31|f>>>1;f=n|f<<31;a=m&a>>31;q=c,r=ic(PMa(f-a|0,h-(a>>>0>f>>>0)|0,o,0),ab)>>>16|0,i[q>>1]=r;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){j[d>>2]=g}Za=l+16|0;return j[l+12>>2]}function Lpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,l=0,m=0,n=0,o=0,q=0,r=0;l=Za-16|0;Za=l;q=l,r=p(j[a>>2],be(a)),j[q+12>>2]=r;kc(l+12|0,c);c=lb(b);h=j[e+4>>2];f=j[l+12>>2];a:{if(!f){g=h;break a}while(1){e=lb(k[c+2|0]);e=lb(k[c+1|0])<<16|e<<8|lb(k[c|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>h>>>0?e:h}c=c+3|0;h=g;f=f-1|0;if(f){continue}break}}c:{if(!g){break c}e=j[l+12>>2];if(!e){break c}m=g-1|0;n=g>>>1|0;o=g;c=j[a+20>>2];while(1){a=lb(k[b+2|0]);a=lb(k[b+1|0])<<16|a<<8|lb(k[b|0])<<24;h=a>>31;f=a;a=h;h=a<<31|f>>>1;f=n|f<<31;a=m&a>>31;q=c,r=ic(PMa(f-a|0,h-(a>>>0>f>>>0)|0,o,0),ab)>>>16|0,i[q>>1]=r;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){j[d>>2]=g}Za=l+16|0;return j[l+12>>2]}function _v(a,b,c,d,e,f){var g=0,i=0,k=q(0),l=0;g=Za-96|0;Za=g;i=a+24|0;oo(j[i>>2]);h[j[i>>2]+1304512|0]=j[a+52>>2]!=0;j[g+92>>2]=f;j[g+88>>2]=e;j[g+84>>2]=d;j[g+80>>2]=c;c=hG(g+32|0,g+80|0,iG(g+80|0),b);d=j[a+32>>2];k=n[a+48>>2];e=j[c+12>>2];j[g+8>>2]=j[c+8>>2];j[g+12>>2]=e;e=j[c+4>>2];j[g>>2]=j[c>>2];j[g+4>>2]=e;d=vaa(g+48|0,g,d,k);e=0;a:{while(1){if(b){c=j[i>>2];j[g+24>>2]=b;j[g+28>>2]=0;j[114626]=0;j[g+16>>2]=134217727;j[g+20>>2]=0;f=E(2145,g+24|0,g+16|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break a}f=j[f>>2];j[114626]=0;c=K(2146,c|0,f|0,d|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}e=c+e|0;b=b-c|0;if(c){continue}}break}if(!(j[a+52>>2]!=1|e)){a=j[i>>2];j[a+480208>>2]=j[a+480208>>2]&-513}Za=g+96|0;return e}a=D()|0;C()|0;G(a|0);z()}function Zv(a,b,c,d,e,f){var g=0,i=0,k=q(0),l=0;g=Za-96|0;Za=g;i=a+24|0;oo(j[i>>2]);h[j[i>>2]+1304512|0]=j[a+52>>2]!=0;j[g+92>>2]=f;j[g+88>>2]=e;j[g+84>>2]=d;j[g+80>>2]=c;c=hG(g+32|0,g+80|0,iG(g+80|0),b);d=j[a+32>>2];k=n[a+48>>2];e=j[c+12>>2];j[g+8>>2]=j[c+8>>2];j[g+12>>2]=e;e=j[c+4>>2];j[g>>2]=j[c>>2];j[g+4>>2]=e;d=saa(g+48|0,g,d,k);e=0;a:{while(1){if(b){c=j[i>>2];j[g+24>>2]=b;j[g+28>>2]=0;j[114626]=0;j[g+16>>2]=134217727;j[g+20>>2]=0;f=E(2145,g+24|0,g+16|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break a}f=j[f>>2];j[114626]=0;c=K(2146,c|0,f|0,d|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}e=c+e|0;b=b-c|0;if(c){continue}}break}if(!(j[a+52>>2]!=1|e)){a=j[i>>2];j[a+480208>>2]=j[a+480208>>2]&-513}Za=g+96|0;return e}a=D()|0;C()|0;G(a|0);z()}function Y7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-80|0;Za=d;a=j[a+4>>2];iu(d+16|0,b);j[114626]=0;b=E(2,d|0,38630)|0;e=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){j[114626]=0;I(3,d+32|0,d+16|0,b|0);e=j[114626];j[114626]=0;if((e|0)==1){break h}j[114626]=0;I(720,d+48|0,d+32|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break g}j[114626]=0;I(9,d- -64|0,0,d+48|0);c=j[114626];j[114626]=0;if((c|0)==1){break f}c=j[j[a>>2]+8>>2];j[114626]=0;F(c|0,a|0,d- -64|0);a=j[114626];j[114626]=0;if((a|0)==1){break e}gb(d- -64|0);gb(d+48|0);gb(d+32|0);gb(b);gb(d+16|0);Za=d+80|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;break c}a=D()|0;C()|0;break d}a=D()|0;C()|0;gb(d- -64|0)}gb(d+48|0)}gb(d+32|0)}gb(b)}gb(d+16|0);G(a|0);z()}function Lx(a,b,c){var d=0,e=0,f=0,g=0,i=0;a:{g=qsa(a,b);if((g|0)==255){break a}b=0;if(Ti(a)){break a}e=oi(a+314|0,g);d=k[c+8|0]|k[c+9|0]<<8|(k[c+10|0]<<16|k[c+11|0]<<24);h[e+8|0]=d;h[e+9|0]=d>>>8;h[e+10|0]=d>>>16;h[e+11|0]=d>>>24;d=k[c+4|0]|k[c+5|0]<<8|(k[c+6|0]<<16|k[c+7|0]<<24);f=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);h[e|0]=f;h[e+1|0]=f>>>8;h[e+2|0]=f>>>16;h[e+3|0]=f>>>24;h[e+4|0]=d;h[e+5|0]=d>>>8;h[e+6|0]=d>>>16;h[e+7|0]=d>>>24;f=zL(g);i=f+3|0;d=1;while(1){e=d;d=d?f:i;Og(j[a>>2],(d|32)&65535,k[Pb(c,b)|0]);Og(j[a>>2],(d|64)&65535,k[Pb(c,b|2)|0]);Og(j[a>>2],(d|96)&65535,k[Pb(c,b|4)|0]);Og(j[a>>2],(d|128)&65535,k[Pb(c,b|6)|0]);Og(j[a>>2],(d|224)&65535,k[Pb(c,b|8)|0]);d=0;b=1;if(e){continue}break}Og(j[a>>2],gs(g)|192,k[Pb(c,10)|0])}}function Via(a,b,c){var d=0,e=0,f=q(0),g=0,h=0,k=0;a:{if(c){g=j[a+36>>2];if(g){break a}}return Tk(a,b+c<<16>>16)}d=g+1|0;b:{if((c|0)>=0){e=c;c=(c|0)/(d|0)|0;e=e-p(d,c)|0;break b}e=g-((c^-1)%(d|0)|0)|0;c=((c+1|0)/(d|0)|0)-1|0}k=i[a+28>>1];h=a+4|0;sb(h);f=q(1);c=b+c<<16>>16;c:{if((c|0)<(k|0)){break c}if((c|0)>(l[a+28>>1]+sb(h)<<16)-65536>>16){break c}if(!e){return n[xb(h,c-i[a+28>>1]|0)>>2]}b=l[a>>1];d:{if((b|0)==3){b=a+16|0;if(sb(b)){f=n[xb(b,e-1|0)>>2];break d}b=l[a>>1]}e:{if((b&65535)!=1){break e}b=a+16|0;if(!sb(b)){break e}d=l[a+30>>1];if((c|0)>=0){d=(c|0)%(d|0)|0}else{d=d+((c^-1)%(d|0)^-1)|0}f=n[xb(b,(p(d<<16>>16,g)+e|0)-1|0)>>2];break d}f=Yd(q(Tk(a,(c<<16)+65536>>16)/Tk(a,c)),q(q(e|0)/q(d|0)))}f=q(n[xb(h,c-i[a+28>>1]|0)>>2]*f)}return f}function Lw(a){a=a|0;var b=0;a:{b:{c:{if(k[a+3|0]!=19){break c}h[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=k[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}h[a+3|0]=2;break a}h[a+3|0]=3;break a}h[a+5|0]=b&15|16;return}h[a+5|0]=b&3|48;return}h[a+5|0]=b&15|32;return}h[a+5|0]=b&15|176;return}h[a+5|0]=b&3|64;return}h[a+3|0]=15;h[a+5|0]=b&15;return}if(b&15){h[a+3|0]=11;h[a+5|0]=b<<4|15;return}break b}if(b&15){h[a+3|0]=11;break a}break b}if((b|0)!=192){break c}h[a|0]=254;break b}if((b|0)!=208){break c}h[a+3|0]=0}return}h[a+3|0]=0;return}h[a+5|0]=b|240}function Hla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Za-80|0;Za=c;h=pL(a,1<<b-1);j[a+12>>2]=b;a:{b=1<<b;f=b>>>2|0;if(f){i=1/+(b>>>0);b=f;e=1;while(1){j[114626]=0;o[c+40>>3]=+(b>>>0)*-6.283185307179586*i;I(1522,c+48|0,30864,c+40|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;F(1214,c- -64|0,c+48|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=_b(h,e);g=j[c+76>>2];j[d+8>>2]=j[c+72>>2];j[d+12>>2]=g;g=j[c+68>>2];j[d>>2]=j[c+64>>2];j[d+4>>2]=g;e=e<<1;b=b>>>1|0;if(b){continue}break}}b=cl(c+24|0,1,0);j[114626]=0;e=j[b+12>>2];j[c+16>>2]=j[b+8>>2];j[c+20>>2]=e;e=j[b+4>>2];j[c+8>>2]=j[b>>2];j[c+12>>2]=e;L(1523,a|0,0,f|0,c+8|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}Za=c+80|0;return a|0}a=D()|0;C()|0;Ko(h);G(a|0);z()}function $wa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;if(!(k[b+5|0]|k[b+3|0]!=4)){Nd(d+8|0,a,l[a+14>>1]);Qd(d+8|0,0);h[b+3|0]=0}c=k[b+2|0];a:{if((c|0)!=11){break a}c=11;if(k[b+4|0]){break a}Nd(d+8|0,a,l[a+14>>1]);c=0;Qd(d+8|0,0);h[b+2|0]=0}b:{c:{d:{if(!k[b|0]){Nd(d+8|0,a,l[a+14>>1]);if(kb(d+8|0)){break d}c=k[b+2|0]}e=k[b+3|0];Nd(d+8|0,a,l[a+14>>1]);Qd(d+8|0,(e|0)==4|(c|0)==11);c=k[b+3|0];break c}c=k[b+3|0];e=k[b+2|0];if(!(c|(e|0)==11)){h[b+5|0]=0;h[b+3|0]=4;break b}if(e|(c|0)==4){break c}h[b+4|0]=0;h[b+2|0]=11}e:{if(!(!k[a+16|0]|c)){h[b+5|0]=125;h[b+3|0]=17;break e}f:{switch(c-16|0){case 0:break f;case 1:break e;default:break b}}if(k[b+5|0]){break b}h[b+5|0]=6;h[a+16|0]=1;break b}h[a+16|0]=0}i[a+14>>1]=(l[a+14>>1]+1>>>0)%l[a+12>>1];Za=d+16|0}function eHa(a,b){var c=0,d=0;d=Za-32|0;Za=d;md(b,0);si(d,1,a);qc(d+16|0,d);j[114626]=0;E(370,b+43|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){gb(d+16|0);c=a+16|0;j[b>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+20|0;j[b+4>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+24|0;j[b+8>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+28|0;j[b+24>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);i[b+30>>1]=k[a+32|0]<<2;i[b+28>>1]=k[a+33|0];a=a+48|0;if(h[a|0]&1){i[b+34>>1]=l[b+34>>1]|2}if(k[a|0]&2){i[b+34>>1]=l[b+34>>1]|4}if(k[a|0]&4){i[b+34>>1]=l[b+34>>1]|1;j[b>>2]=j[b>>2]>>>1;j[b+4>>2]=j[b+4>>2]>>>1;j[b+8>>2]=j[b+8>>2]>>>1}if(k[a|0]&8){i[b+34>>1]=l[b+34>>1]|32}Za=d+32|0;return}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function Oya(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;c=Za-16|0;Za=c;f=Db(a+4|0);d=Hya(a+16|0);h[a+20|0]=0;g=Bya(a+24|0);j[114626]=0;N(80,c+8|0);b=j[114626];j[114626]=0;a:{b:{c:{if((b|0)!=1){dy(d,ud(c+8|0));bf(c+8|0);h[a+20|0]=0;b=0;break c}b=qa(71396,71372)|0;e=C()|0;if((e|0)==(W(71396)|0)){O(b|0)|0;j[114626]=0;M(81);a=j[114626];j[114626]=0;if((a|0)==1){b=D()|0;C()|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)!=1){break b}a=J(0)|0;C()|0;ib(a)}z()}if((W(71372)|0)!=(e|0)){break b}O(b|0)|0;h[a+20|0]=0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){b=D()|0;C()|0;break b}b=k[a+20|0]}if(b&255){break a}j[114626]=0;N(82,a|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}b=D()|0;C()|0}bf(g);bf(d);gb(f);G(b|0);z()}Za=c+16|0;return a|0}function Ida(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,n=0,o=0;if(m[b+24>>2]>m[b+44>>2]){j[b+44>>2]=j[b+24>>2]}l=-1;n=-1;h=f&24;a:{if(!h|((h|0)==24?(e|0)==1:0)){break a}h=j[b+44>>2];if(h){g=h-zb(b+32|0)|0;o=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=j[b+12>>2]-j[b+8>>2]|0;i=e;k=e>>31;break b}e=j[b+24>>2]-j[b+20>>2]|0;i=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}i=o;k=g}d=d+k|0;c=c+i|0;d=i>>>0>c>>>0?d+1|0:d;e=c;c=d;if((d|0)<0|((d|0)>(g|0)?1:(g|0)<=(d|0)?e>>>0>o>>>0:0)){break a}d=f&8;d:{if(!(c|e)){break d}if(j[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!j[b+24>>2]){break a}}if(d){sm(b,j[b+8>>2],e+j[b+8>>2]|0,j[b+44>>2])}if(f&16){hw(b,j[b+20>>2],j[b+28>>2]);kr(b,e)}l=e;n=c}sg(a,l,n)}function cza(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;md(b,0);si(d,1,a);qc(d+16|0,d);j[114626]=0;E(370,b+43|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){gb(d+16|0);c=a+48|0;j[b>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+52|0;j[b+4>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+56|0;j[b+8>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+62|0;j[b+24>>2]=k[c|0]|k[c+1|0]<<8;ls(b,+((k[a+60|0]^8)-120|0)*.005208333333333333);h[d+16|0]=k[a+61|0];h[d|0]=64;e=b,f=k[Yb(d+16|0,d)|0]<<2,i[e+30>>1]=f;i[b+34>>1]=0;a=a+47|0;if(k[a|0]&4){i[b+34>>1]=l[b+34>>1]|1;j[b>>2]=j[b>>2]>>>1}if(k[a|0]&32){i[b+34>>1]=l[b+34>>1]|4}if(h[a|0]<=-1){i[b+34>>1]=l[b+34>>1]|2}Za=d+32|0;return}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function tD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,k=0;g=Za-272|0;Za=g;h=j[b>>2];j[g+12>>2]=h;i=a?a:g+16|0;e=0;a:{b:{c:{d=a?d:256;if(!d|!h){break c}f=c>>>0<d>>>0;if(!(c>>>0>32|c>>>0>=d>>>0)){break b}while(1){f=f?c:d;c=c-f|0;f=q2(i,g+12|0,f);if((f|0)==-1){d=0;h=j[g+12>>2];e=-1;break c}h=(g+16|0)==(i|0);i=h?i:f+i|0;e=e+f|0;d=d-(h?0:f)|0;h=j[g+12>>2];if(!d|!h){break c}f=c>>>0<d>>>0;if(c>>>0>32|c>>>0>=d>>>0){continue}break}break b}if(!h){break a}}if(!d|!c){break a}f=e;while(1){d:{k=Cj(i,j[h>>2],0);e:{if(k+1>>>0<=1){e=-1;if(k){break a}j[g+12>>2]=0;break e}h=j[g+12>>2]+4|0;j[g+12>>2]=h;f=f+k|0;d=d-k|0;if(d){break d}}e=f;break a}i=i+k|0;e=f;c=c-1|0;if(c){continue}break}}if(a){j[b>>2]=j[g+12>>2]}Za=g+272|0;return e|0}function hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-32|0;Za=d;j[114626]=0;N(2008,a|0);e=j[114626];j[114626]=0;a:{b:{c:{if((e|0)==1){break c}j[114626]=0;N(2034,b|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;N(2034,c|0);f=j[114626];j[114626]=0;e=1;if((f|0)==1){break c}f=j[a+24>>2];b=Zb(d+24|0,b);c=Zb(d+16|0,c);j[114626]=0;g=j[b+4>>2];j[d+8>>2]=j[b>>2];j[d+12>>2]=g;b=j[c+4>>2];j[d>>2]=j[c>>2];j[d+4>>2]=b;L(2078,f|0,d+8|0,d|0,1);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37201,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();e=0}Za=d+32|0;return e|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function YI(a,b){var c=q(0),d=q(0),e=q(0);a:{b:{c:{switch(b|0){case 0:mo(a,q(1));lo(a,q(3.725290298461914e-9));ko(a,q(268435456));jo(a,0);break b;case 1:mo(a,q(32));lo(a,q(4.656612873077393e-10));ko(a,q(2147483648));jo(a,0);break b;case 2:mo(a,q(2));lo(a,q(7.450580596923828e-9));ko(a,q(134217728));jo(a,1);break b;default:mo(a,q(1));lo(a,q(7.450580596923828e-9));ko(a,q(134217728));jo(a,1);Vw(a,0);Wk(a,1);Uw(a,1);d=q(256);c=q(128);e=q(128);b=0;break a;case 4:case 5:break c}}mo(a,q(.75));lo(a,q(7.450580596923828e-9));ko(a,q(134217728));jo(a,1);Vw(a,0);b=(b|0)==4;Wk(a,b?2:3);Uw(a,1);d=q(256);c=b?q(256):q(192);e=c;b=1;break a}Vw(a,1);Wk(a,0);Uw(a,0);d=q(128);e=q(100);c=q(256);b=4}n[a+16>>2]=c;n[a+20>>2]=e;n[a+24>>2]=d;j[a+28>>2]=b}function yW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Za-96|0;Za=g;fi(g+48|0,g+40|0,c);j[114626]=0;I(224,g+60|0,g+32|0,d|0);d=j[114626];j[114626]=0;c=1;a:{b:{c:{d:{e:{if((d|0)!=1){j[114626]=0;I(224,g+72|0,g+24|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break e}j[114626]=0;I(224,g+84|0,g+16|0,f|0);c=j[114626];j[114626]=0;if((c|0)==1){break d}j[114626]=0;F(225,g+8|0,g+48|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(72,a|0,b|0,g+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}zB(g+48|0);Za=g+96|0;return}a=D()|0;C()|0;break c}a=D()|0;c=2;C()|0;break c}a=D()|0;C()|0;c=3}c=(g+48|0)+p(c,12)|0;while(1){c=gb(c-12|0);if((c|0)!=(g+48|0)){continue}break}break a}a=D()|0;C()|0;zB(g+48|0)}G(a|0);z()}function Cva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=Za-32|0;Za=e;l=j[a+24>>2];m=j[a+20>>2];n=j[a+16>>2];b=j[a+4>>2];f=j[a>>2];j[e+24>>2]=f;j[e+28>>2]=b;g=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=g;if(d){while(1){k=(((b&2147483647)<<1|f>>>31)&-2)+n|0;b=(f>>>21&2040)+27888|0;o=i[b+6>>1];q=i[b+4>>1];r=i[b+2>>1];s=i[b>>1];g=0;b=1;while(1){j[(e+8|0)+(g<<2)>>2]=(((p(h[g+k|0],r)+p(h[(g|-2)+k|0],s)|0)+p(h[(g|2)+k|0],q)|0)+p(h[(g|4)+k|0],o)<<8)/16384;f=b;b=0;g=1;if(f){continue}break}j[c>>2]=j[c>>2]+p(j[e+8>>2],m);j[c+4>>2]=j[c+4>>2]+p(j[e+12>>2],l);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=j[e+24>>2];b=j[e+28>>2];continue}break}f=j[e+24>>2];b=j[e+28>>2]}j[a>>2]=f;j[a+4>>2]=b;Za=e+32|0}function RJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Db(a);g=nb(b);j[114626]=0;F(523,f|0,g|0);a=j[114626];j[114626]=0;if((a|0)!=1){a:{if(g){while(1){a=d+1|0;e=k[Ub(b,d)|0];b:{c:{if((a|0)==(g|0)|(e|0)!=37){break c}e=k[Ub(b,a)|0];d=e-49|0;if((d&255)>>>0<=8){if(vJa(c)>>>0<=d>>>0){d=a;break b}j[114626]=0;d=E(524,c|0,d|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;E(525,f|0,d|0)|0;e=j[114626];j[114626]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}j[114626]=0;K(526,f|0,1,37)|0;h=j[114626];j[114626]=0;d=a;if((h|0)==1){break a}}j[114626]=0;K(526,f|0,1,e<<24>>24)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}return}}a=D()|0;C()|0;gb(f);G(a|0);z()}function nua(a){var b=0,c=0,d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;zc(d+8|0,a);a:{b:{c:{f=a+16|0;d:{if(bd(f)){while(1){e:{e=j[f>>2];j[114626]=0;e=H(98,e|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break e}c=c|e;b=b+32|0;if(b>>>0<32){continue}break d}break}b=J(71372)|0;if((C()|0)!=(W(71372)|0)){break a}O(b|0)|0;h[a+20|0]=0;j[114626]=0;N(82,a|0);b=j[114626];j[114626]=0;if((b|0)==1){break c}j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){break d}b=D()|0;C()|0;break a}h[a+20|0]=0}if(!k[a+20|0]){a=j[a+24>>2];j[114626]=0;a=H(99,a|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}c=a^c}Za=d+16|0;return c}b=D()|0;C()|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=J(0)|0;C()|0;ib(a);z()}b=D()|0;C()|0}G(b|0);z()}function NQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0;e=Za-32|0;Za=e;j[e+24>>2]=b;m=e,n=nd(a),j[m+8>>2]=n;g=En(e+24|0,e+8|0);b=ti(c,d);a:{b:{if(!b){break b}if(nz(c,zb(a),zb(a)+nb(a)|0)){b=Zh(e+8|0,c,d);c=j[e+24>>2];d=zb(b);g=zb(b);i=nb(b);j[114626]=0;c=P(610,a|0,c|0,d|0,g+i|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){gb(b);break a}a=D()|0;C()|0;gb(b);G(a|0);z()}i=nb(a);f=sc(a);c:{if(b>>>0<=f-i>>>0){f=zb(a);k=i-g|0;if(!k){break c}l=g+f|0;Fl(b+l|0,l,k);break c}tl(a,f,(b+i|0)-f|0,i,g,0,b);f=j[a>>2]}b=b+i|0;Ag(a,b);h[e+8|0]=0;Td(b+f|0,e+8|0);if((c|0)==(d|0)){break b}b=g+f|0;while(1){Td(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}m=e,n=nd(a),j[m+8>>2]=n;c=$e(e+8|0,g)}Za=e+32|0;return c|0}function iF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=Za-16|0;Za=f;a:{b:{c:{d:{if((b|0)>=0){if((Qk(a+8|0)|0)>(b|0)){break d}}b=R(8)|0;j[114626]=0;c=E(85,f|0,40657)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}d=a+32|0;a=(j[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;j[a>>2]=c|j[a>>2]&-134218753;a=(j[d>>2]+p(b,896)|0)+1075072|0;j[a>>2]=c|j[a>>2]&-134218753;a=l[j[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=p(a,896);if((b|0)==l[(e+j[d>>2]|0)+1075792>>1]){e=(e+j[d>>2]|0)+1075072|0;j[e>>2]=c|j[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}Za=f+16|0;return}a=D()|0;C()|0;S(b|0)}G(a|0)}z()}function _Fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Za-32|0;Za=d;j[d+28>>2]=0;ii(a,d+28|0);a:{b:{e=j[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Db(d+16|0);j[114626]=0;i[d+14>>1]=0;f=K(721,a|0,e|0,255)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}if(!f){break d}j[114626]=0;E(712,a|0,d+14|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}j[114626]=0;I(13,d|0,c|0,e|0);f=j[114626];j[114626]=0;if((f|0)==1){break f}j[114626]=0;f=E(722,b|0,d+14|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break e}ob(f,d);gb(d);gb(e);h=h+1|0;if(h>>>0<m[d+28>>2]){continue}break}}mf(j[j[a>>2]-12>>2]+a|0);break c}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d);break a}gb(e)}Za=d+32|0;return}a=D()|0;C()|0}gb(e);G(a|0);z()}function ZFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Za-32|0;Za=d;i[d+30>>1]=0;cf(a,d+30|0);a:{b:{e=l[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Db(d+16|0);j[114626]=0;i[d+14>>1]=0;f=K(723,a|0,e|0,255)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}if(!f){break d}j[114626]=0;E(712,a|0,d+14|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}j[114626]=0;I(13,d|0,c|0,e|0);f=j[114626];j[114626]=0;if((f|0)==1){break f}j[114626]=0;f=E(722,b|0,d+14|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break e}ob(f,d);gb(d);gb(e);h=h+1|0;if(h>>>0<l[d+30>>1]){continue}break}}mf(j[j[a>>2]-12>>2]+a|0);break c}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d);break a}gb(e)}Za=d+32|0;return}a=D()|0;C()|0}gb(e);G(a|0);z()}function PAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Qc(a);g=nb(b);j[114626]=0;F(73,f|0,g|0);a=j[114626];j[114626]=0;if((a|0)!=1){a:{if(g){while(1){a=d+1|0;e=k[Ub(b,d)|0];b:{c:{if((a|0)==(g|0)|(e|0)!=37){break c}e=k[Ub(b,a)|0];d=e-49|0;if((d&255)>>>0<=8){if(yza(c)>>>0<=d>>>0){d=a;break b}j[114626]=0;d=E(74,c|0,d|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;E(75,f|0,d|0)|0;e=j[114626];j[114626]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}j[114626]=0;K(76,f|0,1,37)|0;h=j[114626];j[114626]=0;d=a;if((h|0)==1){break a}}j[114626]=0;K(76,f|0,1,e<<24>>24)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}return}}a=D()|0;C()|0;gb(f);G(a|0);z()}function Ipa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=q(0),h=q(0),l=0,m=q(0),o=0,s=0;f=Za-16|0;Za=f;o=f,s=p(j[a>>2],be(a)),j[o+8>>2]=s;kc(f+8|0,c);c=lb(b);g=n[e+4>>2];e=j[f+8>>2];if(e){while(1){g=q(u(q(r((WMa(2,k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24)),_Ma()))),g));c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==q(0);a:{if(c){break a}e=j[f+8>>2];if(!e){break a}m=c?q(1):q(q(1)/g);c=j[a+20>>2];while(1){n[f+12>>2]=m*(WMa(2,k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24)),_Ma());Kd(f+12|0,q(-1));h=q(n[f+12>>2]*q(32768));n[f+12>>2]=h;a=c;h=Sd(h);b:{if(q(r(h))<q(2147483648)){l=~~h;break b}l=-2147483648}o=a,s=Dc(l),i[o>>1]=s;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){n[d>>2]=g}Za=f+16|0;return j[f+8>>2]}function zpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=q(0),g=0,h=0,l=q(0),m=0,o=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>3;j[e+8>>2]=j[a>>2];c=j[tb(e+12|0,e+8|0)>>2];l=n[d>>2];b=lb(b);if(c){a=j[a+20>>2];d=c;while(1){n[e+12>>2]=l*(WMa(2,k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24)),_Ma());Kd(e+12|0,q(-1));f=q(n[e+12>>2]*q(32768));n[e+12>>2]=f;h=a;f=Sd(f);a:{if(q(r(f))<q(2147483648)){g=~~f;break a}g=-2147483648}m=h,o=Dc(g),i[m>>1]=o;n[e+12>>2]=l*(WMa(2,k[b+4|0]|k[b+5|0]<<8|(k[b+6|0]<<16|k[b+7|0]<<24)),_Ma());Kd(e+12|0,q(-1));f=q(n[e+12>>2]*q(32768));n[e+12>>2]=f;h=a;f=Sd(f);b:{if(q(r(f))<q(2147483648)){g=~~f;break b}g=-2147483648}m=h,o=Dc(g),i[m+2>>1]=o;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}Za=e+16|0;return c<<3}function z4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,k=0;d=Za-32|0;Za=d;e=j[a+28>>2];j[d+16>>2]=e;f=j[a+20>>2];j[d+28>>2]=c;j[d+24>>2]=b;b=f-e|0;j[d+20>>2]=b;e=b+c|0;k=2;b=d+16|0;a:{b:{c:{if(!Oq(ka(j[a+60>>2],d+16|0,2,d+12|0)|0)){while(1){f=j[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<=-1){break b}g=j[b+4>>2];h=g>>>0<f>>>0;i=(h<<3)+b|0;g=f-(h?g:0)|0;j[i>>2]=g+j[i>>2];i=(h?12:4)+b|0;j[i>>2]=j[i>>2]-g;e=e-f|0;b=h?b+8|0:b;k=k-h|0;if(!Oq(ka(j[a+60>>2],b|0,k|0,d+12|0)|0)){continue}break}}if((e|0)!=-1){break b}}b=j[a+44>>2];j[a+28>>2]=b;j[a+20>>2]=b;j[a+16>>2]=b+j[a+48>>2];a=c;break a}j[a+28>>2]=0;j[a+16>>2]=0;j[a+20>>2]=0;j[a>>2]=j[a>>2]|32;a=0;if((k|0)==2){break a}a=c-j[b+4>>2]|0}Za=d+32|0;return a|0}function qca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-32|0;Za=d;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}j[114626]=0;N(2034,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break f}e=j[a+24>>2];j[114626]=0;c=E(85,d|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;L(2069,d+16|0,e|0,c|0,1);b=j[114626];j[114626]=0;if((b|0)==1){break d}b=Gd(zb(d+16|0));gb(d+16|0);gb(c);break b}b=J(0)|0;C()|0;break c}b=J(0)|0;C()|0;break c}b=J(0)|0;C()|0;gb(c)}O(b|0)|0;b=0;j[114626]=0;L(1982,36929,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=d+32|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function jna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Za-32|0;Za=d;a:{b:{c:{d:{e:{if(Pi(b)){break e}i[d+8>>1]=l[a+480190>>1];i[d+24>>1]=j[b+4>>2]-1;c=l[gf(d+8|0,d+24|0)>>1];if(!c){break e}while(1){Nd(d+8|0,b,c);if(!kb(d+8|0)){j[114626]=0;e=E(1418,a|0,c&65535)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}if(e){j[114626]=0;e=E(85,d+8|0,20525)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}j[114626]=0;E(369,((c<<5)+a|0)+946300|0,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}gb(e);g=g+1|0}if(!(l[a+480190>>1]!=(c|0)|c>>>0<2)){i[a+480190>>1]=l[a+480190>>1]-1}}e=c&65535;c=c-1|0;if((e|0)!=1){continue}break}}Za=d+32|0;return g&65535}c=D()|0;C()|0;break a}c=D()|0;C()|0;gb(e);break a}c=D()|0;C()|0}G(c|0);z()}function Bi(a,b,c){var d=0;a:{if((a|0)==(b|0)){break a}if((b-a|0)-c>>>0<=0-(c<<1)>>>0){Vb(a,b,c);return}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){break b}if(!(a&3)){break c}while(1){if(!c){break a}h[a|0]=k[b|0];b=b+1|0;c=c-1|0;a=a+1|0;if(a&3){continue}break}break c}d:{if(d){break d}if(a+c&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;h[d|0]=k[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;j[c+a>>2]=j[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;h[c+a|0]=k[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){j[a>>2]=j[b>>2];b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){h[a|0]=k[b|0];a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}}function $ca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-32|0;Za=d;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}j[114626]=0;N(2034,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break f}e=j[a+24>>2];j[114626]=0;c=E(85,d|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break e}j[114626]=0;I(2035,d+16|0,e|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break d}b=Gd(zb(d+16|0));gb(d+16|0);gb(c);break b}b=J(0)|0;C()|0;break c}b=J(0)|0;C()|0;break c}b=J(0)|0;C()|0;gb(c)}O(b|0)|0;b=0;j[114626]=0;L(1982,35695,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=d+32|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Aj(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;j[a+4>>2]=0;a:{b:{d=4;c:{if(!k[Ji(e+8|0,a,1)|0]){break c}d=j[j[a>>2]-12>>2];j[114626]=0;d=j[(a+d|0)+24>>2];f=j[114626];j[114626]=0;d:{if((f|0)==1){break d}j[114626]=0;b=K(2316,d|0,b|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break d}j[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=J(0)|0;C()|0;O(b|0)|0;Hi(j[j[a>>2]-12>>2]+a|0,1);b=j[j[a>>2]-12>>2];j[114626]=0;b=j[(a+b|0)+20>>2];c=j[114626];j[114626]=0;e:{if((c|0)!=1){if(!(b&1)){break e}j[114626]=0;M(81);a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)==1){break b}G(a|0);z()}Q();d=1}eg(j[j[a>>2]-12>>2]+a|0,d);Za=e+16|0;return}a=J(0)|0;C()|0;ib(a)}z()}function Wda(a){a=a|0;var b=0;b=34280;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=34317;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=34181;break a}b=34294;break a}b=34336;break a}b=34350;break a}b=34364;break a}b=34376;break a}b=34396;break a}b=34417;break a}b=34429;break a}b=34448;break a}b=34480;break a}b=34502;break a}if((a|0)!=357){break a}b=34519}return Gd(b)|0}function FD(a,b,c,d,e,f){var g=0;g=Za-80|0;Za=g;a:{if((f|0)>=16384){$c(g+32|0,b,c,d,e,0,0,0,2147352576);d=j[g+40>>2];e=j[g+44>>2];b=j[g+32>>2];c=j[g+36>>2];if((f|0)<32767){f=f-16383|0;break a}$c(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=j[g+24>>2];e=j[g+28>>2];b=j[g+16>>2];c=j[g+20>>2];break a}if((f|0)>-16383){break a}$c(g- -64|0,b,c,d,e,0,0,0,65536);d=j[g+72>>2];e=j[g+76>>2];b=j[g+64>>2];c=j[g+68>>2];if((f|0)>-32765){f=f+16382|0;break a}$c(g+48|0,b,c,d,e,0,0,0,65536);f=((f|0)>-49146?f:-49146)+32764|0;d=j[g+56>>2];e=j[g+60>>2];b=j[g+48>>2];c=j[g+52>>2]}$c(g,b,c,d,e,0,0,0,f+16383<<16);b=j[g+12>>2];j[a+8>>2]=j[g+8>>2];j[a+12>>2]=b;b=j[g+4>>2];j[a>>2]=j[g>>2];j[a+4>>2]=b;Za=g+80|0}function mMa(a,b){var c=0,d=0,e=0,f=0,g=0,m=0;e=Za-16|0;Za=e;md(b,0);h[b+37|0]=k[a+22|0]<<4;h[e+15|0]=k[a+23|0];h[e+14|0]=64;g=b,m=k[Yb(e+15|0,e+14|0)|0]<<2,i[g+30>>1]=m;h[b+36|0]=k[a+24|0];c=a+25|0;j[b>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);d=a+33|0;a:{if((k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24))>>>0<3){break a}f=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+29|0;if(f>>>0<(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))+(k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24))>>>0){break a}i[b+34>>1]=l[b+34>>1]|2;j[b+4>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[b+8>>2]=(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))+(k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24))}Za=e+16|0}function Dm(a,b,c){var d=0,e=0,f=0,g=0,i=0;a:{if(c){h[b+829|0]=c;break a}c=k[b+829|0]}d=j[a+480180>>2]&202376205?c&240?c&-16:c&15:c;c=j[b+688>>2];b:{if(j[a+480180>>2]&69206029){break b}e=d&240;f=d&15;if((f|0)==15){if(e){Do(a,b,(d&240)>>>4|0,0);return}if(!(h[b+872|0]&1)){break b}c=k[a+480208|0]&2?c:c-60|0;break b}if((e|0)!=240){break b}if(f){Co(a,b,f,0);return}if(!(h[b+872|0]&1)){break b}c=k[a+480208|0]&2?c:c+60|0}c:{if(j[a+1074416>>2]!=1|j[a+480180>>2]!=524288?!(!(h[b+872|0]&1)|k[a+480208|0]&2):0){break c}e=d&255;d=d&15;d:{if(d){if(j[a+480180>>2]&16777248?e&240:0){break d}c=c-(d<<2)|0;break d}c=(e>>>2&60)+c|0}if(j[a+480180>>2]!=1){break c}j[b+88>>2]=j[b+88>>2]|2097152}g=b,i=Gb(c,0,256),j[g+688>>2]=i}function Wua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0;g=Za-16|0;Za=g;k=j[a+24>>2];l=j[a+20>>2];m=j[a+16>>2];h=j[a+4>>2];e=h;f=j[a>>2];j[g+8>>2]=f;j[g+12>>2]=e;h=j[a+12>>2];j[g>>2]=j[a+8>>2];j[g+4>>2]=h;if(d){while(1){e=(e<<1)+m|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((p(i[e+4>>1],i[f+34>>1])+p(i[e+2>>1],i[f+32>>1])|0)+p(i[e+6>>1],i[f+36>>1])|0)+p(i[e+8>>1],i[f+38>>1])|0)/2|0)+((((p(i[e-4>>1],i[f+26>>1])+p(i[e-6>>1],i[f+24>>1])|0)+p(i[e-2>>1],i[f+28>>1])|0)+p(i[e>>1],i[f+30>>1])|0)/2|0)|0)/16384|0;j[c>>2]=j[c>>2]+p(e,l);j[c+4>>2]=j[c+4>>2]+p(e,k);Bb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=j[g+8>>2];e=j[g+12>>2];continue}break}f=j[g+8>>2];e=j[g+12>>2]}j[a>>2]=f;j[a+4>>2]=e;Za=g+16|0}function Ppa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,l=0,m=0,n=0,p=0,q=0,s=0;g=Za-16|0;Za=g;j[g+8>>2]=c>>>3;j[g+4>>2]=j[a>>2];d=j[tb(g+8|0,g+4|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){n=0;e=b;h=k[e+4|0]|k[e+5|0]<<8|(k[e+6|0]<<16|k[e+7|0]<<24);l=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);f=h<<24|l>>>8;e=0;p=f&65280;f=e;e=h<<8|l>>>24;f=f|n;n=e&255|p|(l<<24|l<<8&16711680);e=g;j[e+8>>2]=((h&255)<<24|l>>>8)&-16777216|((h&16777215)<<8|l>>>24)&16711680|(h>>>8&65280|h>>>24)|f;j[e+12>>2]=n;pf(e+8|0,-1,1);m=o[e+8>>3]*32768;o[e+8>>3]=m;e=a;m=zd(m);a:{if(r(m)<2147483648){f=~~m;break a}f=-2147483648}q=e,s=Dc(f),i[q>>1]=s;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}Za=g+16|0;return d<<3}function tx(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;a:{if(!d){break a}if(c){h[b+835|0]=c;break a}c=k[b+835|0]}c=j[a+480180>>2]&1048580?c&240?c&-16:c&15:c;b:{c:{d:{e:{if(!(j[a+480180>>2]&1048580)){d=c&240;c=c&15;if((c|0)==15){if(!d){d=0;break e}if(!(k[a+480209|0]&16)){break b}c=0-(d>>>2|0)|0;break d}f=!c;if(!c|(d|0)!=240){break e}if(!(k[a+480209|0]&16)){break b}c=c<<2;break c}if(k[a+480209|0]&16){break b}mb(e+8|0,a+1074308|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;c=a;if(!kb(e+8|0)){break d}c=(a|0)/4<<24>>24;break d}if(k[a+480209|0]&16){break b}if(!f){c=c<<2;if(!d|!(j[a+480180>>2]&16777248)){break c}break b}c=0-(d>>>2|0)|0}if(!c){break b}}a=Gb(j[b+692>>2]+c|0,0,256);i[b+796>>1]=0;j[b+692>>2]=a}Za=e+16|0}function vE(a,b,c,d){a:{if(b>>>0>20){break a}b:{switch(b-9|0){case 0:b=j[c>>2];j[c>>2]=b+4;j[a>>2]=j[b>>2];return;case 1:b=j[c>>2];j[c>>2]=b+4;b=j[b>>2];j[a>>2]=b;j[a+4>>2]=b>>31;return;case 2:b=j[c>>2];j[c>>2]=b+4;j[a>>2]=j[b>>2];j[a+4>>2]=0;return;case 3:b=j[c>>2]+7&-8;j[c>>2]=b+8;c=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=c;return;case 4:b=j[c>>2];j[c>>2]=b+4;b=i[b>>1];j[a>>2]=b;j[a+4>>2]=b>>31;return;case 5:b=j[c>>2];j[c>>2]=b+4;j[a>>2]=l[b>>1];j[a+4>>2]=0;return;case 6:b=j[c>>2];j[c>>2]=b+4;b=h[b|0];j[a>>2]=b;j[a+4>>2]=b>>31;return;case 7:b=j[c>>2];j[c>>2]=b+4;j[a>>2]=k[b|0];j[a+4>>2]=0;return;case 8:b=j[c>>2]+7&-8;j[c>>2]=b+8;o[a>>3]=o[b>>3];return;case 9:break b;default:break a}}bb[d|0](a,c)}}function zva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0;e=Za-16|0;Za=e;h=j[a+40>>2];k=j[a+36>>2];m=j[a+16>>2];g=j[a+4>>2];b=g;f=j[a>>2];j[e+8>>2]=f;j[e+12>>2]=b;g=j[a+12>>2];j[e>>2]=j[a+8>>2];j[e+4>>2]=g;a:{if(!d){g=h>>12;l=k>>12;break a}while(1){g=j[a+32>>2];k=j[a+28>>2]+k|0;l=k>>12;b=(b<<1)+m|0;f=(f>>>21&2040)+27888|0;b=(((p(i[b>>1],i[f+2>>1])+p(i[b-2>>1],i[f>>1])|0)+p(i[b+2>>1],i[f+4>>1])|0)+p(i[b+4>>1],i[f+6>>1])|0)/16384|0;j[c>>2]=j[c>>2]+p(l,b);h=g+h|0;g=h>>12;j[c+4>>2]=j[c+4>>2]+p(b,g);Bb(e+8|0,e);d=d-1|0;if(d){c=c+8|0;f=j[e+8>>2];b=j[e+12>>2];continue}break}f=j[e+8>>2];b=j[e+12>>2]}j[a+40>>2]=h;j[a+20>>2]=l;j[a+36>>2]=k;j[a+24>>2]=g;j[a>>2]=f;j[a+4>>2]=b;Za=e+16|0}function gea(a,b,c){var d=0,e=0,f=0,g=0,h=0,k=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=l[a+22>>1];f=l[a+20>>1];g=j[a+4>>2];if(c){n=i[a+26>>1];t=i[a+18>>1];o=i[a+24>>1];u=i[a+16>>1];m=j[a>>2]-1|0;q=a+32928|0;while(1){h=Ac(j[b>>2]);d=Ac(j[b+4>>2]);f=Ac((f<<16>>16)-h|0);e=Ac((e<<16>>16)-d|0);f=Dc(Ac((p(f,u)|0)/65536<<1)+h|0);e=Dc(Ac((p(e,t)|0)/65536<<1)+d|0);d=(g<<2)+q|0;h=i[d+2>>1];r=i[d>>1];d=Dc(((p(r,o)|0)/-65536|0)+f|0);g=g+1&127;k=(g<<2)+q|0;s=Dc(((p(h,n)|0)/-65536|0)+e|0);i[k+2>>1]=s;i[k>>1]=d;m=m+1&8191;k=(m<<2)+a|0;v=k,w=Dc(((p(d,o)|0)/65536|0)+r|0),i[v+160>>1]=w;v=k,w=Dc(h+((p(n,s)|0)/65536|0)|0),i[v+162>>1]=w;b=b+8|0;c=c-1|0;if(c){continue}break}}i[a+22>>1]=e;i[a+20>>1]=f;j[a+4>>2]=g}function aE(a){a=a|0;var b=0,c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b:{if(!j[(j[j[a>>2]-12>>2]+a|0)+24>>2]){break b}j[114626]=0;c=E(2320,d+8|0,a|0)|0;b=j[114626];j[114626]=0;c:{if((b|0)!=1){d:{if(!k[c|0]){break d}b=j[(j[j[a>>2]-12>>2]+a|0)+24>>2];j[114626]=0;b=H(2321,b|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=j[j[a>>2]-12>>2];j[114626]=0;F(2322,a+b|0,1);b=j[114626];j[114626]=0;if((b|0)!=1){break d}}b=J(0)|0;C()|0;$D(c);break c}$D(c);break b}b=J(0)|0;C()|0}O(b|0)|0;c=j[j[a>>2]-12>>2];j[114626]=0;N(19,a+c|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}Q()}Za=d+16|0;return a|0}a=D()|0;C()|0;j[114626]=0;M(20);c=j[114626];j[114626]=0;if((c|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Ey(a,b,c){var d=0,e=0,f=0,g=0,j=0,m=0;g=Za-16|0;Za=g;if(h[a|0]&1){h[b+12|0]=k[b+12|0]|1}if(k[a|0]&2){h[b+12|0]=k[b+12|0]|4}if(k[a|0]&4){h[b+12|0]=k[b+12|0]|2}if(k[a|0]&16){h[b+12|0]=k[b+12|0]|16}if(k[a|0]&32){h[b+12|0]=k[b+12|0]|8}h[g+15|0]=k[a+1|0];h[g+14|0]=25;Nf(b,k[Yb(g+15|0,g+14|0)|0]);h[b+15|0]=k[a+2|0];h[b+16|0]=k[a+3|0];h[b+13|0]=k[a+4|0];h[b+14|0]=k[a+5|0];if(sb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=k[e|0]|k[e+1|0]<<8;j=xb(b,d),m=e,i[j>>1]=m;a:{if(!d){break a}e=d-1|0;if(l[xb(b,d)>>1]>=l[xb(b,e)>>1]){break a}e=l[xb(b,e)>>1];j=xb(b,d),m=e+1|0,i[j>>1]=m}f=f+8|0;f=Gb((k[f|0]|k[f+1|0]<<8)<<16>>16>>c,0,64);j=xb(b,d),m=f,h[j+2|0]=m;d=d+1|0;if(sb(b)>>>0>d>>>0){continue}break}}Za=g+16|0}function $5(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,m=0;if((d|0)>=1){f=b+7548|0;i=a+6152|0;while(1){g=p(e,28)+c|0;m=l[g+4>>1];h=j[b+4>>2];V5(i,(p(e,39)+b|0)+16156|0,b,g,f,e);U5((p(e,2304)+b|0)+2940|0,b,g,f,m+h|0);e=e+1|0;if((e|0)!=(d|0)){continue}break}}e=k[a+6155|0];a:{if(e&16){T5(b+2940|0,b+16195|0,c,a+6152|0);break a}if((e&224)!=96){break a}YE(b+2940|0,576)}if((d|0)>=1){m=b+7708|0;e=0;while(1){f=k[a+6153|0];f=(k[c+12|0]!=0)<<1<<((p((f>>>3&1)+(f>>>4&1)|0,3)+(k[a+6154|0]>>>2&3)|0)==2);g=(p(e,2304)+b|0)+2940|0;i=g;if(k[c+14|0]){S5(((p(e,2304)+b|0)+p(f,72)|0)+2940|0,m,j[c>>2]+k[c+13|0]|0);h=f-1|0}else{h=31}R5(i,h);Q5(g,p(e,1152)+a|0,k[c+11|0],f);P5(g);c=c+28|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}}function xla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;d=Db(e);a:{b:{if(c>>>0>=64){j[114626]=0;c=H(339,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}if((c|0)<=0){j[114626]=0;E(85,a|0,30880)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break b}break a}j[114626]=0;F(111,d|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}}c:{while(1){d:{j[114626]=0;c=H(387,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}if(!c){break c}j[114626]=0;K(1524,d|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}}break}break a}j[114626]=0;E(338,b|0,4)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}Nc(a,d)}gb(d);Za=e+16|0;return}a=D()|0;C()|0;gb(d);G(a|0);z()}function Z5(a,b,c){var d=0,e=0,f=0,g=0,i=0,j=0,l=0,m=0;e=M5(a,c);a:{if(!k[c+768|0]){e=0;break a}g=50096;while(1){if((d|0)==(j|0)){g=k[e|0]+50096|0;j=k[e+2|0]+j|0;l=k[e+1|0];e=e+3|0}m=d<<1;f=k[Bd(b,l)+g|0];h[(m+c|0)+770|0]=f;i=k[c+769|0];if(i>>>0>d>>>0){f=k[Bd(b,l)+g|0];i=k[c+769|0]}h[((m|1)+c|0)+770|0]=i?f:0;d=d+1|0;f=k[c+768|0];if(d>>>0<f>>>0){continue}break}if(!f){e=f<<1;break a}d=0;while(1){g=c+d|0;b:{if(!k[g+770|0]){e=6;break b}e=2;if((k[a+1|0]&6)==6){break b}e=Bd(b,2);f=k[c+768|0]}h[g+834|0]=e;e=f<<1&510;d=d+1|0;if(e>>>0>d>>>0){continue}break}}L5(b,c+770|0,c+834|0,e,c);d=k[c+769|0];a=k[c+768|0];if(d>>>0<a>>>0){while(1){h[((d<<1|1)+c|0)+770|0]=0;d=d+1|0;if(a>>>0>d>>>0){continue}break}}}function Ab(a,b,c){var d=0,e=0,f=0,g=0;a:{if(!c){break a}d=a+c|0;h[d-1|0]=b;h[a|0]=b;if(c>>>0<3){break a}h[d-2|0]=b;h[a+1|0]=b;h[d-3|0]=b;h[a+2|0]=b;if(c>>>0<7){break a}h[d-4|0]=b;h[a+3|0]=b;if(c>>>0<9){break a}d=0-a&3;e=d+a|0;b=p(b&255,16843009);j[e>>2]=b;c=c-d&-4;d=c+e|0;j[d-4>>2]=b;if(c>>>0<9){break a}j[e+8>>2]=b;j[e+4>>2]=b;j[d-8>>2]=b;j[d-12>>2]=b;if(c>>>0<25){break a}j[e+24>>2]=b;j[e+20>>2]=b;j[e+16>>2]=b;j[e+12>>2]=b;j[d-16>>2]=b;j[d-20>>2]=b;j[d-24>>2]=b;j[d-28>>2]=b;g=e&4|24;c=c-g|0;if(c>>>0<32){break a}d=b;f=b;b=e+g|0;while(1){j[b+24>>2]=f;j[b+28>>2]=d;j[b+16>>2]=f;j[b+20>>2]=d;j[b+8>>2]=f;j[b+12>>2]=d;j[b>>2]=f;j[b+4>>2]=d;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function Xua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0;g=Za-16|0;Za=g;l=j[a+24>>2];m=j[a+20>>2];n=j[a+16>>2];k=j[a+4>>2];e=k;f=j[a>>2];j[g+8>>2]=f;j[g+12>>2]=e;k=j[a+12>>2];j[g>>2]=j[a+8>>2];j[g+4>>2]=k;if(d){while(1){e=e+n|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((p(h[e+2|0],i[f+34>>1])+p(h[e+1|0],i[f+32>>1])|0)+p(h[e+3|0],i[f+36>>1])|0)+p(h[e+4|0],i[f+38>>1])<<8)/2|0)+((((p(h[e-2|0],i[f+26>>1])+p(h[e-3|0],i[f+24>>1])|0)+p(h[e-1|0],i[f+28>>1])|0)+p(h[e|0],i[f+30>>1])<<8)/2|0)|0)/16384|0;j[c>>2]=j[c>>2]+p(e,m);j[c+4>>2]=j[c+4>>2]+p(e,l);Bb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=j[g+8>>2];e=j[g+12>>2];continue}break}f=j[g+8>>2];e=j[g+12>>2]}j[a>>2]=f;j[a+4>>2]=e;Za=g+16|0}function mLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;md(b,0);j[b>>2]=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);c=wt(a+4|0,a);j[b+4>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=wt(a+8|0,a);j[b+8>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);h[d+15|0]=127;h[d+14|0]=k[a+15|0];f=b,g=(((k[Yb(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,i[f+30>>1]=g;e=a+12|0;if(k[e|0]>=16){c=k[e|0];i[b+34>>1]=32;i[b+28>>1]=c&240}c=a+13|0;j[b+24>>2]=(k[c|0]|k[c+1|0]<<8)<<1;if(!(k[c|0]|k[c+1|0]<<8)){j[b+24>>2]=16726}f=b,g=(p(ms(0,k[e|0]<<28>>24),j[b+24>>2])>>>0)/8363|0,j[f+24>>2]=g;if(m[b+4>>2]<m[b+8>>2]){i[b+34>>1]=l[b+34>>1]|2}if(k[a+16|0]&132){i[b+34>>1]=l[b+34>>1]|1}Za=d+16|0}function Oba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,l=0,m=0,n=0,o=0;e=Za-16|0;Za=e;a:{b:{if(!ce(b,-1)){f=j[a+12>>2];g=j[a+8>>2];if(j[a+24>>2]==j[a+28>>2]){c=-1;if(!(k[a+48|0]&16)){break a}h=j[a+24>>2];i=j[a+20>>2];l=j[a+44>>2];m=j[a+20>>2];j[114626]=0;c=a+32|0;F(110,c|0,0);d=j[114626];j[114626]=0;if((d|0)==1){break b}d=sc(c);j[114626]=0;F(149,c|0,d|0);d=j[114626];j[114626]=0;if((d|0)==1){break b}d=zb(c);hw(a,d,nb(c)+d|0);kr(a,h-i|0);j[a+44>>2]=j[a+20>>2]+(l-m|0)}j[e+12>>2]=j[a+24>>2]+1;n=a,o=j[Gc(e+12|0,a+44|0)>>2],j[n+44>>2]=o;if(k[a+48|0]&8){c=zb(a+32|0);sm(a,c,c+(f-g|0)|0,j[a+44>>2])}c=xG(a,rm(b));break a}c=jr(b);break a}a=J(0)|0;C()|0;O(a|0)|0;Q();c=-1}Za=e+16|0;return c|0}function Hoa(a,b,c){var d=0,e=0,f=0,g=0;a:{d=j[a+480208>>2];if(!(d&4096)){break a}b:{switch(c&15){case 0:j[b+88>>2]=j[b+88>>2]&-257;return;case 1:j[b+692>>2]=128;j[b+88>>2]=j[b+88>>2]|256;return;case 8:j[b+88>>2]=j[b+88>>2]&-25165825|16777216;return;case 9:j[b+88>>2]=j[b+88>>2]&-25165825|8388608;return;case 10:j[a+480208>>2]=d&-16385;return;case 11:j[a+480208>>2]=d|16384;return;case 12:j[a+480208>>2]=d&-8193;return;case 13:j[a+480208>>2]=d|8192;return;case 14:j[b+88>>2]=j[b+88>>2]&-129;return;case 15:break b;default:break a}}c:{if(!j[b+76>>2]|(j[b>>2]|j[b+4>>2])){break c}if(e=!Lf(b+810|0),f=0,g=k[b+88|0]&2,g?e:f){break c}c=j[b+76>>2]-1|0;j[b>>2]=-1;j[b+4>>2]=c}j[b+88>>2]=j[b+88>>2]|128}}function Ava(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,n=0;e=Za-16|0;Za=e;k=j[a+40>>2];l=j[a+36>>2];n=j[a+16>>2];g=j[a+4>>2];b=g;f=j[a>>2];j[e+8>>2]=f;j[e+12>>2]=b;g=j[a+12>>2];j[e>>2]=j[a+8>>2];j[e+4>>2]=g;a:{if(!d){g=k>>12;m=l>>12;break a}while(1){g=j[a+32>>2];l=j[a+28>>2]+l|0;m=l>>12;b=b+n|0;f=(f>>>21&2040)+27888|0;b=(((p(h[b|0],i[f+2>>1])+p(h[b-1|0],i[f>>1])|0)+p(h[b+1|0],i[f+4>>1])|0)+p(h[b+2|0],i[f+6>>1])<<8)/16384|0;j[c>>2]=j[c>>2]+p(m,b);k=g+k|0;g=k>>12;j[c+4>>2]=j[c+4>>2]+p(b,g);Bb(e+8|0,e);d=d-1|0;if(d){c=c+8|0;f=j[e+8>>2];b=j[e+12>>2];continue}break}f=j[e+8>>2];b=j[e+12>>2]}j[a+40>>2]=k;j[a+20>>2]=m;j[a+36>>2]=l;j[a+24>>2]=g;j[a>>2]=f;j[a+4>>2]=b;Za=e+16|0}function xH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=Za-48|0;Za=c;j[c+8>>2]=542066252;d=c+8|4;h[d|0]=0;h[d+1|0]=0;h[d+2|0]=0;h[d+3|0]=0;d=j[b+4220>>2];h[c+16|0]=d;h[c+17|0]=d>>>8;h[c+18|0]=d>>>16;h[c+19|0]=d>>>24;d=j[b+4224>>2];h[c+20|0]=d;h[c+21|0]=d>>>8;h[c+22|0]=d>>>16;h[c+23|0]=d>>>24;d=j[b+4228>>2];h[c+24|0]=d;h[c+25|0]=d>>>8;h[c+26|0]=d>>>16;h[c+27|0]=d>>>24;d=j[b+4232>>2];h[c+28|0]=d;h[c+29|0]=d>>>8;h[c+30|0]=d>>>16;h[c+31|0]=d>>>24;d=j[b+4236>>2];h[c+32|0]=d;h[c+33|0]=d>>>8;h[c+34|0]=d>>>16;h[c+35|0]=d>>>24;h[c+36|0]=k[b+4240|0];h[c+37|0]=k[b+4241|0];h[c+38|0]=k[b+4242|0];h[c+39|0]=k[b+4243|0];h[c+40|0]=k[b+4244|0];b=b+4208|0;ek(b,33);Vb(j[b>>2],c+8|0,33);xi(c,b);vd(a,c);Za=c+48|0}function Q8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=Za-32|0;Za=b;e=Mg(a);ld(b+24|0);j[114626]=0;a=E(2192,j[b+24>>2],j[b+28>>2])|0;c=j[114626];j[114626]=0;a:{b:{if((c|0)==1){break b}j[114626]=0;F(1525,e|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}a=0;c:{while(1){j[114626]=0;c=E(2192,j[b+24>>2],j[b+28>>2])|0;d=j[114626];j[114626]=0;d:{if((d|0)!=1){if((a|0)<(c|0)){break d}Za=b+32|0;return}a=D()|0;C()|0;break a}c=j[j[b+24>>2]+(a<<3)>>2];j[114626]=0;c=E(85,b+8|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(1527,e|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break c}gb(c);a=a+1|0;continue}break}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(c);break a}a=D()|0;C()|0}Uc(e);G(a|0);z()}function fX(a,b){var c=0,d=0,e=0,f=0,g=0;c=16;d=a>>>0>16?a:16;a:{if(!(d-1&d)){a=d;break a}while(1){a=c;c=a<<1;if(a>>>0<d>>>0){continue}break}}if(-64-a>>>0<=b>>>0){j[114600]=48;return 0}d=b>>>0<11?16:b+11&-8;c=_c((d+a|0)+12|0);if(!c){return 0}b=c-8|0;b:{if(!(c&a-1)){a=b;break b}f=c-4|0;g=j[f>>2];c=((a+c|0)-1&0-a)-8|0;a=c-b>>>0>15?c:a+c|0;c=a-b|0;e=(g&-8)-c|0;if(!(g&3)){b=j[b>>2];j[a+4>>2]=e;j[a>>2]=b+c;break b}j[a+4>>2]=e|j[a+4>>2]&1|2;e=a+e|0;j[e+4>>2]=j[e+4>>2]|1;j[f>>2]=c|j[f>>2]&1|2;j[a+4>>2]=j[a+4>>2]|1;fq(b,c)}b=j[a+4>>2];c:{if(!(b&3)){break c}c=b&-8;if(c>>>0<=d+16>>>0){break c}j[a+4>>2]=d|b&1|2;b=a+d|0;d=c-d|0;j[b+4>>2]=d|3;c=a+c|0;j[c+4>>2]=j[c+4>>2]|1;fq(b,d)}return a+8|0}function XH(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=Za-48|0;Za=e;f=Db(e+32|0);j[114626]=0;E(1612,a|0,e+24|0)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){g=j[e+28>>2];d=j[e+24>>2];De(f);j[114626]=0;g=!g&d>>>0<255?d:255;F(149,f|0,g|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=Ub(f,d);j[114626]=0;E(1613,a|0,h|0)|0;h=j[114626];j[114626]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if((YB(f)|0)!=-1){a=YB(f);j[114626]=0;F(149,f|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}}j[114626]=0;I(13,e+8|0,c|0,f|0);a=j[114626];j[114626]=0;if((a|0)!=1){break b}break a}break a}ob(b,e+8|0);gb(e+8|0);gb(f);Za=e+48|0;return}a=D()|0;C()|0;gb(f);G(a|0);z()}function I9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,m=0;d=Za+ -64|0;Za=d;a:{b:{if((b|0)>=0){e=a+24|0;if((Ui(Fb(j[e>>2]+484360|0))|0)>(b|0)){break b}}a=a+16|0;break a}g=l[ac(Fb(j[e>>2]+484360|0),b)>>1];c:{if(!xp(j[e>>2]+484344|0,g)){break c}if((c|0)>=0){f=c;if((f|0)<j[Ib(j[e>>2]+484344|0,g)+12>>2]){break c}}a=a+16|0;break a}i[j[e>>2]+1074438>>1]=b;b=b&65535;yJ(j[e>>2],b);j[j[e>>2]+1074428>>2]=f;c=j[e>>2];e=k[a+64|0];b=_ma(d+24|0,b,f);f=j[b+20>>2];j[d+16>>2]=j[b+16>>2];j[d+20>>2]=f;f=j[b+12>>2];j[d+8>>2]=j[b+8>>2];j[d+12>>2]=f;f=j[b+4>>2];j[d>>2]=j[b>>2];j[d+4>>2]=f;Yr(d+48|0,c,e?7:1,d);h=a,m=o[yg(d+48|0)>>3],o[h+16>>3]=m;hl(d+48|0);a=a+16|0}Za=d- -64|0;return+o[a>>3]}function V4(a,b,c,d){var e=0,f=0,g=0,h=q(0),i=q(0),j=0,k=0,l=0,m=0,o=0,p=q(0);a:{if((a|0)<4){break a}e=a>>2;m=(e|0)>1?e:1;i=q(a|0);h=q(q(1)/i);e=0;while(1){j=e<<2;f=+q(q(q(g<<2)*q(3.1415927410125732))*h);o=j+b|0,p=q(ge(f)),n[o>>2]=p;k=e|1;l=k<<2;o=l+b|0,p=q(-q(Kh(f))),n[o>>2]=p;f=+q(q(q(k|0)*q(1.5707963705062866))*h);o=c+j|0,p=q(q(ge(f))*q(.5)),n[o>>2]=p;o=c+l|0,p=q(q(Kh(f))*q(.5)),n[o>>2]=p;e=e+2|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}if((a|0)<8){break a}a=a>>3;a=(a|0)>1?a:1;h=q(q(1)/i);e=0;g=0;while(1){b=e|1;f=+q(q(q(b<<1)*q(3.1415927410125732))*h);o=(e<<2)+d|0,p=q(ge(f)),n[o>>2]=p;o=(b<<2)+d|0,p=q(-q(Kh(f))),n[o>>2]=p;e=e+2|0;g=g+1|0;if((a|0)!=(g|0)){continue}break}}}function Ona(a){var b=0,c=0,d=0;j[114626]=0;H(1396,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){b=j[a+4>>2];if(b){Mna(b);Cb(b)}j[a+4>>2]=0;lx(a+1304500|0);Nr(a+1304436|0);gb(a+1304424|0);gb(a+1304412|0);gb(a+1304400|0);Mr(a+1304396|0);Lr(a+1304392|0);Bo(a+1304360|0);b=a+946300|0;c=a+906300|0;while(1){b=ym(b-160|0);if((c|0)!=(b|0)){continue}break}js(a+484360|0);kx(a+484344|0);Ud(a+480248|0);return a}c=J(0)|0;C()|0;lx(a+1304500|0);Nr(a+1304436|0);gb(a+1304424|0);gb(a+1304412|0);gb(a+1304400|0);Mr(a+1304396|0);Lr(a+1304392|0);Bo(a+1304360|0);b=a+946300|0;d=a+906300|0;while(1){b=ym(b-160|0);if((d|0)!=(b|0)){continue}break}js(a+484360|0);kx(a+484344|0);Ud(a+480248|0);ib(c);z()}function wo(a,b,c){var d=0,e=0,f=0;d=Db(a);a=nb(b);j[114626]=0;F(111,d|0,a|0);a=j[114626];j[114626]=0;if((a|0)!=1){a:{if(nb(b)){while(1){f=j[Li(b,e)>>2];a=32;b:{c:{while(1){if(j[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}j[114626]=0;F(110,d|0,a<<24>>24);a=j[114626];j[114626]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(j[(a<<2)+c>>2]==(f|0)){j[114626]=0;F(110,d|0,a<<24>>24);a=j[114626];j[114626]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}j[114626]=0;F(110,d|0,63);a=j[114626];j[114626]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(nb(b)>>>0>e>>>0){continue}break}}return}}a=D()|0;C()|0;gb(d);G(a|0);z()}function Qn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,l=0,m=0;i=Za-16|0;Za=i;f=d?d:461644;d=j[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}l=a?a:i+12|0;d:{if(d){a=c;break d}a=k[b|0];d=a<<24>>24;if((d|0)>=0){j[l>>2]=a;e=(d|0)!=0;break a}a=h[b|0];if(!j[j[21215]>>2]){j[l>>2]=a&57343;e=1;break a}a=(a&255)-194|0;if(a>>>0>50){break c}d=j[(a<<2)+57712>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=k[b|0];m=g>>>3|0;if((m-16|(d>>26)+m)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){j[f>>2]=0;j[l>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=k[b|0];if((g&192)==128){continue}break}}j[f>>2]=0;j[114600]=25;e=-1;break a}j[f>>2]=d}Za=i+16|0;return e|0}function nka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0;f=Za-32|0;Za=f;j[f+24>>2]=b;b=j[a>>2];k=f,l=Lb(a),j[k>>2]=l;b=b+p(Dr(f+24|0,f),6)|0;a:{b:{if(!c){break b}g=j[hb(a)>>2];h=j[a+4>>2];if((g-h|0)/6>>>0>=c>>>0){e=c;i=h-b|0;g=(i|0)/6|0;if(g>>>0<c>>>0){bz(a,c-g|0,d);e=g;if(!i){break b}}lka(a,b,h,p(c,6)+b|0);g=b;if(b>>>0<=d>>>0){d=m[a+4>>2]>d>>>0?p(c,6)+d|0:d}Tja(g,e,d);break b}e=hb(a);e=KP(f,Sy(a,Kf(a)+c|0),(b-j[a>>2]|0)/6|0,e);j[114626]=0;I(707,e|0,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}j[114626]=0;b=K(1558,a|0,e|0,b|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}Qs(e)}a=Qe(b);Za=f+32|0;return a|0}a=D()|0;C()|0;Qs(e);G(a|0);z()}function Yqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0;e=Za-32|0;Za=e;j[e+24>>2]=b;b=j[a>>2];k=e,l=Lb(a),j[k>>2]=l;b=b+(vp(e+24|0,e)<<1)|0;a:{f=Dx(c,d);b:{if((f|0)<1){break b}g=j[hb(a)>>2];h=j[a+4>>2];if((f|0)<=g-h>>1){j[e>>2]=d;i=h-b|0;g=i>>1;if((f|0)>(g|0)){j[e>>2]=c;j[e>>2]=j[e>>2]+(g<<1);PL(a,j[e>>2],d,f-g|0);if((i|0)<1){break b}}Wqa(a,b,h,(f<<1)+b|0);Pe(c,j[e>>2],b);break b}h=hb(a);f=KT(e,ej(a,bc(a)+f|0),b-j[a>>2]>>1,h);j[114626]=0;I(1241,f|0,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}j[114626]=0;b=K(1242,a|0,f|0,b|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}uA(f)}a=Qe(b);Za=e+32|0;return a|0}a=D()|0;C()|0;uA(f);G(a|0);z()}function Spa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=q(0),g=0,h=0,l=0,m=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>3;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){j[e+12>>2]=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);Kd(e+12|0,q(-1));f=q(n[e+12>>2]*q(32768));n[e+12>>2]=f;h=a;f=Sd(f);a:{if(q(r(f))<q(2147483648)){g=~~f;break a}g=-2147483648}l=h,m=Dc(g),i[l>>1]=m;j[e+12>>2]=k[b+4|0]|k[b+5|0]<<8|(k[b+6|0]<<16|k[b+7|0]<<24);Kd(e+12|0,q(-1));f=q(n[e+12>>2]*q(32768));n[e+12>>2]=f;h=a;f=Sd(f);b:{if(q(r(f))<q(2147483648)){g=~~f;break b}g=-2147483648}l=h,m=Dc(g),i[l+2>>1]=m;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<3}function bua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;d=Za-48|0;Za=d;a:{b:{if(j[a+8>>2]!=j[Ob(a)>>2]){break b}g=a+8|0;h=a+4|0;c=j[a+4>>2];e=j[a>>2];if(c>>>0>e>>>0){f=c;c=((c-e>>2)+1|0)/-2<<2;i=g,k=Pe(f,j[g>>2],f+c|0),j[i>>2]=k;j[h>>2]=c+j[h>>2];break b}i=d,k=j[Ob(a)>>2]-j[a>>2]>>1,j[i+24>>2]=k;j[d+44>>2]=1;c=j[Gc(d+24|0,d+44|0)>>2];c=sn(d+24|0,c,c>>>2|0,j[a+16>>2]);e=zc(d+16|0,j[a+4>>2]);f=j[zc(d+8|0,j[a+8>>2])>>2];e=j[e>>2];j[114626]=0;I(1156,c|0,e|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}Hb(a,c);Hb(h,c+4|0);Hb(g,c+8|0);Hb(Ob(a),Ob(c));xh(c)}sP(j[a+16>>2],j[a+8>>2],b);j[a+8>>2]=j[a+8>>2]+4;Za=d+48|0;return}a=D()|0;C()|0;xh(c);G(a|0);z()}function TJa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;d=Za-48|0;Za=d;a:{b:{if(j[a+8>>2]!=j[Ob(a)>>2]){break b}g=a+8|0;h=a+4|0;c=j[a+4>>2];e=j[a>>2];if(c>>>0>e>>>0){f=c;c=((c-e>>1)+1|0)/-2<<1;i=g,k=AJa(f,j[g>>2],f+c|0),j[i>>2]=k;j[h>>2]=c+j[h>>2];break b}i=d,k=j[Ob(a)>>2]-j[a>>2]|0,j[i+24>>2]=k;j[d+44>>2]=1;c=j[Gc(d+24|0,d+44|0)>>2];c=zR(d+24|0,c,c>>>2|0,j[a+16>>2]);e=zc(d+16|0,j[a+4>>2]);f=j[zc(d+8|0,j[a+8>>2])>>2];e=j[e>>2];j[114626]=0;I(522,c|0,e|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}Hb(a,c);Hb(h,c+4|0);Hb(g,c+8|0);Hb(Ob(a),Ob(c));rt(c)}Cz(j[a+16>>2],j[a+8>>2],b);j[a+8>>2]=j[a+8>>2]+2;Za=d+48|0;return}a=D()|0;C()|0;rt(c);G(a|0);z()}function O4(a){var b=0,c=q(0),d=q(0),e=q(0),f=0,g=q(0),h=q(0);b=(ZMa(a),VMa(2));a:{b:{if(!((b|0)>-1?b>>>0>=8388608:0)){if(!(b&2147483647)){return q(q(-1)/q(a*a))}if((b|0)<=-1){return q(q(a-a)/q(0))}b=(ZMa(q(a*q(33554432))),VMa(2));f=-152;break b}if(b>>>0>2139095039){break a}f=-127;a=q(0);if((b|0)==1065353216){break a}}b=b+4913933|0;g=q((b>>>23|0)+f|0);a=q((WMa(2,(b&8388607)+1060439283|0),_Ma())+q(-1));c=q(a/q(a+q(2)));d=q(c*c);e=q(d*d);h=a;a=q(a*q(a*q(.5)));a=q(q(g*q(.6931381225585938))+q(h+q(q(q(g*q(905800061445916e-20))+q(c*q(a+q(q(d*q(q(e*q(.2849878668785095))+q(.6666666269302368)))+q(e*q(q(e*q(.24279078841209412))+q(.40000972151756287)))))))-a)))}return a}function kF(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=Za-16|0;Za=d;a:{b:{c:{d:{if((b|0)>=0){if((Qk(a+8|0)|0)>(b|0)){break d}}a=R(8)|0;j[114626]=0;d=E(85,d|0,40657)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}Wb(a,d);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;gb(d);break b}if(!(c<=1?!(c<0):0)){a=R(8)|0;j[114626]=0;d=E(85,d|0,40635)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Wb(a,d);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;gb(d);break b}b=D()|0;C()|0;S(a|0);break b}e=Mm(c*64);j[(j[a+32>>2]+p(b,896)|0)+1075744>>2]=e;Za=d+16|0;return}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=Uh(a,b,c,d);j[a>>2]=79668;c=ri(a+4208|0);d=a+4288|0;j[d>>2]=0;j[d+4>>2]=0;j[a+4280>>2]=0;j[a+4284>>2]=0;j[114626]=0;d=T(1387)|0;e=j[114626];j[114626]=0;a:{if((e|0)==1){break a}j[114626]=0;d=H(1388,d|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break a}j[a+4228>>2]=1049926264;j[a+4232>>2]=0;j[a+4220>>2]=1056964608;j[a+4224>>2]=1056964608;j[a+4296>>2]=d;h[a+4244|0]=0;j[a+4236>>2]=2147483647;j[a+4240>>2]=0;tw(a);xr(a);j[114626]=0;K(1632,a+44|0,2,2)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;N(1633,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}return a|0}a=D()|0;C()|0;wg(c);we(b);G(a|0);z()}function kEa(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;L(414,d+8|0,3,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(761,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}j[114626]=0;E(470,d|0,d+24|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+24|0)}lc(d+40|0);G(a|0);z()}function gG(a,b,c,d){var e=0,f=0,g=0,i=0,k=q(0),l=0;e=Za-80|0;Za=e;g=a+24|0;oo(j[g>>2]);h[j[g>>2]+1304512|0]=j[a+52>>2]!=0;c=Xd(e+32|0,d,c,b);d=j[a+32>>2];k=n[a+48>>2];j[e+8>>2]=j[c+8>>2];i=j[c+4>>2];j[e>>2]=j[c>>2];j[e+4>>2]=i;i=qaa(e+48|0,e,d,k);c=0;a:{while(1){if(b){d=j[g>>2];j[e+24>>2]=b;j[e+28>>2]=0;j[114626]=0;j[e+16>>2]=134217727;j[e+20>>2]=0;f=E(2145,e+24|0,e+16|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break a}f=j[f>>2];j[114626]=0;d=K(2146,d|0,f|0,i|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}c=c+d|0;b=b-d|0;if(d){continue}}break}if(!(j[a+52>>2]!=1|c)){a=j[g>>2];j[a+480208>>2]=j[a+480208>>2]&-513}Za=e+80|0;return c}a=D()|0;C()|0;G(a|0);z()}function fG(a,b,c,d){var e=0,f=0,g=0,i=0,k=q(0),l=0;e=Za-80|0;Za=e;g=a+24|0;oo(j[g>>2]);h[j[g>>2]+1304512|0]=j[a+52>>2]!=0;c=Xd(e+32|0,d,c,b);d=j[a+32>>2];k=n[a+48>>2];j[e+8>>2]=j[c+8>>2];i=j[c+4>>2];j[e>>2]=j[c>>2];j[e+4>>2]=i;i=oaa(e+48|0,e,d,k);c=0;a:{while(1){if(b){d=j[g>>2];j[e+24>>2]=b;j[e+28>>2]=0;j[114626]=0;j[e+16>>2]=134217727;j[e+20>>2]=0;f=E(2145,e+24|0,e+16|0)|0;l=j[114626];j[114626]=0;if((l|0)==1){break a}f=j[f>>2];j[114626]=0;d=K(2146,d|0,f|0,i|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}c=c+d|0;b=b-d|0;if(d){continue}}break}if(!(j[a+52>>2]!=1|c)){a=j[g>>2];j[a+480208>>2]=j[a+480208>>2]&-513}Za=e+80|0;return c}a=D()|0;C()|0;G(a|0);z()}function ZJa(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;L(414,d+8|0,2,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(518,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}j[114626]=0;E(470,d|0,d+24|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+24|0)}lc(d+40|0);G(a|0);z()}function PFa(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;L(414,d+8|0,2,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(511,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}j[114626]=0;E(470,d|0,d+24|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+24|0)}lc(d+40|0);G(a|0);z()}function FKa(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;L(414,d+8|0,3,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(469,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}j[114626]=0;E(470,d|0,d+24|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+24|0)}lc(d+40|0);G(a|0);z()}function dx(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0;c=Za-16|0;Za=c;if(!ad(a)){m=c,n=Lb(a),j[m+8>>2]=n;m=c,n=Mb(a),j[m>>2]=n;if(rb(c+8|0,c)){while(1){b=j[c+8>>2];wn(b,4194304,67108864);e=j[b>>2];f=e+f|0;b=g;b=f>>>0<e>>>0?b+1|0:b;g=b;Id(c+8|0);if(rb(c+8|0,c)){continue}break}}b=sb(a);h=sb(a);m=c,n=Lb(a),j[m+8>>2]=n;m=c,n=Mb(a),j[m>>2]=n;b=RMa(f,g,b,0);e=ab;f=h<<24;g=0;if(rb(c+8|0,c)){h=b;e=((e&1)<<31|b>>>1)&2147483647;while(1){b=j[c+8>>2];i=b;d=j[b>>2];b=d>>>8|0;d=e+(d<<24)|0;b=b+k|0;b=Wc(RMa(d,e>>>0>d>>>0?b+1|0:b,h,l),ab);j[i>>2]=b;d=f;f=d-b|0;g=g-(b>>>0>d>>>0)|0;Id(c+8|0);if(rb(c+8|0,c)){continue}break}}a=jc(a,0);j[a>>2]=f+j[a>>2]}Za=c+16|0}function Y5(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,l=0,m=0,o=0,r=0,s=q(0);g=k[c+768|0];e=576;while(1){a:{if(!(g&255)){g=0;break a}h=(p(d,j)<<2)+a|0;i=0;while(1){m=e;f=k[(c+i|0)+770|0];b:{if(!f){break b}if(f>>>0<=16){if((d|0)<1){break b}l=(-1<<f-1)+1|0;e=0;while(1){r=(e<<2)+h|0,s=q(Bd(b,f)+l|0),n[r>>2]=s;e=e+1|0;if((e|0)!=(d|0)){continue}break}break b}e=2<<f-17;f=e|1;e=Bd(b,(e-(f>>>3|0)|0)+3|0);if((d|0)<1){break b}l=f>>>1|0;g=0;while(1){o=e;e=(e>>>0)/(f>>>0)|0;n[(g<<2)+h>>2]=(o-p(f,e)|0)-l|0;g=g+1|0;if((g|0)!=(d|0)){continue}break}}e=18-m|0;h=(m<<2)+h|0;i=i+1|0;g=k[c+768|0];if(i>>>0<g<<1>>>0){continue}break}}j=j+1|0;if((j|0)!=4){continue}break}return d<<2}function Lc(a){var b=0,c=0,d=0,e=0,f=0,g=0,i=0,l=0,n=0;a:{c=j[a+112>>2];d=j[a+116>>2];b:{if(c|d){b=c>>>0<=m[a+120>>2];c=j[a+124>>2];if((d|0)<(c|0)?1:(d|0)<=(c|0)?b:0){break b}}g=kv(a);if((g|0)>-1){break a}}j[a+104>>2]=0;return-1}i=a;b=j[a+116>>2];l=b;d=j[a+8>>2];c=d;f=j[a+112>>2];c:{if(!(b|f)){break c}c=d;e=j[a+120>>2]^-1;f=e+f|0;b=(j[a+124>>2]^-1)+l|0;b=f>>>0<e>>>0?b+1|0:b;l=j[a+4>>2];e=d-l|0;n=f>>>0>=e>>>0;e=e>>31;if((b|0)>(e|0)?1:(e|0)<=(b|0)?n:0){break c}c=f+l|0}j[i+104>>2]=c;i=j[a+4>>2];if(d){c=a;b=(d-i|0)+1|0;d=b+j[a+120>>2]|0;a=j[a+124>>2]+(b>>31)|0;j[c+120>>2]=d;j[c+124>>2]=d>>>0<b>>>0?a+1|0:a}a=i-1|0;if(k[a|0]!=(g|0)){h[a|0]=g}return g}function qg(a,b){var c=q(0),d=q(0),e=q(0),f=q(0),g=q(0);d=n[a+4268>>2];f=UG(a);c=q(q(n[a+4224>>2]*q(1.899999976158142))+q(.10000000149011612));e=Yd(q(10),q(q(q(j[((b<<2)+a|0)+4292>>2])*q(-3))/q(n[a+4268>>2]*q(q(n[a+4220>>2]*q(19.899999618530273))+q(.10000000149011612)))));c=q(q(Yd(e,q(q(2)-q(q(2)/c)))+q(-1))/q(q(1)-_n(c>q(1)?q(3.1415927410125732):q(q(f*q(6.2831854820251465))/d))));a:{if(c==q(0)){break a}f=q(c+c);d=q(q(-2)-f);c=q(y(q(q(d*d)+q(q(c*c)*q(-4)))));g=q(q(c-d)/f);if(q(r(g))<=q(1)){break a}g=q(q(-q(c+d))/f)}b=(b<<3)+a|0;n[b+4404>>2]=g;n[b+4400>>2]=e;c=n[a+4272>>2];c=q(c*c);d=q(q(1)-c);e=q(e*e);return q(q(q(q(d*d)*e)/q(q(1)-q(c*e)))+c)}function mza(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-32|0;Za=d;md(b,0);xN(d,a+1|0);qc(d+16|0,d);j[114626]=0;E(370,b+43|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){gb(d+16|0);c=a+73|0;j[b+24>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+54|0;j[b>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+58|0;j[b+4>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+62|0;if(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24)){j[b+8>>2]=(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))+1}i[b+30>>1]=(k[a+68|0]<<1)+2;i[b+34>>1]=l[b+34>>1]&65533|k[a|0]>>>6&2;kc(b+8|0,j[b>>2]);kc(b+4|0,j[b+8>>2]);Za=d+32|0;return}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function Xya(a,b){var c=0,d=0,e=0;c=Za+ -64|0;Za=c;Ee(c+40|0,a,4);a=j[c+40>>2];j[114626]=0;d=H(412,c+40|0)|0;e=j[114626];j[114626]=0;a:{b:{c:{if((e|0)==1){break c}j[114626]=0;d=H(413,d|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;L(414,c+8|0,3,d|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;F(415,c+24|0,c+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}j[114626]=0;F(981,c|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}j[114626]=0;E(470,c|0,c+24|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break b}gb(c+24|0);lc(c+40|0);Za=c- -64|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(c+24|0)}lc(c+40|0);G(a|0);z()}function Tva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0;e=Za-32|0;Za=e;l=j[a+24>>2];m=j[a+20>>2];n=j[a+16>>2];g=j[a+4>>2];f=g;b=j[a>>2];j[e+24>>2]=b;j[e+28>>2]=f;g=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=g;if(d){while(1){o=b>>>18|0;h=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+n|0;g=0;b=1;while(1){k=g<<1;f=i[k+h>>1];j[(e+8|0)+(g<<2)>>2]=f+((p(i[(k|4)+h>>1]-f|0,o)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}j[c>>2]=j[c>>2]+p(j[e+8>>2],m);j[c+4>>2]=j[c+4>>2]+p(j[e+12>>2],l);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;b=j[e+24>>2];f=j[e+28>>2];continue}break}b=j[e+24>>2];f=j[e+28>>2]}j[a>>2]=b;j[a+4>>2]=f;Za=e+32|0}function Kk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;j=1;i=d&2147483647;m=i;k=c;a:{if(!c&(i|0)==2147418112?a|b:(i|0)==2147418112&(c|0)!=0|i>>>0>2147418112){break a}l=h&2147483647;n=l;i=g;if(!g&(l|0)==2147418112?e|f:(l|0)==2147418112&(g|0)!=0|l>>>0>2147418112){break a}if(!(a|e|(i|k)|(b|f|(m|n)))){return 0}k=d&h;if((k|0)>0?1:(k|0)>=0){j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:(d|0)<(h|0)?1:(d|0)<=(h|0)?c>>>0<g>>>0:0){break a}return(a^e|c^g)!=0|(b^f|d^h)!=0}j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:(d|0)>(h|0)?1:(d|0)>=(h|0)?c>>>0>g>>>0:0){break a}j=(a^e|c^g)!=0|(b^f|d^h)!=0}return j}function zla(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,l=0,m=0,n=0,o=0;e=ne(11555);if(e){n=j[a+12>>2];c=b+16|0;if(Xj(a,k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))){g=b+12|0;c=g;a:{if(!(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))){break a}h=b+4|0;while(1){if(!jf(a,4)){break a}b:{if((k[h|0]|k[h+1|0]<<8)>>>0>=64){if((yla(a)|0)<1){break b}}d=0;b=1;while(1){c=vt(a);if(c){o=po(c<<24>>24);i=d>>>0>=e>>>0;l=i&b;c=l;c:{if(i){break c}c=l;if(!(b&1)){break c}c=k[d+11555|0]==(o&255)}b=c;d=d+1|0;continue}break}Fc(a,4);f=b?(d|0)==(e|0)?1:f:f}m=m+1|0;b=g;if(m>>>0<(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))>>>0){continue}break}}d=f&1}Xj(a,n)}return d}function wwa(a){var b=0,c=0,d=0;b=Za+ -64|0;Za=b;a:{b:{c:{d:{e:{while(1){j[b+60>>2]=c;j[b+60>>2]=c<<3;Hz(b+32|0,c>>>0<16?18126:18061);j[114626]=0;F(509,b+16|0,b+60|0);d=j[114626];j[114626]=0;if((d|0)==1){break e}j[114626]=0;I(510,b+48|0,b+32|0,b+16|0);d=j[114626];j[114626]=0;if((d|0)==1){break d}j[114626]=0;F(511,b+8|0,(c<<5)+a|0);d=j[114626];j[114626]=0;if((d|0)==1){break c}j[114626]=0;E(470,b+8|0,b+48|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break c}gb(b+48|0);gb(b+16|0);qb(b+32|0);c=c+1|0;if((c|0)!=128){continue}break}Za=b- -64|0;return}c=D()|0;C()|0;break a}c=D()|0;C()|0;break b}c=D()|0;C()|0;gb(b+48|0)}gb(b+16|0)}qb(b+32|0);G(c|0);z()}function Ala(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,l=0,m=0,n=0,o=0;e=ne(11555);if(e){n=j[a+8>>2];c=b+16|0;if(xc(a,k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))){g=b+12|0;c=g;a:{if(!(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))){break a}h=b+4|0;while(1){if(!yb(a,4)){break a}b:{if((k[h|0]|k[h+1|0]<<8)>>>0>=64){if((mh(a)|0)<1){break b}}d=0;b=1;while(1){c=dd(a);if(c){o=po(c<<24>>24);i=d>>>0>=e>>>0;l=i&b;c=l;c:{if(i){break c}c=l;if(!(b&1)){break c}c=k[d+11555|0]==(o&255)}b=c;d=d+1|0;continue}break}Jb(a,4);f=b?(d|0)==(e|0)?1:f:f}m=m+1|0;b=g;if(m>>>0<(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))>>>0){continue}break}}d=f&1}xc(a,n)}return d}function osa(a,b,c,d,e){var f=0,g=0,m=0,n=0,o=0,p=0;g=Za-16|0;Za=g;m=Uj(a,b);a:{if((m|0)==255){break a}if(Ti(a)){break a}b:{if(c>>>0>6208431){n=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}n=f;c=OMa(1<<20-f,0,c,0)+24858e3|0;f=ab;c=Wc(RMa(c,c>>>0<24858e3?f+1|0:f,49716e3,0),ab)}if(e){i[g+14>>1]=(b&3)+c;i[g+12>>1]=1023;c=l[gf(g+14|0,g+12|0)>>1]}e=gs(m);b=a+4|0;o=Pb(b,m),p=(n<<10|c)>>>8|(d?0:32),h[o|0]=p;Og(j[a>>2],e|160,c&255);Og(j[a>>2],e|176,k[Pb(b,m)|0]);h[a+530|0]=1}Za=g+16|0}function Ima(a){var b=0,c=0,d=0;d=Za-32|0;Za=d;kM(d);b=j[d+28>>2];c=j[d+24>>2];h[a+24|0]=c;h[a+25|0]=c>>>8;h[a+26|0]=c>>>16;h[a+27|0]=c>>>24;h[a+28|0]=b;h[a+29|0]=b>>>8;h[a+30|0]=b>>>16;h[a+31|0]=b>>>24;b=j[d+20>>2];c=j[d+16>>2];h[a+16|0]=c;h[a+17|0]=c>>>8;h[a+18|0]=c>>>16;h[a+19|0]=c>>>24;h[a+20|0]=b;h[a+21|0]=b>>>8;h[a+22|0]=b>>>16;h[a+23|0]=b>>>24;b=j[d+12>>2];c=j[d+8>>2];h[a+8|0]=c;h[a+9|0]=c>>>8;h[a+10|0]=c>>>16;h[a+11|0]=c>>>24;h[a+12|0]=b;h[a+13|0]=b>>>8;h[a+14|0]=b>>>16;h[a+15|0]=b>>>24;b=j[d+4>>2];c=j[d>>2];h[a|0]=c;h[a+1|0]=c>>>8;h[a+2|0]=c>>>16;h[a+3|0]=c>>>24;h[a+4|0]=b;h[a+5|0]=b>>>8;h[a+6|0]=b>>>16;h[a+7|0]=b>>>24;Za=d+32|0}function fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Za+ -64|0;Za=e;j[e+56>>2]=d;d=j[a+28>>2];jn(j[j[d>>2]-12>>2]+d|0,0);if(j[j[b>>2]+4>>2]){h=j[a+28>>2];f=j[a+12>>2];g=j[j[b>>2]+4>>2];d=g+j[a+8>>2]|0;f=sg(e+40|0,d,d>>>0<g>>>0?f+1|0:f);d=j[f+12>>2];j[e+8>>2]=j[f+8>>2];j[e+12>>2]=d;d=j[f+4>>2];j[e>>2]=j[f>>2];j[e+4>>2]=d;Gi(h,e)}Ve(e+16|0,j[a+28>>2]);d=j[e+28>>2];j[e+32>>2]=j[e+24>>2];j[e+36>>2]=d;XH(j[a+28>>2],c,j[e+56>>2]);c=j[b>>2];b=Rl(e+16|0,fc(a+32|0,j[j[b>>2]>>2]),l[j[b>>2]+12>>1]);j[114626]=0;P(1623,a|0,c|0,b|0,e+32|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){qb(b);Za=e- -64|0;return}a=D()|0;C()|0;qb(b);G(a|0);z()}function dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Za+ -64|0;Za=e;j[e+56>>2]=d;d=j[a+28>>2];jn(j[j[d>>2]-12>>2]+d|0,0);if(j[j[b>>2]+4>>2]){h=j[a+28>>2];f=j[a+12>>2];g=j[j[b>>2]+4>>2];d=g+j[a+8>>2]|0;f=sg(e+40|0,d,d>>>0<g>>>0?f+1|0:f);d=j[f+12>>2];j[e+8>>2]=j[f+8>>2];j[e+12>>2]=d;d=j[f+4>>2];j[e>>2]=j[f>>2];j[e+4>>2]=d;Gi(h,e)}Ve(e+16|0,j[a+28>>2]);d=j[e+28>>2];j[e+32>>2]=j[e+24>>2];j[e+36>>2]=d;SH(c,j[a+28>>2],j[e+56>>2]);c=j[b>>2];b=Rl(e+16|0,fc(a+32|0,j[j[b>>2]>>2]),l[j[b>>2]+12>>1]);j[114626]=0;P(1623,a|0,c|0,b|0,e+32|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){qb(b);Za=e- -64|0;return}a=D()|0;C()|0;qb(b);G(a|0);z()}function BO(a,b,c,d,e,f){var g=0,h=0,k=0,m=0,n=0,o=0,q=0;while(1){n=l[ac(b,g)>>1];o=n+1|0;q=(h&65535)>>>0>n>>>0|n>>>0>127;k=q?k:c>>>0>g>>>0?o:k;m=(m&65535)>>>0>n>>>0?m:o;h=q?h:o;g=g+1|0;if((g|0)!=128){continue}break}bg(b,c);c=j[a+8>>2];a:{b:{if(!f){break b}g=h&65535;if((c+((g<<11)+f|0)|0)!=(jj(a)&-2)){break b}xc(a,c+(g<<10)|0);if(Ay(a,16,1)){i[e>>1]=8}xc(a,c);break a}g=k&65535;if((g|0)==(h&65535)){h=k;break a}if(l[e>>1]!=4|f){break a}xc(a,c+(g<<10)|0);f=Ay(a,64,1);xc(a,c);h=f?h:k}f=m&65535;c:{if(f>>>0>(h&65535)>>>0){if(((c+d|0)+(p(f,l[e>>1])<<8)|0)==(jj(a)|0)){break c}}if(f>>>0>=255){zy(b,254,65534);zy(b,255,65535)}m=h}return m&65535}function Eia(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Za-48|0;Za=d;lj(a,d+40|0);e=j[d+44>>2];if(!e&m[d+40>>2]>256|e){j[d+40>>2]=256;j[d+44>>2]=0}a:{b:{c:{d:{if(j[d+40>>2]|j[d+44>>2]){while(1){cf(a,d+38|0);e=Db(d+24|0);j[114626]=0;K(723,a|0,e|0,255)|0;f=j[114626];j[114626]=0;if((f|0)==1){break d}j[114626]=0;I(13,d+8|0,c|0,e|0);f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;f=E(1610,b|0,d+38|0)|0;h=j[114626];j[114626]=0;if((h|0)==1){break b}ob(f,d+8|0);gb(d+8|0);gb(e);e=j[d+44>>2];g=g+1|0;if(!e&g>>>0<m[d+40>>2]|e){continue}break}}Za=d+48|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+8|0)}gb(e);G(a|0);z()}function qsa(a,b){var c=0,d=0,e=0,f=0,g=0,j=0,m=0,n=0;g=255;a:{b:{e=a+58|0;c=k[Pb(e,b)|0];if((c|0)==255){break b}if(h[Pb(e,b)|0]>-1){break a}d=a+22|0;c=c&127;if(l[Oc(d,c)>>1]!=65535){if(l[Oc(d,c)>>1]!=(b|0)){break b}}m=Oc(d,c),n=b,i[m>>1]=n;m=Pb(e,b),n=c,h[m|0]=n;break a}j=a+4|0;f=a+22|0;c=0;d=255;while(1){if(l[Oc(f,c)>>1]==65535){m=Oc(f,c),n=b,i[m>>1]=n;m=Pb(e,b),n=c,h[m|0]=n;break a}if(!(k[Pb(j,c)|0]&32)){g=h[Pb(e,l[Oc(f,c)>>1])|0]>-1?g:c;d=c}c=c+1|0;if((c|0)!=18){continue}break}if((d&255)!=255){c=(g&255)==255?d:g;d=c&255;m=Pb(e,l[Oc(f,d)>>1]),n=255,h[m|0]=n;m=Oc(f,d),n=b,i[m>>1]=n;m=Pb(e,b),n=c,h[m|0]=n}c=Uj(a,b)}return c&255}function Faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Za-32|0;Za=c;tG(c+24|0);qG(a+24|0,ud(c+24|0));kh(c+24|0);i[a+28>>1]=0;Eaa(c+24|0,fM());ps(a+32|0,c+24|0);bf(c+24|0);sG(c+24|0,j[a>>2]);CG(a+4|0,ud(c+24|0));Hc(c+24|0);nm(j[a+24>>2],j[a+4>>2]);j[a+60>>2]=0;j[a+48>>2]=1065353216;j[a+52>>2]=0;j[a+16>>2]=0;j[a+20>>2]=0;j[a+8>>2]=0;h[a- -64|0]=0;e=c,f=Wm(b),j[e+24>>2]=f;e=c,f=ki(b),j[e+16>>2]=f;a:{if(ji(c+24|0,c+16|0)){while(1){d=Rg(c+24|0);b=Mf(c,d);j[114626]=0;L(2074,a|0,b|0,d+12|0,0);d=j[114626];j[114626]=0;if((d|0)==1){break a}gb(b);dp(c+24|0);if(ji(c+24|0,c+16|0)){continue}break}}Za=c+32|0;return}a=D()|0;C()|0;gb(b);G(a|0);z()}function fHa(a,b,c){var d=0,e=0,f=0,g=0,l=0,n=0;d=Za-32|0;Za=d;ug(d,1,a);qc(d+16|0,d);j[114626]=0;E(369,b+492|0,d+16|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){gb(d+16|0);a:{if(!(k[a+378|0]|k[a+379|0]<<8)){break a}j[d+16>>2]=120;j[d>>2]=116;if(!j[tb(d+16|0,d)>>2]){break a}f=b+236|0;e=0;while(1){g=k[(a+e|0)+32|0];l=Oc(f,e+12|0),n=c+g|0,i[l>>1]=n;j[d+16>>2]=120;j[d>>2]=116;e=e+1|0;if(e>>>0<m[tb(d+16|0,d)>>2]){continue}break}}j[b>>2]=k[a+376|0]|k[a+377|0]<<8;jz(a,b+48|0,0);jz(a,b+68|0,1);jz(a,b+88|0,2);a=k[b+100|0];if(a&1){h[b+100|0]=a|16}if(!(j[b>>2]|h[b+60|0]&1)){j[b>>2]=32767}Za=d+32|0;return}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function mE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=Za-16|0;Za=f;c=1;a:{b:{switch(b-a>>2){case 2:b=b-4|0;if(!rd(b,a)){break a}Hb(a,b);break a;case 3:em(a,a+4|0,b-4|0);break a;case 4:rv(a,a+4|0,a+8|0,b-4|0);break a;case 5:qv(a,a+4|0,a+8|0,a+12|0,b-4|0);break a;case 0:case 1:break a;default:break b}}e=a+8|0;em(a,a+4|0,e);d=a+12|0;c:{while(1){g=(b|0)==(d|0);if(g){break c}d:{if(rd(d,e)){j[f+12>>2]=j[d>>2];h=d;while(1){e:{c=e;j[h>>2]=j[c>>2];if((a|0)==(c|0)){c=a;break e}h=c;e=c-4|0;if(rd(f+12|0,e)){continue}}break}j[c>>2]=j[f+12>>2];i=i+1|0;if((i|0)==8){break d}}e=d;d=d+4|0;continue}break}c=(d+4|0)==(b|0)}c=c|g}Za=f+16|0;return c&1}function Sva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0;b=Za-16|0;Za=b;g=j[a+40>>2];i=j[a+36>>2];n=j[a+16>>2];f=j[a+4>>2];e=f;k=j[a>>2];j[b+8>>2]=k;j[b+12>>2]=e;f=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=f;a:{if(!d){f=g>>12;l=i>>12;break a}while(1){f=j[a+32>>2];m=e+n|0;e=h[m|0];i=j[a+28>>2]+i|0;l=i>>12;e=((p(h[m+1|0]-e|0,k>>>10&4194048)|0)/16384|0)+(e<<8)|0;j[c>>2]=j[c>>2]+p(l,e);g=f+g|0;f=g>>12;j[c+4>>2]=j[c+4>>2]+p(e,f);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;k=j[b+8>>2];e=j[b+12>>2];continue}break}k=j[b+8>>2];e=j[b+12>>2]}j[a+40>>2]=g;j[a+20>>2]=l;j[a+36>>2]=i;j[a+24>>2]=f;j[a>>2]=k;j[a+4>>2]=e;Za=b+16|0}function Uva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0,n=0;e=Za-32|0;Za=e;k=j[a+24>>2];l=j[a+20>>2];m=j[a+16>>2];b=j[a+4>>2];f=j[a>>2];j[e+24>>2]=f;j[e+28>>2]=b;g=j[a+12>>2];j[e+16>>2]=j[a+8>>2];j[e+20>>2]=g;if(d){while(1){n=f>>>10&4194048;i=(((b&2147483647)<<1|f>>>31)&-2)+m|0;g=0;b=1;while(1){f=h[g+i|0];j[(e+8|0)+(g<<2)>>2]=((p(h[(g|2)+i|0]-f|0,n)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}j[c>>2]=j[c>>2]+p(j[e+8>>2],l);j[c+4>>2]=j[c+4>>2]+p(j[e+12>>2],k);Bb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=j[e+24>>2];b=j[e+28>>2];continue}break}f=j[e+24>>2];b=j[e+28>>2]}j[a>>2]=f;j[a+4>>2]=b;Za=e+32|0}function v5(a,b,c,d,e,f){var g=0,h=0,i=0,l=0;j[a+1504>>2]=0;j[a+1508>>2]=0;a:{if(j[a+96>>2]){break a}if(!h5(a)){break a}if(Tb(a,1)){Nb(a,35);return 0}h=c;b:{c:{if(!(j[a+84>>2]!=j[a+92>>2]?j[a+80>>2]:0)){c=Tb(a,Nk(j[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=j[a+408>>2]){break a}j[f>>2]=c;c=p(c,6)+a|0;if(!k[c+412|0]){g=j[a+112>>2];f=g>>1;break c}g=j[a+116>>2];f=g>>1;i=Tb(a,1);l=Tb(a,1);if(!k[c+412|0]|i){break c}j[b>>2]=g-j[a+112>>2]>>2;b=j[a+112>>2]+g>>2;break b}X(50440,50496,3137,50528);z()}j[b>>2]=0;b=f}j[h>>2]=b;d:{if(!(!k[c+412|0]|l)){b=p(g,3);j[d>>2]=b-j[a+112>>2]>>2;g=b+j[a+112>>2]>>2;break d}j[d>>2]=f}j[e>>2]=g;g=1}return g}function mca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-32|0;Za=c;j[114626]=0;N(2008,a|0);d=j[114626];j[114626]=0;a:{b:{c:{if((d|0)==1){break c}j[114626]=0;N(2034,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break c}d=j[a+24>>2];b=Zb(c+8|0,b);j[114626]=0;e=j[b+4>>2];j[c>>2]=j[b>>2];j[c+4>>2]=e;L(2073,c+16|0,d|0,c|0,1);b=j[114626];j[114626]=0;if((b|0)==1){break c}b=Gd(zb(c+16|0));gb(c+16|0);break b}b=J(0)|0;C()|0;O(b|0)|0;b=0;j[114626]=0;L(1982,37051,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=c+32|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function cia(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Za+ -64|0;Za=d;e=j[a+28>>2];jn(j[j[e>>2]-12>>2]+e|0,0);if(j[j[b>>2]+4>>2]){h=j[a+28>>2];e=j[a+12>>2];g=j[j[b>>2]+4>>2];f=g+j[a+8>>2]|0;f=sg(d+48|0,f,f>>>0<g>>>0?e+1|0:e);g=j[f+12>>2];j[d+16>>2]=j[f+8>>2];j[d+20>>2]=g;e=j[f+4>>2];j[d+8>>2]=j[f>>2];j[d+12>>2]=e;Gi(h,d+8|0)}Ve(d+24|0,j[a+28>>2]);e=j[d+36>>2];j[d+40>>2]=j[d+32>>2];j[d+44>>2]=e;bb[1181](j[a+28>>2],c,j[j[b>>2]+8>>2]);c=j[b>>2];e=Rl(d+24|0,fc(a+32|0,j[j[b>>2]>>2]),l[j[b>>2]+12>>1]);j[114626]=0;b=P(1623,a|0,c|0,e|0,d+40|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){qb(e);Za=d- -64|0;return b}a=D()|0;C()|0;qb(e);G(a|0);z()}function Rva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0;b=Za-16|0;Za=b;g=j[a+40>>2];h=j[a+36>>2];n=j[a+16>>2];f=j[a+4>>2];e=f;k=j[a>>2];j[b+8>>2]=k;j[b+12>>2]=e;f=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=f;a:{if(!d){f=g>>12;l=h>>12;break a}while(1){f=j[a+32>>2];m=(e<<1)+n|0;e=i[m>>1];h=j[a+28>>2]+h|0;l=h>>12;e=e+((p(i[m+2>>1]-e|0,k>>>18|0)|0)/16384|0)|0;j[c>>2]=j[c>>2]+p(l,e);g=f+g|0;f=g>>12;j[c+4>>2]=j[c+4>>2]+p(e,f);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;k=j[b+8>>2];e=j[b+12>>2];continue}break}k=j[b+8>>2];e=j[b+12>>2]}j[a+40>>2]=g;j[a+20>>2]=l;j[a+36>>2]=h;j[a+24>>2]=f;j[a>>2]=k;j[a+4>>2]=e;Za=b+16|0}function Nna(a){a=a|0;var b=0,c=0,d=0;c=a+1304360|0;b=a+1074984|0;while(1){j[b+104>>2]=0;j[b+656>>2]=0;j[b+76>>2]=0;j[b+16>>2]=0;b=b+896|0;if((c|0)!=(b|0)){continue}break}qI(a+484344|0);De(a+1304400|0);De(a+1304412|0);De(a+1304424|0);yz(a+1304500|0);c=a+900380|0;b=a+484380|0;while(1){Om(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=j[b>>2];if(d){Cb(Ns(d))}j[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){nH(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}j[a+480180>>2]=0;j[a+480184>>2]=0;a=a+480186|0;i[a>>1]=0;i[a+2>>1]=0;i[a+4>>1]=0;i[a+6>>1]=0;return 1}function mIa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;md(b,0);si(d,1,a);qc(d+16|0,d);j[114626]=0;E(370,b+43|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){gb(d+16|0);c=a+32|0;j[b+24>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+13|0;i[b+34>>1]=l[b+34>>1]&65533|(k[c|0]|k[c+1|0]<<8)<<1&2;c=a+16|0;j[b>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+20|0;j[b+4>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+24|0;j[b+8>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);h[d+16|0]=k[a+15|0];h[d|0]=64;e=b,f=k[Yb(d+16|0,d)|0]<<2,i[e+30>>1]=f;Za=d+32|0;return}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function gF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=Za-16|0;Za=e;a:{b:{c:{d=a+8|0;d:{if(!Pk(d)){if((b|0)<0|(fr(d)|0)<=(b|0)){break d}a=Yo(j[a+32>>2],b+1&65535);i[a+34>>1]=l[a+34>>1]&64511|(c?1024:0);break b}d=Pk(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}a=R(8)|0;j[114626]=0;c=E(85,e|0,40673)|0;b=j[114626];j[114626]=0;e:{if((b|0)!=1){Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;gb(c);break e}b=D()|0;C()|0;S(a|0)}G(b|0);z()}b=b+1<<2;a=a+32|0;if(!j[(b+j[a>>2]|0)+900380>>2]){break b}a=j[(b+j[a>>2]|0)+900380>>2];h[a+15|0]=k[a+15|0]&253|(c?2:0)}Za=e+16|0;return}z()}function W0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=Za-48|0;Za=f;j[f+40>>2]=b;a:{if(!(j[c+4>>2]&1)){c=bb[j[j[a>>2]+24>>2]](a,b,c,d,e)|0;break a}hc(f+24|0,c);j[114626]=0;a=H(2442,f+24|0)|0;b=j[114626];j[114626]=0;b:{if((b|0)!=1){wb(f+24|0);c:{if(e){Gg(f+24|0,a);break c}Fg(f+24|0,a)}g=f,h=nd(f+24|0),j[g+16>>2]=h;while(1){g=f,h=tj(f+24|0),j[g+8>>2]=h;if(!rb(f+16|0,f+8|0)){c=j[f+40>>2];pc(f+24|0);break a}a=j[j[f+16>>2]>>2];j[114626]=0;E(2465,f+40|0,a|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Id(f+16|0);continue}break}c=D()|0;C()|0;pc(f+24|0);break b}c=D()|0;C()|0;wb(f+24|0)}G(c|0);z()}Za=f+48|0;return c|0}function Yla(a){var b=0,c=0,d=0,e=0,f=0;b=Za+ -64|0;Za=b;a:{e=j[a+4>>2];if(!e){break a}d=78400;while(1){c=j[a+4>>2];j[b+56>>2]=j[a>>2];j[b+60>>2]=c;c=Zb(b+48|0,j[d+8>>2]);f=j[b+60>>2];j[b+24>>2]=j[b+56>>2];j[b+28>>2]=f;f=j[c+4>>2];j[b+16>>2]=j[c>>2];j[b+20>>2]=f;if(XI(b+24|0,b+16|0)){break a}d=d+12|0;if((d|0)!=78916){continue}break}d=78928;while(1){b:{c=j[a+4>>2];j[b+40>>2]=j[a>>2];j[b+44>>2]=c;c=Zb(b+32|0,j[d+8>>2]);e=j[b+44>>2];j[b+8>>2]=j[b+40>>2];j[b+12>>2]=e;e=j[c+4>>2];j[b>>2]=j[c>>2];j[b+4>>2]=e;c=XI(b+8|0,b);if(c){break b}d=d+12|0;if((d|0)!=78976){continue}}break}Za=b- -64|0;return c}Za=b- -64|0;return(e|0)!=0}function hR(a,b,c,d,e){var f=0,g=0,i=0,j=0,l=0,m=0;a:{if(!d){break a}j=k[e|0];if(!j|!b){break a}g=d-6|0;l=35>>>g&(g&255)>>>0<6;i=p(0-c|0,6);m=(d-2&255)>>>0>2;while(1){g=a+i|0;f=k[g+3|0];b:{if(!((f-2&255)>>>0>2|m)){c=1;if(k[(a+i|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!l|f>>>0>11)){break b}c=1}c:{if(m){break c}f=a+i|0;if((k[f+2|0]-11&255)>>>0>2){break c}if(k[f+4|0]){break a}}d:{if(!l){break d}f=a+i|0;if((k[f+2|0]-3&255)>>>0>3){break d}if(k[f+4|0]){break a}}e:{if(!c){break e}c=j;a=k[(a+i|0)+5|0];if(a?(c|0)!=(a|0):0){break a}if((a|0)!=(c|0)){break e}h[e|0]=0;return}a=g;b=b-1|0;if(b){continue}break}}}function f1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,i=0;f=Za-48|0;Za=f;j[f+40>>2]=b;a:{if(!(j[c+4>>2]&1)){c=bb[j[j[a>>2]+24>>2]](a,b,c,d,e)|0;break a}hc(f+24|0,c);j[114626]=0;a=H(2408,f+24|0)|0;b=j[114626];j[114626]=0;b:{if((b|0)!=1){wb(f+24|0);c:{if(e){Gg(f+24|0,a);break c}Fg(f+24|0,a)}g=f,i=nd(f+24|0),j[g+16>>2]=i;while(1){g=f,i=_e(f+24|0),j[g+8>>2]=i;if(!rb(f+16|0,f+8|0)){c=j[f+40>>2];gb(f+24|0);break a}a=h[j[f+16>>2]];j[114626]=0;E(2328,f+40|0,a|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Xf(f+16|0);continue}break}c=D()|0;C()|0;gb(f+24|0);break b}c=D()|0;C()|0;wb(f+24|0)}G(c|0);z()}Za=f+48|0;return c|0}function dwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0;b=Za-16|0;Za=b;h=j[a+40>>2];k=j[a+36>>2];m=j[a+16>>2];e=j[a+4>>2];f=e;g=j[a>>2];j[b+8>>2]=g;j[b+12>>2]=e;e=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=e;a:{if(!d){e=h>>12;l=k>>12;break a}while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+m|0;g=i[f+2>>1];e=j[a+32>>2];k=j[a+28>>2]+k|0;l=k>>12;j[c>>2]=j[c>>2]+p(l,i[f>>1]);h=e+h|0;e=h>>12;j[c+4>>2]=j[c+4>>2]+p(g,e);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=j[b+8>>2];f=j[b+12>>2];continue}break}g=j[b+8>>2];f=j[b+12>>2]}j[a+40>>2]=h;j[a+20>>2]=l;j[a+36>>2]=k;j[a+24>>2]=e;j[a>>2]=g;j[a+4>>2]=f;Za=b+16|0}function kBa(a,b,c,d){var e=0,f=0,g=0;e=Za-80|0;Za=e;De(b);Ee(e+56|0,a,d);a=j[e+56>>2];j[114626]=0;f=H(412,e+56|0)|0;g=j[114626];j[114626]=0;a:{b:{c:{if((g|0)==1){break c}j[114626]=0;f=H(413,f|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;L(414,e+8|0,2,f|0,a|0);f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;F(415,e+24|0,e+8|0);f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;I(13,e+40|0,c|0,e+24|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}ob(b,e+40|0);gb(e+40|0);gb(e+24|0);lc(e+56|0);Za=e+80|0;return!d|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(e+24|0)}lc(e+56|0);G(a|0);z()}function TBa(a,b,c,d){var e=0,f=0,g=0;e=Za-80|0;Za=e;De(b);Ee(e+56|0,a,d);a=j[e+56>>2];j[114626]=0;f=H(412,e+56|0)|0;g=j[114626];j[114626]=0;a:{b:{c:{if((g|0)==1){break c}j[114626]=0;f=H(413,f|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break c}j[114626]=0;L(414,e+8|0,3,f|0,a|0);f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;F(415,e+24|0,e+8|0);f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;I(13,e+40|0,c|0,e+24|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}ob(b,e+40|0);gb(e+40|0);gb(e+24|0);lc(e+56|0);Za=e+80|0;return!d|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(e+24|0)}lc(e+56|0);G(a|0);z()}function Ji(a,b,c){var d=0,e=0,f=0,g=0,i=0;d=Za-32|0;Za=d;h[a|0]=0;f=mf(j[j[b>>2]-12>>2]+b|0);e=j[j[b>>2]-12>>2]+b|0;a:{b:{if(f){if(j[e+72>>2]){Jq(j[(j[j[b>>2]-12>>2]+b|0)+72>>2])}c:{if(!(j[(j[j[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}hc(d+24|0,j[j[b>>2]-12>>2]+b|0);j[114626]=0;f=H(21,d+24|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}wb(d+24|0);c=dm(d+16|0,b);e=ck(d+8|0);while(1){d:{if(!Tn(c,e)){break d}if(!ng(f,8192,Bj(c))){break d}Ik(c);continue}break}if(!Ii(c,e)){break c}eg(j[j[b>>2]-12>>2]+b|0,6)}g=a,i=mf(j[j[b>>2]-12>>2]+b|0),h[g|0]=i;break b}eg(e,4)}Za=d+32|0;return a}a=D()|0;C()|0;wb(d+24|0);G(a|0);z()}function qD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-16|0;Za=d;Za=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=k[b|0];e=d<<24>>24;if((e|0)>=0){j[a>>2]=d;e=(e|0)!=0;break a}d=h[b|0];if(!j[j[21215]>>2]){j[a>>2]=d&57343;e=1;break a}d=(d&255)-194|0;if(d>>>0>50){break b}d=j[(d<<2)+57712>>2];if(d<<p(c,6)-6<0?c>>>0<=3:0){break b}c=k[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){j[a>>2]=c;e=2;break a}d=k[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){j[a>>2]=c;e=3;break a}b=k[b+3|0]-128|0;if(b>>>0>63){break b}j[a>>2]=b|c<<6;e=4;break a}j[114600]=25;e=-1}return e|0}function kK(a,b,c){var d=0,e=0;a:{if(j[a+480180>>2]==4){d=k[b+834|0];if(c){h[b+834|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(j[a+480180>>2]!=1048576){break a}if(c){h[b+833|0]=c;break a}c=k[b+833|0]}b:{if(!(h[b+872|0]&1)|!(c&255)){break b}d=j[b+700>>2];if(!d){break b}c:{if(!(k[a+480208|0]&16)){break c}d=j[b+700>>2];if(j[a+480180>>2]==4){break c}e=b;a=cK(a,c&15);b=OMa(a,a>>31,d,d>>31)+32768|0;a=ab;a=ic(PMa(b,b>>>0<32768?a+1|0:a,65536,0),ab);j[e+700>>2]=((a|0)==(d|0))+a;return}c=d-(c&255)|0;j[b+700>>2]=c;if((c|0)>0){break b}j[b+700>>2]=1;if(j[a+480180>>2]!=2){break b}j[b+696>>2]=0;j[b+88>>2]=j[b+88>>2]|2101248}}function xE(a,b,c,d,e){var f=0,g=0,i=0;f=Za-208|0;Za=f;j[f+204>>2]=c;Ab(f+160|0,0,40);j[f+200>>2]=j[f+204>>2];a:{if((wv(0,b,f+200|0,f+80|0,f+160|0,d,e)|0)<0){b=-1;break a}g=j[a+76>>2]>=0;c=j[a>>2];if(h[a+74|0]<=0){j[a>>2]=c&-33}i=c&32;b:{if(j[a+48>>2]){b=wv(a,b,f+200|0,f+80|0,f+160|0,d,e);break b}j[a+48>>2]=80;j[a+16>>2]=f+80;j[a+28>>2]=f;j[a+20>>2]=f;c=j[a+44>>2];j[a+44>>2]=f;d=wv(a,b,f+200|0,f+80|0,f+160|0,d,e);b=d;if(!c){break b}bb[j[a+36>>2]](a,0,0)|0;j[a+48>>2]=0;j[a+44>>2]=c;j[a+28>>2]=0;j[a+16>>2]=0;b=j[a+20>>2];j[a+20>>2]=0;b=b?d:-1}c=a;a=j[a>>2];j[c>>2]=a|i;b=a&32?-1:b;if(!g){break a}}Za=f+208|0;return b}function Uma(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,k=0,m=0;g=Za-32|0;Za=g;a:{if(l[a+480192>>1]<b>>>0){break a}b=j[((b<<2)+a|0)+900380>>2];if(!b){break a}jM(g+16|0,b);k=g,m=cP(g+16|0),j[k+8>>2]=m;k=g,m=_i(g+16|0),j[k>>2]=m;while(1){b:{j[114626]=0;b=E(785,g+8|0,g|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break b}if(!b){cp(g+16|0);break a}j[114626]=0;b=H(786,g+8|0)|0;i=j[114626];j[114626]=0;if((i|0)==1){break b}b=l[b>>1];if(b>>>0<=l[a+480190>>1]){b=p(b,104)+a|0;h[b+484421|0]=f;h[b+484418|0]=c;h[b+484420|0]=e;h[b+484419|0]=d}Os(g+8|0);continue}break}a=D()|0;C()|0;cp(g+16|0);G(a|0);z()}Za=g+32|0}function ewa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0;b=Za-16|0;Za=b;i=j[a+40>>2];k=j[a+36>>2];m=j[a+16>>2];e=j[a+4>>2];f=e;g=j[a>>2];j[b+8>>2]=g;j[b+12>>2]=e;e=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=e;a:{if(!d){e=i>>12;l=k>>12;break a}while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+m|0;g=h[f+1|0];e=j[a+32>>2];k=j[a+28>>2]+k|0;l=k>>12;j[c>>2]=j[c>>2]+(p(l,h[f|0])<<8);i=e+i|0;e=i>>12;j[c+4>>2]=j[c+4>>2]+(p(g,e)<<8);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=j[b+8>>2];f=j[b+12>>2];continue}break}g=j[b+8>>2];f=j[b+12>>2]}j[a+40>>2]=i;j[a+20>>2]=l;j[a+36>>2]=k;j[a+24>>2]=e;j[a>>2]=g;j[a+4>>2]=f;Za=b+16|0}function pya(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Za-80|0;Za=f;fi(f+40|0,f+32|0,c);j[114626]=0;I(240,f+52|0,f+24|0,d|0);d=j[114626];j[114626]=0;c=1;a:{b:{c:{d:{if((d|0)!=1){j[114626]=0;I(224,f- -64|0,f+16|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break d}j[114626]=0;F(241,f+8|0,f+40|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(72,a|0,b|0,f+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}Kl(f+40|0);Za=f+80|0;return}a=D()|0;C()|0;break c}a=D()|0;C()|0;c=2}c=(f+40|0)+p(c,12)|0;while(1){c=gb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=D()|0;C()|0;Kl(f+40|0)}G(a|0);z()}



function Go(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,i=0,l=0,m=0,n=0,o=0,q=0;f=Za-16|0;Za=f;if(e){h[e|0]=0}m=a+484344|0;d=Se(Ib(m,b),c,d);g=k[d+5|0];a:{b:{c:{d:{i=k[d+3|0];switch(i-10|0){case 2:case 4:case 7:break c;case 0:break d;default:break a}}j[f+12>>2]=2;l=0;break b}j[f+12>>2]=1;l=0;if((i|0)!=17){break b}l=j[a+480180>>2]==4}o=f,q=j[Ib(m,b)+12>>2]+(c^-1)|0,j[o+8>>2]=q;c=j[tb(f+8|0,f+12|0)>>2];if(!c){break a}while(1){n=p(Jj(Ib(m,b)),6);a=n+d|0;if(k[a+3|0]!=34){break a}i=g<<8;g=l?g>>>0<256?i+ -8192|0:i:i;d=k[(d+n|0)+5|0];c=c-1|0;if(e){h[e|0]=1}g=d|g;d=a;if(c){continue}break}}Za=f+16|0;return g|0}function Dta(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,k=0,m=0,n=0;f=Za+ -64|0;Za=f;d=be(a);m=d<<6;h=j[a+20>>2];g=h+(p(j[a>>2],d)<<1)|0;while(1){if(d){k=p(d,e);n=p(e^-1,d);c=0;while(1){i[g+(c+k<<1)>>1]=l[g+(c-d<<1)>>1];i[(c+n<<1)+h>>1]=l[(c<<1)+h>>1];c=c+1|0;if((c|0)!=(d|0)){continue}break}}e=e+1|0;if((e|0)!=16){continue}break}g=g+(d<<5)|0;c=l[a+34>>1];if(c&2){k=j[a+8>>2];e=j[a+4>>2];mb(f+32|0,b+1074308|0,33);eM(f+40|0,g,(p(d,e)<<1)+h|0,k-e|0,d,(c&4)>>>2|0,kb(f+32|0));c=l[a+34>>1]}if(c&8){e=j[a+16>>2];a=j[a+12>>2];mb(f+32|0,b+1074308|0,33);eM(f+8|0,g+(m<<1)|0,(p(a,d)<<1)+h|0,e-a|0,d,(c&16)>>>4|0,kb(f+32|0))}Za=f- -64|0}function u3(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;j[114626]=0;e=E(15,c+8|0,a|0)|0;d=j[114626];j[114626]=0;a:{b:{c:{if((d|0)!=1){d:{if(!k[e|0]){break d}d=sk(c,a);j[114626]=0;E(2328,d|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){if(!rk(d)){break d}b=j[j[a>>2]-12>>2];j[114626]=0;F(18,a+b|0,1);b=j[114626];j[114626]=0;if((b|0)!=1){break d}}b=J(0)|0;C()|0;nf(e);break c}nf(e);break b}b=J(0)|0;C()|0}O(b|0)|0;b=j[j[a>>2]-12>>2];j[114626]=0;N(19,a+b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=c+16|0;return}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function bI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=q(0),h=0,k=q(0),m=0,o=0,p=q(0);e=Za-16|0;Za=e;if(!(!l[b>>1]|i[d>>1]>i[d+2>>1]|(!(n[c>>2]>q(0))|(i[d+2>>1]-i[d>>1]|0)>32766))){i[a>>1]=3;f=a+4|0;Xh(f);i[a+28>>1]=65472;j[e+12>>2]=1065353216;eI(f,128,e+12|0);j[a+32>>2]=0;i[a+30>>1]=0;Xh(a+16|0);i[a+28>>1]=l[d>>1];m=a,o=cja(l[b>>1]),i[m+30>>1]=o;g=q(r(n[c>>2]));n[a+32>>2]=g;g=Yd(g,q(q(1)/q(i[a+30>>1])));h=1;Sk(f,(i[d+2>>1]-i[d>>1]|0)+1|0);b=i[d>>1];if((b|0)<=i[d+2>>1]){while(1){k=Yd(g,q(b|0));m=xb(f,b-i[a+28>>1]|0),p=k,n[m>>2]=p;c=i[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}io(a)}Za=e+16|0;return h|0}function Z9(a,b){a=a|0;b=b|0;var c=0,d=q(0);c=Za-16|0;Za=c;a:{b:{c:{d:{switch(b-1|0){case 0:d=q(dX(n[a+48>>2])*q(2e3));if(!(q(r(d))<q(2147483648))){break c}a=~~d;break b;case 1:a=(p(j[j[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:a=Y9(k[j[a+24>>2]+24648|0]);break b;case 3:j[c>>2]=0;X9(c,j[a+24>>2]+24604|0);a=j[c>>2];break b;default:break d}}a=R(8)|0;j[114626]=0;c=E(85,c|0,38669)|0;b=j[114626];j[114626]=0;e:{if((b|0)!=1){Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;gb(c);break e}b=D()|0;C()|0;S(a|0)}G(b|0);z()}a=-2147483648}Za=c+16|0;return a|0}z()}function WGa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Za-80|0;Za=f;fi(f+40|0,f+32|0,c);j[114626]=0;I(224,f+52|0,f+24|0,d|0);d=j[114626];j[114626]=0;c=1;a:{b:{c:{d:{if((d|0)!=1){j[114626]=0;I(224,f- -64|0,f+16|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break d}j[114626]=0;F(241,f+8|0,f+40|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(72,a|0,b|0,f+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}Kl(f+40|0);Za=f+80|0;return}a=D()|0;C()|0;break c}a=D()|0;C()|0;c=2}c=(f+40|0)+p(c,12)|0;while(1){c=gb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=D()|0;C()|0;Kl(f+40|0)}G(a|0);z()}function kW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Za-80|0;Za=f;Ll(f+40|0,f+32|0,c);j[114626]=0;I(240,f+52|0,f+24|0,d|0);d=j[114626];j[114626]=0;c=1;a:{b:{c:{d:{if((d|0)!=1){j[114626]=0;I(240,f- -64|0,f+16|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break d}j[114626]=0;F(241,f+8|0,f+40|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(72,a|0,b|0,f+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}Kl(f+40|0);Za=f+80|0;return}a=D()|0;C()|0;break c}a=D()|0;C()|0;c=2}c=(f+40|0)+p(c,12)|0;while(1){c=gb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=D()|0;C()|0;Kl(f+40|0)}G(a|0);z()}function Wza(a,b,c,d){var e=0,f=0,g=0,h=0;f=Za-16|0;Za=f;c=ei(c,b);j[f+12>>2]=c;a:{if((c|0)<1){break a}e=j[b+4>>2];b:{if(!e){e=j[d>>2];break b}g=32-e|0;j[f+8>>2]=g;c=j[Pd(f+8|0,f+12|0)>>2];j[f+12>>2]=j[f+12>>2]-c;e=j[d>>2];g=-1<<j[b+4>>2]&-1>>>g-c;h=j[b>>2];j[e>>2]=j[e>>2]&(g^-1)|g&j[h>>2];c=c+j[d+4>>2]|0;j[d+4>>2]=c&31;e=e+(c>>>3&536870908)|0;j[d>>2]=e;j[b>>2]=h+4;c=j[f+12>>2]}h=e;e=(c|0)/32|0;c=e<<2;Bi(h,j[b>>2],c);e=j[f+12>>2]-(e<<5)|0;j[f+12>>2]=e;g=c+j[d>>2]|0;j[d>>2]=g;if((e|0)<1){break a}h=b;b=c+j[b>>2]|0;j[h>>2]=b;c=-1>>>32-e|0;j[g>>2]=j[g>>2]&(c^-1)|c&j[b>>2];j[d+4>>2]=j[f+12>>2]}vd(a,d);Za=f+16|0}function Csa(a,b){var c=0,d=0,e=0;j[a+3832>>2]=0;j[a+3836>>2]=0;c=a+3837|0;h[c|0]=0;h[c+1|0]=0;h[c+2|0]=0;h[c+3|0]=0;h[c+4|0]=0;h[c+5|0]=0;h[c+6|0]=0;h[c+7|0]=0;while(1){lf((p(e,84)+a|0)+808|0,a);e=e+1|0;if((e|0)!=36){continue}break}while(1){j[(p(d,44)+a|0)+32>>2]=a;d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){c=j[(d<<2)+19808>>2];e=(p(d,44)+a|0)+16|0;a:{if(!(!(1<<d&3591)|d>>>0>11)){c=p(c,84)+a|0;JL(e,c+808|0,c+1060|0,c+1312|0,c+1564|0);break a}c=p(c,84)+a|0;JL(e,c+808|0,c+1060|0,0,0)}d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){Lm((p(d,84)+a|0)+808|0);d=d+1|0;if((d|0)!=36){continue}break}IL(a,b)}function C2(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,l=0,m=0,n=0,o=0,p=0;f=j[a>>2]+1794895138|0;e=Fk(j[a+8>>2],f);g=Fk(j[a+12>>2],f);d=Fk(j[a+16>>2],f);a:{if(b>>>2>>>0<=e>>>0){break a}h=b-(e<<2)|0;if((d|g)&3|(h>>>0<=g>>>0|d>>>0>=h>>>0)){break a}n=d>>>2|0;o=g>>>2|0;g=0;while(1){h=e>>>1|0;i=h+g|0;l=i<<1;d=(l+o<<2)+a|0;m=Fk(j[d>>2],f);d=Fk(j[d+4>>2],f);if(d>>>0>=b>>>0|b-d>>>0<=m>>>0|k[(d+m|0)+a|0]){break a}d=Mh(c,a+d|0);if(!d){c=(n+l<<2)+a|0;e=Fk(j[c>>2],f);c=Fk(j[c+4>>2],f);if(c>>>0>=b>>>0|e>>>0>=b-c>>>0){break a}p=k[(c+e|0)+a|0]?0:a+c|0;break a}if((e|0)==1){break a}d=(d|0)<0;e=d?h:e-h|0;g=d?g:i;continue}}return p}function Wf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=Za+ -64|0;Za=e;a:{b:{if(c-1>>>0>1023){break b}if(tg(a,b)){break b}c:{d:{if(df(a)>>>0<=b>>>0){d=Ew(e+8|0,a);j[114626]=0;I(1575,a|0,b+1|0,d|0);f=j[114626];j[114626]=0;if((f|0)==1){break d}Xk(d)}d=te(a,b);j[114626]=0;E(1576,d|0,c|0)|0;c=j[114626];j[114626]=0;e:{if((c|0)!=1){c=te(a,b);j[c+16>>2]=0;j[c+20>>2]=0;c=te(a,b);j[114626]=0;E(1577,c|0,32324)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break e}}a=J(71396)|0;b=C()|0;break c}g=th(te(a,b));break b}a=J(71396)|0;b=C()|0;Xk(d)}if((W(71396)|0)!=(b|0)){break a}O(a|0)|0;Q()}Za=e- -64|0;return g|0}G(a|0);z()}function kca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;j[114626]=0;N(2008,a|0);e=j[114626];j[114626]=0;a:{b:{c:{if((e|0)==1){break c}j[114626]=0;N(2034,b|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}e=j[a+24>>2];b=Zb(d+8|0,b);j[114626]=0;f=j[b+4>>2];j[d>>2]=j[b>>2];j[d+4>>2]=f;L(2075,e|0,d|0,(c|0)!=0|0,1);c=j[114626];j[114626]=0;b=1;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37102,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}Za=d+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function t$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;b=Za-32|0;Za=b;d=Db(b+16|0);j[114626]=0;c=Qe(d);e=j[114626];j[114626]=0;a:{b:{if((e|0)==1){break b}e=zb(f);g=zb(f);f=nb(f);j[114626]=0;P(2498,b+8|0,c|0,e|0,f+g|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break b}c=zb(d);j[114626]=0;e=j[114626];j[114626]=0;c:{if((e|0)!=1){e=Db(a);j[114626]=0;a=Qe(e);f=j[114626];j[114626]=0;if((f|0)==1){break c}f=ne(c);j[114626]=0;P(2500,b|0,a|0,c|0,c+f|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}gb(d);Za=b+32|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(e);break a}a=D()|0;C()|0}gb(d);G(a|0);z()}function I4(a){var b=0,c=0,d=0,e=0;e=Za-16|0;Za=e;c=(ZMa(a),VMa(2));b=c&2147483647;a:{if(b>>>0<=1061752794){if(b>>>0<964689920){break a}a=hm(+a,0);break a}if(b>>>0<=1081824209){d=+a;if(b>>>0<=1075235811){a=hm(((c|0)>-1?-1.5707963267948966:1.5707963267948966)+d,1);break a}a=hm(((c|0)>-1?-3.141592653589793:3.141592653589793)+d,0);break a}if(b>>>0<=1088565717){d=+a;if(b>>>0<=1085271519){a=hm(((c|0)>-1?-4.71238898038469:4.71238898038469)+d,1);break a}a=hm(((c|0)>-1?-6.283185307179586:6.283185307179586)+d,0);break a}if(b>>>0>=2139095040){a=q(a-a);break a}b=yv(a,e+8|0);a=hm(o[e+8>>3],b&1)}Za=e+16|0;return a}function bya(a,b){var c=0,d=0,e=0,f=0,g=0;d=Za-32|0;Za=d;md(b,0);dk(d,2,a);qc(d+16|0,d);j[114626]=0;E(370,b+43|0,d+16|0)|0;c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){gb(d+16|0);c=a+24|0;j[b+24>>2]=k[c|0]|k[c+1|0]<<8;h[d+16|0]=k[a+22|0];h[d|0]=64;f=b,g=k[Yb(d+16|0,d)|0]<<2,i[f+30>>1]=g;c=a+16|0;j[b>>2]=k[c|0]|k[c+1|0]<<8;c=a+18|0;j[b+4>>2]=k[c|0]|k[c+1|0]<<8;a=a+20|0;a=k[a|0]|k[a+1|0]<<8;j[b+8>>2]=a;c=j[b>>2];if(c>>>0>1){break b}j[b>>2]=0;break a}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}e=j[b+4>>2];if((a|0)==65535|c>>>0<=e>>>0|a>>>0<=e>>>0){break a}i[b+34>>1]=2;f=b,g=j[tb(b+8|0,b)>>2],j[f+8>>2]=g}Za=d+32|0}function zH(a,b,c){a=a|0;b=b|0;c=q(c);var d=0;d=Za-16|0;Za=d;n[d+12>>2]=c;uw(a);Kd(d+12|0,q(0));a:{b:{switch(b|0){case 0:n[a+4220>>2]=n[d+12>>2];break a;case 1:n[a+4224>>2]=n[d+12>>2];break a;case 2:n[a+4228>>2]=n[d+12>>2];tw(a);break a;case 3:h[a+4240|0]=n[d+12>>2]>=q(.5);tw(a);break a;case 4:b=a;a=qh(q(n[d+12>>2]*q(32)));j[b+4232>>2]=(a|0)<5?a:5;Za=d+16|0;return;case 5:h[a+4241|0]=n[d+12>>2]>=q(.5);break a;case 6:h[a+4242|0]=n[d+12>>2]>=q(.5);break a;case 7:h[a+4244|0]=n[d+12>>2]>=q(.5);break a;case 8:break b;default:break a}}b=a;c=n[d+12>>2];if(c==q(0)){sw(a);c=n[d+12>>2]}o[b+4256>>3]=c}Za=d+16|0}function CU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Za-48|0;Za=d;rc(b);aq(a);a:{if(!kf(b,d+40|0)){break a}if(!NA(d+40|0)){break a}if(!c){f=1;break a}if(!yb(b,4)){break a}tu(a);su(d+24|0);ru(yg(a)+28|0,d+24|0);$p(d+24|0);c=j[yg(a)+28>>2];e=jj(b);if(e&1){break a}g=e-4|0;xc(b,g);e=dd(b);e=dd(b)<<8|e<<16|dd(b);if(!e){break a}j[114626]=0;F(331,c|0,e|0);h=j[114626];j[114626]=0;f=1;if((h|0)==1){a=J(71396)|0;if((C()|0)==(W(71396)|0)){O(a|0)|0;Q();f=0;break a}G(a|0);z()}xc(b,4);AU(MA(b),g,lb(j[c>>2]),e);xi(d+8|0,c);ou(d+16|0,d+8|0);b=Dn(d+24|0,d+16|0,0);Ed(yg(a)+12|0,b);jb(b)}Za=d+48|0;return f|0}function cna(a,b,c){var d=0,e=0,f=0;d=Za-32|0;Za=d;a:{if(vJ(b)){j[d+16>>2]=j[5144];c=j[5141];j[d>>2]=j[5140];j[d+4>>2]=c;c=j[5143];j[d+8>>2]=j[5142];j[d+12>>2]=c;Eb(a,((b<<2)+d|0)-1004|0);break a}if(Ld(b)){f=Qc(d);j[114626]=0;e=b-1|0;b=(e<<16>>16)/12|0;c=E(1426,f|0,(e-p(b,12)<<16>>16<<2)+c|0)|0;e=j[114626];j[114626]=0;b:{if((e|0)==1){break b}j[114626]=0;b=K(1427,c|0,1,(b<<16)+3145728>>16)|0;c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;E(4,a|0,b|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break b}gb(f);break a}a=D()|0;C()|0;gb(f);G(a|0);z()}if(!b){Eb(a,20580);break a}Eb(a,20584)}Za=d+32|0}function J$(a,b,c,d,e,f,g,i,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;k=k|0;l=l|0;var m=0,n=0,o=0;m=Za-16|0;Za=m;a:{if(a){a=RC(b);pj(m,a);b=j[m>>2];h[c|0]=b;h[c+1|0]=b>>>8;h[c+2|0]=b>>>16;h[c+3|0]=b>>>24;oj(m,a);Dh(k,m);pc(m);Fg(m,a);Dh(i,m);pc(m);n=d,o=Hh(a),j[n>>2]=o;n=e,o=Gh(a),j[n>>2]=o;Uf(m,a);ob(f,m);gb(m);Gg(m,a);Dh(g,m);pc(m);a=nj(a);break a}a=QC(b);pj(m,a);b=j[m>>2];h[c|0]=b;h[c+1|0]=b>>>8;h[c+2|0]=b>>>16;h[c+3|0]=b>>>24;oj(m,a);Dh(k,m);pc(m);Fg(m,a);Dh(i,m);pc(m);n=d,o=Hh(a),j[n>>2]=o;n=e,o=Gh(a),j[n>>2]=o;Uf(m,a);ob(f,m);gb(m);Gg(m,a);Dh(g,m);pc(m);a=nj(a)}j[l>>2]=a;Za=m+16|0}function lW(a){var b=0,c=0,d=0;b=Za+ -64|0;Za=b;d=Qc(a);j[114626]=0;c=E(2,b+16|0,7127)|0;a=j[114626];j[114626]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){j[114626]=0;F(219,b+32|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break f}j[114626]=0;j[b+12>>2]=12;j[b+8>>2]=0;j[b+4>>2]=0;V(239,b+48|0,b+32|0,b+12|0,b+8|0,b+4|0);a=j[114626];j[114626]=0;if((a|0)==1){break e}j[114626]=0;E(192,d|0,b+48|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break d}gb(b+48|0);qb(b+32|0);gb(c);Za=b- -64|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;break c}a=D()|0;C()|0;gb(b+48|0)}qb(b+32|0)}gb(c)}gb(d);G(a|0);z()}function ica(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=Za-16|0;Za=e;j[114626]=0;N(2008,a|0);d=j[114626];j[114626]=0;a:{b:{c:{if((d|0)==1){break c}j[114626]=0;N(2034,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break c}d=j[a+24>>2];b=Zb(e+8|0,b);j[114626]=0;f=j[b+4>>2];j[e>>2]=j[b>>2];j[e+4>>2]=f;Ua(2077,d|0,e|0,+c,1);d=j[114626];j[114626]=0;b=1;if((d|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37164,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}Za=e+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function _Ga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-704|0;Za=e;a:{b:{if(d>>>0<=511){d=0;if(!ZGa(b,e+24|0)){break b}GT(e+24|0,c);d=554;break b}f=j[b+8>>2];YGa(b,e+24|0);d=AT(e+24|0,c,j[a+480180>>2]);xc(b,f+d|0);if(!vh(b,13380)){break b}cd(e+8|0,b,hf(b));j[114626]=0;b=H(255,e+8|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}j[114626]=0;a=E(618,e+8|0,13385)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}if(a){j[114626]=0;a=H(387,e+8|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}h[c+34|0]=a>>>0>250?0:a}d=(b+d|0)+8|0;jb(e+8|0)}Za=e+704|0;return d|0}a=D()|0;C()|0;jb(e+8|0);G(a|0);z()}function Uu(a,b,c,d,e){var f=0,g=0;f=Za-16|0;Za=f;hc(f+8|0,b);j[114626]=0;b=H(2441,f+8|0)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;P(2455,b|0,62160,62192,c|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;b=H(2442,f+8|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}j[114626]=0;c=H(2456,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break a}j[d>>2]=c;j[114626]=0;c=H(2452,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[e>>2]=c;j[114626]=0;F(2453,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}wb(f+8|0);Za=f+16|0;return}a=D()|0;C()|0;wb(f+8|0);G(a|0);z()}function Lm(a){var b=0,c=0,d=0;b=(l[a+24>>1]<<2)+(l[j[a+4>>2]+28>>1]>>>(!k[a+77|0]<<1)|0)|0;j[a+40>>2]=((b&3)<<4)+18720;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;i[a+32>>1]=d;i[a+36>>1]=b?1:1<<c-12;i[a+34>>1]=-1<<d^-1;if(l[a+24>>1]==15){i[a+36>>1]=4095}b=(l[a+26>>1]<<2)+(l[j[a+4>>2]+28>>1]>>>(!k[a+77|0]<<1)|0)|0;j[a+52>>2]=((b&3)<<4)+18720;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;i[a+44>>1]=d;i[a+48>>1]=b?1:1<<c-12;i[a+46>>1]=-1<<d^-1;b=(l[a+30>>1]<<2)+(l[j[a+4>>2]+28>>1]>>>(!k[a+77|0]<<1)|0)|0;j[a+64>>2]=((b&3)<<4)+18720;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;i[a+56>>1]=d;i[a+60>>1]=b?1:1<<c-12;i[a+58>>1]=-1<<d^-1}function Fga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=q(0);c=Za-4112|0;Za=c;f=bb[j[j[a>>2]+112>>2]](a)|0;if(!f){bb[j[j[a>>2]+116>>2]](a)}j[c+12>>2]=0;Ega(a+44|0);if(b){g=c+2064|0;while(1){j[c+8>>2]=b;kc(c+8|0,512);Vo(c+16|0);bb[j[j[a>>2]+60>>2]](a,c+16|0,g,j[c+8>>2]);d=0;e=0;if(j[c+8>>2]){while(1){d=(c+16|0)+(e<<2)|0;n[c+4>>2]=r(n[d>>2]);h=c,i=n[pw(c+12|0,c+4|0)>>2],n[h+12>>2]=i;n[c+4>>2]=r(n[d+2048>>2]);h=c,i=n[pw(c+12|0,c+4|0)>>2],n[h+12>>2]=i;d=j[c+8>>2];e=e+1|0;if(d>>>0>e>>>0){continue}break}}b=b-d|0;if(b){continue}break}}if(!f){bb[j[j[a>>2]+120>>2]](a)}Za=c+4112|0;return q(n[c+12>>2])}function jz(a,b,c){var d=0,e=0,f=0,g=0,m=0,n=0;e=Za-16|0;Za=e;d=(c<<3)+a|0;f=k[d+356|0];h[b+12|0]=k[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Nf(b,kd(k[d+352|0],2,16));h[b+13|0]=k[d+354|0];h[b+14|0]=k[d+355|0];d=k[d+353|0];h[b+15|0]=d;h[b+16|0]=d;d=0;i[e+14>>1]=0;if(sb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;while(1){c=a+(d<<2)|0;g=c+160|0;i[e+12>>1]=k[g|0]|k[g+1|0]<<8;g=l[ui(e+14|0,e+12|0)>>1];i[e+14>>1]=g;m=xb(b,d),n=g,i[m>>1]=n;i[e+14>>1]=l[e+14>>1]+1;c=c+162|0;j[e+8>>2]=(k[c|0]|k[c+1|0]<<8)>>>f;j[e+4>>2]=64;c=j[Pd(e+8|0,e+4|0)>>2];m=xb(b,d),n=c,h[m+2|0]=n;d=d+1|0;if(sb(b)>>>0>d>>>0){continue}break}}Za=e+16|0}function Sza(a,b,c,d){var e=0,f=0,g=0,h=0;f=Za-16|0;Za=f;c=ei(c,b);j[f+12>>2]=c;a:{if((c|0)<1){break a}e=j[b+4>>2];if(e){g=32-e|0;j[f+8>>2]=g;c=j[Pd(f+8|0,f+12|0)>>2];j[f+12>>2]=j[f+12>>2]-c;e=j[d>>2];g=-1<<j[b+4>>2]&-1>>>g-c;j[e>>2]=j[e>>2]&(g^-1)|g&j[j[b>>2]>>2];c=c+j[d+4>>2]|0;j[d+4>>2]=c&31;j[d>>2]=e+(c>>>3&536870908);j[b>>2]=j[b>>2]+4;c=j[f+12>>2]}e=(c|0)/32|0;c=e<<2;Bi(j[d>>2],j[b>>2],c);e=j[f+12>>2]-(e<<5)|0;j[f+12>>2]=e;j[d>>2]=c+j[d>>2];if((e|0)<1){break a}g=b;b=c+j[b>>2]|0;j[g>>2]=b;c=j[d>>2];g=c;h=j[c>>2];c=-1>>>32-e|0;j[g>>2]=h&(c^-1)|c&j[b>>2];j[d+4>>2]=j[f+12>>2]}vd(a,d);Za=f+16|0}function Qq(a,b,c,d,e,f){var g=0,h=0,i=0,k=0;g=Za-240|0;Za=g;h=j[c>>2];j[g+232>>2]=h;c=j[c+4>>2];j[g>>2]=a;j[g+236>>2]=c;i=1;a:{b:{c:{d:{if(c?0:(h|0)==1){break d}h=a-j[(d<<2)+f>>2]|0;if((bb[b|0](h,a)|0)<1){break d}k=!e;while(1){e:{c=h;if(!(!k|(d|0)<2)){e=j[((d<<2)+f|0)-8>>2];h=a-4|0;if((bb[b|0](h,c)|0)>-1){break e}if((bb[b|0](h-e|0,c)|0)>-1){break e}}j[(i<<2)+g>>2]=c;a=rE(g+232|0);Rq(g+232|0,a);i=i+1|0;d=a+d|0;if(j[g+236>>2]?0:j[g+232>>2]==1){break b}e=0;k=1;a=c;h=c-j[(d<<2)+f>>2]|0;if((bb[b|0](h,j[g>>2])|0)>0){continue}break c}break}c=a;break b}c=a}if(e){break a}}qE(g,i);vv(c,b,d,f)}Za=g+240|0}function Yq(a,b,c){var d=0,e=0;d=a,e=Ph(q(q(q(q(q(q(q(q(q(n[c+3328>>2]+n[c+256>>2])*q(213))+q(q(n[c+3584>>2]-n[c>>2])*q(29)))+q(q(n[c+3072>>2]-n[c+512>>2])*q(459)))+q(q(n[c+2816>>2]+n[c+768>>2])*q(2037)))+q(q(n[c+2560>>2]-n[c+1024>>2])*q(5153)))+q(q(n[c+2304>>2]+n[c+1280>>2])*q(6574)))+q(q(n[c+2048>>2]-n[c+1536>>2])*q(37489)))+q(n[c+1792>>2]*q(75038)))),i[d>>1]=e;d=(b<<5)+a|0,e=Ph(q(q(q(q(q(q(q(q(n[c+3080>>2]*q(1567))+q(n[c+3592>>2]*q(104)))+q(n[c+2568>>2]*q(9727)))+q(n[c+2056>>2]*q(64019)))+q(n[c+1544>>2]*q(-9975)))+q(n[c+1032>>2]*q(-45)))+q(n[c+520>>2]*q(146)))+q(n[c+8>>2]*q(-5)))),i[d>>1]=e}function S$(a,b,c,d,e,f,g,i,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;k=k|0;l=l|0;var m=0,n=0,o=0;m=Za-16|0;Za=m;a:{if(a){a=VC(b);pj(m,a);b=j[m>>2];h[c|0]=b;h[c+1|0]=b>>>8;h[c+2|0]=b>>>16;h[c+3|0]=b>>>24;oj(m,a);ob(k,m);gb(m);Fg(m,a);ob(i,m);gb(m);n=d,o=Hh(a),h[n|0]=o;n=e,o=Gh(a),h[n|0]=o;Uf(m,a);ob(f,m);gb(m);Gg(m,a);ob(g,m);gb(m);a=nj(a);break a}a=UC(b);pj(m,a);b=j[m>>2];h[c|0]=b;h[c+1|0]=b>>>8;h[c+2|0]=b>>>16;h[c+3|0]=b>>>24;oj(m,a);ob(k,m);gb(m);Fg(m,a);ob(i,m);gb(m);n=d,o=Hh(a),h[n|0]=o;n=e,o=Gh(a),h[n|0]=o;Uf(m,a);ob(f,m);gb(m);Gg(m,a);ob(g,m);gb(m);a=nj(a)}j[l>>2]=a;Za=m+16|0}function Wu(a,b,c,d,e){var f=0,g=0;f=Za-16|0;Za=f;hc(f+8|0,b);j[114626]=0;b=H(21,f+8|0)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;P(2432,b|0,62160,62192,c|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;b=H(2408,f+8|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}j[114626]=0;c=H(2433,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break a}h[d|0]=c;j[114626]=0;c=H(2423,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}h[e|0]=c;j[114626]=0;F(2424,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}wb(f+8|0);Za=f+16|0;return}a=D()|0;C()|0;wb(f+8|0);G(a|0);z()}function ME(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(he(a)){Nb(a,31);return 0}f=a,g=he(a),h[f+1375|0]=g;d=Oh(a);b=Oh(a);Oh(a);f=a,g=Oh(a),j[f+1112>>2]=g;Oh(a);c=he(a);j[a+1116>>2]=c;if(!Fv(a,a+1120|0,c)){Nb(a,10);return 0}j[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=j[a+1116>>2];while(1){if((b|0)<1){break a}b=b-1|0;if(k[(b+a|0)+1120|0]==255){continue}break}j[a+1408>>2]=d;j[a+1404>>2]=b}if(k[a+1377|0]){e=j[a+1116>>2];b=27;b:{if((e|0)<1){break b}c=0;b=0;while(1){c=k[(a+b|0)+1120|0]+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}b=c+27|0}j[a- -64>>2]=d;j[a+60>>2]=j[a+56>>2]+(b+e|0)}j[a+1380>>2]=0;return 1}function Ut(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Za-16|0;Za=c;j[c+12>>2]=b;a:{b:{c:{if(b>>>0<=4294967279){f=sc(a);h=c,i=nb(a),j[h+8>>2]=i;b=j[Gc(c+12|0,c+8|0)>>2];j[c+12>>2]=b;d=Dk(b);j[c+12>>2]=d;if((d|0)==(f|0)){break a}if((d|0)==10){g=1;b=a;e=j[a>>2];break b}b=j[c+12>>2]+1|0;if(d>>>0>f>>>0){b=Sh(b);break c}j[114626]=0;b=E(30,a|0,b|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break c}a=J(0)|0;C()|0;O(a|0)|0;Q();break a}kg();z()}g=qe(a);e=zb(a)}lh(b,e,nb(a)+1|0);if(g){Yf(a,e,f+1|0)}d:{if((d|0)!=10){jg(a,j[c+12>>2]+1|0);ee(a,j[c+8>>2]);lf(a,b);break d}Ue(a,j[c+8>>2])}}Za=c+16|0}function nca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;j[114626]=0;N(2008,a|0);d=j[114626];j[114626]=0;a:{b:{c:{if((d|0)==1){break c}j[114626]=0;N(2034,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break c}d=j[a+24>>2];b=Zb(c+8|0,b);j[114626]=0;f=j[b+4>>2];j[c>>2]=j[b>>2];j[c+4>>2]=f;e=+ca(2072,d|0,c|0,1);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37014,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();e=0}Za=c+16|0;return+e}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function XX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Za-16|0;Za=c;j[c+12>>2]=b;a:{b:{c:{if(b>>>0<=1073741807){f=lq(a);h=c,i=nb(a),j[h+8>>2]=i;b=j[Gc(c+12|0,c+8|0)>>2];j[c+12>>2]=b;d=Ql(b);j[c+12>>2]=d;if((d|0)==(f|0)){break a}g=1;if((d|0)==1){b=a;e=j[a>>2];break b}b=j[c+12>>2]+1|0;if(d>>>0>f>>>0){b=Ak(b);break c}j[114626]=0;b=E(2832,a|0,b|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){break c}a=J(0)|0;C()|0;O(a|0)|0;Q();break a}kg();z()}g=qe(a);e=zb(a)}Jh(b,e,nb(a)+1|0);if(g){Kn(e,f+1|0)}d:{if((d|0)!=1){jg(a,j[c+12>>2]+1|0);ee(a,j[c+8>>2]);lf(a,b);break d}Ue(a,j[c+8>>2])}}Za=c+16|0}function fF(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-16|0;Za=d;a:{b:{c:{c=a+8|0;d:{if(!Pk(c)){if((b|0)<0|(fr(c)|0)<=(b|0)){break d}c=(k[Yo(j[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=Pk(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}a=R(8)|0;j[114626]=0;c=E(85,d|0,40673)|0;b=j[114626];j[114626]=0;e:{if((b|0)!=1){Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;gb(c);break e}b=D()|0;C()|0;S(a|0)}G(b|0);z()}b=b+1<<2;a=a+32|0;c=1;if(!j[(b+j[a>>2]|0)+900380>>2]){break b}c=(k[j[(b+j[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}Za=d+16|0;return c|0}z()}function rGa(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;L(414,d+8|0,2,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;E(378,b|0,d+24|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+24|0)}lc(d+40|0);G(a|0);z()}function pca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{c:{if((c|0)==1){break c}j[114626]=0;N(2034,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break c}c=j[a+24>>2];b=Zb(d+8|0,b);j[114626]=0;e=j[b+4>>2];j[d>>2]=j[b>>2];j[d+4>>2]=e;b=K(2070,c|0,d|0,1)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36952,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}Za=d+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function XLa(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;L(414,d+8|0,2,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;E(369,b|0,d+24|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+24|0)}lc(d+40|0);G(a|0);z()}function WLa(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;L(414,d+8|0,1,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;E(370,b|0,d+24|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+24|0)}lc(d+40|0);G(a|0);z()}function RIa(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;L(414,d+8|0,3,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;E(370,b|0,d+24|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+24|0)}lc(d+40|0);G(a|0);z()}function Lxa(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;L(414,d+8|0,2,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;E(370,b|0,d+24|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+24|0)}lc(d+40|0);G(a|0);z()}function xM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,i=0,k=0,l=0,m=0,n=0,o=0;f=Za-16|0;Za=f;j[f+8>>2]=e;j[f+12>>2]=d;a:{if(!d){break a}De(a);Ut(a,c);if(!c){break a}e=0;while(1){l=c-g|0;j[f+4>>2]=l;i=j[tb(f+12|0,f+4|0)>>2];Gn(a,lb(b)+g|0,i);ws(a,1,13);k=e+i|0;if(k>>>0>e>>>0){while(1){b:{c:{d:{m=h[Ol(a,e)|0];switch(m-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(m){break b}}n=Ol(a,e),o=32,h[n|0]=o}e=e+1|0;if((k|0)!=(e|0)){continue}break}}j[f+4>>2]=l-i;e=k+1|0;g=j[tb(f+8|0,f+4|0)>>2]+(i+g|0)|0;if(g>>>0<c>>>0){continue}break}}Za=f+16|0;return(d|0)!=0|0}function jca(a,b,c,d){var e=0,f=0,g=0;e=Za-16|0;Za=e;j[114626]=0;N(2008,a|0);f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;N(2034,b|0);f=j[114626];j[114626]=0;if((f|0)==1){break c}f=j[a+24>>2];b=Zb(e+8|0,b);j[114626]=0;g=j[b+4>>2];j[e>>2]=j[b>>2];j[e+4>>2]=g;ua(2076,f|0,e|0,c|0,d|0,1);c=j[114626];j[114626]=0;b=1;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37133,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}Za=e+16|0;return b}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function aJa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;md(b,0);j[b>>2]=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);c=a+4|0;j[b+12>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+8|0;j[b+16>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+12|0;c=k[c|0]|k[c+1|0]<<8;i[b+32>>1]=64;j[b+24>>2]=c;e=b;c=a+14|0;d=256;a:{if(!k[c|0]){break a}d=k[c|0]+1|0}i[e+30>>1]=d;i[b+34>>1]=l[b+34>>1]&32767|!k[c|0]<<15;a=a+15|0;if(!(!(h[a|0]&1)|m[b+16>>2]<=m[b+12>>2])){i[b+34>>1]=l[b+34>>1]|8}if(k[a|0]&2){i[b+34>>1]=l[b+34>>1]|1;j[b>>2]=j[b>>2]>>>1;j[b+12>>2]=j[b+12>>2]>>>1;j[b+16>>2]=j[b+16>>2]>>>1}}function WR(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;L(414,d+8|0,3,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;E(369,b|0,d+24|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+24|0)}lc(d+40|0);G(a|0);z()}function VR(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{b:{c:{if((f|0)==1){break c}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;L(414,d+8|0,3,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break c}j[114626]=0;E(378,b|0,d+24|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+24|0)}lc(d+40|0);G(a|0);z()}function Si(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,i=0,k=0,m=0;c=Za-32|0;Za=c;g=Jo(a);f=Ui(g);vra(a,f);a:{if(!b){break a}d=a+12|0;es(d);if(jd(d)>>>0>1023){break a}j[c+28>>2]=0;e=j[a+24>>2]+484344|0;k=c,m=Lb(e),j[k+24>>2]=m;k=c,m=Mb(e),j[k+16>>2]=m;if(rb(c+24|0,c+16|0)){while(1){j[c+12>>2]=j[j[c+24>>2]+12>>2];k=c,m=j[Gc(c+28|0,c+12|0)>>2],j[k+28>>2]=m;Hx(c+24|0);if(rb(c+24|0,c+16|0)){continue}break}e=j[c+28>>2]}else{e=0}hL(d,e)}if(f){d=0;while(1){e=Zc(a,d);i=Gx(a,l[ac(g,d)>>1]);b:{if(b){h[c+28|0]=0;gL(e,i,c+28|0);break b}qy(e,i,0)}d=d+1|0;if((f|0)!=(d|0)){continue}break}}Za=c+32|0}function Vma(a,b){var c=0,d=0;c=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=c;c=k[b+11|0]|k[b+12|0]<<8|(k[b+13|0]<<16|k[b+14|0]<<24);d=k[b+7|0]|k[b+8|0]<<8|(k[b+9|0]<<16|k[b+10|0]<<24);h[a+7|0]=d;h[a+8|0]=d>>>8;h[a+9|0]=d>>>16;h[a+10|0]=d>>>24;h[a+11|0]=c;h[a+12|0]=c>>>8;h[a+13|0]=c>>>16;h[a+14|0]=c>>>24;h[a+15|0]=k[b+15|0];c=j[b+44>>2];j[a+40>>2]=j[b+40>>2];j[a+44>>2]=c;c=j[b+36>>2];j[a+32>>2]=j[b+32>>2];j[a+36>>2]=c;c=j[b+28>>2];j[a+24>>2]=j[b+24>>2];j[a+28>>2]=c;c=j[b+20>>2];j[a+16>>2]=j[b+16>>2];j[a+20>>2]=c;ex(a+48|0,b+48|0);ex(a+68|0,b+68|0);ex(a+88|0,b+88|0);Vb(a+108|0,b+108|0,448)}function Cta(a,b){var c=0,d=0,e=0,f=0,g=0,i=0,m=0,n=0,o=0;f=Za+ -64|0;Za=f;d=be(a);n=d<<6;i=j[a+20>>2];g=i+p(j[a>>2],d)|0;while(1){if(d){m=p(d,e);o=p(e^-1,d);c=0;while(1){h[g+(c+m|0)|0]=k[g+(c-d|0)|0];h[(c+o|0)+i|0]=k[c+i|0];c=c+1|0;if((c|0)!=(d|0)){continue}break}}e=e+1|0;if((e|0)!=16){continue}break}g=g+(d<<4)|0;c=l[a+34>>1];if(c&2){m=j[a+8>>2];e=j[a+4>>2];mb(f+32|0,b+1074308|0,33);dM(f+40|0,g,p(d,e)+i|0,m-e|0,d,(c&4)>>>2|0,kb(f+32|0));c=l[a+34>>1]}if(c&8){e=j[a+16>>2];a=j[a+12>>2];mb(f+32|0,b+1074308|0,33);dM(f+8|0,g+n|0,p(a,d)+i|0,e-a|0,d,(c&16)>>>4|0,kb(f+32|0))}Za=f- -64|0}function $k(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;f=a+1074308|0;mb(e+8|0,f,84);a:{if(kb(e+8|0)){break a}b:{if(j[a+480208>>2]&16384){break b}if((d|0)!=8){mb(e+8|0,f,10);if(!kb(e+8|0)){break b}}j[b+88>>2]=j[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(j[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}j[b+88>>2]=j[b+88>>2]|256;c=128}j[b+692>>2]=c}i[b+796>>1]=0;j[b+88>>2]=j[b+88>>2]|2097152;mb(e+8|0,f,10);if(!kb(e+8|0)){break a}h[b+851|0]=0;i[b+790>>1]=0}Za=e+16|0}function Bg(a){var b=0,c=0,d=0,e=0;a:{YMa(+a);b=VMa(1)|0;VMa(0)|0;c=b;b=b&2147483647;b:{if(b>>>0>=1083174912){if(!((c|0)<0|b>>>0<1083179008)){return a*8.98846567431158e+307}if(b>>>0>=2146435072){return-1/a}if(a<=-1075^1){break a}d=0;if((c|0)<-1?1:(c|0)<=-1){break b}break a}if(b>>>0>1016070143){break a}d=a+1}return d}e=a+26388279066624;YMa(+e);VMa(1)|0;c=(VMa(0)|0)+128|0;b=c<<4&4080;d=o[b+72320>>3];a=a-(e+ -26388279066624)-o[(b|8)+72320>>3];return Bh(d+d*a*(a*(a*(a*(a*.0013333559164630223+.009618129842126066)+.0555041086648214)+.2402265069591)+.6931471805599453),(c&-256)/256|0)}function lX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,l=0,m=0,n=0,o=0,p=0;if(Rf(a,j[b+8>>2],f)){Bu(b,c,d,e);return}l=k[b+53|0];g=j[a+12>>2];h[b+53|0]=0;m=k[b+52|0];h[b+52|0]=0;n=a+16|0;zu(n,b,c,d,e,f);o=k[b+53|0];l=l|o;p=k[b+52|0];m=m|p;a:{if((g|0)<2){break a}n=n+(g<<3)|0;g=a+24|0;while(1){if(k[b+54|0]){break a}b:{if(p){if(j[b+24>>2]==1){break a}if(k[a+8|0]&2){break b}break a}if(!o){break b}if(!(h[a+8|0]&1)){break a}}i[b+52>>1]=0;zu(g,b,c,d,e,f);o=k[b+53|0];l=o|l;p=k[b+52|0];m=p|m;g=g+8|0;if(n>>>0>g>>>0){continue}break}}h[b+53|0]=(l&255)!=0;h[b+52|0]=(m&255)!=0}function fKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=Za-32|0;Za=e;j[e+24>>2]=b;b=j[a>>2];f=e,g=Lb(a),j[f>>2]=g;b=b+(vp(e+24|0,e)<<1)|0;a:{b:{if(m[a+4>>2]<m[hb(a)>>2]){d=j[a+4>>2];if((d|0)==(b|0)){VJa(a,c);break b}UJa(a,b,d,b+2|0);c=b>>>0<=c>>>0?m[a+4>>2]>c>>>0?c+2|0:c:c;h[b|0]=k[c|0];h[b+1|0]=k[c+1|0];break b}d=hb(a);d=zR(e,ej(a,bc(a)+1|0),b-j[a>>2]>>1,d);j[114626]=0;F(514,d|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}j[114626]=0;b=K(515,a|0,d|0,b|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}rt(d)}a=Qe(b);Za=e+32|0;return a|0}a=D()|0;C()|0;rt(d);G(a|0);z()}function oca(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{c:{if((c|0)==1){break c}j[114626]=0;N(2034,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break c}c=j[a+24>>2];b=Zb(d+8|0,b);j[114626]=0;e=j[b+4>>2];j[d>>2]=j[b>>2];j[d+4>>2]=e;b=IB(c,d,1);e=j[114626];j[114626]=0;c=ab;if((e|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36983,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0;c=0}Za=d+16|0;ab=c;return b}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function c6(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0;a:{if((b|0)>=5){l=b-4|0;while(1){if(ZE(a)){g=Lv(a,j[c>>2]);h=g+ao(a)|0;i=0;b:{c:{if(g){break c}f=4;n=e+4|0;while(1){if(((f<<1)+e|0)>=(l|0)){break b}g=0;k=a+f|0;d:{if(!bo(a,k)){break d}i=f-ao(a)|0;m=ao(k)+i|0;if((m+(f+n|0)|0)>(b|0)){break d}if(!bo(a,k+m|0)){break d}j[c>>2]=i;g=i;h=f}i=!g;if(f>>>0>2302){break c}f=f+1|0;if(!g){continue}break}}if((e+h|0)>(b|0)|i){break b}if(W5(a,b-e|0,g)){break a}}if(!((b|0)!=(h|0)|e)){e=0;h=b;break a}j[c>>2]=0}a=a+1|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}}h=0;e=b}j[d>>2]=h;return e}function mu(a,b,c,d){var e=0,f=0;e=Za-32|0;Za=e;j[e+28>>2]=d;a:{f=j[b>>2];b:{if(!(bb[j[j[f>>2]+40>>2]](f,c,d)|0)){zh(a);break b}tk(e+8|0,b);j[114626]=0;b=H(271,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[j[b>>2]+24>>2];j[114626]=0;b=H(d|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;j[e+4>>2]=b-c;b=E(33,e+28|0,e+4|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}b=j[b>>2];j[114626]=0;L(272,e+16|0,e+8|0,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}RA(a,e+16|0,0);jb(e+16|0);jb(e+8|0)}Za=e+32|0;return}a=D()|0;C()|0;jb(e+8|0);G(a|0);z()}function BFa(a,b){var c=0,d=0;c=(a|0)==(b|0);h[b+12|0]=c;a:{if(c){break a}while(1){if(k[j[b+8>>2]+12|0]){break a}d=Qg(j[b+8>>2]);c=j[b+8>>2];b:{c:{if(d){c=j[j[c+8>>2]+4>>2];if(!(!c|k[c+12|0])){c=c+12|0;b=j[b+8>>2];h[b+12|0]=1;b=j[b+8>>2];break c}if(!Qg(b)){b=j[b+8>>2];gp(b)}a=j[b+8>>2];h[a+12|0]=1;a=j[a+8>>2];h[a+12|0]=0;fp(a);return}c=j[j[c+8>>2]>>2];if(!c|k[c+12|0]){break b}c=c+12|0;b=j[b+8>>2];h[b+12|0]=1;b=j[b+8>>2]}h[b+12|0]=(a|0)==(b|0);h[c|0]=1;if((a|0)!=(b|0)){continue}break a}break}if(Qg(b)){b=j[b+8>>2];fp(b)}a=j[b+8>>2];h[a+12|0]=1;a=j[a+8>>2];h[a+12|0]=0;gp(a)}}function $D(a){var b=0,c=0;a:{b=j[a+4>>2];b:{if(!j[(j[j[b>>2]-12>>2]+b|0)+24>>2]){break b}b=j[a+4>>2];if(!mf(j[j[b>>2]-12>>2]+b|0)){break b}b=j[a+4>>2];if(!(j[(j[j[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(kE()){break b}b=j[a+4>>2];b=j[(j[j[b>>2]-12>>2]+b|0)+24>>2];j[114626]=0;b=H(2321,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=j[a+4>>2];b=j[j[a>>2]-12>>2];j[114626]=0;F(2322,a+b|0,1);a=j[114626];j[114626]=0;if((a|0)!=1){break b}}a=J(0)|0;C()|0;O(a|0)|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)==1){break a}}return}a=J(0)|0;C()|0;ib(a);z()}function W2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Za-32|0;Za=c;d=ce(b,-1);e=k[a+52|0];a:{if(d){d=b;if(e){break a}d=j[a+48>>2];f=a,g=ce(d,-1)^1,h[f+52|0]=g;break a}if(e){f=c,g=rm(j[a+48>>2]),h[f+19|0]=g;b:{c:{switch(yq(j[a+36>>2],j[a+40>>2],c+19|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)-1|0){case 2:d=j[a+48>>2];j[c+20>>2]=c+25;h[c+24|0]=d;default:while(1){d=j[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break b}d=d-1|0;j[c+20>>2]=d;if((Dq(h[d|0],j[a+32>>2])|0)!=-1){continue}break}break;case 0:case 1:break c}}d=-1;e=0}if(!e){break a}}h[a+52|0]=1;j[a+48>>2]=b;d=b}Za=c+32|0;return d|0}function EA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=Za-16|0;Za=e;c=j[b+16>>2];j[a+4>>2]=0;j[a>>2]=c;d=b+80|0;g=a;c=j[b+84>>2];f=j[d>>2];a:{if(c>>>0<=15){break a}j[e+12>>2]=c-16;f=j[Gc(d,e+12|0)>>2]}j[g+8>>2]=f;b:{if(!(k[b+88|0]&2)|!k[b+816|0]){break b}c:{d:{e:{if(!((j[b+88>>2]&2050)==2?(k[j[b+104>>2]+34|0]&8)>>>3|0:0)){c=j[b+104>>2];break e}c=j[b+104>>2];if(j[b+80>>2]!=j[c+12>>2]){break e}d=j[b+84>>2];if((d|0)==j[c+16>>2]){break d}}b=j[b+84>>2];if((b|0)!=j[c+8>>2]){break b}b=(j[c>>2]-b|0)+48|0;break c}b=(j[c>>2]-d|0)+112|0}h=a,i=j[a>>2]+p(xn(c),b)|0,j[h+4>>2]=i}Za=e+16|0}function A8(a){var b=0,c=0,d=0,e=0;c=Za-160|0;Za=c;a=mm(c+16|0,a,8);d=j[j[a>>2]-12>>2];j[114626]=0;b=T(122)|0;e=j[114626];j[114626]=0;a:{if((e|0)==1){break a}j[114626]=0;I(123,c+8|0,d+(c+16|0)|0,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}wb(c+8|0);j[114626]=0;d=E(180,a|0,144)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;d=E(181,d|0,c+4|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[j[d>>2]-12>>2];j[114626]=0;d=H(174,b+d|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[c+4>>2];Xe(a);Za=c+160|0;return d?0:b}c=D()|0;C()|0;Xe(a);G(c|0);z()}function To(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,m=0,n=0;f=Za-16|0;Za=f;g=sb(a)-1|0;a:{if((sb(a)|0)==1){break a}while(1){if(l[jc(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<sb(a)-1>>>0){continue}break}}h=l[jc(a,g)>>1];j[f+12>>2]=0;b:{if((b|0)>=(h|0)){m=f,n=(k[jc(a,g)+2|0]<<16)/(d|0)|0,j[m+12>>2]=n;break b}e=0;if(g){e=g-1|0;i=(k[jc(a,e)+2|0]<<16)/(d|0)|0;j[f+12>>2]=i;e=l[jc(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}m=f,n=((p(((k[jc(a,g)+2|0]<<16)/(d|0)|0)-i|0,b-e|0)|0)/(h-e|0)|0)+i|0,j[m+12>>2]=n}Md(f+12|0,0,65536);Za=f+16|0;return(p(j[f+12>>2],c)+32768|0)/65536|0}function Hv(a,b,c){var d=0,e=0,f=0,g=q(0),h=q(0),i=q(0),j=q(0),k=q(0),l=q(0),m=q(0),o=0;d=Za-32|0;Za=d;UE(q(-n[a>>2]),q(n[a+12>>2]+n[a+24>>2]),q(n[a+36>>2]+n[a+48>>2]),d+20|0);UE(n[a+60>>2],q(n[a+48>>2]-n[a+36>>2]),q(n[a+24>>2]-n[a+12>>2]),d+8|0);n[d+12>>2]=-n[d+12>>2];a=0;while(1){e=a<<2;f=e+c|0;h=n[f>>2];o=f;f=e+49008|0;g=n[f>>2];i=n[e+(d+20|0)>>2];j=n[e+(d+8|0)>>2];k=n[f+12>>2];n[o>>2]=q(g*i)-q(j*k);f=b+e|0;l=n[(0-a<<2)+49016>>2];e=5-a<<2;m=n[e+49008>>2];g=q(q(g*j)+q(k*i));n[f>>2]=q(h*l)-q(m*g);n[b+e>>2]=q(m*h)+q(g*l);a=a+1|0;if((a|0)!=3){continue}break}Za=d+32|0}function mya(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Za-144|0;Za=c;fy(a);a:{b:{if(!jf(a,64)){break b}c:{d:{e:{if(!Xj(a,60)){break e}if(!dN(a,17212)){break e}b=15;break d}fy(a);if(!jf(a,128)){break b}b=0;f=1;if(!Xj(a,124)){break d}d=31;if(dN(a,17217)){break c}}d=b;if(f){break a}}fy(a);b=0;while(1){if(hya(a)>>>0>131072){break a}b=b+1|0;if((b&65535)>>>0<d>>>0){continue}break}Fc(a,4);if(!jf(a,2)){break b}if(gya(a)>>>0<178){break a}e=-1;b=p(d,30);if(!jf(a,b)){break a}Fc(a,b);b=a;a=c+8|0;b=eya(b,a);if(!b){oO(a)}if(!b){break a}e=cN(c+8|0);break a}e=-1}Za=c+144|0;return e|0}function f9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Za-32|0;Za=c;f=Mg(a);a:{b:{c:{d:{e:{e=b+24|0;if(l[j[e>>2]+480188>>1]){a=0;while(1){d=j[e>>2];j[114626]=0;F(2184,c|0,(d+(a<<5)|0)+480289|0);d=j[114626];j[114626]=0;if((d|0)==1){break e}j[114626]=0;I(2177,c+16|0,b|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break d}j[114626]=0;F(1527,f|0,c+16|0);d=j[114626];j[114626]=0;if((d|0)==1){break c}gb(c+16|0);gb(c);a=a+1|0;if(a>>>0<l[j[e>>2]+480188>>1]){continue}break}}Za=c+32|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;gb(c+16|0)}gb(c)}Uc(f);G(a|0);z()}function O2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,i=0,l=0;c=Za-32|0;Za=c;a:{b:{c:{if(ce(b,-1)){break c}i=c,l=rm(b),h[i+23|0]=l;if(k[a+44|0]){if((Ai(c+23|0,1,1,j[a+32>>2])|0)!=1){break b}break c}j[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+23|0;while(1){e=yq(j[a+36>>2],j[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(j[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Ai(d,1,1,j[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=j[c+16>>2]-(c+24|0)|0;if((Ai(c+24|0,1,d,j[a+32>>2])|0)!=(d|0)){break b}d=j[c+12>>2];if((e|0)==1){continue}break}}a=jr(b);break a}a=-1}Za=c+32|0;return a|0}function ij(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{c=j[a+28>>2];if((c|0)>=(b|0)){e=j[a+24>>2];break a}i=a+32|0;f=j[a+20>>2];d=j[a+16>>2];g=c;while(1){b:{if(d>>>0>=f>>>0){f=_p(a,i,1024);j[a+16>>2]=0;j[a+20>>2]=f;if(!f){break b}d=0;g=j[a+28>>2]}h=d+1|0;j[a+16>>2]=h;d=k[(a+d|0)+32|0];c=g+8|0;j[a+28>>2]=c;e=j[a+24>>2]|d<<g;j[a+24>>2]=e;d=h;g=c;if((c|0)<(b|0)){continue}break a}break}a=R(8)|0;j[114626]=0;H(264,a|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){b=D()|0;C()|0;S(a|0);G(b|0);z()}Y(a|0,77072,265);z()}j[a+28>>2]=c-b;j[a+24>>2]=e>>>b;return(-1<<b^-1)&e}function e5(a,b,c,d,e,f){var g=0,h=0,m=0,o=0,r=0,s=0,t=q(0);h=1;b=k[(k[(j[b+4>>2]+p(c,3)|0)+2|0]+b|0)+9|0];if(!l[((b<<1)+a|0)+132>>1]){Nb(a,21);return}m=d>>1;g=j[a+260>>2]+p(b,1596)|0;b=p(k[g+1588|0],i[f>>1]);a=0;o=j[g+1592>>2];if((o|0)>=2){r=g+1592|0;s=g+1588|0;while(1){d=k[(g+h|0)+838|0]<<1;c=i[d+f>>1];if((c|0)>=0){c=p(k[s|0],c&65535);d=l[(d+g|0)+338>>1];if((d|0)!=(a|0)){$4(e,a,b,d,c,m);o=j[r>>2];a=d}b=c}h=h+1|0;if((o|0)>(h|0)){continue}break}}if((a|0)<(m|0)){t=n[(b<<2)+50880>>2];while(1){b=(a<<2)+e|0;n[b>>2]=n[b>>2]*t;a=a+1|0;if((m|0)!=(a|0)){continue}break}}}function BHa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,l=0,n=0,o=0;e=Za-32|0;Za=e;j[e+28>>2]=d;a:{b:{if(k[a+24|0]){if(!d){break a}i=a+40|0;break b}l=bb[j[j[a>>2]+44>>2]](a,b,c,d)|0;break a}while(1){f=KIa(a,c);g=c-j[oi(i,f)>>2]|0;j[e+8>>2]=4096-g;n=e,o=j[tb(e+8|0,e+28|0)>>2],j[n+24>>2]=o;d=e;if(m[oi(i,f)+4>>2]>g>>>0){h=j[oi(i,f)+4>>2]-g|0}else{h=0}j[d+20>>2]=h;d=j[tb(e+24|0,e+20|0)>>2];uz(e+8|0,a,f);h=j[e+8>>2];uz(e,a,f);Pe(g+h|0,d+(j[e>>2]+g|0)|0,b);f=j[e+28>>2]-d|0;j[e+28>>2]=f;l=d+l|0;if(d>>>0<m[e+24>>2]){break a}c=c+d|0;b=b+d|0;if(f){continue}break}}Za=e+32|0;return l}function kza(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-32|0;Za=d;md(b,0);xN(d,a+1|0);qc(d+16|0,d);j[114626]=0;E(370,b+43|0,d+16|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){gb(d+16|0);c=a+78|0;j[b+24>>2]=k[c|0]|k[c+1|0]<<8;c=a+58|0;j[b>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+62|0;j[b+4>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+66|0;j[b+8>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);i[b+30>>1]=(k[a+73|0]<<1)+2;i[b+34>>1]=l[b+34>>1]&65533|k[a|0]>>>6&2;kc(b+8|0,j[b>>2]);kc(b+4|0,j[b+8>>2]);Za=d+32|0;return}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function e3(a){a=a|0;var b=0;b=j[14222];d3(b);c3();b3(b);a3();b=j[14223];RD(461412,b,461460);jv(460776,461412);QD(461468,b,461516);iv(460860,461468);b=j[13922];RD(461524,b,461572);jv(460944,461524);jv(461112,j[(j[j[115236]-12>>2]+460944|0)+24>>2]);QD(461580,b,461628);iv(461028,461580);iv(461196,j[(j[j[115257]-12>>2]+461028|0)+24>>2]);Aq(j[j[115150]-12>>2]+460600|0,460776);Aq(j[j[115172]-12>>2]+460688|0,460860);PD(j[j[115236]-12>>2]+460944|0);PD(j[j[115257]-12>>2]+461028|0);Aq(j[j[115236]-12>>2]+460944|0,460776);Aq(j[j[115257]-12>>2]+461028|0,460860);return a|0}function KIa(a,b){var c=0,d=0,e=0,f=0,g=0,i=0,l=0;d=Za-16|0;Za=d;f=a+40|0;c=a+232|0;g=b-(b&4095)|0;a:{while(1){b:{b=j[Be(c,e)>>2];if(!k[oi(f,b)+8|0]){break b}if(j[oi(f,b)>>2]!=(g|0)){break b}i=d,l=j[Be(c,e)>>2],j[i+8>>2]=l;a=e<<2;ht(c,a+c|0,(a+c|0)+4|0);a=j[d+8>>2];i=Be(c,0),l=a,j[i>>2]=l;break a}e=e+1|0;if((e|0)!=16){continue}break}i=d,l=j[Be(c,15)>>2],j[i+8>>2]=l;ht(c,c+60|0,c- -64|0);b=j[d+8>>2];i=Be(c,0),l=b,j[i>>2]=l;b=j[Be(c,0)>>2];c=oi(f,b);j[c>>2]=g;uz(d+8|0,a,b);i=c,l=bb[j[j[a>>2]+44>>2]](a,j[d+8>>2],g,4096)|0,j[i+4>>2]=l;h[c+8|0]=1}Za=d+16|0;return b}function R2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Za-32|0;Za=c;d=ce(b,-1);e=k[a+52|0];a:{if(d){d=b;if(e){break a}d=j[a+48>>2];f=a,g=ce(d,-1)^1,h[f+52|0]=g;break a}if(e){j[c+16>>2]=j[a+48>>2];b:{c:{switch(yq(j[a+36>>2],j[a+40>>2],c+16|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)-1|0){case 2:d=j[a+48>>2];j[c+20>>2]=c+25;h[c+24|0]=d;default:while(1){d=j[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break b}d=d-1|0;j[c+20>>2]=d;if((Dq(h[d|0],j[a+32>>2])|0)!=-1){continue}break}break;case 0:case 1:break c}}d=-1;e=0}if(!e){break a}}h[a+52|0]=1;j[a+48>>2]=b;d=b}Za=c+32|0;return d|0}function Eva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0;b=Za-16|0;Za=b;h=j[a+24>>2];k=j[a+20>>2];l=j[a+16>>2];g=j[a+4>>2];e=g;f=j[a>>2];j[b+8>>2]=f;j[b+12>>2]=e;g=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=g;if(d){while(1){e=(e<<1)+l|0;f=(f>>>21&2040)+27888|0;e=(((p(i[e>>1],i[f+2>>1])+p(i[e-2>>1],i[f>>1])|0)+p(i[e+2>>1],i[f+4>>1])|0)+p(i[e+4>>1],i[f+6>>1])|0)/16384|0;j[c>>2]=j[c>>2]+p(e,k);j[c+4>>2]=j[c+4>>2]+p(e,h);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=j[b+8>>2];e=j[b+12>>2];continue}break}f=j[b+8>>2];e=j[b+12>>2]}j[a>>2]=f;j[a+4>>2]=e;Za=b+16|0}function ysa(a,b,c){var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;while(1){xsa((p(e,44)+a|0)+16|0,d+14|0,d+12|0);f=i[d+12>>1]+f|0;g=i[d+14>>1]+g|0;e=e+1|0;if((e|0)!=18){continue}break}e=b;b=(g|0)<32767?g:32767;i[e>>1]=(b|0)>-32768?b:-32768;b=(f|0)<32767?f:32767;i[c>>1]=(b|0)>-32768?b:-32768;i[a+3832>>1]=l[a+3832>>1]+1;b=(l[a+3834>>1]+1>>>0)%13440|0;i[a+3834>>1]=b;b=((b>>>0<6720?b:13440-b|0)|0)/256|0;i[a+3836>>1]=b;if(!k[a+3843|0]){i[a+3836>>1]=(b&65532)>>>2}b=l[a+3838>>1]+1|0;i[a+3838>>1]=b;if((b&65535)>>>0>=1024){i[a+3838>>1]=0;i[a+3840>>1]=l[a+3840>>1]+1&7}Za=d+16|0}function Gwa(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;j[e+12>>2]=c;d=j[b+4>>2];a:{if(d){j[e+8>>2]=32-d;c=j[tb(e+8|0,e+12|0)>>2];d=j[b>>2];f=-1<<j[b+4>>2]&-1>>>j[e+8>>2]-c&(j[d>>2]^-1);if(f){Cc(a,d,NMa(f));break a}f=j[e+12>>2];if((f|0)==(c|0)){$x(a,b,c);break a}c=f-c|0;j[e+12>>2]=c;j[b>>2]=d+4}if(c>>>0>=32){d=j[b>>2];while(1){f=j[d>>2];if((f|0)!=-1){Cc(a,d,NMa(f^-1));break a}d=d+4|0;j[b>>2]=d;c=c-32|0;j[e+12>>2]=c;if(c>>>0>31){continue}break}}b:{if(!c){d=j[b>>2];break b}d=j[b>>2];b=(j[d>>2]^-1)&-1>>>32-c;if(!b){break b}Cc(a,d,NMa(b));break a}Cc(a,d,c)}Za=e+16|0}function fwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0;b=Za-16|0;Za=b;g=j[a+40>>2];h=j[a+36>>2];m=j[a+16>>2];e=j[a+4>>2];f=e;k=j[a>>2];j[b+8>>2]=k;j[b+12>>2]=e;e=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=e;a:{if(!d){e=g>>12;l=h>>12;break a}while(1){e=j[a+32>>2];f=i[(f<<1)+m>>1];h=j[a+28>>2]+h|0;l=h>>12;j[c>>2]=j[c>>2]+p(f,l);g=e+g|0;e=g>>12;j[c+4>>2]=j[c+4>>2]+p(f,e);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=j[b+12>>2];continue}break}k=j[b+8>>2];f=j[b+12>>2]}j[a+40>>2]=g;j[a+20>>2]=l;j[a+36>>2]=h;j[a+24>>2]=e;j[a>>2]=k;j[a+4>>2]=f;Za=b+16|0}function Ih(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;f=Za-16|0;Za=f;YMa(+b);h=VMa(1)|0;e=VMa(0)|0;g=h&2147483647;c=g;d=e;g=c+ -1048576|0;a:{if((g|0)==2145386495|g>>>0<2145386495){i=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){i=e<<28;c=h;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e|2147418112;break a}if(!(c|d)){c=0;d=0;break a}g=c;c=c>>>0<1?s(e)+32|0:s(c);We(f,d,g,0,0,c+49|0);k=j[f>>2];i=j[f+4>>2];e=15372-c<<16;c=j[f+8>>2];d=e|j[f+12>>2]^65536}j[a>>2]=k;j[a+4>>2]=i;j[a+8>>2]=c;j[a+12>>2]=h&-2147483648|d;Za=f+16|0}function ora(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;j[e+12>>2]=c;d=j[b+4>>2];a:{if(d){j[e+8>>2]=32-d;c=j[tb(e+8|0,e+12|0)>>2];f=-1<<d&-1>>>j[e+8>>2]-c;d=j[b>>2];f=f&(j[d>>2]^-1);if(f){Cc(a,d,NMa(f));break a}f=j[e+12>>2];if((f|0)==(c|0)){YK(a,b,c);break a}c=f-c|0;j[e+12>>2]=c;j[b>>2]=d+4}if(c>>>0>=32){d=j[b>>2];while(1){f=j[d>>2];if((f|0)!=-1){Cc(a,d,NMa(f^-1));break a}d=d+4|0;j[b>>2]=d;c=c-32|0;j[e+12>>2]=c;if(c>>>0>31){continue}break}}b:{if(!c){d=j[b>>2];break b}d=j[b>>2];b=(j[d>>2]^-1)&-1>>>32-c;if(!b){break b}Cc(a,d,NMa(b));break a}Cc(a,d,c)}Za=e+16|0}function kya(a,b,c){var d=0,e=0,f=0,g=0,m=0;d=Za-16|0;Za=d;md(b,1);j[b>>2]=c;h[b+37|0]=k[a+24|0]<<4;h[d+15|0]=k[a+25|0];h[d+14|0]=64;g=b,m=k[Yb(d+15|0,d+14|0)|0]<<2,i[g+30>>1]=m;c=a+26|0;c=k[c|0]|k[c+1|0]<<8;a=a+28|0;e=j[b>>2];a:{if(!e){break a}f=k[a|0]|k[a+1|0]<<8;a=(c<<8&16711680|c<<24)>>>16|0;j[b+4>>2]=a;c=((f<<8&16711680|f<<24)>>>15|0)+a|0;j[b+8>>2]=c;if(a>>>0>=e>>>0){a=e-1|0;j[b+4>>2]=a}if(c>>>0>e>>>0){j[b+8>>2]=e;c=e}if(!(c-a>>>0>3?!(c>>>0<4|a>>>0>c>>>0):0)){j[b+4>>2]=0;j[b+8>>2]=0;break a}if(a>>>0>=c>>>0){break a}i[b+34>>1]=l[b+34>>1]|2}Za=d+16|0}function fna(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;n[c+8>>2]=2;i[c+14>>1]=12;j[c+4>>2]=15;d=ue(64);j[114626]=0;e=H(1420,d|0)|0;f=j[114626];j[114626]=0;a:{b:{if((f|0)!=1){d=gx(c,e);e=j[d>>2];j[114626]=0;F(1421,e|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}b=j[d>>2];j[114626]=0;b=K(1422,b|0,c+14|0,c+8|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break b}c:{if(!b){fx(a);break c}b=j[d>>2];j[114626]=0;F(1423,b|0,c+4|0);b=j[114626];j[114626]=0;if((b|0)==1){break b}hp(a,d)}Jf(d);Za=c+16|0;return}a=D()|0;C()|0;Cb(d);break a}a=D()|0;C()|0;Jf(d)}G(a|0);z()}function gwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0,m=0;b=Za-16|0;Za=b;g=j[a+40>>2];i=j[a+36>>2];m=j[a+16>>2];e=j[a+4>>2];f=e;k=j[a>>2];j[b+8>>2]=k;j[b+12>>2]=e;e=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=e;a:{if(!d){e=g>>12;l=i>>12;break a}while(1){e=j[a+32>>2];f=h[f+m|0]<<8;i=j[a+28>>2]+i|0;l=i>>12;j[c>>2]=j[c>>2]+p(f,l);g=e+g|0;e=g>>12;j[c+4>>2]=j[c+4>>2]+p(f,e);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=j[b+12>>2];continue}break}k=j[b+8>>2];f=j[b+12>>2]}j[a+40>>2]=g;j[a+20>>2]=l;j[a+36>>2]=i;j[a+24>>2]=e;j[a>>2]=k;j[a+4>>2]=f;Za=b+16|0}function Lda(a,b,c,d,e,f,g,h,i,k){var l=0,m=0,n=0,o=0;m=Za-32|0;Za=m;o=j[c>>2];n=j[c+8>>2];l=m;c=j[c+4>>2];j[l+8>>2]=c;j[l+12>>2]=n;j[114626]=0;j[l+24>>2]=c;j[l+28>>2]=n;j[l+20>>2]=o;j[l+16>>2]=d;c=j[l+20>>2];j[l>>2]=j[l+16>>2];j[l+4>>2]=c;d=wa(2e3,a|0,b|0,l|0)|0;a=j[114626];j[114626]=0;a:{if((a|0)==1){a=J(0)|0;C()|0;O(a|0)|0;j[114626]=0;Z(1993,34684,e|0,f|0,g|0,h|0,i|0,k|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=-255}Za=m+32|0;return d}b=D()|0;C()|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)!=1){G(b|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Fva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0;b=Za-16|0;Za=b;k=j[a+24>>2];l=j[a+20>>2];m=j[a+16>>2];g=j[a+4>>2];e=g;f=j[a>>2];j[b+8>>2]=f;j[b+12>>2]=e;g=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=g;if(d){while(1){e=e+m|0;f=(f>>>21&2040)+27888|0;e=(((p(h[e|0],i[f+2>>1])+p(h[e-1|0],i[f>>1])|0)+p(h[e+1|0],i[f+4>>1])|0)+p(h[e+2|0],i[f+6>>1])<<8)/16384|0;j[c>>2]=j[c>>2]+p(e,l);j[c+4>>2]=j[c+4>>2]+p(e,k);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=j[b+8>>2];e=j[b+12>>2];continue}break}f=j[b+8>>2];e=j[b+12>>2]}j[a>>2]=f;j[a+4>>2]=e;Za=b+16|0}function oma(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,m=0,n=0;d=Za-16|0;Za=d;a:{if(!Yw(a,b,0)){break a}e=j[b+656>>2];h=a+1074308|0;mb(d+8|0,h,31);b:{if(kb(d+8|0)){a=j[b+728>>2];if(a){break b}break a}a=j[b+728>>2]}mb(d+8|0,h,31);f=e+48|0;i=a-kb(d+8|0)|0;a=To(f,i,256,64);g=k[e+65|0];c:{if((g|0)==255){break c}b=j[b+732>>2];if((b|0)==-1){break c}g=k[xb(f,g)+2|0];f=l[xb(f,k[e+65|0])>>1];mb(d+8|0,h,94);e=g<<2;a=(f|0)==(i|0)?e:a;if(kb(d+8|0)){a=b+(a-e<<1)|0;break c}if(!g){a=0;break c}a=(p(a,b)|0)/(e|0)|0}m=c,n=(p(j[c>>2],Gb(a,0,512))|0)/256|0,j[m>>2]=n}Za=d+16|0}function gJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,i=0;c=Za-16|0;Za=c;a:{if(k[b+813|0]!=27){a=h[b+851|0];break a}e=a+1074308|0;mb(c+8|0,e,21);d=kb(c+8|0);f=a;a=k[b+841|0];a=Zw(f,k[b+848|0],d?a:a+16>>>2|0);mb(c+8|0,e,45);b:{if(!(!kb(c+8|0)|k[b+848|0]!=3)){f=b;d=k[b+841|0];c:{if(!(!d|d>>>0>=k[b+849|0])){a=k[b+852|0];d=d+1|0;break c}h[b+852|0]=a;d=1}h[f+841|0]=d;a=a<<24>>24;break b}h[b+841|0]=k[b+841|0]+k[b+849|0]}mb(c+8|0,e,47);if(!kb(c+8|0)){break a}h[b+851|0]=a}if(a){g=b,i=Gb(j[b+684>>2]+((p(k[b+850|0],a)+2|0)/8|0)|0,0,256),j[g+684>>2]=i}Za=c+16|0}function dZ(){var a=0;a:{if(h[462752]&1){break a}if(!fd(462752)){break a}a=462464;while(1){a=Db(a)+12|0;if((a|0)!=462752){continue}break}ed(462752)}vc(462464,67596);vc(462476,67604);vc(462488,67613);vc(462500,67619);vc(462512,67625);vc(462524,67629);vc(462536,67634);vc(462548,67639);vc(462560,67646);vc(462572,67656);vc(462584,67664);vc(462596,67673);vc(462608,67682);vc(462620,67686);vc(462632,67690);vc(462644,67694);vc(462656,67625);vc(462668,67698);vc(462680,67702);vc(462692,67706);vc(462704,67710);vc(462716,67714);vc(462728,67718);vc(462740,67722)}function aZ(){var a=0;a:{if(h[463056]&1){break a}if(!fd(463056)){break a}a=462768;while(1){a=Me(a)+12|0;if((a|0)!=463056){continue}break}ed(463056)}Kc(462768,67728);Kc(462780,67760);Kc(462792,67796);Kc(462804,67820);Kc(462816,67844);Kc(462828,67860);Kc(462840,67880);Kc(462852,67900);Kc(462864,67928);Kc(462876,67968);Kc(462888,68e3);Kc(462900,68036);Kc(462912,68072);Kc(462924,68088);Kc(462936,68104);Kc(462948,68120);Kc(462960,67844);Kc(462972,68136);Kc(462984,68152);Kc(462996,68168);Kc(463008,68184);Kc(463020,68200);Kc(463032,68216);Kc(463044,68232)}function Oxa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{b:{if(!ke(a)){break b}f=j[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break b}Om(b);by(b,a);j[b+20>>2]=0;j[b>>2]=d;if(!Qo(b)){break b}if(j[a>>2]!=(d|0)){Ab(b+68|0,0,36)}f=j[b+20>>2];j[114626]=0;f=H(466,f|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break a}a=j[a+20>>2];j[114626]=0;a=H(466,a|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break a}Vb(f,a+c|0,d);a=l[b+34>>1];if(e){j[b+8>>2]=d;j[b+4>>2]=0;i[b+34>>1]=a|2;return}j[b+4>>2]=0;j[b+8>>2]=0;i[b+34>>1]=a&65533}return}a=J(0)|0;C()|0;ib(a);z()}function L2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Za-32|0;Za=c;a:{b:{c:{if(ce(b,-1)){break c}j[c+20>>2]=b;if(k[a+44|0]){if((Ai(c+20|0,4,1,j[a+32>>2])|0)!=1){break b}break c}j[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+20|0;while(1){e=yq(j[a+36>>2],j[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(j[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Ai(d,1,1,j[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=j[c+16>>2]-(c+24|0)|0;if((Ai(c+24|0,1,d,j[a+32>>2])|0)!=(d|0)){break b}d=j[c+12>>2];if((e|0)==1){continue}break}}a=jr(b);break a}a=-1}Za=c+32|0;return a|0}function t4(){var a=0,b=0,c=0,d=0;a=Za-48|0;Za=a;j[114626]=0;b=E(2300,0,a+32|0)|0;c=j[114626];j[114626]=0;a:{b:{c:{if((c|0)==1){break c}if(b){j[114626]=0;a=j[114626];j[114626]=0;if((a|0)==1){break c}a=j[114600];j[114626]=0;F(2302,a|0,55692);a=j[114626];j[114626]=0;if((a|0)!=1){break b}break c}b=Nq(a+16|0,a+32|0);j[a+4>>2]=j[a+36>>2]/1e3;c=Nq(a+8|0,a+4|0);j[114626]=0;b=HB(2303,b,c);c=ab;d=j[114626];j[114626]=0;if((d|0)!=1){break a}}a=J(0)|0;C()|0;ib(a)}z()}j[a+24>>2]=b;j[a+28>>2]=c;b=Sj(a+40|0,a+24|0);c=j[b+4>>2];b=j[b>>2];Za=a+48|0;ab=c;return b}function TN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-80|0;Za=e;a:{if(j[b+4>>2]==j[d+4>>2]){f=j[b+4>>2];j[e+72>>2]=j[b>>2];j[e+76>>2]=f;b=j[c+4>>2];j[e+64>>2]=j[c>>2];j[e+68>>2]=b;b=vd(e+56|0,d);c=j[e+76>>2];j[e+8>>2]=j[e+72>>2];j[e+12>>2]=c;c=j[e+68>>2];j[e>>2]=j[e+64>>2];j[e+4>>2]=c;Wza(a,e+8|0,e,b);break a}f=j[b+4>>2];j[e+48>>2]=j[b>>2];j[e+52>>2]=f;b=j[c+4>>2];j[e+40>>2]=j[c>>2];j[e+44>>2]=b;b=vd(e+32|0,d);c=j[e+52>>2];j[e+24>>2]=j[e+48>>2];j[e+28>>2]=c;c=j[e+44>>2];j[e+16>>2]=j[e+40>>2];j[e+20>>2]=c;Vza(a,e+24|0,e+16|0,b)}Za=e+80|0}function v2(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;j[c+12>>2]=0;rD(a,c+12|0,1);d=j[c+12>>2];e=d>>>2&3;h[c+11|0]=e;if(e){h[c+4|0]=3;d=k[Yb(c+4|0,c+11|0)|0];h[c+4|0]=0;h[c|0]=0;h[c+10|0]=0;a:{if(!d){break a}dh(a,c+4|0);if((d|0)==1){break a}dh(a,c);if(d>>>0<3){break a}dh(a,c+10|0);f=k[c+10|0]<<24}d=k[c+12|0]|k[c+4|0]<<8|k[c|0]<<16|f;j[c+12>>2]=d}j[c+4>>2]=d>>>4;j[c>>2]=1e6;qm(b,j[tb(c+4|0,c)>>2]);if(nb(b)){d=0;while(1){Aj(a,Ub(b,d),1);d=d+1|0;if(nb(b)>>>0>d>>>0){continue}break}}b=(j[c+12>>2]>>>4|0)-nb(b)|0;j[c+12>>2]=b;if(b){Hk(a,b,-1)}Za=c+16|0}function qqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,l=0,m=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d+8>>2]=j[a>>2]<<1;e=j[tb(d+8|0,d+12|0)>>2];j[d+8>>2]=j[a>>2]<<1;j[d+4>>2]=j[d+12>>2]-e;g=j[tb(d+8|0,d+4|0)>>2]>>>1|0;c=lb(b);h=e>>>1|0;if(h){f=j[a+20>>2];e=h;while(1){l=f,m=(lb(k[c|0])|lb(k[c+1|0])<<8)^32768,i[l>>1]=m;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=lb(b);if(g){f=j[a+20>>2]+2|0;c=b+(j[a>>2]<<1)|0;e=g;while(1){l=f,m=(lb(k[c|0])|lb(k[c+1|0])<<8)^32768,i[l>>1]=m;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}Za=d+16|0;return g+h<<1}function mqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,l=0,m=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d+8>>2]=j[a>>2]<<1;e=j[tb(d+8|0,d+12|0)>>2];j[d+8>>2]=j[a>>2]<<1;j[d+4>>2]=j[d+12>>2]-e;g=j[tb(d+8|0,d+4|0)>>2]>>>1|0;c=lb(b);h=e>>>1|0;if(h){f=j[a+20>>2];e=h;while(1){l=f,m=(lb(k[c+1|0])|lb(k[c|0])<<8)^32768,i[l>>1]=m;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=lb(b);if(g){f=j[a+20>>2]+2|0;c=b+(j[a>>2]<<1)|0;e=g;while(1){l=f,m=(lb(k[c+1|0])|lb(k[c|0])<<8)^32768,i[l>>1]=m;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}Za=d+16|0;return g+h<<1}function Hwa(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;j[e+12>>2]=c;d=j[b+4>>2];a:{if(d){j[e+8>>2]=32-d;c=tb(e+8|0,e+12|0);d=j[b>>2];c=j[c>>2];f=j[d>>2]&(-1<<j[b+4>>2]&-1>>>j[e+8>>2]-c);if(f){Cc(a,d,NMa(f));break a}f=j[e+12>>2];if((f|0)==(c|0)){$x(a,b,c);break a}c=f-c|0;j[e+12>>2]=c;j[b>>2]=d+4}if(c>>>0>=32){d=j[b>>2];while(1){f=j[d>>2];if(f){Cc(a,d,NMa(f));break a}d=d+4|0;j[b>>2]=d;c=c-32|0;j[e+12>>2]=c;if(c>>>0>31){continue}break}}b:{if(!c){d=j[b>>2];break b}d=j[b>>2];b=j[d>>2]&-1>>>32-c;if(!b){break b}Cc(a,d,NMa(b));break a}Cc(a,d,c)}Za=e+16|0}function wO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=yBa(a);a:{if(c>>>0>5){break a}while(1){b=p(d,30)+a|0;c=xBa(b+20|0)+c|0;if(c>>>0>48){break a}e=b+45|0;if(k[b+44|0]|k[e|0]>64){break a}b=b+42|0;f=k[b|0]|k[b+1|0]<<8;if((f<<24|f<<8&16711680)>>>16>>>0>32768){break a}b=k[b|0]|k[b+1|0]<<8;g=((b<<24|b<<8&16711680)>>>16|0)+g|0;h=k[e|0]|h;d=d+1|0;if((d|0)!=15){continue}break}if(!g|!(h&255)){break a}b=a+470|0;if(k[b|0]>128){break a}c=a+471|0;if(k[c|0]>220){break a}a=a+472|0;a=k[fBa(a,a+128|0)|0];if(a>>>0>63|(a|k[b|0]?0:!k[c|0])){break a}i=1}return i}function Ooa(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b:{if(c){d=k[b+861|0];c:{if(d){c=d-1|0;h[b+861|0]=c;if(c&255){break c}mb(e+8|0,a+1074308|0,16);if(!kb(e+8|0)){c=-1;if(j[a+480180>>2]!=2){break a}}j[b+804>>2]=j[a+1074424>>2]+1;break b}mb(e+8|0,a+1074308|0,17);if(!(kb(e+8|0)|j[a+480180>>2]&3|!l[a+480188>>1])){d=a+1074984|0;while(1){if(k[d+861|0]?(b|0)!=(d|0):0){break b}d=d+896|0;f=f+1|0;if(l[a+480188>>1]>(f&65535)>>>0){continue}break}}h[b+861|0]=c}c=j[b+804>>2];j[a+1074432>>2]=c;break a}j[b+804>>2]=j[a+1074424>>2]}c=-1}Za=e+16|0;return c}function oqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,l=0,m=0;e=Za-16|0;Za=e;j[e+12>>2]=c;j[e+8>>2]=j[a>>2]<<1;f=j[tb(e+8|0,e+12|0)>>2];j[e+8>>2]=j[a>>2]<<1;j[e+4>>2]=j[e+12>>2]-f;h=j[tb(e+8|0,e+4|0)>>2]>>>1|0;c=lb(b);l=f>>>1|0;if(l){g=j[a+20>>2];f=l;m=d;while(1){m=(lb(k[c|0])|lb(k[c+1|0])<<8)+m|0;i[g>>1]=m;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}b=lb(b);if(h){g=j[a+20>>2]+2|0;c=b+(j[a>>2]<<1)|0;f=h;while(1){d=(lb(k[c|0])|lb(k[c+1|0])<<8)+d|0;i[g>>1]=d;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}Za=e+16|0;return h+l<<1}function lqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,l=0,m=0;e=Za-16|0;Za=e;j[e+12>>2]=c;j[e+8>>2]=j[a>>2]<<1;f=j[tb(e+8|0,e+12|0)>>2];j[e+8>>2]=j[a>>2]<<1;j[e+4>>2]=j[e+12>>2]-f;h=j[tb(e+8|0,e+4|0)>>2]>>>1|0;c=lb(b);l=f>>>1|0;if(l){g=j[a+20>>2];f=l;m=d;while(1){m=(lb(k[c+1|0])|lb(k[c|0])<<8)+m|0;i[g>>1]=m;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}b=lb(b);if(h){g=j[a+20>>2]+2|0;c=b+(j[a>>2]<<1)|0;f=h;while(1){d=(lb(k[c+1|0])|lb(k[c|0])<<8)+d|0;i[g>>1]=d;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}Za=e+16|0;return h+l<<1}function Gya(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=Za-80|0;Za=d;e=j[a+4>>2];f=j[b+4>>2];g=j[b>>2];j[d+72>>2]=g;j[d+76>>2]=f;h=j[c+4>>2];c=j[c>>2];j[d+64>>2]=c;j[d+68>>2]=h;j[d+24>>2]=g;j[d+28>>2]=f;j[d+16>>2]=c;j[d+20>>2]=h;b=nN(d+24|0,d+16|0)+j[a+4>>2]|0;j[a+4>>2]=b;if(!((b-1^e-1)>>>0<32?e:0)){i=j[a>>2];j[(b>>>0<33?i:i+(b-1>>>3&536870908)|0)>>2]=0}j[d+48>>2]=c;j[d+52>>2]=h;j[d+56>>2]=g;j[d+60>>2]=f;rn(d+40|0,a,e);a=j[d+60>>2];j[d+8>>2]=j[d+56>>2];j[d+12>>2]=a;a=j[d+52>>2];j[d>>2]=j[d+48>>2];j[d+4>>2]=a;TN(d+32|0,d+8|0,d,d+40|0);Za=d+80|0}function rga(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0;e=Za-16|0;Za=e;d=j[a+8>>2];c=j[a+12>>2];a:{if((c|0)<0){break a}if(i=1,k=(m=pb(a)>>>0<d>>>0,n=0,o=(c|0)>=0,o?m:n),l=(c|0)>0,l?i:k){break a}d=pb(a);f=j[a+8>>2];g=0-((d>>>0<f>>>0)+j[a+12>>2]|0)|0;c=e;j[c+8>>2]=d-f;j[c+12>>2]=g;i=c,k=Xg(b),j[i>>2]=k;j[c+4>>2]=0;c=iz(c+8|0,c);c=yQ(j[c>>2],j[c+4>>2]);if((c|0)!=(Xg(b)|0)){break a}Pe(j[b>>2],j[b>>2]+c|0,lb(j[a>>2]+j[a+8>>2]|0));b=a;d=c+j[a+8>>2]|0;a=j[a+12>>2];j[b+8>>2]=d;j[b+12>>2]=c>>>0>d>>>0?a+1|0:a;h=1}Za=e+16|0;return h}function pra(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;j[e+12>>2]=c;d=j[b+4>>2];a:{if(d){j[e+8>>2]=32-d;c=tb(e+8|0,e+12|0);f=j[b>>2];c=j[c>>2];d=j[f>>2]&(-1<<d&-1>>>j[e+8>>2]-c);if(d){Cc(a,f,NMa(d));break a}d=j[e+12>>2];if((d|0)==(c|0)){YK(a,b,c);break a}c=d-c|0;j[e+12>>2]=c;j[b>>2]=f+4}if(c>>>0>=32){d=j[b>>2];while(1){f=j[d>>2];if(f){Cc(a,d,NMa(f));break a}d=d+4|0;j[b>>2]=d;c=c-32|0;j[e+12>>2]=c;if(c>>>0>31){continue}break}}b:{if(!c){d=j[b>>2];break b}d=j[b>>2];b=j[d>>2]&-1>>>32-c;if(!b){break b}Cc(a,d,NMa(b));break a}Cc(a,d,c)}Za=e+16|0}function ST(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Za-16|0;Za=d;j[d+12>>2]=j[j[a+1056>>2]>>2]-j[a+1060>>2];j[d+8>>2]=16384;e=j[tb(d+12|0,d+8|0)>>2];j[a+1068>>2]=e;c=17;j[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=ij(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}Lp(d+4|0,ij(a,4));break b}if((c|0)>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}Lp(d+4|0,e-c|0);break b}zA(a,e,f,b);break b}c=e&(f^-1);if(e&f){j[d+4>>2]=c+1;break b}zA(a,c,0,b)}if(!j[a+1068>>2]){break a}c=j[d+4>>2];if((c|0)<18){continue}break}}Za=d+16|0}function ZAa(a,b){var c=0,d=0,e=0,f=0;f=64;while(1){c=b;d=k[c+4|0]|k[c+5|0]<<8|(k[c+6|0]<<16|k[c+7|0]<<24);e=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);h[a|0]=e;h[a+1|0]=e>>>8;h[a+2|0]=e>>>16;h[a+3|0]=e>>>24;h[a+4|0]=d;h[a+5|0]=d>>>8;h[a+6|0]=d>>>16;h[a+7|0]=d>>>24;d=k[c+12|0]|k[c+13|0]<<8|(k[c+14|0]<<16|k[c+15|0]<<24);c=k[c+8|0]|k[c+9|0]<<8|(k[c+10|0]<<16|k[c+11|0]<<24);h[a+8|0]=c;h[a+9|0]=c>>>8;h[a+10|0]=c>>>16;h[a+11|0]=c>>>24;h[a+12|0]=d;h[a+13|0]=d>>>8;h[a+14|0]=d>>>16;h[a+15|0]=d>>>24;a=a+16|0;f=f-1|0;if(f){continue}break}}function Apa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=q(0),g=0,h=0,l=q(0),m=0,o=0;e=Za-16|0;Za=e;j[e+8>>2]=c>>>2;j[e+4>>2]=j[a>>2];g=j[tb(e+8|0,e+4|0)>>2];l=n[d>>2];b=lb(b);if(g){d=j[a+20>>2];c=g;while(1){a=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);n[e+12>>2]=l*(WMa(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),_Ma());Kd(e+12|0,q(-1));f=q(n[e+12>>2]*q(32768));n[e+12>>2]=f;a=d;f=Sd(f);a:{if(q(r(f))<q(2147483648)){h=~~f;break a}h=-2147483648}m=a,o=Dc(h),i[m>>1]=o;d=d+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return g<<2}function RT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Za-16|0;Za=d;j[d+12>>2]=j[j[a+1056>>2]>>2]-j[a+1060>>2];j[d+8>>2]=32768;e=j[tb(d+12|0,d+8|0)>>2];j[a+1068>>2]=e;c=9;j[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=ij(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}Lp(d+4|0,ij(a,3));break b}if((c|0)>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}Lp(d+4|0,e-c|0);break b}yA(a,e,f,b);break b}c=e&(f^-1);if(e&f){j[d+4>>2]=c+1;break b}yA(a,c,0,b)}if(!j[a+1068>>2]){break a}c=j[d+4>>2];if((c|0)<10){continue}break}}Za=d+16|0}function _da(a){a=a|0;var b=0,c=0;b=Za-32|0;Za=b;a:{b:{if(!a){a=Gd(34181);break b}j[114626]=0;c=E(85,b|0,a|0)|0;a=j[114626];j[114626]=0;c:{d:{if((a|0)!=1){j[114626]=0;F(1986,b+16|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}a=Gd(zb(b+16|0));gb(b+16|0);gb(c);break b}a=J(0)|0;C()|0;break c}a=J(0)|0;C()|0;gb(c)}O(a|0)|0;a=0;j[114626]=0;L(1982,34182,0,0,0);c=j[114626];j[114626]=0;if((c|0)==1){break a}Q()}Za=b+32|0;return a|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function uca(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=Za-16|0;Za=g;j[114626]=0;N(2008,a|0);h=j[114626];j[114626]=0;a:{b:{if((h|0)!=1){c:{h=j[a+24>>2];j[114626]=0;Z(2066,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=j[114626];j[114626]=0;if((b|0)==1){break c}b=Gd(zb(g));gb(g);break b}}b=J(0)|0;C()|0;O(b|0)|0;b=0;j[114626]=0;L(1982,36818,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=g+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function tca(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=Za-16|0;Za=g;j[114626]=0;N(2008,a|0);h=j[114626];j[114626]=0;a:{b:{if((h|0)!=1){c:{h=j[a+24>>2];j[114626]=0;Z(2067,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=j[114626];j[114626]=0;if((b|0)==1){break c}b=Gd(zb(g));gb(g);break b}}b=J(0)|0;C()|0;O(b|0)|0;b=0;j[114626]=0;L(1982,36860,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=g+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function sEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0;d=Za-32|0;Za=d;g=d+8|0;e=b;i=e;if(pP(e,d+24|0)){f=d+26|0;f=k[f|0]|k[f+1|0]<<8|(k[f+2|0]<<16|k[f+3|0]<<24)}cd(g,i,f);e=k[d+24|0]|k[d+25|0]<<8|(k[d+26|0]<<16|k[d+27|0]<<24);h[a|0]=e;h[a+1|0]=e>>>8;h[a+2|0]=e>>>16;h[a+3|0]=e>>>24;e=k[d+28|0]|k[d+29|0]<<8;h[a+4|0]=e;h[a+5|0]=e>>>8;Cl(a+8|0,d+8|0);jb(d+8|0);a:{if(!c){break a}e=(f>>>0)%(c>>>0)|0;if(!e){break a}j[114626]=0;E(338,b|0,c-e|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break a}b=D()|0;C()|0;Re(a);G(b|0);z()}Za=d+32|0}function $ka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-32|0;Za=e;f=Ow(a);a:{b:{c:{d:{while(1){j[114626]=0;a=E(258,b|0,8)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}if(a){j[114626]=0;I(1547,e+8|0,b|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}j[114626]=0;F(1548,f|0,e+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Re(e+8|0);a=mt(f);if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=(d|0)){continue}}break}Za=e+32|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;Re(e+8|0);break a}a=D()|0;C()|0}Vk(f);G(a|0);z()}function ota(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,k=0,m=0,n=0;c=Za-16|0;Za=c;f=l[mk(a,b)>>1];a:{if(!Po(a,b)){break a}d=j[a+24>>2]+484360|0;m=c,n=Lb(d),j[m+8>>2]=n;m=c,n=Mb(d),j[m>>2]=n;if(!rb(c+8|0,c)){break a}h=f&65535;while(1){b:{g=j[c+8>>2];k=nt(g);if(k){e=0;while(1){if(!(!((a|0)!=(g|0)|(b|0)!=(e|0))|l[ac(g,e)>>1]!=(h|0))){d=nI(j[a+24>>2]+484344|0,h,0);if((d|0)!=65535){break b}}e=e+1|0;if((k|0)!=(e|0)){continue}break}}Qx(c+8|0);if(rb(c+8|0,c)){continue}break a}break}m=mk(a,b),n=d,i[m>>1]=n;f=d}Za=c+16|0;return f&65535}function UKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-208|0;Za=d;Rz(c,a);bS(c,d+16|0,p(k[a+4|0],3));a:{if(k[a+4|0]<2){break a}h[d+12|0]=64;Nf(b,k[Yb(a+4|0,d+12|0)|0]);h[b+13|0]=k[a+2|0];h[b+14|0]=k[a+3|0];a=k[a+1|0];h[b+15|0]=a;h[b+16|0]=a;if(!sb(b)){break a}a=0;while(1){if(a){c=l[xb(b,a-1|0)>>1];j[d+12>>2]=1;e=(d+16|0)+p(a,3)|0;j[d+8>>2]=(h[e+1|0]&1)<<8|k[e|0];e=l[zf(d+12|0,d+8|0)>>1];f=xb(b,a),g=c+e|0,i[f>>1]=g}c=k[((d+16|0)+p(a,3)|0)+2|0];f=xb(b,a),g=c,h[f+2|0]=g;a=a+1|0;if(sb(b)>>>0>a>>>0){continue}break}}Za=d+208|0}function U0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=Za-32|0;Za=a;i[a+28>>1]=k[62208]|k[62209]<<8;j[a+24>>2]=k[62204]|k[62205]<<8|(k[62206]<<16|k[62207]<<24);vj(a+24|1,62196,1,j[c+4>>2]);g=j[c+4>>2];f=a-16|0;Za=f;h=Wd();j[a>>2]=e;e=g>>>9&1;g=Ke(f,e+13|0,h,a+24|0,a)+f|0;h=Tf(f,g,c);e=f-((e<<3)+107&112)|0;Za=e;hc(a+8|0,c);j[114626]=0;Z(2466,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=j[114626];j[114626]=0;if((f|0)!=1){wb(a+8|0);b=Wl(b,e,j[a+20>>2],j[a+16>>2],c,d);Za=a+32|0;return b|0}b=D()|0;C()|0;wb(a+8|0);G(b|0);z()}function vza(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-32|0;Za=e;f=ny(a);a:{b:{c:{d:{while(1){j[114626]=0;a=E(258,b|0,8)|0;g=j[114626];j[114626]=0;if((g|0)==1){break b}if(a){j[114626]=0;I(968,e+8|0,b|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}j[114626]=0;F(969,f|0,e+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}Re(e+8|0);a=mt(f);if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=(d|0)){continue}}break}Za=e+32|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;Re(e+8|0);break a}a=D()|0;C()|0}gl(f);G(a|0);z()}function Qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,l=0,m=0;d=Za-32|0;Za=d;ug(d,2,a+6|0);qc(d+16|0,d);j[114626]=0;E(369,b+492|0,d+16|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){gb(d+16|0);f=b+236|0;g=c+1|0;c=0;e=0;while(1){h=k[(a+c|0)+38|0];l=Oc(f,c),m=g+h|0,i[l>>1]=m;e=e+1|0;c=e&255;if(c>>>0<128){continue}break}c=a+226|0;j[b>>2]=(k[c|0]|k[c+1|0]<<8)<<5;Nw(a+180|0,b+48|0,0);Nw(a+228|0,b+88|0,2);Nw(a+276|0,b+68|0,1);a=a+324|0;if(!(k[a|0]|k[a+1|0]<<8)){Ab(b+236|0,0,256)}Za=d+32|0;return}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function rqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,l=0,m=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d+8>>2]=j[a>>2]<<1;e=j[tb(d+8|0,d+12|0)>>2];j[d+8>>2]=j[a>>2]<<1;j[d+4>>2]=j[d+12>>2]-e;g=j[tb(d+8|0,d+4|0)>>2]>>>1|0;c=lb(b);h=e>>>1|0;if(h){f=j[a+20>>2];e=h;while(1){l=f,m=lb(k[c|0])|lb(k[c+1|0])<<8,i[l>>1]=m;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=lb(b);if(g){f=j[a+20>>2]+2|0;c=b+(j[a>>2]<<1)|0;e=g;while(1){l=f,m=lb(k[c|0])|lb(k[c+1|0])<<8,i[l>>1]=m;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}Za=d+16|0;return g+h<<1}function nqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,l=0,m=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d+8>>2]=j[a>>2]<<1;e=j[tb(d+8|0,d+12|0)>>2];j[d+8>>2]=j[a>>2]<<1;j[d+4>>2]=j[d+12>>2]-e;g=j[tb(d+8|0,d+4|0)>>2]>>>1|0;c=lb(b);h=e>>>1|0;if(h){f=j[a+20>>2];e=h;while(1){l=f,m=lb(k[c+1|0])|lb(k[c|0])<<8,i[l>>1]=m;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=lb(b);if(g){f=j[a+20>>2]+2|0;c=b+(j[a>>2]<<1)|0;e=g;while(1){l=f,m=lb(k[c+1|0])|lb(k[c|0])<<8,i[l>>1]=m;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}Za=d+16|0;return g+h<<1}function Du(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;f=j[a>>2];e=j[f-4>>2];f=j[f-8>>2];j[d+20>>2]=0;j[d+16>>2]=b;j[d+12>>2]=a;j[d+8>>2]=c;b=0;Ab(d+24|0,0,39);a=a+f|0;a:{if(Rf(e,c,0)){j[d+56>>2]=1;bb[j[j[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=j[d+32>>2]==1?a:0;break a}bb[j[j[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(j[d+44>>2]){case 0:b=j[d+48>>2]==1?j[d+36>>2]==1?j[d+40>>2]==1?j[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(j[d+32>>2]!=1){if(j[d+48>>2]|j[d+36>>2]!=1|j[d+40>>2]!=1){break a}}b=j[d+24>>2]}Za=d- -64|0;return b}function nK(a,b,c){var d=0,e=0,f=0;d=Za-16|0;Za=d;a:{if(b){h[c|0]=b;break a}b=k[c|0]}b=j[a+480180>>2]&1048580?b&240?b&-16:b&15:b;c=b&240;e=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(k[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=j[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(c){if(j[a+480180>>2]&59314208?b:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}c=a+1074444|0;j[d+12>>2]=j[c>>2]+(b<<!(j[a+480180>>2]&59314208));Md(d+12|0,0,256);j[c>>2]=j[d+12>>2]}Za=d+16|0}function q4(){var a=0,b=0,c=0,d=0;a=Za-48|0;Za=a;j[114626]=0;b=E(2300,1,a+32|0)|0;c=j[114626];j[114626]=0;a:{b:{c:{if((c|0)==1){break c}if(b){j[114626]=0;a=j[114626];j[114626]=0;if((a|0)==1){break c}a=j[114600];j[114626]=0;F(2302,a|0,55729);a=j[114626];j[114626]=0;if((a|0)!=1){break b}break c}b=Nq(a+16|0,a+32|0);c=Nq(a+8|0,a+32|4);j[114626]=0;b=HB(2304,b,c);c=ab;d=j[114626];j[114626]=0;if((d|0)!=1){break a}}a=J(0)|0;C()|0;ib(a)}z()}j[a+24>>2]=b;j[a+28>>2]=c;b=Sj(a+40|0,a+24|0);c=j[b+4>>2];b=j[b>>2];Za=a+48|0;ab=c;return b}function cua(a,b,c){var d=0,e=0,f=0,g=0;e=Za-32|0;Za=e;j[e+24>>2]=b;b=j[a>>2];f=e,g=Lb(a),j[f>>2]=g;b=b+(Ms(e+24|0,e)<<2)|0;a:{b:{if(m[a+4>>2]<m[hb(a)>>2]){d=j[a+4>>2];if((d|0)!=(b|0)){break b}tP(a,c);break a}d=hb(a);d=sn(e,ie(a,sb(a)+1|0),b-j[a>>2]>>2,d);j[114626]=0;F(1154,d|0,c|0);c=j[114626];j[114626]=0;c:{if((c|0)==1){break c}j[114626]=0;b=K(1155,a|0,d|0,b|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}xh(d);break a}a=D()|0;C()|0;xh(d);G(a|0);z()}$ta(a,b,d,b+4|0);i[b>>1]=l[c>>1];h[b+2|0]=k[c+2|0]}Qe(b);Za=e+32|0}function Bma(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=j[a+24620>>2];c=ic(PMa(OMa(c,c>>31,100,0),ab,1e3,0),ab);a:{if(!c){break a}e=c>>>0<1048576?c:1048576;j[a+1074380>>2]=e;b=l[a+480212>>1];if(!b){break a}h=b>>>0>1?b:1;f=a+1074376|0;b=0;while(1){a=p(l[((b<<1)+f|0)+90>>1],896)+f|0;d=a+1280|0;j[d>>2]=0;j[d+4>>2]=0;j[a+708>>2]=e;d=j[a+632>>2]<<12;j[a+648>>2]=d;g=j[a+628>>2]<<12;j[a+644>>2]=g;j[a+696>>2]=j[a+696>>2]|65536;j[a+636>>2]=(0-g|0)/(e|0);j[a+640>>2]=(0-d|0)/(e|0);b=b+1|0;if((h|0)!=(b|0)){continue}break}}return(c|0)!=0}function lK(a,b,c){var d=0,e=0;a:{if(j[a+480180>>2]==4){d=k[b+834|0];if(c){h[b+834|0]=d&240|c&15;break a}c=d&15;break a}if(j[a+480180>>2]!=1048576){break a}if(c){h[b+833|0]=c;break a}c=k[b+833|0]}b:{if(!(h[b+872|0]&1)|!(c&255)){break b}d=j[b+700>>2];if(!d){break b}c:{if(!(k[a+480208|0]&16)){break c}d=j[b+700>>2];if(j[a+480180>>2]==4){break c}e=b;a=bK(a,c&15);b=OMa(a,a>>31,d,d>>31)+32768|0;a=ab;a=ic(PMa(b,b>>>0<32768?a+1|0:a,65536,0),ab);j[e+700>>2]=a-((a|0)==(d|0));return}a=(c&255)+d|0;j[b+700>>2]=(a|0)<65535?a:65535}}function e1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=Za-32|0;Za=a;i[a+28>>1]=k[62208]|k[62209]<<8;j[a+24>>2]=k[62204]|k[62205]<<8|(k[62206]<<16|k[62207]<<24);vj(a+24|1,62196,1,j[c+4>>2]);g=j[c+4>>2];f=a-16|0;Za=f;h=Wd();j[a>>2]=e;g=Ke(f,(g>>>9&1)+13|0,h,a+24|0,a)+f|0;h=Tf(f,g,c);e=f-32|0;Za=e;hc(a+8|0,c);j[114626]=0;Z(2457,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=j[114626];j[114626]=0;if((f|0)!=1){wb(a+8|0);b=Al(b,e,j[a+20>>2],j[a+16>>2],c,d);Za=a+32|0;return b|0}b=D()|0;C()|0;wb(a+8|0);G(b|0);z()}function wca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=Za-16|0;Za=f;j[114626]=0;N(2008,a|0);g=j[114626];j[114626]=0;a:{b:{if((g|0)!=1){c:{g=j[a+24>>2];j[114626]=0;aa(2064,f|0,g|0,b|0,c|0,d|0,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break c}b=Gd(zb(f));gb(f);break b}}b=J(0)|0;C()|0;O(b|0)|0;b=0;j[114626]=0;L(1982,36715,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=f+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function vca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=Za-16|0;Za=f;j[114626]=0;N(2008,a|0);g=j[114626];j[114626]=0;a:{b:{if((g|0)!=1){c:{g=j[a+24>>2];j[114626]=0;aa(2065,f|0,g|0,b|0,c|0,d|0,e|0);b=j[114626];j[114626]=0;if((b|0)==1){break c}b=Gd(zb(f));gb(f);break b}}b=J(0)|0;C()|0;O(b|0)|0;b=0;j[114626]=0;L(1982,36765,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}Za=f+16|0;return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function tza(a){a=a|0;var b=0,c=0,d=0,e=0;b=Za-16|0;Za=b;h[b+15|0]=128;d=lt(a,127,b+15|0);j[114626]=0;h[b+14|0]=64;e=K(881,a+12|0,127,b+14|0)|0;c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){j[114626]=0;h[b+13|0]=0;K(970,a+24|0,127,b+13|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break b}j[a+36>>2]=-1;j[a+40>>2]=108855296;h[a+44|0]=0;h[a+45|0]=0;h[a+46|0]=0;h[a+47|0]=0;h[a+48|0]=0;h[a+49|0]=0;h[a+50|0]=0;h[a+51|0]=0;h[a+52|0]=0;h[a+53|0]=0;Za=b+16|0;return a|0}a=D()|0;C()|0;break a}a=D()|0;C()|0;Od(e)}Od(d);G(a|0);z()}function lj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,i=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=Za-16|0;Za=e;j[b>>2]=0;j[b+4>>2]=0;h[e+15|0]=0;i=Cg(a,e+15|0);g=k[e+15|0];j[b>>2]=(g&252)>>>2;j[b+4>>2]=0;c=g&3;if(c){n=(c|0)==1?1:-1<<c^-1;while(1){h[e+15|0]=0;o=Cg(a,e+15|0);d=j[b>>2];p=j[b+4>>2];l=k[e+15|0];c=f;f=m+1|0;c=f>>>0<1?c+1|0:c;m=f;f=c;g=b;q=b;r=d;c=(m<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=l<<d;d=0}else{c=(1<<d)-1&l>>>32-d;d=l<<d}j[q>>2]=r|d;j[g+4>>2]=c|p;i=i&o;if((m|0)!=(n|0)|f){continue}break}}Za=e+16|0;return i|0}function tBa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-528|0;Za=d;c=-1;a:{if(!jf(a,1468)){break a}Xj(a,1464);FO(a,d+524|0);if(!Jd(d+524|0,16026)){c=0;if(!Jd(d+524|0,16031)){break a}}Xj(a,20);b=1;while(1){c=-1;if(!CO(a,d)){break a}e=Dy(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}YAa(a,d+520|0);e=Pc(d+520|0);c=0;if(k[d+520|0]>128){break a}sBa(a,d);a=d+512|0;b=d;c=k[e|0];b:{while(1){if(c>>>0<k[b|0]){break b}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}Za=d+528|0;return c|0}function S8(a){var b=0,c=0,d=0,e=0;b=Za-160|0;Za=b;a=mm(b+16|0,a,8);c=j[j[a>>2]-12>>2];j[114626]=0;d=T(122)|0;e=j[114626];j[114626]=0;a:{if((e|0)==1){break a}j[114626]=0;I(123,b+8|0,c+(b+16|0)|0,d|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}wb(b+8|0);j[114626]=0;c=E(178,a|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[j[c>>2]-12>>2];j[114626]=0;c=H(174,c+d|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b+4>>2];e=j[b>>2];Xe(a);Za=b+160|0;ab=c?0:d;return c?0:e}b=D()|0;C()|0;Xe(a);G(b|0);z()}function ila(a,b){var c=0,d=0,e=0,f=0,g=0,l=0;d=Za-16|0;Za=d;e=a+206|0;j[b>>2]=k[e|0]|k[e+1|0]<<8;LI(a,b+48|0,k[a+192|0],k[a+200|0],k[a+194|0],k[a+195|0],k[a+196|0],0);LI(a,b+68|0,k[a+193|0],k[a+201|0],k[a+197|0],k[a+198|0],k[a+199|0],1);e=b+236|0;while(1){f=k[a+c|0];g=Oc(e,c+12|0),l=f,i[g>>1]=l;c=c+1|0;if((c|0)!=96){continue}break}if(k[a+208|0]){h[b+31|0]=k[a+209|0]+1;hla(b+31|0);c=a+210|0;i[d+14>>1]=k[c|0]|k[c+1|0]<<8;i[d+12>>1]=127;g=b,l=k[gf(d+14|0,d+12|0)|0]+1|0,h[g+30|0]=l}h[b+33|0]=k[a+212|0];Za=d+16|0}function b1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=Za-32|0;Za=a;i[a+28>>1]=k[62208]|k[62209]<<8;j[a+24>>2]=k[62204]|k[62205]<<8|(k[62206]<<16|k[62207]<<24);vj(a+24|1,62196,0,j[c+4>>2]);g=j[c+4>>2];f=a-16|0;Za=f;h=Wd();j[a>>2]=e;g=Ke(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=Tf(f,g,c);e=f-32|0;Za=e;hc(a+8|0,c);j[114626]=0;Z(2457,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=j[114626];j[114626]=0;if((f|0)!=1){wb(a+8|0);b=Al(b,e,j[a+20>>2],j[a+16>>2],c,d);Za=a+32|0;return b|0}b=D()|0;C()|0;wb(a+8|0);G(b|0);z()}function Ux(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;a:{if(ad(a)){break a}i[j[a>>2]>>1]=0;Ae(j[a>>2]+2|0,b);e=c,f=Lb(a),j[e>>2]=f;e=c,f=So(c,1),j[e+8>>2]=f;e=c,f=Mb(a),j[e>>2]=f;if(!rb(c+8|0,c)){break a}while(1){d=j[c+8>>2];e=c,f=mM(c+8|0,1),j[e>>2]=f;d=l[ui(d,j[c>>2])>>1];i[j[c+8>>2]>>1]=d;Ae(j[c+8>>2]+2|0,b);LS(c+8|0);e=c,f=Mb(a),j[e>>2]=f;if(rb(c+8|0,c)){continue}break}}Ae(a+14|0,sb(a)-1&255);Ae(a+13|0,k[a+14|0]);Ae(a+16|0,sb(a)-1&255);Ae(a+15|0,k[a+16|0]);if(k[a+17|0]!=255){Ae(a+17|0,sb(a)-1&255)}Za=c+16|0}function R0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=Za-32|0;Za=a;i[a+28>>1]=k[62208]|k[62209]<<8;j[a+24>>2]=k[62204]|k[62205]<<8|(k[62206]<<16|k[62207]<<24);vj(a+24|1,62196,0,j[c+4>>2]);g=j[c+4>>2];f=a-16|0;Za=f;h=Wd();j[a>>2]=e;g=Ke(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=Tf(f,g,c);e=f-96|0;Za=e;hc(a+8|0,c);j[114626]=0;Z(2466,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=j[114626];j[114626]=0;if((f|0)!=1){wb(a+8|0);b=Wl(b,e,j[a+20>>2],j[a+16>>2],c,d);Za=a+32|0;return b|0}b=D()|0;C()|0;wb(a+8|0);G(b|0);z()}function Oka(a,b,c,d,e){var f=0,g=0,i=0;f=Za-16|0;Za=f;j[f+8>>2]=e;j[f+12>>2]=c;g=j[tb(f+12|0,f+8|0)>>2];a:{b:{if(!g){c=b;break b}e=g;c=b;while(1){i=k[d|0];h[c|0]=i;if(!i){break a}d=d+1|0;c=c+1|0;e=e-1|0;if(e){continue}break}}e=0}c:{d:{e:{switch(a-1|0){case 0:case 1:d=j[f+12>>2];h[f+7|0]=0;Fr(c,((c+d|0)-g|0)+e|0,f+7|0);break d;case 2:case 3:break e;default:break c}}d=j[f+12>>2];h[f+6|0]=32;Fr(c,((c+d|0)-g|0)+e|0,f+6|0)}f:{switch(a-1|0){case 0:case 3:break f;default:break c}}h[(j[f+12>>2]+b|0)-1|0]=0}Za=f+16|0}function wT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;tF(b);a:{if(!(k[a|0]|k[a+1|0]<<8)){c=a+2|0;if(!(k[c|0]|k[c+1|0]<<8)){break a}}j[b+20>>2]=((k[a|0]|k[a+1|0]<<8)>>>9|0)+80;d=b,e=Gb((k[a|0]|k[a+1|0]<<8)>>>5&15,1,12)-1|0,j[d+16>>2]=e;d=b,e=Gb((k[a|0]|k[a+1|0]<<8)&31,1,31),j[d+12>>2]=e;c=a+2|0;d=b,e=Gb((k[c|0]|k[c+1|0]<<8)>>>11|0,0,23),j[d+8>>2]=e;d=b,e=Gb((k[c|0]|k[c+1|0]<<8)>>>5&63,0,59),j[d+4>>2]=e;d=b,e=Gb((k[c|0]|k[c+1|0]<<8)<<1&62,0,59),j[d>>2]=e}a=a+4|0;j[b+44>>2]=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24)}function oX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Rf(a,j[b+8>>2],e)){Au(b,c,d);return}a:{if(Rf(a,j[b>>2],e)){if(!(j[b+20>>2]!=(c|0)?j[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}j[b+32>>2]=1;return}j[b+32>>2]=d;b:{if(j[b+44>>2]==4){break b}i[b+52>>1]=0;a=j[a+8>>2];bb[j[j[a>>2]+20>>2]](a,b,c,c,1,e);if(k[b+53|0]){j[b+44>>2]=3;if(!k[b+52|0]){break b}break a}j[b+44>>2]=4}j[b+20>>2]=c;j[b+40>>2]=j[b+40>>2]+1;if(j[b+36>>2]!=1|j[b+24>>2]!=2){break a}h[b+54|0]=1;return}a=j[a+8>>2];bb[j[j[a>>2]+24>>2]](a,b,c,d,e)}}function OGa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,m=0,n=0;f=Za-32|0;Za=f;j[f+28>>2]=c;h=yb(b,c<<2);a:{if(!h){break a}kc(f+28|0,65535);bg(a,l[f+28>>1]);m=f,n=Lb(a),j[m+16>>2]=n;m=f,n=Mb(a),j[m+8>>2]=n;if(!rb(f+16|0,f+8|0)){break a}while(1){a=j[f+16>>2];Ws(b,f+24|0);c=f+24|0;c=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);i[a>>1]=c;c=c&65535;g=65535;b:{c:{if((c|0)==(d|0)){break c}if((c|0)!=(e|0)){break b}g=65534}i[a>>1]=g}je(f+16|0);if(rb(f+16|0,f+8|0)){continue}break}}Za=f+32|0;return h|0}function M0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,l=0;a=Za-208|0;Za=a;i[a+204>>1]=k[62214]|k[62215]<<8;j[a+200>>2]=k[62210]|k[62211]<<8|(k[62212]<<16|k[62213]<<24);f=Wd();j[a>>2]=e;h=Ke(a+176|0,20,f,a+200|0,a);e=h+(a+176|0)|0;f=Tf(a+176|0,e,c);hc(a+8|0,c);j[114626]=0;g=H(2441,a+8|0)|0;l=j[114626];j[114626]=0;if((l|0)!=1){wb(a+8|0);hD(g,a+176|0,e,a+16|0);g=b;b=(a+16|0)+(h<<2)|0;b=Wl(g,a+16|0,(e|0)==(f|0)?b:((f-a<<2)+a|0)-688|0,b,c,d);Za=a+208|0;return b|0}b=D()|0;C()|0;wb(a+8|0);G(b|0);z()}function fm(a,b,c,d,e,f){var g=0,h=0,i=0,k=0;a:{if(f&64){c=f+ -64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}h=e;i=d;k=64-f|0;g=k&31;if((k&63)>>>0>=32){h=i<<g;k=0}else{h=(1<<g)-1&i>>>32-g|h<<g;k=i<<g}i=b;g=f;b=g&31;if((g&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=k|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}j[a>>2]=b;j[a+4>>2]=c;j[a+8>>2]=d;j[a+12>>2]=e}function nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;j[114626]=0;N(2008,a|0);d=j[114626];j[114626]=0;a:{if((d|0)==1){break a}j[114626]=0;N(2019,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[a+24>>2];j[114626]=0;b=E(2020,d|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[c>>2]=b;return 1}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35262,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)!=1){Q();return 0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Zw(a,b,c){var d=0,e=0;e=Za-16|0;Za=e;mb(e+8|0,a+1074308|0,21);a:{if(kb(e+8|0)){c=c&255;b:{switch((b&3)-1|0){default:d=h[c+21616|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=bJ(Bm(a))+ -64|0;break a}d=h[(c>>>1&31)+20720|0];if(j[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=h[a+21488|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=h[a+21552|0]}a=d;Za=e+16|0;return a}function Tqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;f=Db(a);a:{b:{c:{if(cc(b)){a=0;while(1){d:{if(!a){break d}j[114626]=0;E(1245,f|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break d}a=D()|0;C()|0;break a}d=Zc(b,a);j[114626]=0;F(1246,e|0,d|0);d=j[114626];j[114626]=0;if((d|0)==1){break c}j[114626]=0;E(1245,f|0,e|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}gb(e);a=a+1|0;if(cc(b)>>>0>a>>>0){continue}break}}Za=e+16|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(e)}gb(f);G(a|0);z()}function Ww(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0;h=Za-16|0;Za=h;a:{if((c|0)<2){break a}k=(c-2|0)/2|0;f=d-a|0;if((k|0)<f>>1){break a}g=f+1|0;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){j=no(b,l[e>>1],l[e+2>>1]);e=j?e+2|0:e;g=j?f:g}if(no(b,l[e>>1],l[d>>1])){break a}i[h+14>>1]=l[d>>1];while(1){b:{f=e;i[d>>1]=l[e>>1];if((g|0)>(k|0)){break b}d=g<<1;g=d|1;e=(g<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){j=no(b,l[e>>1],l[e+2>>1]);e=j?e+2|0:e;g=j?d:g}d=f;if(!no(b,l[e>>1],l[h+14>>1])){continue}}break}i[f>>1]=l[h+14>>1]}Za=h+16|0}function b2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;a:{b:{c:{if((a|0)!=(b|0)){g=j[114600];j[114600]=0;a=mD(a,e+12|0,d,Wd());d=ab;f=j[114600];d:{if(f){if(j[e+12>>2]!=(b|0)){break d}if((f|0)==68){break b}break c}j[114600]=g;if(j[e+12>>2]==(b|0)){break c}}}j[c>>2]=4;b=0;break a}if(((d|0)<-1?1:(d|0)<=-1?a>>>0<2147483648:0)|((d|0)>0?1:(d|0)>=0?a>>>0>2147483647:0)){break b}b=a;break a}j[c>>2]=4;b=2147483647;if((d|0)>0?1:(d|0)>=0?a>>>0>=1:0){break a}b=-2147483648}Za=e+16|0;return b|0}function Z8(a){var b=0,c=0,d=0,e=0;b=Za-160|0;Za=b;a=mm(b+16|0,a,8);d=j[j[a>>2]-12>>2];j[114626]=0;c=T(122)|0;e=j[114626];j[114626]=0;a:{if((e|0)==1){break a}j[114626]=0;I(123,b+8|0,d+(b+16|0)|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}wb(b+8|0);j[114626]=0;d=E(177,a|0,b+6|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[j[d>>2]-12>>2];j[114626]=0;d=H(174,c+d|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}c=l[b+6>>1];Xe(a);Za=b+160|0;return(d?0:c)&65535}b=D()|0;C()|0;Xe(a);G(b|0);z()}function Qpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,l=0,m=0;e=Za-16|0;Za=e;j[e+8>>2]=c>>>3;j[e+4>>2]=j[a>>2];d=j[tb(e+8|0,e+4|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){g=k[b+4|0]|k[b+5|0]<<8|(k[b+6|0]<<16|k[b+7|0]<<24);j[e+8>>2]=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);j[e+12>>2]=g;pf(e+8|0,-1,1);f=o[e+8>>3]*32768;o[e+8>>3]=f;g=a;f=zd(f);a:{if(r(f)<2147483648){h=~~f;break a}h=-2147483648}l=g,m=Dc(h),i[l>>1]=m;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<3}function vr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=Za-32|0;Za=d;e=a;c=j[b>>2];f=j[b+8>>2];c=c&24576?c:j[b+4>>2]?(f|0)!=-1?c&-12289|8192:c:c;b=143;a:{b:{if(c&1){break b}if(!(c&2)){break a}b=144}aw(e,b)}c:{if(c&4096){break c}if(c&8192){g=d,h=Qe(4),j[g+24>>2]=h;rG(a,d+24|0);break c}if(!(c&16384)){break c}g=d,h=Qe(256),j[g+16>>2]=h;rG(a,d+16|0)}b=a;d:{if(c&16){e=145}else{if(!(c&32)){break d}e=146}aw(b,e)}if((f|0)!=-1){g=d,h=Qe(f),j[g+8>>2]=h;a=j[j[a>>2]-12>>2]+a|0;a;j[a+8>>2]=j[d+8>>2]}Za=d+32|0}function Tpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=q(0),h=0,l=0,m=0;e=Za-16|0;Za=e;j[e+8>>2]=c>>>2;j[e+4>>2]=j[a>>2];d=j[tb(e+8|0,e+4|0)>>2];b=lb(b);if(d){c=j[a+20>>2];a=d;while(1){f=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);j[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);Kd(e+12|0,q(-1));g=q(n[e+12>>2]*q(32768));n[e+12>>2]=g;f=c;g=Sd(g);a:{if(q(r(g))<q(2147483648)){h=~~g;break a}h=-2147483648}l=f,m=Dc(h),i[l>>1]=m;c=c+2|0;b=b+4|0;a=a-1|0;if(a){continue}break}}Za=e+16|0;return d<<2}function y2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0;f=Za-32|0;Za=f;a:{b:{if(wD(c)){while(1){if(a>>>d&1){k=(d<<2)+c|0,l=xD(d,b),j[k>>2]=l}d=d+1|0;if((d|0)!=6){continue}break}break b}while(1){i=(f+8|0)+(d<<2)|0;e=1<<d&a;g=j[(d<<2)+c>>2];c:{if(!(e|!c)){break c}g=xD(d,e?b:58123)}e=g;j[i>>2]=e;h=((e|0)!=0)+h|0;d=d+1|0;if((d|0)!=6){continue}break}d=57968;d:{switch(h|0){case 0:break a;case 1:break d;default:break b}}if(j[f+8>>2]!=57940){break b}d=57992;break a}d=c}Za=f+32|0;return d|0}function eW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;f=Qc(a);a:{b:{c:{if(cc(b)){a=0;while(1){d:{if(!a){break d}j[114626]=0;E(192,f|0,c|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){break d}a=D()|0;C()|0;break a}d=Zc(b,a);j[114626]=0;F(252,e|0,d|0);d=j[114626];j[114626]=0;if((d|0)==1){break c}j[114626]=0;E(192,f|0,e|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}gb(e);a=a+1|0;if(cc(b)>>>0>a>>>0){continue}break}}Za=e+16|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(e)}gb(f);G(a|0);z()}function yv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;f=(ZMa(a),VMa(2));c=f&2147483647;a:{if(c>>>0<=1305022426){g=+a;d=g*.6366197723675814+6755399441055744+ -6755399441055744;o[b>>3]=g+d*-1.5707963109016418+d*-1.5893254773528196e-8;if(r(d)<2147483648){c=~~d;break a}c=-2147483648;break a}if(c>>>0>=2139095040){o[b>>3]=q(a-a);c=0;break a}h=c;c=(c>>>23|0)-150|0;o[e+8>>3]=(WMa(2,h-(c<<23)|0),_Ma());c=DE(e+8|0,e,c,1,0);d=o[e>>3];if((f|0)<=-1){o[b>>3]=-d;c=0-c|0;break a}o[b>>3]=d}Za=e+16|0;return c}function X0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,l=0;a=Za-96|0;Za=a;i[a+92>>1]=k[62214]|k[62215]<<8;j[a+88>>2]=k[62210]|k[62211]<<8|(k[62212]<<16|k[62213]<<24);f=Wd();j[a>>2]=e;h=Ke(a- -64|0,20,f,a+88|0,a);e=h+(a- -64|0)|0;f=Tf(a- -64|0,e,c);hc(a+8|0,c);j[114626]=0;g=H(21,a+8|0)|0;l=j[114626];j[114626]=0;if((l|0)!=1){wb(a+8|0);jD(g,a- -64|0,e,a+16|0);g=b;b=(a+16|0)+h|0;b=Al(g,a+16|0,(e|0)==(f|0)?b:((f-a|0)+a|0)-48|0,b,c,d);Za=a+96|0;return b|0}b=D()|0;C()|0;wb(a+8|0);G(b|0);z()}function bM(a,b){var c=0,d=0,e=0,f=0,g=0,i=0,l=0,m=0,n=0;n=b?33:32;f=j[a+8>>2];c=f-1|0;d=j[a+12>>2];g=j[a>>2]+p(d,31)|0;i=b?1:-1;e=i;while(1){b=0;if((d|0)>0){while(1){h[b+g|0]=k[j[a+4>>2]+(p(c,d)+b|0)|0];b=b+1|0;d=j[a+12>>2];if((b|0)<(d|0)){continue}break}f=j[a+8>>2]}b=p(d,i);l=f-1|0;a:{if(!((l|0)!=(c|0)|(e|0)<1)){if(!k[a+16|0]){e=1;c=0;break a}e=-1;c=c-((c|0)!=0&k[a+17|0]!=0)|0;break a}if(!((e|0)>-1|c)){c=k[a+16|0];e=c?1:-1;c=c?0:l;break a}c=c+e|0}g=b+g|0;m=m+1|0;if((n|0)!=(m|0)){continue}break}}function Tta(a,b){var c=0,d=0,e=0;kc(a,65536);kc(a+4|0,64);kc(a+8|0,256);Sf(a+28|0,16384);Ae(a+30|0,128);Ae(a+31|0,17);if(k[a+16|0]>=4){h[a+16|0]=0}if(k[a+17|0]>=5){h[a+17|0]=0}if(k[a+18|0]>=3){h[a+18|0]=0}Ae(a+19|0,64);Ae(a+20|0,100);Yta(a+26|0);Ae(a+23|0,64);Ae(a+24|0,64);Ux(a+48|0,64);Ux(a+68|0,64);Ux(a+88|0,(b|0)==4096?255:64);c=a+108|0;b=0;while(1){a:{if(k[Pb(c,b)|0]){if(k[Pb(c,b)|0]<121){break a}}d=Pb(c,b),e=b+1|0,h[d|0]=e}b=b+1|0;if(b>>>0<128){continue}break}if(!qn(k[a+14|0])){h[a+14|0]=5}}function Ro(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=l[a+34>>1];if(!b){b=a;if(d&512){gM(a);d=l[a+34>>1]}i[b+34>>1]=d&65023;return}j[a>>2]=4;i[a+34>>1]=d&64958|512;Qo(a);b=k[c+8|0]|k[c+9|0]<<8|(k[c+10|0]<<16|k[c+11|0]<<24);h[a+76|0]=b;h[a+77|0]=b>>>8;h[a+78|0]=b>>>16;h[a+79|0]=b>>>24;b=k[c+4|0]|k[c+5|0]<<8|(k[c+6|0]<<16|k[c+7|0]<<24);c=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);h[a+68|0]=c;h[a+69|0]=c>>>8;h[a+70|0]=c>>>16;h[a+71|0]=c>>>24;h[a+72|0]=b;h[a+73|0]=b>>>8;h[a+74|0]=b>>>16;h[a+75|0]=b>>>24}function jK(a,b,c,d){var e=0,f=0,g=0;e=Za-16|0;Za=e;a:{b:{c:{f=!d;d=c>>31;d=d+c^d;if(f|(d|0)<224){break c}mb(e+8|0,a+1074308|0,3);if(kb(e+8|0)){break c}if(!(h[(p(b,896)+a|0)+1075856|0]&1)){break a}c=p((c>>31)+((c|0)>0)|0,d&15);c=(d|0)>239?c<<2:c;break b}if(h[(p(b,896)+a|0)+1075856|0]&1){mb(e+8|0,a+1074308|0,3);if(!kb(e+8|0)){break a}}c=c<<2}if(!c){break a}d=rx(a,b);if(!d){break a}f=d;a=j[(p(b,896)+a|0)+1075640>>2];g=13;d:{if(!a){break d}g=k[a+33|0]}bb[j[j[d>>2]+80>>2]](f,c,g<<24>>24,b)}Za=e+16|0}function ZF(a){var b=0,c=0,d=0,e=0;b=Za-160|0;Za=b;a=mm(b+16|0,a,8);d=j[j[a>>2]-12>>2];j[114626]=0;c=T(122)|0;e=j[114626];j[114626]=0;a:{if((e|0)==1){break a}j[114626]=0;I(123,b+8|0,d+(b+16|0)|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}wb(b+8|0);j[114626]=0;d=E(173,a|0,b+4|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[j[d>>2]-12>>2];j[114626]=0;d=H(174,c+d|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2];Xe(a);Za=b+160|0;return d?0:c}b=D()|0;C()|0;Xe(a);G(b|0);z()}function We(a,b,c,d,e,f){var g=0,h=0,i=0,k=0;a:{if(f&64){d=b;e=f+ -64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;i=f;d=f&31;if((f&63)>>>0>=32){h=g<<d;k=0}else{h=(1<<d)-1&g>>>32-d|e<<d;k=g<<d}d=c;g=b;f=64-f|0;e=f&31;if((f&63)>>>0>=32){f=0;d=d>>>e|0}else{f=d>>>e|0;d=((1<<e)-1&d)<<32-e|g>>>e}d=k|d;e=f|h;f=b;b=i&31;if((i&63)>>>0>=32){h=f<<b;b=0}else{h=(1<<b)-1&f>>>32-b|c<<b;b=f<<b}c=h}j[a>>2]=b;j[a+4>>2]=c;j[a+8>>2]=d;j[a+12>>2]=e}function H8(a){var b=0,c=0,d=0,e=0,f=0;b=Za-160|0;Za=b;a=mm(b+16|0,a,8);c=j[j[a>>2]-12>>2];j[114626]=0;d=T(122)|0;e=j[114626];j[114626]=0;a:{if((e|0)==1){break a}j[114626]=0;I(123,b+8|0,c+(b+16|0)|0,d|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}wb(b+8|0);j[114626]=0;c=E(179,a|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[j[c>>2]-12>>2];j[114626]=0;c=H(174,c+d|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}f=o[b>>3];Xe(a);Za=b+160|0;return c?0:f}b=D()|0;C()|0;Xe(a);G(b|0);z()}function Wpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>4;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){lb(k[b|0]);lb(k[b+1|0]);lb(k[b+2|0]);lb(k[b+3|0]);lb(k[b+4|0]);lb(k[b+5|0]);f=a,g=lb(k[b+6|0])|lb(k[b+7|0])<<8,i[f>>1]=g;lb(k[b+8|0]);lb(k[b+9|0]);lb(k[b+10|0]);lb(k[b+11|0]);lb(k[b+12|0]);lb(k[b+13|0]);f=a,g=lb(k[b+14|0])|lb(k[b+15|0])<<8,i[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<4}function Vpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>4;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){lb(k[b+7|0]);lb(k[b+6|0]);lb(k[b+5|0]);lb(k[b+4|0]);lb(k[b+3|0]);lb(k[b+2|0]);f=a,g=lb(k[b+1|0])|lb(k[b|0])<<8,i[f>>1]=g;lb(k[b+15|0]);lb(k[b+14|0]);lb(k[b+13|0]);lb(k[b+12|0]);lb(k[b+11|0]);lb(k[b+10|0]);f=a,g=lb(k[b+9|0])|lb(k[b+8|0])<<8,i[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<4}function lKa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,m=0;f=Za-32|0;Za=f;j[f+28>>2]=c;g=yb(b,c<<1);a:{if(!g){break a}kc(f+28|0,65535);bg(a,l[f+28>>1]);h=f,m=Lb(a),j[h+16>>2]=m;h=f,m=Mb(a),j[h+8>>2]=m;if(!rb(f+16|0,f+8|0)){break a}while(1){a=j[f+16>>2];Sz(b,f+24|0);c=f+24|0;c=k[c|0]|k[c+1|0]<<8;c=(c<<24|c<<8&16711680)>>>16|0;i[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}i[a>>1]=c}je(f+16|0);if(rb(f+16|0,f+8|0)){continue}break}}Za=f+32|0;return g|0}function M9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Za-32|0;Za=b;a:{b:{if(Qh(a)){eo(b+24|0);break b}om(b+8|0,a);j[114626]=0;F(2167,b+24|0,b+8|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}Ye(b+8|0)}c=a+36|0;c:{if(Qh(a)){break c}c=j[b+24>>2]}a=j[a+8>>2];d:{if((a|0)==-1){e=b,f=Lb(c),j[e+8>>2]=f;e=b,f=Mb(c),j[e>>2]=f;if(!rb(b+8|0,b)){break d}while(1){d=o[j[b+8>>2]>>3]+d;fk(b+8|0);if(rb(b+8|0,b)){continue}break}break d}d=o[yc(c,a)>>3]}Gj(b+24|0);Za=b+32|0;return+d}a=D()|0;C()|0;Ye(b+8|0);G(a|0);z()}function P1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;a:{b:{c:{if((a|0)!=(b|0)){d:{e:{f=k[a|0];if((f|0)!=45){break e}a=a+1|0;if((b|0)!=(a|0)){break e}break d}h=j[114600];j[114600]=0;a=_u(a,e+12|0,d,Wd());d=ab;g=j[114600];f:{if(g){if(j[e+12>>2]!=(b|0)){break f}if((g|0)==68){break c}break b}j[114600]=h;if(j[e+12>>2]==(b|0)){break b}}}}j[c>>2]=4;a=0;b=0;break a}j[c>>2]=4;a=-1;b=-1;break a}b=a;c=(f|0)==45;a=c?0-a|0:a;b=c?0-(d+((b|0)!=0)|0)|0:d}Za=e+16|0;ab=b;return a|0}function Bpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=q(0),g=0,h=q(0),l=0,m=0,o=0;e=Za-16|0;Za=e;j[e+8>>2]=c>>>2;j[e+4>>2]=j[a>>2];c=j[tb(e+8|0,e+4|0)>>2];h=n[d>>2];b=lb(b);if(c){a=j[a+20>>2];d=c;while(1){n[e+12>>2]=h*(WMa(2,k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24)),_Ma());Kd(e+12|0,q(-1));f=q(n[e+12>>2]*q(32768));n[e+12>>2]=f;l=a;f=Sd(f);a:{if(q(r(f))<q(2147483648)){g=~~f;break a}g=-2147483648}m=l,o=Dc(g),i[m>>1]=o;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}Za=e+16|0;return c<<2}function Noa(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=Za-16|0;Za=c;j[c+8>>2]=b;d=j[a+8>>2];a:{if((j[a+480180>>2]&16392?1e4:32e4)>>>0<=b>>>0){b=j[a+480208>>2];mb(c,a+1074308|0,92);if((kb(c)|0)==((b&4096)>>>12|0)){break a}j[c>>2]=p(j[d+24>>2],1e4);g=a+1074420|0,h=j[tb(c+8|0,c)>>2],j[g>>2]=h;break a}if(k[a+480209|0]&16){break a}e=a+1074420|0;b=(b>>>0)/1e4|0;f=p(b&15,1e4);j[e>>2]=j[e>>2]+((b&240)==16?f:0-f|0);b=j[d+20>>2];d=j[d+24>>2];mb(c,a+1074308|0,8);wn(e,p(b,1e4),kb(c)?255e4:p(d,1e4))}Za=c+16|0}function f7(a,b,c,d,e){var f=0,g=0,h=0,k=0,l=0,m=0,n=0,p=0,q=0,s=0;h=Za-16|0;Za=h;if(e){m=c+16|0;while(1){k=0;if(d){while(1){g=zd(o[Jg(b,k,l)>>3]*134217728);f=Be(c,k);n=f;f=Vi(g)+(j[f>>2]>>1)|0;p=f;f=ar(m)+f&-4096;j[n>>2]=p-f;o[h+8>>3]=+(f|0)*7.450580596923828e-9;pf(h+8|0,-1,1);g=o[h+8>>3]*32768;o[h+8>>3]=g;g=zd(g);a:{if(r(g)<2147483648){f=~~g;break a}f=-2147483648}f=Dc(f);q=jm(a,k,l),s=f,i[q>>1]=s;k=k+1|0;if((k|0)!=(d|0)){continue}break}}l=l+1|0;if((l|0)!=(e|0)){continue}break}}Za=h+16|0}function aS(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;De(b);Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{if((f|0)==1){break a}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}j[114626]=0;L(414,d+8|0,3,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}ob(b,d+24|0);gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;lc(d+40|0);G(a|0);z()}function I7(a,b,c,d,e){var f=0,g=0,h=0,k=0,l=0,m=0,n=0,p=0,q=0,s=0;h=Za-16|0;Za=h;if(e){m=c+16|0;while(1){k=0;if(d){while(1){g=zd(o[Jg(b,k,l)>>3]*134217728);f=Be(c,k);n=f;f=Vi(g)+(j[f>>2]>>1)|0;p=f;f=ar(m)+f&-4096;j[n>>2]=p-f;o[h+8>>3]=+(f|0)*7.450580596923828e-9;pf(h+8|0,-1,1);g=o[h+8>>3]*32768;o[h+8>>3]=g;g=zd(g);a:{if(r(g)<2147483648){f=~~g;break a}f=-2147483648}f=Dc(f);q=lm(a,k,l),s=f,i[q>>1]=s;k=k+1|0;if((k|0)!=(d|0)){continue}break}}l=l+1|0;if((l|0)!=(e|0)){continue}break}}Za=h+16|0}function BR(a,b,c){var d=0,e=0,f=0;d=Za+ -64|0;Za=d;De(b);Ee(d+40|0,a,c);a=j[d+40>>2];j[114626]=0;e=H(412,d+40|0)|0;f=j[114626];j[114626]=0;a:{if((f|0)==1){break a}j[114626]=0;e=H(413,e|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}j[114626]=0;L(414,d+8|0,2,e|0,a|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}j[114626]=0;F(415,d+24|0,d+8|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}ob(b,d+24|0);gb(d+24|0);lc(d+40|0);Za=d- -64|0;return!c|(a|0)!=0}a=D()|0;C()|0;lc(d+40|0);G(a|0);z()}function Wl(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0;i=Za-16|0;Za=i;a:{b:{if(!a){break b}h=j[e+12>>2];g=c-b|0;if((g|0)>=1){g=g>>2;if((zl(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>=1){f=gD(i,b,f);h=zb(f);j[114626]=0;h=K(2469,a|0,h|0,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break a}pc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>=1){b=b>>2;if((zl(a,c,b)|0)!=(b|0)){break b}}fy(e);k=a}Za=i+16|0;return k|0}a=D()|0;C()|0;pc(f);G(a|0);z()}function xW(a){a=a|0;var b=0,c=0,d=0,e=0;b=Za-32|0;Za=b;c=Eb(b,7035);j[114626]=0;I(226,b+16|0,a|0,c|0);a=j[114626];j[114626]=0;a:{b:{c:{if((a|0)!=1){gb(c);if(cc(b+16|0)){break c}a=0;break a}d=D()|0;C()|0;gb(c);break b}a=0;while(1){d:{c=Zc(b+16|0,d);j[114626]=0;c=H(227,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=cc(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=D()|0;C()|0;Ok(b+16|0)}G(d|0);z()}Ok(b+16|0);Za=b+32|0;return a|0}function cM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,m=0,n=0,o=0,q=0;m=b?33:32;e=j[a+12>>2];g=j[a>>2]+p(e,62)|0;d=b?1:-1;n=p(e,d)<<1;f=j[a+8>>2]-1|0;c=f;while(1){if((e|0)>=1){o=p(c,e);q=j[a+4>>2];b=0;while(1){i[(b<<1)+g>>1]=l[(b+o<<1)+q>>1];b=b+1|0;if((e|0)!=(b|0)){continue}break}}a:{if(!((c|0)!=(f|0)|(d|0)<=0)){if(!k[a+16|0]){d=1;c=0;break a}d=-1;c=f-((f|0)!=0&k[a+17|0]!=0)|0;break a}if(!((d|0)>-1|c)){b=k[a+16|0];d=b?1:-1;c=b?0:f;break a}c=d+c|0}g=g+n|0;h=h+1|0;if((m|0)!=(h|0)){continue}break}}function SG(a){var b=q(0),c=q(0),d=q(0),e=q(0),f=q(0),g=0;LK(a+4208|0,n[a+4272>>2]);b=q(q(n[a+4208>>2]*q(15920))+q(80));g=xe(j[a+16>>2]);c=Yd(q(10),q(q(q(n[a+4216>>2]*q(30))+q(-15))*q(.02500000037252903)));b=q(q(b*q(6.2831854820251465))/q(g>>>0));d=EE(b);e=_n(b);d=q(d*M4(q(q(q(b*q(.02888113260269165))*q(q(n[a+4212>>2]*q(35))+q(1)))/d)));f=q(d/c);b=q(f+q(1));n[a+4236>>2]=q(q(1)-f)/b;e=q(q(e*q(-2))/b);n[a+4232>>2]=e;c=q(d*c);n[a+4228>>2]=q(q(1)-c)/b;n[a+4224>>2]=e;n[a+4220>>2]=q(c+q(1))/b}function Wva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0;b=Za-16|0;Za=b;i=j[a+24>>2];k=j[a+20>>2];l=j[a+16>>2];f=j[a+4>>2];e=f;g=j[a>>2];j[b+8>>2]=g;j[b+12>>2]=e;f=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=f;if(d){while(1){f=e+l|0;e=h[f|0];e=((p(h[f+1|0]-e|0,g>>>10&4194048)|0)/16384|0)+(e<<8)|0;j[c>>2]=j[c>>2]+p(e,k);j[c+4>>2]=j[c+4>>2]+p(e,i);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=j[b+8>>2];e=j[b+12>>2];continue}break}g=j[b+8>>2];e=j[b+12>>2]}j[a>>2]=g;j[a+4>>2]=e;Za=b+16|0}function S0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=Za-32|0;Za=a;j[a+24>>2]=37;j[a+28>>2]=0;vj(a+24|1,62198,1,j[c+4>>2]);h=j[c+4>>2];g=a-32|0;Za=g;i=Wd();j[a>>2]=e;j[a+4>>2]=f;e=h>>>9&1;f=Ke(g,e+23|0,i,a+24|0,a)+g|0;h=Tf(g,f,c);e=g-((e<<3)+187&240)|0;Za=e;hc(a+8|0,c);j[114626]=0;Z(2466,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=j[114626];j[114626]=0;if((f|0)!=1){wb(a+8|0);b=Wl(b,e,j[a+20>>2],j[a+16>>2],c,d);Za=a+32|0;return b|0}b=D()|0;C()|0;wb(a+8|0);G(b|0);z()}function Q0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=Za-32|0;Za=a;j[a+24>>2]=37;j[a+28>>2]=0;vj(a+24|1,62198,0,j[c+4>>2]);h=j[c+4>>2];g=a-32|0;Za=g;i=Wd();j[a>>2]=e;j[a+4>>2]=f;e=h>>>9&1;f=Ke(g,e+23|0,i,a+24|0,a)+g|0;h=Tf(g,f,c);e=g-((e<<3)+187&240)|0;Za=e;hc(a+8|0,c);j[114626]=0;Z(2466,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=j[114626];j[114626]=0;if((f|0)!=1){wb(a+8|0);b=Wl(b,e,j[a+20>>2],j[a+16>>2],c,d);Za=a+32|0;return b|0}b=D()|0;C()|0;wb(a+8|0);G(b|0);z()}function GMa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=vh(b,11882);a:{if(!e){break a}if(!yb(b,6)){break a}while(1){b:{d=hf(b);c:{if((d|0)==(nk(11887)|0)){break c}c=k[11892]|k[11893]<<8|(k[11894]<<16|k[11895]<<24);if(!(d&1616928864)|d&-2139062144){break c}if((c|0)!=(d|0)){break b}}cg(b,4);break a}c=1;g=Of(b);if(l[a+480192>>1]){while(1){f=j[(((c&65535)<<2)+a|0)+900380>>2];if(f){IMa(f,d,g,b)}c=c+1|0;if(l[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(yb(b,6)){continue}break}}return e|0}function Vva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0;b=Za-16|0;Za=b;h=j[a+24>>2];k=j[a+20>>2];l=j[a+16>>2];f=j[a+4>>2];e=f;g=j[a>>2];j[b+8>>2]=g;j[b+12>>2]=e;f=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=f;if(d){while(1){f=(e<<1)+l|0;e=i[f>>1];e=e+((p(i[f+2>>1]-e|0,g>>>18|0)|0)/16384|0)|0;j[c>>2]=j[c>>2]+p(e,k);j[c+4>>2]=j[c+4>>2]+p(e,h);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=j[b+8>>2];e=j[b+12>>2];continue}break}g=j[b+8>>2];e=j[b+12>>2]}j[a>>2]=g;j[a+4>>2]=e;Za=b+16|0}function G5(a,b,c,d,e,f){var g=0,h=0,i=0,l=q(0),m=0,o=0,p=q(0),r=q(0),s=0;h=k[c|0];if(h){s=k[d+1|0]&8?7:64;m=c;while(1){o=k[d+3|0]&32;a:{b:{if(j[((i>>>0)%3<<2)+e>>2]>=(i|0)){break b}g=k[b+i|0];if(g>>>0>=s>>>0){break b}p=o?q(1.4142135381698608):q(1);c:{if(k[d+1|0]&8){g=g<<3;l=n[g+48656>>2];r=n[(g|4)+48656>>2];break c}l=Iv(q(1),g+1>>>1<<f);g=g&1;r=g?q(1):l;l=g?l:q(1)}E5(a,h,q(l*p),q(r*p));break a}if(!o){break a}YE(a,h)}a=(k[m|0]<<2)+a|0;i=i+1|0;m=i+c|0;h=k[m|0];if(h){continue}break}}}function W1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=k[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=j[114600];j[114600]=0;a=_u(a,e+12|0,d,Wd());d=ab;g=j[114600];g:{if(g){if(j[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}j[114600]=h;if(j[e+12>>2]==(b|0)){break d}}}}j[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}j[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}Za=e+16|0;return a&65535}function qK(a,b){var c=0,d=0,e=0;a:{b:{if(!k[b+866|0]|j[a+480180>>2]!=1){break b}d=j[b+104>>2];if(!d){break b}if(!ke(d)|(l[d+34>>1]&3)!=2){break b}c=k[b+867|0]+k[(k[b+866|0]&15)+21408|0]|0;h[b+867|0]=c;if(c<<24>>24>-1){break b}h[b+867|0]=0;c=j[b+784>>2]+1|0;j[b+784>>2]=c>>>0<j[d+8>>2]-j[d+4>>2]>>>0?c:0;c=j[d+20>>2];j[114626]=0;c=H(466,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break a}b=lb(c)+(j[b+784>>2]+j[d+4>>2]|0)|0;h[b|0]=k[b|0]^-1;Sx(d,a,0)}return}a=J(0)|0;C()|0;ib(a);z()}function ida(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;j[114626]=0;N(2008,a|0);h=j[114626];j[114626]=0;a:{b:{if((h|0)!=1){h=j[a+24>>2];j[114626]=0;b=ia(2025,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35378,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function fda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;j[114626]=0;N(2008,a|0);h=j[114626];j[114626]=0;a:{b:{if((h|0)!=1){h=j[a+24>>2];j[114626]=0;b=ia(2028,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35467,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function hwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0;b=Za-16|0;Za=b;g=j[a+24>>2];h=j[a+20>>2];k=j[a+16>>2];e=j[a+4>>2];f=j[a>>2];j[b+8>>2]=f;j[b+12>>2]=e;l=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=l;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;f=i[e+2>>1];j[c>>2]=j[c>>2]+p(i[e>>1],h);j[c+4>>2]=j[c+4>>2]+p(f,g);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=j[b+8>>2];e=j[b+12>>2];continue}break}f=j[b+8>>2];e=j[b+12>>2]}j[a>>2]=f;j[a+4>>2]=e;Za=b+16|0}function _ba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;j[114626]=0;N(2081,a|0);f=j[114626];j[114626]=0;a:{b:{if((f|0)!=1){f=j[a+28>>2];g=j[j[f>>2]+72>>2];j[114626]=0;b=Ra(g|0,f|0,b|0,c|0,+d,+e)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,38080,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=-1}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Cqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,l=0,m=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d+8>>2]=j[a>>2];g=j[tb(d+8|0,d+12|0)>>2];j[d+8>>2]=j[a>>2];j[d+4>>2]=j[d+12>>2]-g;i=j[tb(d+8|0,d+4|0)>>2];c=lb(b);if(g){e=j[a+20>>2];f=g;while(1){l=e,m=lb(k[c|0])^128,h[l|0]=m;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=lb(b);if(i){c=b+j[a>>2]|0;e=j[a+20>>2]+1|0;f=i;while(1){l=e,m=lb(k[c|0])^128,h[l|0]=m;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}Za=d+16|0;return g+i|0}function Bqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,l=0,m=0;e=Za-16|0;Za=e;j[e+12>>2]=c;j[e+8>>2]=j[a>>2];i=j[tb(e+8|0,e+12|0)>>2];j[e+8>>2]=j[a>>2];j[e+4>>2]=j[e+12>>2]-i;l=j[tb(e+8|0,e+4|0)>>2];c=lb(b);if(i){f=j[a+20>>2];g=i;m=d;while(1){m=lb(k[c|0])+m|0;h[f|0]=m;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=lb(b);if(l){c=b+j[a>>2]|0;f=j[a+20>>2]+1|0;g=l;while(1){d=lb(k[c|0])+d|0;h[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}Za=e+16|0;return i+l|0}function iwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0;b=Za-16|0;Za=b;g=j[a+24>>2];i=j[a+20>>2];k=j[a+16>>2];e=j[a+4>>2];f=j[a>>2];j[b+8>>2]=f;j[b+12>>2]=e;l=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=l;if(d){while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+k|0;f=h[e+1|0];j[c>>2]=j[c>>2]+(p(h[e|0],i)<<8);j[c+4>>2]=j[c+4>>2]+(p(f,g)<<8);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=j[b+8>>2];e=j[b+12>>2];continue}break}f=j[b+8>>2];e=j[b+12>>2]}j[a>>2]=f;j[a+4>>2]=e;Za=b+16|0}function E$(a,b,c){var d=0,e=0,f=0,g=0;f=Za-16|0;Za=f;d=nb(a);e=lq(a);g=Ks(b,c);a:{if(!g){break a}if(nz(b,zb(a),zb(a)+(nb(a)<<2)|0)){d=Za-16|0;Za=d;lD(f,b,c);Za=d+16|0;b=f;c=zb(b);d=nb(b);j[114626]=0;K(2492,a|0,c|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){pc(b);break a}a=D()|0;C()|0;pc(b);G(a|0);z()}if(e-d>>>0<g>>>0){WB(a,e,(d+g|0)-e|0,d,d)}e=zb(a)+(d<<2)|0;while(1){if((b|0)!=(c|0)){ze(e,b);b=b+4|0;e=e+4|0;continue}break}j[f>>2]=0;ze(e,f);Ag(a,d+g|0)}Za=f+16|0;return a}function z7(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];e=j[d+24>>2];j[c+40>>2]=j[d+20>>2];j[c+44>>2]=e;e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;ih(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];e=j[c+76>>2];j[c+24>>2]=j[c+72>>2];j[c+28>>2]=e;e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;x7(c+16|0,c,b,a,f);Za=c+80|0}function y7(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];e=j[d+24>>2];j[c+40>>2]=j[d+20>>2];j[c+44>>2]=e;e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;ih(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];e=j[c+76>>2];j[c+24>>2]=j[c+72>>2];j[c+28>>2]=e;e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;v7(c+16|0,c,b,a,f);Za=c+80|0}function bma(a,b){a=a|0;b=b|0;var c=0;b=78400;$la(a);a:{while(1){b:{if(!ad(a)){if(!Mh(j[b+8>>2],j[Ri(a)>>2])){break b}}j[114626]=0;F(1509,a|0,b+8|0);c=j[114626];j[114626]=0;if((c|0)!=1){break b}break a}b=b+12|0;if((b|0)!=78916){continue}break}b=78928;while(1){c:{if(!ad(a)){if(!Mh(j[b+8>>2],j[Ri(a)>>2])){break c}}j[114626]=0;F(1509,a|0,b+8|0);c=j[114626];j[114626]=0;if((c|0)!=1){break c}break a}b=b+12|0;if((b|0)!=78976){continue}break}return}b=D()|0;C()|0;Tw(a);G(b|0);z()}function Uv(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];e=j[d+24>>2];j[c+40>>2]=j[d+20>>2];j[c+44>>2]=e;e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;ih(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];e=j[c+76>>2];j[c+24>>2]=j[c+72>>2];j[c+28>>2]=e;e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;P7(c+16|0,c,b,a,f);Za=c+80|0}function Tv(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];e=j[d+24>>2];j[c+40>>2]=j[d+20>>2];j[c+44>>2]=e;e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;ih(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];e=j[c+76>>2];j[c+24>>2]=j[c+72>>2];j[c+28>>2]=e;e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;J7(c+16|0,c,b,a,f);Za=c+80|0}function Sv(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];e=j[d+24>>2];j[c+40>>2]=j[d+20>>2];j[c+44>>2]=e;e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;ih(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];e=j[c+76>>2];j[c+24>>2]=j[c+72>>2];j[c+28>>2]=e;e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;w7(c+16|0,c,b,a,f);Za=c+80|0}function S7(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];e=j[d+24>>2];j[c+40>>2]=j[d+20>>2];j[c+44>>2]=e;e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;ih(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];e=j[c+76>>2];j[c+24>>2]=j[c+72>>2];j[c+28>>2]=e;e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;Q7(c+16|0,c,b,a,f);Za=c+80|0}function R7(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];e=j[d+24>>2];j[c+40>>2]=j[d+20>>2];j[c+44>>2]=e;e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;ih(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];e=j[c+76>>2];j[c+24>>2]=j[c+72>>2];j[c+28>>2]=e;e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;O7(c+16|0,c,b,a,f);Za=c+80|0}function N7(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];e=j[d+24>>2];j[c+40>>2]=j[d+20>>2];j[c+44>>2]=e;e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;ih(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];e=j[c+76>>2];j[c+24>>2]=j[c+72>>2];j[c+28>>2]=e;e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;L7(c+16|0,c,b,a,f);Za=c+80|0}function M7(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];e=j[d+24>>2];j[c+40>>2]=j[d+20>>2];j[c+44>>2]=e;e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;ih(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];e=j[c+76>>2];j[c+24>>2]=j[c+72>>2];j[c+28>>2]=e;e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;I7(c+16|0,c,b,a,f);Za=c+80|0}function C7(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];e=j[d+24>>2];j[c+40>>2]=j[d+20>>2];j[c+44>>2]=e;e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;ih(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];e=j[c+76>>2];j[c+24>>2]=j[c+72>>2];j[c+28>>2]=e;e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;A7(c+16|0,c,b,a,f);Za=c+80|0}function Al(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0;i=Za-16|0;Za=i;a:{b:{if(!a){break b}g=j[e+12>>2];h=c-b|0;if((h|0)>=1){if((zl(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>=1){f=gj(i,b,f);g=zb(f);j[114626]=0;g=K(28,a|0,g|0,b|0)|0;h=j[114626];j[114626]=0;if((h|0)==1){break a}gb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>=1){if((zl(a,c,b)|0)!=(b|0)){break b}}fy(e);k=a}Za=i+16|0;return k|0}a=D()|0;C()|0;gb(f);G(a|0);z()}function $q(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];e=j[d+24>>2];j[c+40>>2]=j[d+20>>2];j[c+44>>2]=e;e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;ih(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];e=j[c+76>>2];j[c+24>>2]=j[c+72>>2];j[c+28>>2]=e;e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;B7(c+16|0,c,b,a,f);Za=c+80|0}function sba(a){var b=0,c=0,d=0;b=Za-160|0;Za=b;c=Eb(b+120|0,38211);j[114626]=0;I(6,b+104|0,1,20681);d=j[114626];j[114626]=0;a:{b:{c:{d:{e:{if((d|0)!=1){j[114626]=0;I(3,b+136|0,c|0,b+104|0);d=j[114626];j[114626]=0;if((d|0)==1){break e}j[114626]=0;V(2109,b+88|0,a|0,1,38204,b+136|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}gb(b+136|0);gb(b+104|0);break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;break c}a=D()|0;C()|0;gb(b+136|0)}gb(b+104|0)}gb(c);G(a|0);z()}gb(c);Za=b+160|0}function sQ(a,b){a=a|0;b=b|0;var c=0,d=0;d=k[a+3|0];a:{if(d>>>0>18){break a}d=1<<d;b:{if(!(d&126991)){if(d&396800){break b}break a}if(!k[a|0]){break a}}c:{d:{switch(k[a+3|0]){case 10:case 17:case 18:c=8;break c;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:c=k[a|0];if(!(c&7)){break c};case 11:c=k[a+3|0];return p(fz(a),b+1>>>1|0)+(((c|0)==11)<<4)|0;case 9:break d;default:break c}}c=16}d=k[a+3|0];c=p(fz(a),p(c>>>3|0,b))+(((d|0)==11)<<4)|0}return c|0}function c1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=Za-32|0;Za=a;j[a+24>>2]=37;j[a+28>>2]=0;vj(a+24|1,62198,1,j[c+4>>2]);h=j[c+4>>2];g=a-32|0;Za=g;i=Wd();j[a>>2]=e;j[a+4>>2]=f;f=Ke(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=Tf(g,f,c);e=g-48|0;Za=e;hc(a+8|0,c);j[114626]=0;Z(2457,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=j[114626];j[114626]=0;if((f|0)!=1){wb(a+8|0);b=Al(b,e,j[a+20>>2],j[a+16>>2],c,d);Za=a+32|0;return b|0}b=D()|0;C()|0;wb(a+8|0);G(b|0);z()}function a1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=Za-32|0;Za=a;j[a+24>>2]=37;j[a+28>>2]=0;vj(a+24|1,62198,0,j[c+4>>2]);h=j[c+4>>2];g=a-32|0;Za=g;i=Wd();j[a>>2]=e;j[a+4>>2]=f;f=Ke(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=Tf(g,f,c);e=g-48|0;Za=e;hc(a+8|0,c);j[114626]=0;Z(2457,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=j[114626];j[114626]=0;if((f|0)!=1){wb(a+8|0);b=Al(b,e,j[a+20>>2],j[a+16>>2],c,d);Za=a+32|0;return b|0}b=D()|0;C()|0;wb(a+8|0);G(b|0);z()}function jN(a){var b=0;a:{if((k[a+44|0]|k[a+45|0]<<8|(k[a+46|0]<<16|k[a+47|0]<<24))!=1179472976|k[a+28|0]!=26|k[a+30|0]>2){break a}b=a+40|0;if(k[b|0]|k[b+1|0]<<8){break a}b=a+38|0;if(!(k[b|0]|k[b+1|0]<<8)|(k[b|0]|k[b+1|0]<<8)>>>0>32){break a}b=a+32|0;if(!(k[b|0]|k[b+1|0]<<8)|(k[b|0]|k[b+1|0]<<8)>>>0>256){break a}b=a+34|0;if(!(k[b|0]|k[b+1|0]<<8)|(k[b|0]|k[b+1|0]<<8)>>>0>255){break a}a=a+36|0;if(!(k[a|0]|k[a+1|0]<<8)){break a}return(k[a|0]|k[a+1|0]<<8)>>>0<129}return 0}function ina(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Za-32|0;Za=c;a:{if((b-1&65535)>>>0>3998){break a}f=1;e=(p(b,104)+a|0)+484380|0;if(!ke(e)){break a}g=a+1304360|0;d=a+1074984|0;while(1){if(j[d+104>>2]==(e|0)){j[d+76>>2]=0;j[d>>2]=0;j[d+4>>2]=0;j[d+16>>2]=0}d=d+896|0;if((g|0)!=(d|0)){continue}break}Om(e);j[e>>2]=0;a=(p(b,104)+a|0)+484414|0;i[a>>1]=l[a>>1]&65470;j[c+24>>2]=0;j[c+8>>2]=0;j[c+16>>2]=0;j[c+20>>2]=0;j[c>>2]=0;j[c+4>>2]=0;Ro(e,0,c)}Za=c+32|0;return f|0}function g7(a,b,c,d,e){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0;g=Za-16|0;Za=g;if(e){l=c+4|0;while(1){h=0;if(d){while(1){f=o[Jg(b,h,j)>>3];Pb(c,h);m=g,n=+(Vi(zd(f*134217728))-1024+((br(l)^-2147483648)>>>21)|0)*7.450580596923828e-9,o[m+8>>3]=n;pf(g+8|0,-1,1);f=o[g+8>>3]*32768;o[g+8>>3]=f;f=zd(f);a:{if(r(f)<2147483648){k=~~f;break a}k=-2147483648}k=Dc(k);m=jm(a,h,j),p=k,i[m>>1]=p;h=h+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}Za=g+16|0}function J7(a,b,c,d,e){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0;g=Za-16|0;Za=g;if(e){l=c+4|0;while(1){h=0;if(d){while(1){f=o[Jg(b,h,j)>>3];Pb(c,h);m=g,n=+(Vi(zd(f*134217728))-1024+((br(l)^-2147483648)>>>21)|0)*7.450580596923828e-9,o[m+8>>3]=n;pf(g+8|0,-1,1);f=o[g+8>>3]*32768;o[g+8>>3]=f;f=zd(f);a:{if(r(f)<2147483648){k=~~f;break a}k=-2147483648}k=Dc(k);m=lm(a,h,j),p=k,i[m>>1]=p;h=h+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}Za=g+16|0}function T5(a,b,c,d){var e=0,f=0,g=0,l=0,m=0,n=0,o=0;f=Za-16|0;Za=f;m=k[c+14|0];g=m+k[c+13|0]|0;H5(a+2304|0,j[c>>2],g,f+4|0);if(k[c+13|0]){e=j[f+12>>2];l=j[f+8>>2];n=j[f+4>>2];l=(l|0)>(n|0)?l:n;e=(e|0)>(l|0)?e:l;j[f+12>>2]=e;j[f+8>>2]=e;j[f+4>>2]=e}m=m?3:1;l=g-m|0;e=0;while(1){n=e+l|0;g=n-m|0;o=k[d+1|0]<<28>>31&3;a:{if((g|0)<=j[(f+4|0)+(e<<2)>>2]){break a}o=k[b+g|0]}g=o;h[b+n|0]=g;e=e+1|0;if((m|0)!=(e|0)){continue}break}G5(a,b,j[c>>2],d,f+4|0,i[c+36>>1]&1);Za=f+16|0}function Dqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,l=0,m=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d+8>>2]=j[a>>2];g=j[tb(d+8|0,d+12|0)>>2];j[d+8>>2]=j[a>>2];j[d+4>>2]=j[d+12>>2]-g;i=j[tb(d+8|0,d+4|0)>>2];c=lb(b);if(g){e=j[a+20>>2];f=g;while(1){l=e,m=Fm(k[c|0]),h[l|0]=m;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=lb(b);if(i){c=b+j[a>>2]|0;e=j[a+20>>2]+1|0;f=i;while(1){l=e,m=Fm(k[c|0]),h[l|0]=m;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}Za=d+16|0;return g+i|0}function bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;j[114626]=0;N(2081,a|0);e=j[114626];j[114626]=0;a:{b:{if((e|0)!=1){e=j[a+28>>2];f=j[j[e>>2]+12>>2];j[114626]=0;b=P(f|0,e|0,b|0,c|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37764,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=-1}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Tq(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!c|!(a&3)){break c}e=b&255;while(1){if((e|0)==k[a|0]){break b}a=a+1|0;c=c-1|0;d=(c|0)!=0;if(!c){break c}if(a&3){continue}break}}if(!d){break a}}d:{if(k[a|0]==(b&255)|c>>>0<4){break d}d=p(b&255,16843009);while(1){e=d^j[a>>2];if((e^-1)&e-16843009&-2139062144){break d}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}b=b&255;while(1){if((b|0)==k[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;j[114626]=0;N(2081,a|0);e=j[114626];j[114626]=0;a:{b:{if((e|0)!=1){e=j[a+28>>2];f=j[j[e>>2]+8>>2];j[114626]=0;b=P(f|0,e|0,b|0,c|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37721,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=-1}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function uE(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0;h=j[a+104>>2];b=(h<<3)+a|0;c=((h+7>>>0)%12<<3)+a|0;f=j[c>>2];e=j[c+4>>2];i=j[a+96>>2];k=j[a+100>>2];a:{if(!(i|k)){g=j[b+4>>2];d=g;c=j[b>>2];l=(d|0)==(e|0)&c>>>0>f>>>0|e>>>0<d>>>0;break a}g=j[b+4>>2];d=g;c=j[b>>2];l=(d|0)==(e|0)&c>>>0>=f>>>0|e>>>0<d>>>0}d=f-i|0;j[b>>2]=d-c;j[b+4>>2]=e-((f>>>0<i>>>0)+k|0)-((c>>>0>d>>>0)+g)&65535;j[a+104>>2]=(h+1>>>0)%12;j[a+96>>2]=l;j[a+100>>2]=0;ab=j[b+4>>2];return j[b>>2]}function Yba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;j[114626]=0;N(2081,a|0);d=j[114626];j[114626]=0;e=1;a:{b:{if((d|0)!=1){d=j[a+28>>2];f=j[j[d>>2]+64>>2];j[114626]=0;I(f|0,d|0,b|0,(c|0)!=0|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,38026,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();e=0}return e|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Wba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;j[114626]=0;N(2081,a|0);d=j[114626];j[114626]=0;e=1;a:{b:{if((d|0)!=1){d=j[a+28>>2];f=j[j[d>>2]+56>>2];j[114626]=0;I(f|0,d|0,b|0,(c|0)!=0|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37978,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();e=0}return e|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Uh(a,b,c,d);j[a>>2]=80992;d=Ij(a+4208|0);j[a+4240>>2]=0;j[a+4244>>2]=0;c=xe(c);j[a+4260>>2]=0;j[a+4256>>2]=c;j[a+4236>>2]=0;c=a+4228|0;j[c>>2]=1048576e3;j[c+4>>2]=1048576e3;j[a+4220>>2]=1056964608;j[a+4224>>2]=1056964608;j[114626]=0;K(1632,a+44|0,2,2)|0;c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;N(1633,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}return a|0}a=D()|0;C()|0;xf(d);we(b);G(a|0);z()}function kD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=k[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=j[114600];j[114600]=0;a=_u(a,e+12|0,d,Wd());d=ab;g=j[114600];g:{if(g){if(j[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}j[114600]=h;if(j[e+12>>2]==(b|0)){break d}}}}j[c>>2]=4;a=0;break a}if(!d){break b}}j[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}Za=e+16|0;return a|0}function eLa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,m=0;f=Za-32|0;Za=f;j[f+28>>2]=c;g=yb(b,c<<1);a:{if(!g){break a}kc(f+28|0,65535);bg(a,l[f+28>>1]);h=f,m=Lb(a),j[h+16>>2]=m;h=f,m=Mb(a),j[h+8>>2]=m;if(!rb(f+16|0,f+8|0)){break a}while(1){a=j[f+16>>2];Sz(b,f+24|0);c=f+24|0;c=k[c|0]|k[c+1|0]<<8;i[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}i[a>>1]=c}je(f+16|0);if(rb(f+16|0,f+8|0)){continue}break}}Za=f+32|0;return g|0}function Cj(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!j[j[21215]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){h[a+1|0]=b&63|128;h[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344?b>>>0>=55296:0)){h[a+2|0]=b&63|128;h[a|0]=b>>>12|224;h[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){h[a+3|0]=b&63|128;h[a|0]=b>>>18|240;h[a+2|0]=b>>>6&63|128;h[a+1|0]=b>>>12&63|128;return 4}}j[114600]=25;a=-1}else{a=1}return a|0}h[a|0]=b;return 1}function sJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Za-560|0;Za=d;i[d+558>>1]=b;a:{b:{if((b-1&65535)>>>0>254){break b}f=((b<<2)+a|0)+900380|0;e=j[f>>2];c:{if(e){b=lM(d,c);Vma(e,b);Ns(b);break c}b=lg(556);if(!b){e=0;j[f>>2]=0;break b}j[114626]=0;e=E(1428,b|0,c|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}j[((l[d+558>>1]<<2)+a|0)+900380>>2]=b}g=a,h=l[ui(a+480192|0,d+558|0)>>1],i[g+480192>>1]=h}Za=d+560|0;return e|0}a=D()|0;C()|0;Cb(b);G(a|0);z()}function Upa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=q(0),g=0,h=0,l=0,m=0;e=Za-16|0;Za=e;j[e+8>>2]=c>>>2;j[e+4>>2]=j[a>>2];d=j[tb(e+8|0,e+4|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){j[e+12>>2]=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);Kd(e+12|0,q(-1));f=q(n[e+12>>2]*q(32768));n[e+12>>2]=f;h=a;f=Sd(f);a:{if(q(r(f))<q(2147483648)){g=~~f;break a}g=-2147483648}l=h,m=Dc(g),i[l>>1]=m;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<2}function rKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-32|0;Za=d;JJa(a);e=a;a:{b:{c:{d:{while(1){j[114626]=0;a=E(258,b|0,8)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}if(!a){break c}j[114626]=0;I(512,d+8|0,b|0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[114626]=0;F(513,e|0,d+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}Re(d+8|0);continue}break}a=D()|0;C()|0;break a}a=D()|0;C()|0;Re(d+8|0);break a}Za=d+32|0;return}a=D()|0;C()|0}Gz(e);G(a|0);z()}function eIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-32|0;Za=d;NHa(a);e=a;a:{b:{c:{d:{while(1){j[114626]=0;a=E(258,b|0,8)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}if(!a){break c}j[114626]=0;I(599,d+8|0,b|0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[114626]=0;F(600,e|0,d+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}Re(d+8|0);continue}break}a=D()|0;C()|0;break a}a=D()|0;C()|0;Re(d+8|0);break a}Za=d+32|0;return}a=D()|0;C()|0}pz(e);G(a|0);z()}function GEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-32|0;Za=d;ODa(a);e=a;a:{b:{c:{d:{while(1){j[114626]=0;a=E(258,b|0,6)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}if(!a){break c}j[114626]=0;I(757,d+8|0,b|0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[114626]=0;F(758,e|0,d+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}Re(d+8|0);continue}break}a=D()|0;C()|0;break a}a=D()|0;C()|0;Re(d+8|0);break a}Za=d+32|0;return}a=D()|0;C()|0}Qy(e);G(a|0);z()}function oGa(a,b){var c=0,d=0,e=0,f=0,g=0;e=Za-16|0;Za=e;a:{if(Rs(a)){j[b>>2]=0;a=0;break a}f=Vg(a,e,16);d=lb(k[e|0]);c=d&127;j[b>>2]=c;d=d<<24>>24;b:{if(!(f>>>0<2|(d|0)>-1)){d=c?32-s(c)|0:0;c=1;while(1){g=lb(k[c+e|0]);j[b>>2]=g&127|j[b>>2]<<7;d=d+7|0;c=c+1|0;if((f|0)==(c|0)){Jb(a,f);f=Vg(a,e,16);c=0}g=g<<24>>24;if((g|0)<0?c>>>0<f>>>0:0){continue}break}Jb(a,c);a=(g|0)<0;if(d>>>0<33){break b}j[b>>2]=-1;a=0;break a}Jb(a,1);a=(d|0)<0}a=a^1}Za=e+16|0;return a}function jH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Uh(a,b,c,d);j[a>>2]=80352;c=Ij(a+4260|0);j[a+4232>>2]=1061997773;d=a+4224|0;j[d>>2]=1061158912;j[d+4>>2]=1059082943;d=a+4216|0;j[d>>2]=1038174126;j[d+4>>2]=1065353216;j[a+4208>>2]=1056964608;j[a+4212>>2]=1036831949;j[114626]=0;K(1632,a+44|0,2,2)|0;d=j[114626];j[114626]=0;a:{if((d|0)==1){break a}j[114626]=0;N(1633,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}return a|0}a=D()|0;C()|0;xf(c);we(b);G(a|0);z()}function _ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-32|0;Za=d;e=Ow(a);a:{b:{c:{d:{while(1){j[114626]=0;a=E(258,b|0,8)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}if(!a){break c}j[114626]=0;I(1547,d+8|0,b|0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[114626]=0;F(1548,e|0,d+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}Re(d+8|0);continue}break}a=D()|0;C()|0;break a}a=D()|0;C()|0;Re(d+8|0);break a}Za=d+32|0;return}a=D()|0;C()|0}Vk(e);G(a|0);z()}function Uba(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;j[114626]=0;N(2081,a|0);d=j[114626];j[114626]=0;e=1;a:{b:{if((d|0)!=1){d=j[a+28>>2];f=j[j[d>>2]+48>>2];j[114626]=0;Ta(f|0,d|0,b|0,+c);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37940,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();e=0}return e|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function xca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;j[114626]=0;N(2008,a|0);f=j[114626];j[114626]=0;a:{b:{if((f|0)!=1){f=j[a+24>>2];j[114626]=0;b=U(2063,f|0,b|0,c|0,d|0,e|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36668,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function jda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;j[114626]=0;N(2008,a|0);f=j[114626];j[114626]=0;a:{b:{if((f|0)!=1){f=j[a+24>>2];j[114626]=0;b=U(2024,f|0,b|0,c|0,d|0,e|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35351,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function gda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;j[114626]=0;N(2008,a|0);f=j[114626];j[114626]=0;a:{b:{if((f|0)!=1){f=j[a+24>>2];j[114626]=0;b=U(2027,f|0,b|0,c|0,d|0,e|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35434,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function uza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-32|0;Za=d;e=ny(a);a:{b:{c:{d:{while(1){j[114626]=0;a=E(258,b|0,8)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}if(!a){break c}j[114626]=0;I(968,d+8|0,b|0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[114626]=0;F(969,e|0,d+8|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}Re(d+8|0);continue}break}a=D()|0;C()|0;break a}a=D()|0;C()|0;Re(d+8|0);break a}Za=d+32|0;return}a=D()|0;C()|0}gl(e);G(a|0);z()}function Vv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!er(b)){break a}a=a+24|0;if(!tg(j[a>>2]+484344|0,b&65535)){break a}b=Ib(j[a>>2]+484344|0,b);if((d|0)<0|j[b+12>>2]<=(c|0)|(c|0)<0|(l[j[a>>2]+480188>>1]<=(d|0)|e>>>0>5)){break a}a=Se(b,c,d&65535);b:{switch(e|0){case 0:f=k[a|0];break a;case 1:f=k[a+1|0];break a;case 2:f=k[a+2|0];break a;case 3:f=k[a+3|0];break a;case 4:f=k[a+4|0];break a;case 5:break b;default:break a}}f=k[a+5|0]}return f|0}function kL(a,b){var c=0,d=0,e=0,f=0;i[a+24>>1]=0;j[a+20>>2]=0;j[a>>2]=0;j[a+4>>2]=0;j[a+8>>2]=0;j[a+12>>2]=0;e=a;d=3546895/+(b>>>0);c=d*.25;a:{if(r(c)<2147483648){b=~~c;break a}b=-2147483648}j[e+16>>2]=b;c=(d- +(b<<2))*4294967296;b:{if(r(c)<0x8000000000000000){f=~~c>>>0;b=r(c)>=1?c>0?~~t(v(c*2.3283064365386963e-10),4294967295)>>>0:~~w((c- +(~~c>>>0>>>0))*2.3283064365386963e-10)>>>0:0;break b}b=-2147483648}j[a>>2]=0;j[a+4>>2]=0;j[a+8>>2]=f;j[a+12>>2]=b}function N$(a,b,c){var d=0,e=0,f=0,g=0;f=Za-32|0;Za=f;d=nb(a);e=sc(a);g=ti(b,c);a:{if(!g){break a}if(nz(b,zb(a),zb(a)+nb(a)|0)){b=Zh(f+16|0,b,c);c=zb(b);d=nb(b);j[114626]=0;K(2484,a|0,c|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){gb(b);break a}a=D()|0;C()|0;gb(b);G(a|0);z()}if(e-d>>>0<g>>>0){tl(a,e,(d+g|0)-e|0,d,d,0,0)}e=zb(a)+d|0;while(1){if((b|0)!=(c|0)){Td(e,b);b=b+1|0;e=e+1|0;continue}break}h[f+15|0]=0;Td(e,f+15|0);Ag(a,d+g|0)}Za=f+32|0;return a}function dR(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=j[a+1060>>2];if((b|0)>255){break a}while(1){f=(p(b,6)+a|0)+1068|0,g=ij(a,7),h[f|0]=g;d=ij(a,1);e=ij(a,1);c=j[a+1056>>2];if((c|0)>255){break a}b=j[a+1060>>2]+1|0;j[a+1056>>2]=b;j[a+1060>>2]=b;b:{if(d){i[(p(c,6)+a|0)+1064>>1]=b;dR(a);b=j[a+1060>>2];break b}i[(p(c,6)+a|0)+1064>>1]=65535}j[a+1056>>2]=b;if(e){i[(p(c,6)+a|0)+1066>>1]=b;if((b|0)<=255){continue}break a}break}i[(p(c,6)+a|0)+1066>>1]=65535}}function XB(a,b,c,d,e,f,g,h){var i=0,k=0,l=0;i=Za-16|0;Za=i;if((b^-1)+1073741807>>>0>=c>>>0){k=zb(a);a:{if(b>>>0<536870887){j[i+8>>2]=b<<1;j[i+12>>2]=b+c;c=Ql(j[Gc(i+12|0,i+8|0)>>2]);break a}c=1073741806}l=c+1|0;c=Ak(l);if(e){Jh(c,k,e)}if(g){Jh(c+(e<<2)|0,h,g)}d=d-f|0;h=d-e|0;if(h){e=e<<2;Jh((e+c|0)+(g<<2)|0,(e+k|0)+(f<<2)|0,h)}b=b+1|0;if((b|0)!=2){Kn(k,b)}lf(a,c);jg(a,l);b=a;a=d+g|0;ee(b,a);j[i+4>>2]=0;ze(c+(a<<2)|0,i+4|0);Za=i+16|0;return}kg();z()}function fla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,l=0,m=0,n=0;c=Za-32|0;Za=c;ila(a+33|0,b);l=b+236|0;e=a+27|0;while(1){f=0;g=(a+d|0)+33|0;if(k[g|0]<(k[e|0]|k[e+1|0]<<8)>>>0){f=k[g|0]}m=Oc(l,d+12|0),n=f,i[m>>1]=n;d=d+1|0;if((d|0)!=96){continue}break}on(c,3,a+4|0);qc(c+16|0,c);j[114626]=0;E(369,b+492|0,c+16|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){gb(c+16|0);if(!k[a+241|0]){h[b+30|0]=k[a+26|0]}Za=c+32|0;return}a=D()|0;C()|0;gb(c+16|0);G(a|0);z()}function Tb(a,b){var c=0,d=0,e=0;a:{b:{c=j[a+1396>>2];if((c|0)>=0){c:{if((b|0)>(c|0)){if((b|0)>=25){break b}if(!c){j[a+1392>>2]=0}while(1){c=-1;e=Xq(a);d=0;if((e|0)==-1){break c}d=j[a+1396>>2];c=d+8|0;j[a+1396>>2]=c;j[a+1392>>2]=j[a+1392>>2]+(e<<d);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}d=j[a+1392>>2];j[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}j[a+1396>>2]=c}return d}return Tb(a,24)+(Tb(a,b-24|0)<<24)|0}X(50550,50496,1617,50569);z()}function $4(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=q(0);g=e-c|0;i=d-b|0;e=(g|0)/(i|0)|0;f=(d|0)>(f|0)?f:d;a:{if((f|0)<=(b|0)){break a}d=(b<<2)+a|0;n[d>>2]=n[d>>2]*n[((c&255)<<2)+50880>>2];d=b+1|0;if((f|0)<=(d|0)){break a}b=0;j=g>>31;j=p((e|0)<0?e:0-e|0,i)+(j+g^j)|0;g=(g|0)<0?-1:1;while(1){h=(d<<2)+a|0;k=h;l=n[h>>2];b=b+j|0;h=(b|0)<(i|0);c=(c+e|0)+(h?0:g)|0;n[k>>2]=l*n[((c&255)<<2)+50880>>2];b=b-(h?0:i)|0;d=d+1|0;if((f|0)!=(d|0)){continue}break}}}function zia(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-144|0;Za=c;d=Lg(c+8|0);e=j[j[d>>2]-12>>2];j[114626]=0;f=T(122)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;I(123,c|0,e+(c+8|0)|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}wb(c);j[114626]=0;F(134,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(125,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Hd(d);Za=c+144|0;return}a=D()|0;C()|0;Hd(d);G(a|0);z()}function ria(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-144|0;Za=c;d=Lg(c+8|0);e=j[j[d>>2]-12>>2];j[114626]=0;f=T(122)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;I(123,c|0,e+(c+8|0)|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}wb(c);j[114626]=0;F(135,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(125,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Hd(d);Za=c+144|0;return}a=D()|0;C()|0;Hd(d);G(a|0);z()}function oja(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-144|0;Za=c;d=Lg(c+8|0);e=j[j[d>>2]-12>>2];j[114626]=0;f=T(122)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;I(123,c|0,e+(c+8|0)|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}wb(c);j[114626]=0;F(131,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(125,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Hd(d);Za=c+144|0;return}a=D()|0;C()|0;Hd(d);G(a|0);z()}function _ha(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-144|0;Za=c;d=Lg(c+8|0);e=j[j[d>>2]-12>>2];j[114626]=0;f=T(122)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;I(123,c|0,e+(c+8|0)|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}wb(c);j[114626]=0;F(136,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(125,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Hd(d);Za=c+144|0;return}a=D()|0;C()|0;Hd(d);G(a|0);z()}function Oia(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-144|0;Za=c;d=Lg(c+8|0);e=j[j[d>>2]-12>>2];j[114626]=0;f=T(122)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;I(123,c|0,e+(c+8|0)|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}wb(c);j[114626]=0;F(133,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(125,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Hd(d);Za=c+144|0;return}a=D()|0;C()|0;Hd(d);G(a|0);z()}function Mba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;j[114626]=0;N(2081,a|0);c=j[114626];j[114626]=0;d=1;a:{b:{if((c|0)!=1){c=j[a+28>>2];e=j[j[c>>2]+20>>2];j[114626]=0;F(e|0,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37818,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=0}return d|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;j[114626]=0;N(2081,a|0);c=j[114626];j[114626]=0;d=1;a:{b:{if((c|0)!=1){c=j[a+28>>2];e=j[j[c>>2]+16>>2];j[114626]=0;F(e|0,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37800,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=0}return d|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Eja(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-144|0;Za=c;d=Lg(c+8|0);e=j[j[d>>2]-12>>2];j[114626]=0;f=T(122)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;I(123,c|0,e+(c+8|0)|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}wb(c);j[114626]=0;F(130,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(125,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Hd(d);Za=c+144|0;return}a=D()|0;C()|0;Hd(d);G(a|0);z()}function $ba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;j[114626]=0;N(2081,a|0);c=j[114626];j[114626]=0;d=1;a:{b:{if((c|0)!=1){c=j[a+28>>2];e=j[j[c>>2]+76>>2];j[114626]=0;F(e|0,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,38090,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=0}return d|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function cI(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-144|0;Za=c;d=Lg(c+8|0);e=j[j[d>>2]-12>>2];j[114626]=0;f=T(122)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;I(123,c|0,e+(c+8|0)|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}wb(c);j[114626]=0;F(132,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(125,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Hd(d);Za=c+144|0;return}a=D()|0;C()|0;Hd(d);G(a|0);z()}function Sba(a,b){a=a|0;b=+b;var c=0,d=0,e=0;j[114626]=0;N(2081,a|0);c=j[114626];j[114626]=0;d=1;a:{b:{if((c|0)!=1){c=j[a+28>>2];e=j[j[c>>2]+40>>2];j[114626]=0;fa(e|0,c|0,+b);c=j[114626];j[114626]=0;if((c|0)!=1){break b}}d=J(0)|0;C()|0;O(d|0)|0;j[114626]=0;L(1982,37904,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=0}return d|0}a=D()|0;C()|0;j[114626]=0;M(20);d=j[114626];j[114626]=0;if((d|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Qw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=Za-48|0;Za=f;a:{if(!c){c=_b(a,b);a=j[d+12>>2];j[c+8>>2]=j[d+8>>2];j[c+12>>2]=a;a=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=a;break a}e=j[d+12>>2];j[f+24>>2]=j[d+8>>2];j[f+28>>2]=e;g=j[d+4>>2];e=f;j[e+16>>2]=j[d>>2];j[e+20>>2]=g;g=c>>>1|0;Qw(a,b,g,e+16|0);nh(e+32|0,d,_b(a,c));d=j[e+44>>2];j[e+8>>2]=j[e+40>>2];j[e+12>>2]=d;d=j[e+36>>2];j[e>>2]=j[e+32>>2];j[e+4>>2]=d;Qw(a,b|c,g,e)}Za=f+48|0}function Qba(a,b){a=a|0;b=+b;var c=0,d=0,e=0;j[114626]=0;N(2081,a|0);c=j[114626];j[114626]=0;d=1;a:{b:{if((c|0)!=1){c=j[a+28>>2];e=j[j[c>>2]+32>>2];j[114626]=0;fa(e|0,c|0,+b);c=j[114626];j[114626]=0;if((c|0)!=1){break b}}d=J(0)|0;C()|0;O(d|0)|0;j[114626]=0;L(1982,37870,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=0}return d|0}a=D()|0;C()|0;j[114626]=0;M(20);d=j[114626];j[114626]=0;if((d|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Nba(a,b){a=a|0;b=+b;var c=0,d=0,e=0;j[114626]=0;N(2081,a|0);c=j[114626];j[114626]=0;d=1;a:{b:{if((c|0)!=1){c=j[a+28>>2];e=j[j[c>>2]+24>>2];j[114626]=0;fa(e|0,c|0,+b);c=j[114626];j[114626]=0;if((c|0)!=1){break b}}d=J(0)|0;C()|0;O(d|0)|0;j[114626]=0;L(1982,37836,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=0}return d|0}a=D()|0;C()|0;j[114626]=0;M(20);d=j[114626];j[114626]=0;if((d|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Hw(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-144|0;Za=c;d=Lg(c+8|0);e=j[j[d>>2]-12>>2];j[114626]=0;f=T(122)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;I(123,c|0,e+(c+8|0)|0,f|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}wb(c);j[114626]=0;F(124,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(125,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Hd(d);Za=c+144|0;return}a=D()|0;C()|0;Hd(d);G(a|0);z()}function kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;j[114626]=0;N(2008,a|0);e=j[114626];j[114626]=0;a:{b:{if((e|0)!=1){e=j[a+24>>2];j[114626]=0;b=P(2023,e|0,b|0,c|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35326,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;j[114626]=0;N(2008,a|0);e=j[114626];j[114626]=0;a:{b:{if((e|0)!=1){e=j[a+24>>2];j[114626]=0;b=P(2026,e|0,b|0,c|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35403,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;j[114626]=0;N(2008,a|0);e=j[114626];j[114626]=0;a:{b:{if((e|0)!=1){e=j[a+24>>2];j[114626]=0;b=P(2029,e|0,b|0,c|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35498,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;j[114626]=0;N(2008,a|0);e=j[114626];j[114626]=0;a:{b:{if((e|0)!=1){e=j[a+24>>2];j[114626]=0;b=P(2030,e|0,b|0,c|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35537,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;j[114626]=0;N(2008,a|0);e=j[114626];j[114626]=0;a:{b:{if((e|0)!=1){e=j[a+24>>2];j[114626]=0;b=P(2031,e|0,b|0,c|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35574,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;j[114626]=0;N(2008,a|0);e=j[114626];j[114626]=0;a:{b:{if((e|0)!=1){e=j[a+24>>2];j[114626]=0;b=P(2032,e|0,b|0,c|0,d|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35619,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Vba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;j[114626]=0;N(2081,a|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){c=j[a+28>>2];e=j[j[c>>2]+52>>2];j[114626]=0;d=+Sa(e|0,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37959,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=0}return+d}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function U9(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=Za-16|0;Za=h;a:{b:{c:{if(!(g?!(!f|(!d|!e)):0)){b=R(8)|0;j[114626]=0;c=E(85,h|0,38690)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}Rh(a,b,4);c=_v(a,c,d,e,f,g);o[a+16>>3]=+(c>>>0)/+(b|0)+o[a+16>>3];Za=h+16|0;return c|0}a=D()|0;C()|0;S(b|0)}G(a|0)}z()}function R9(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=Za-16|0;Za=h;a:{b:{c:{if(!(g?!(!f|(!d|!e)):0)){b=R(8)|0;j[114626]=0;c=E(85,h|0,38690)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}Rh(a,b,4);c=Zv(a,c,d,e,f,g);o[a+16>>3]=+(c>>>0)/+(b|0)+o[a+16>>3];Za=h+16|0;return c|0}a=D()|0;C()|0;S(b|0)}G(a|0)}z()}function nE(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;h=-1;f=d&2147483647;i=f;g=c;a:{if(!c&(f|0)==2147418112?a|b:(f|0)==2147418112&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;j=f;if((f|0)==2147418112?0:f>>>0>2147418112){break a}if(!(a|g|(i|j|b))){return 0}g=d&e;if((g|0)>0?1:(g|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c)!=0|(d^e|b)!=0}if(!c&(d|0)==(e|0)?a|b:(d|0)>(e|0)?1:(d|0)>=(e|0)?c:0){break a}h=(a|c)!=0|(d^e|b)!=0}return h}function gma(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;j[c+12>>2]=j[a+4>>2];j[c+8>>2]=j[b+4>>2];a:{b:{if(!j[tb(c+12|0,c+8|0)>>2]){break b}while(1){e=po(h[fc(a,d)|0]);f=po(h[fc(b,d)|0]);if((e|0)!=(f|0)){d=(e&255)>>>0<(f&255)>>>0?-1:1;break a}if(e){j[c+12>>2]=j[a+4>>2];j[c+8>>2]=j[b+4>>2];d=d+1|0;if(d>>>0>=m[tb(c+12|0,c+8|0)>>2]){break b}continue}break}d=0;break a}d=0;if(j[a+4>>2]==j[b+4>>2]){break a}d=m[a+4>>2]<m[b+4>>2]?-1:1}Za=c+16|0;return d}function eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;hc(a,b);j[114626]=0;I(128,d+8|0,b|0,c|0);e=j[114626];j[114626]=0;a:{if((e|0)==1){break a}wb(d+8|0);j[114626]=0;e=H(27,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}if(e){j[114626]=0;b=H(27,b|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break a}j[114626]=0;I(129,d|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}wb(d)}Za=d+16|0;return}b=D()|0;C()|0;wb(a);G(b|0);z()}function Zba(a,b){a=a|0;b=b|0;var c=0,d=0;j[114626]=0;N(2081,a|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){c=j[a+28>>2];d=j[j[c>>2]+68>>2];j[114626]=0;b=E(d|0,c|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,38053,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=-1}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Xba(a,b){a=a|0;b=b|0;var c=0,d=0;j[114626]=0;N(2081,a|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){c=j[a+28>>2];d=j[j[c>>2]+60>>2];j[114626]=0;b=E(d|0,c|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,38002,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=-1}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function lp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,m=0;f=Za-32|0;Za=f;j[f+28>>2]=c;g=yb(b,c);a:{if(!g){break a}kc(f+28|0,65535);bg(a,l[f+28>>1]);h=f,m=Lb(a),j[h+16>>2]=m;h=f,m=Mb(a),j[h+8>>2]=m;if(!rb(f+16|0,f+8|0)){break a}while(1){a=j[f+16>>2];KHa(b,f+27|0);c=k[f+27|0];i[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}i[a>>1]=c}je(f+16|0);if(rb(f+16|0,f+8|0)){continue}break}}Za=f+32|0;return g|0}function jla(a,b,c){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=Za+ -64|0;Za=f;while(1){h=+(g-4096|0)*.0001220703125;e=0;d=0;while(1){j=kla(d,h,b,c);o[(d<<3)+f>>3]=j;e=j+e;d=d+1|0;if((d|0)!=8){continue}break}e=1/e;l=g<<3;d=0;while(1){m=(d+l<<1)+a|0;h=u(t(v(o[(d<<3)+f>>3]*32768*e+.5),32768),-32768);a:{if(r(h)<2147483648){k=~~h;break a}k=-2147483648}i[m>>1]=k;d=d+1|0;if((d|0)!=8){continue}break}g=g+1|0;if((g|0)!=8193){continue}break}Za=f- -64|0}function HI(a){var b=0;a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=1163089229){break a}b=a+4|0;if((k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))!=-1095062050?(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))!=-1346458146:0){break a}b=a+16|0;if(!(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))){break a}a=a+8|0;return((k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))+24|0)==(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))}return 0}function NH(a){var b=0,c=0,d=0,e=0;c=Za-32|0;Za=c;a:{b:{if(Hj(a)>>>0<=Te(a)>>>0){break b}b=hb(a);d=Te(a);e=Te(a);j[114626]=0;b=P(1636,c+8|0,d|0,e|0,b|0)|0;d=j[114626];j[114626]=0;c:{d:{if((d|0)!=1){j[114626]=0;F(1637,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}zr(b);break b}a=J(0)|0;C()|0;break c}a=J(0)|0;C()|0;zr(b)}O(a|0)|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)==1){break a}}Za=c+32|0;return}a=J(0)|0;C()|0;ib(a);z()}function LH(a){var b=0,c=0,d=0,e=0;c=Za-32|0;Za=c;a:{b:{if(jd(a)>>>0<=sb(a)>>>0){break b}b=hb(a);d=sb(a);e=sb(a);j[114626]=0;b=P(1638,c+8|0,d|0,e|0,b|0)|0;d=j[114626];j[114626]=0;c:{d:{if((d|0)!=1){j[114626]=0;F(1639,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}yr(b);break b}a=J(0)|0;C()|0;break c}a=J(0)|0;C()|0;yr(b)}O(a|0)|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)==1){break a}}Za=c+32|0;return}a=J(0)|0;C()|0;ib(a);z()}function nEa(a,b){var c=0,d=0,e=0,f=0;d=Za-16|0;Za=d;h[b+12|0]=0;vP(b);WDa(b);c=k[a+1|0];a:{if(!c){break a}f=0-c|0;while(1){h[d+7|0]=64;f=(f<<16>>16)+c|0;VDa(b,ep(d+8|0,f&65535,k[Yb(((e<<1)+a|0)+2|0,d+7|0)|0]));e=e+1|0;if((e|0)==15){break a}c=k[((e<<1)+a|0)+1|0];if(c){continue}break}}c=k[a+32|0];h[b+14|0]=c>>>4;h[b+13|0]=c&15;a=k[a+31|0];c=a&15;h[b+15|0]=c;h[b+16|0]=c;if(a&16){h[b+12|0]=k[b+12|0]|4}if(a&32){h[b+12|0]=k[b+12|0]|2}Za=d+16|0}function Uh(a,b,c,d){var e=0,f=0;j[a+20>>2]=d;j[a+16>>2]=c;j[a+12>>2]=b;j[a+4>>2]=0;j[a+8>>2]=0;j[a>>2]=79872;c=a+24|0;j[c>>2]=0;j[c+4>>2]=0;j[c+16>>2]=0;j[c+8>>2]=0;j[c+12>>2]=0;Kga(a+44|0);j[a+4196>>2]=1065353216;j[a+4200>>2]=0;b=0;i[a+4204>>1]=0;j[c>>2]=a+99&-8;e=j[a+20>>2];d=j[a+16>>2];if((e|0)!=(d+906300|0)){f=a+4200|0;while(1){a:{c=b+1|0;if(b>>>0>247){break a}b=c;if((e|0)!=((p(c,160)+d|0)+906300|0)){continue}}break}h[f|0]=c}return a}function q$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-160|0;Za=e;j[e+152>>2]=b;f=e+144|0;a:{b:while(1){if(c>>>0<d>>>0){j[e+8>>2]=c;if((bb[j[j[a>>2]+16>>2]](a,e+144|0,c,(d-c|0)>32?c+32|0:d,e+8|0,e+16|0,f,e+12|0)|0)==2){break a}b=e+16|0;if(j[e+8>>2]==(c|0)){break a}while(1)if(m[e+12>>2]<=b>>>0){c=j[e+8>>2];continue b}else{j[e+4>>2]=j[b>>2];VB(j[e+152>>2],j[e+4>>2]);b=b+4|0;continue}}break}Za=e+160|0;return j[e+152>>2]}Sl(62980);z()}function pW(a,b){a=a|0;b=b|0;var c=0;a=Qc(a);a:{if(k[b+16|0]){j[114626]=0;E(235,a|0,7065)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}}if(k[b+17|0]){j[114626]=0;E(235,a|0,7072)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}}if(Ec(a)){j[114626]=0;E(235,a|0,7079)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}}if(k[b+18|0]){j[114626]=0;E(235,a|0,7085)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}}return}b=D()|0;C()|0;gb(a);G(b|0);z()}function wM(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;a=Db(a);d=nb(b);j[114626]=0;F(111,a|0,d|0);d=j[114626];j[114626]=0;if((d|0)!=1){a:{e=c,f=nd(b),j[e+8>>2]=f;e=c,f=_e(b),j[e>>2]=f;if(rb(c+8|0,c)){while(1){b=k[j[c+8>>2]];b:{if((b|0)==13){j[114626]=0;F(110,a|0,10);break b}j[114626]=0;F(110,a|0,b<<24>>24)}b=j[114626];j[114626]=0;if((b|0)==1){break a}Xf(c+8|0);if(rb(c+8|0,c)){continue}break}}Za=c+16|0;return}}b=D()|0;C()|0;gb(a);G(b|0);z()}function Y4(a,b,c,d){var e=0,f=0,g=q(0);f=JE(a,b);a:{if((f|0)<0){break a}e=j[b>>2];a=(d|0)>(e|0)?e:d;f=p(e,f);if(k[b+22|0]){e=1;if((a|0)<1){break a}d=0;while(1){e=(d<<2)+c|0;g=q(n[j[b+28>>2]+(d+f<<2)>>2]+g);n[e>>2]=n[e>>2]+g;g=q(n[b+12>>2]+g);e=1;d=d+1|0;if((a|0)!=(d|0)){continue}break}break a}e=1;if((a|0)<1){break a}d=0;while(1){e=(d<<2)+c|0;n[e>>2]=n[e>>2]+n[j[b+28>>2]+(d+f<<2)>>2];e=1;d=d+1|0;if((a|0)!=(d|0)){continue}break}}return e}function Le(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0;e=Za-16|0;Za=e;g=so(a);f=e;i=e;a:{if(b){k=j[b+4>>2];h=j[b>>2];break a}h=so(a)}j[i+8>>2]=h;j[f+12>>2]=k;f=j[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;d=c>>>0>a>>>0?d+1|0:d;b=a;j[e>>2]=2048;j[e+4>>2]=0;a=bA(e+8|0,e);c=j[a>>2];a=j[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;c=j[e+12>>2];if((c|0)==(d|0)&b>>>0>m[e+8>>2]|c>>>0<d>>>0){break b}}a=1}Za=e+16|0;return a}function HO(a,b,c,d){var e=0,f=0;f=Za-16|0;Za=f;e=l[c>>1];while(1){a:{e=e<<1;i[c>>1]=e;h[b|0]=(e&65534)>>>0>255;e=k[c|0];i[c>>1]=e;if(!e){if(!re(a,f+15|0)){break a}e=k[f+15|0];i[c>>1]=e<<1|1;h[b|0]=e>>>7;i[c>>1]=k[c|0]}h[d|0]=k[b|0]+(k[d|0]<<1);e=l[c>>1]<<1;i[c>>1]=e;h[b|0]=(e&65534)>>>0>255;e=k[c|0];i[c>>1]=e;if(!e){if(!re(a,f+14|0)){break a}e=k[f+14|0];i[c>>1]=e<<1|1;h[b|0]=e>>>7;e=k[c|0];i[c>>1]=e}if(k[b|0]){continue}}break}Za=f+16|0}function lR(a){var b=0,c=0,d=0,e=0;c=Za-32|0;Za=c;a:{b:{if(Af(a)>>>0<=tc(a)>>>0){break b}b=hb(a);d=tc(a);e=tc(a);j[114626]=0;b=P(39,c+8|0,d|0,e|0,b|0)|0;d=j[114626];j[114626]=0;c:{d:{if((d|0)!=1){j[114626]=0;F(40,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break d}Et(b);break b}a=J(0)|0;C()|0;break c}a=J(0)|0;C()|0;Et(b)}O(a|0)|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)==1){break a}}Za=c+32|0;return}a=J(0)|0;C()|0;ib(a);z()}function Sca(a,b){a=a|0;b=b|0;var c=0,d=q(0);j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;d=q(da(2043,c|0,b|0));b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35973,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=q(0)}return q(d)}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}



function lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;j[114626]=0;N(2008,a|0);d=j[114626];j[114626]=0;e=1;a:{b:{if((d|0)!=1){d=j[a+24>>2];j[114626]=0;I(2022,d|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35294,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();e=0}return e|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function h3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-32|0;Za=d;j[d+16>>2]=b;e=j[a+48>>2];j[d+20>>2]=c-((e|0)!=0);f=j[a+44>>2];j[d+28>>2]=e;j[d+24>>2]=f;e=-1;a:{b:{if(!Oq(Ka(j[a+60>>2],d+16|0,2,d+12|0)|0)){e=j[d+12>>2];if((e|0)>0){break b}}j[a>>2]=j[a>>2]|e&48^16;break a}g=j[d+20>>2];if(g>>>0>=e>>>0){break a}f=j[a+44>>2];j[a+4>>2]=f;j[a+8>>2]=f+(e-g|0);if(j[a+48>>2]){j[a+4>>2]=f+1;h[(b+c|0)-1|0]=k[f|0]}e=c}Za=d+32|0;return e|0}function Aga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,l=0,m=0;d=Za-32|0;Za=d;f=j[c+12>>2];a:{if(!f){break a}g=h[c+16|0];e=nb(b);if(!e){break a}i=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(i|0)){if(k[Ub(b,0)|0]==43){break b}if(k[Ub(b,0)|0]==45){break b}}l=d,m=nd(b),j[l+8>>2]=m;l=d,m=$e(d+8|0,e-c|0),j[l+16>>2]=m;Cd(d+24|0,d+16|0);Yv(b,j[d+24>>2],1,g)}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Nc(a,b);Za=d+32|0}function pn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0;d=Za-32|0;Za=d;j[d+24>>2]=0;j[d+28>>2]=0;j[d+16>>2]=0;j[d+20>>2]=0;j[d+12>>2]=c;a:{if(c){while(1){j[d+8>>2]=16;e=j[tb(d+8|0,d+12|0)>>2];f=j[a>>2];if((e|0)!=((k=f,l=lb(d+16|0),m=j[a+8>>2]+g|0,n=e,i=j[j[f>>2]+28>>2],bb[i](k|0,l|0,m|0,n|0)|0)|0)){break a}if(Yc(d+16|0,b+g|0,e)){break a}f=j[d+12>>2]-e|0;j[d+12>>2]=f;g=e+g|0;if(f){continue}break}}Jb(a,c);h=1}Za=d+32|0;return h}function pba(a){var b=0,c=0,d=0;b=Za-48|0;Za=b;uB(b+16|0);j[114626]=0;c=E(2,b|0,39569)|0;d=j[114626];j[114626]=0;a:{b:{c:{d:{if((d|0)!=1){j[114626]=0;I(251,b+32|0,b+16|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break d}j[114626]=0;I(9,a|0,0,b+32|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}gb(b+32|0);gb(c);gb(b+16|0);Za=b+48|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;gb(b+32|0)}gb(c)}gb(b+16|0);G(a|0);z()}function oda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;j[114626]=0;N(2008,a|0);d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){d=j[a+24>>2];j[114626]=0;e=+ca(2018,d|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35224,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();e=0}return+e}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Uh(a,b,c,d);j[a>>2]=80584;c=Ij(a+4256|0);d=a+4224|0;j[d>>2]=1017370378;j[d+4>>2]=1065353216;d=a+4216|0;j[d>>2]=1028670828;j[d+4>>2]=1059760811;j[a+4208>>2]=1056964608;j[a+4212>>2]=1017370378;j[114626]=0;K(1632,a+44|0,2,2)|0;d=j[114626];j[114626]=0;a:{if((d|0)==1){break a}j[114626]=0;N(1633,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}return a|0}a=D()|0;C()|0;xf(c);we(b);G(a|0);z()}function _w(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;f=e;a:{if(!Wi(b)){c=_J(a,c,j[b+704>>2],d);break a}c=j[b+700>>2]}j[f+12>>2]=c;b=j[b+656>>2];b:{if(!b){break b}f=j[b+40>>2];if(!f){break b}d=(f|0)/2|0;b=j[a+1074420>>2];b=OMa(b,b>>31,c,c>>31);c=d+b|0;d=ab+(d>>31)|0;g=e,h=ic(PMa(c,b>>>0>c>>>0?d+1|0:d,f,f>>31),ab),j[g+12>>2]=h}kc(e+12|0,2147483647);a=PMa(0,j[e+12>>2],j[a+24620>>2]<<4,0);Za=e+16|0;return a|0}function Rca(a,b){a=a|0;b=b|0;var c=0,d=q(0);j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;d=q(da(2044,c|0,b|0));b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36016,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=q(0)}return q(d)}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Qca(a,b){a=a|0;b=b|0;var c=0,d=q(0);j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;d=q(da(2045,c|0,b|0));b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36059,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=q(0)}return q(d)}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Pca(a,b){a=a|0;b=b|0;var c=0,d=q(0);j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;d=q(da(2046,c|0,b|0));b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36103,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=q(0)}return q(d)}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Oca(a,b){a=a|0;b=b|0;var c=0,d=q(0);j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;d=q(da(2047,c|0,b|0));b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36151,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=q(0)}return q(d)}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Tba(a){a=a|0;var b=0,c=0,d=0;j[114626]=0;N(2081,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+28>>2];d=j[j[b>>2]+44>>2];j[114626]=0;c=+$(d|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37922,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();c=0}return+c}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Rba(a){a=a|0;var b=0,c=0,d=0;j[114626]=0;N(2081,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+28>>2];d=j[j[b>>2]+36>>2];j[114626]=0;c=+$(d|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37887,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();c=0}return+c}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Pba(a){a=a|0;var b=0,c=0,d=0;j[114626]=0;N(2081,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+28>>2];d=j[j[b>>2]+28>>2];j[114626]=0;c=+$(d|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37853,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();c=0}return+c}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function sna(a){var b=0,c=0;while(1){Pm((p(b,896)+a|0)+1074984|0,a,b&65535);b=b+1|0;if((b|0)!=256){continue}break}Si(a+1304360|0,1);j[a+1074444>>2]=j[a+480200>>2];b=a+1074416|0;j[b>>2]=j[a+480196>>2];j[a+1074420>>2]=j[a+480204>>2];j[a+480208>>2]=j[a+480208>>2]&-769;wx(a+1074376|0);i[a+1074440>>1]=0;c=a+1074428|0;j[c>>2]=0;j[c+4>>2]=0;c=a+1074396|0;j[c>>2]=0;j[c+4>>2]=0;j[a+1074376>>2]=0;j[a+1074380>>2]=0;j[a+1074392>>2]=j[b>>2]}function Yda(a){a=a|0;var b=0,c=0;b=Za-16|0;Za=b;a:{b:{if(!a){break b}a=Zb(b+8|0,a);j[114626]=0;c=j[a+4>>2];j[b>>2]=j[a>>2];j[b+4>>2]=c;a=H(1989,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break a}a=J(0)|0;C()|0;O(a|0)|0;j[114626]=0;L(1982,34236,0,0,0);a=j[114626];j[114626]=0;if((a|0)!=1){Q();break b}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}a=0}Za=b+16|0;return a|0}function qea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;h[a+4202|0]=1;b=di(q(q(xe(j[a+16>>2])>>>0)*q(.04500000178813934)));c=di(q(q(b>>>0)*q(1.1892070770263672)));d=di(q(q(c>>>0)*q(1.1892070770263672)));g=di(q(q(d>>>0)*q(1.1892070770263672)));e=di(q(q(b+d>>>0)*q(.11546666920185089)));f=di(q(q(c+g>>>0)*q(.11546666920185089)));j[a+4292>>2]=f;j[a+4288>>2]=e;j[a+4276>>2]=d-e;j[a+4272>>2]=b-e;j[a+4284>>2]=g-f;j[a+4280>>2]=c-f;QG(a);NG(a)}function J2(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=Za-16|0;Za=d;f=(ZMa(b),VMa(2));c=f&2147483647;a:{if(c-8388608>>>0<=2130706431){e=c;c=c>>>7|0;g=e<<25;c=c+1065353216|0;break a}if(c>>>0>=2139095040){c=f;e=c>>>7|0;g=c<<25;c=e|2147418112;break a}if(!c){c=0;break a}e=c;c=s(c);We(d,e,0,0,0,c+81|0);h=j[d>>2];i=j[d+4>>2];g=j[d+8>>2];c=j[d+12>>2]^65536|16265-c<<16}j[a>>2]=h;j[a+4>>2]=i;j[a+8>>2]=g;j[a+12>>2]=f&-2147483648|c;Za=d+16|0}function Sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=Uh(a,b,c,d);j[a>>2]=79464;d=Ij(a+4208|0);j[a+4220>>2]=0;j[a+4224>>2]=0;e=a,f=xe(c),j[e+4232>>2]=f;j[114626]=0;N(1631,a+4260|0);c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;K(1632,a+44|0,2,2)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}j[114626]=0;N(1633,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}return a|0}a=D()|0;C()|0;xf(d);we(b);G(a|0);z()}function Joa(a,b,c,d,e){var f=0,g=0;if(k[a+480209|0]&16){if((c&255)>>>0>=16){h[b+869|0]=(c&240)>>>4}a=c&15;if(a){h[b+870|0]=a}h[b+868|0]=k[b+869|0];return}c=k[b+868|0]-1|0;h[b+868|0]=c;a:{if(c&255){break a}h[b+868|0]=k[b+869|0];c=k[b+870|0];c=d?c:0-c|0;b:{if(Wi(b)){j[b+876>>2]=j[b+876>>2]+p(c,j[j[j[b+656>>2]+44>>2]+36>>2]);break b}f=b,g=Zf(a,Qr(a,j[b+700>>2],0,0)+c|0,8363,0),j[f+700>>2]=g}if(!e){break a}j[b>>2]=0;j[b+4>>2]=0}}function Fs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,i=0;d=(k[Pb(a,0)|0]&15)<<8|k[Pb(a,1)|0];a:{if(!d|(d|0)==4095){break a}e=108;while(1){f=l[(c<<1)+20848>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(l[(c<<1)+20846>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}h[b|0]=e;c=k[Pb(a,2)|0];g=b,i=k[Pb(a,0)|0]&16|c>>>4,h[g+1|0]=i;g=b,i=k[Pb(a,2)|0]&15,h[g+3|0]=i;g=b,i=k[Pb(a,3)|0],h[g+5|0]=i}function Mz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0;d=Za-32|0;Za=d;j[d+24>>2]=0;j[d+28>>2]=0;j[d+16>>2]=0;j[d+20>>2]=0;j[d+12>>2]=c;a:{if(c){while(1){j[d+8>>2]=16;e=j[tb(d+8|0,d+12|0)>>2];if((e|0)!=((k=a,l=lb(d+16|0),m=j[a+12>>2]+f|0,n=e,i=j[j[a>>2]+28>>2],bb[i](k|0,l|0,m|0,n|0)|0)|0)){break a}if(Yc(d+16|0,b+f|0,e)){break a}g=j[d+12>>2]-e|0;j[d+12>>2]=g;f=e+f|0;if(g){continue}break}}Fc(a,c);h=1}Za=d+32|0;return h}function vda(a,b){a=a|0;b=b|0;var c=0,d=0;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;d=1;a:{b:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;F(2011,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,34986,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=0}return d|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function vHa(a,b){var c=0;md(b,0);c=a+32|0;j[b>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+38|0;j[b+4>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+42|0;c=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);j[b+24>>2]=16726;j[b+8>>2]=c;i[b+30>>1]=k[a+37|0]<<4;if(h[a+46|0]&1){j[b>>2]=j[b>>2]>>>1;j[b+4>>2]=j[b+4>>2]>>>1;j[b+8>>2]=j[b+8>>2]>>>1}if(!(!(k[a+47|0]&8)|m[b+8>>2]<=m[b+4>>2])){i[b+34>>1]=l[b+34>>1]|2}}function tda(a,b){a=a|0;b=b|0;var c=0,d=0;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;d=1;a:{b:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;F(2013,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35052,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();d=0}return d|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function c4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=Za-16|0;Za=e;while(1){a:{if((c|0)<=(f|0)){break a}d=j[a+16>>2];g=j[a+12>>2];b:{if(d>>>0>g>>>0){j[e+12>>2]=2147483647;j[e+8>>2]=d-g>>2;j[e+4>>2]=c-f;d=j[Pd(e+12|0,Pd(e+8|0,e+4|0))>>2];Jh(b,j[a+12>>2],d);j[a+12>>2]=j[a+12>>2]+(d<<2);b=(d<<2)+b|0;break b}d=bb[j[j[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}j[b>>2]=d;d=1;b=b+4|0}f=d+f|0;continue}break}Za=e+16|0;return f|0}function bxa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;g=Za-48|0;Za=g;a:{b:{if(c>>>0>d>>>0){break b}if(me(b)>>>0<=d>>>0){break b}while(1){f=c&65535;if(th(te(b,f))){h=Lb(te(b,f));i=Mb(te(b,f));f=LM(g,e);j[114626]=0;L(1026,g+24|0,h|0,i|0,f|0);h=j[114626];j[114626]=0;if((h|0)==1){break a}Vd(g+24|0);Vd(f)}c=c+1|0;if((c&65535)>>>0<=d>>>0){continue}break}}KM(a,e);Za=g+48|0;return}a=D()|0;C()|0;Vd(f);G(a|0);z()}function l5(a){var b=0,c=0,d=0,e=0;Ab(a+36|0,255,2048);b=j[(k[a+23|0]?2092:4)+a>>2];if((b|0)>=1){b=(b|0)<32767?b:32767;e=(b|0)>1?b:1;d=j[a+8>>2];while(1){a:{if(k[c+d|0]>10){break a}b:{if(k[a+23|0]){b=Lk(j[j[a+2084>>2]+(c<<2)>>2]);break b}b=j[j[a+32>>2]+(c<<2)>>2]}if(b>>>0>1023){break a}while(1){i[((b<<1)+a|0)+36>>1]=c;d=j[a+8>>2];b=(1<<k[d+c|0])+b|0;if(b>>>0<1024){continue}break}}c=c+1|0;if((e|0)!=(c|0)){continue}break}}}function hba(a){var b=0,c=0,d=0;b=Za-48|0;Za=b;c=Eb(b+16|0,39574);j[114626]=0;F(2113,b|0,2);d=j[114626];j[114626]=0;a:{b:{c:{d:{if((d|0)!=1){j[114626]=0;I(3,b+32|0,c|0,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break d}j[114626]=0;I(9,a|0,0,b+32|0);a=j[114626];j[114626]=0;if((a|0)==1){break c}gb(b+32|0);gb(b);gb(c);Za=b+48|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;break b}a=D()|0;C()|0;gb(b+32|0)}gb(b)}gb(c);G(a|0);z()}function g4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,k=0;e=Za-16|0;Za=e;while(1){a:{if((c|0)<=(f|0)){break a}d=j[a+16>>2];g=j[a+12>>2];b:{if(d>>>0>g>>>0){j[e+12>>2]=2147483647;j[e+8>>2]=d-g;j[e+4>>2]=c-f;d=j[Pd(e+12|0,Pd(e+8|0,e+4|0))>>2];lh(b,j[a+12>>2],d);j[a+12>>2]=j[a+12>>2]+d;break b}d=bb[j[j[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}i=b,k=rm(d),h[i|0]=k;d=1}b=b+d|0;f=d+f|0;continue}break}Za=e+16|0;return f|0}function q7(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];j[c+40>>2]=j[d+20>>2];e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;km(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];j[c+24>>2]=j[c+72>>2];e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;o7(c+16|0,c,b,a,f);Za=c+80|0}function p7(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];j[c+40>>2]=j[d+20>>2];e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;km(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];j[c+24>>2]=j[c+72>>2];e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;l7(c+16|0,c,b,a,f);Za=c+80|0}function j7(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];j[c+40>>2]=j[d+20>>2];e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;km(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];j[c+24>>2]=j[c+72>>2];e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;h7(c+16|0,c,b,a,f);Za=c+80|0}function i7(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];j[c+40>>2]=j[d+20>>2];e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;km(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];j[c+24>>2]=j[c+72>>2];e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;f7(c+16|0,c,b,a,f);Za=c+80|0}function a7(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];j[c+40>>2]=j[d+20>>2];e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;co(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];j[c+24>>2]=j[c+72>>2];e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;Z6(c+16|0,c,b,a,f);Za=c+80|0}function _q(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];j[c+40>>2]=j[d+20>>2];e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;co(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];j[c+24>>2]=j[c+72>>2];e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;$6(c+16|0,c,b,a,f);Za=c+80|0}function X6(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];j[c+40>>2]=j[d+20>>2];e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;co(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];j[c+24>>2]=j[c+72>>2];e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;V6(c+16|0,c,b,a,f);Za=c+80|0}function W7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;yi(c,b);j[a+44>>2]=0;b=j[a+48>>2];if(b&8){d=a,e=zb(c)+nb(c)|0,j[d+44>>2]=e;sm(a,zb(c),zb(c),j[a+44>>2]);b=j[a+48>>2]}a:{if(!(b&16)){break a}b=nb(c);d=a,e=b+zb(c)|0,j[d+44>>2]=e;qm(c,sc(c));hw(a,zb(c),zb(c)+nb(c)|0);if(!(k[a+48|0]&3)){break a}b:{if((b|0)<=-1){c=b-2147483647|0;while(1){b=c;kr(a,2147483647);c=1;if((b|0)<0){continue}break}break b}if(!b){break a}}kr(a,b)}}function W6(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];j[c+40>>2]=j[d+20>>2];e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;co(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];j[c+24>>2]=j[c+72>>2];e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;T6(c+16|0,c,b,a,f);Za=c+80|0}function Rv(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];j[c+40>>2]=j[d+20>>2];e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;km(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];j[c+24>>2]=j[c+72>>2];e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;m7(c+16|0,c,b,a,f);Za=c+80|0}function Qv(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];j[c+40>>2]=j[d+20>>2];e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;km(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];j[c+24>>2]=j[c+72>>2];e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;g7(c+16|0,c,b,a,f);Za=c+80|0}function Ov(a,b){var c=0,d=0,e=0,f=0;c=Za-80|0;Za=c;d=j[a>>2];f=j[d+4>>2];j[c+40>>2]=j[d+20>>2];e=j[d+16>>2];j[c+32>>2]=j[d+12>>2];j[c+36>>2]=e;co(c- -64|0,c+32|0,f);d=Xd(c+48|0,j[j[a+4>>2]>>2],j[j[a+8>>2]>>2],j[j[a+12>>2]>>2]);f=j[j[a+12>>2]>>2];a=j[j[a+8>>2]>>2];j[c+24>>2]=j[c+72>>2];e=j[c+68>>2];j[c+16>>2]=j[c+64>>2];j[c+20>>2]=e;j[c+8>>2]=j[d+8>>2];e=j[d+4>>2];j[c>>2]=j[d>>2];j[c+4>>2]=e;U6(c+16|0,c,b,a,f);Za=c+80|0}function zca(a,b){a=a|0;b=b|0;var c=0;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;b=E(2061,c|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36599,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function yca(a,b){a=a|0;b=b|0;var c=0;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;b=E(2062,c|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36632,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function md(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-16|0;Za=d;Om(a);j[a+16>>2]=0;j[a+8>>2]=0;j[a+12>>2]=0;j[a>>2]=0;j[a+4>>2]=0;i[a+32>>1]=64;j[a+24>>2]=8363;j[a+28>>2]=16777344;j[a+36>>2]=0;h[a+39|0]=0;h[a+40|0]=0;h[a+41|0]=0;h[a+42|0]=0;c=l[a+34>>1]&-25151;i[a+34>>1]=(b|0)==4?c|32:c;b=Eb(d,18532);j[114626]=0;E(370,a+43|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){gb(b);gM(a);Za=d+16|0;return}a=D()|0;C()|0;gb(b);G(a|0);z()}function SH(a,b,c){var d=0,e=0;d=Za-16|0;Za=d;a:{if(sb(a)>>>0>511){break a}if(!mf(j[j[b>>2]-12>>2]+b|0)){break a}bia(d+8|0,b,c);b:{c:{if(!bd(d+8|0)){j[114626]=0;I(1624,d|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break c}dQ(d+8|0,ud(d));Jf(d)}if(!bd(d+8|0)){break b}e=j[d+8>>2];j[114626]=0;F(1625,a|0,d+8|0);a=j[114626];j[114626]=0;if((a|0)!=1){break b}}a=D()|0;C()|0;Jf(d+8|0);G(a|0);z()}Jf(d+8|0)}Za=d+16|0;return e}function IE(a){var b=q(0),c=0,d=q(0),e=q(0),f=q(0),g=q(0),h=0,i=q(0),j=0,k=0,l=q(0),m=q(0),o=q(0),p=q(0),r=0;j=a-24|0;b=n[j>>2];c=a-8|0;d=n[c>>2];e=q(b+d);k=a-16|0;f=n[k>>2];l=n[a>>2];g=q(f+l);n[a>>2]=e+g;n[c>>2]=g-e;c=a-28|0;g=n[c>>2];h=a-12|0;m=n[h>>2];e=q(g+m);r=h;h=a-20|0;i=n[h>>2];a=a-4|0;o=n[a>>2];p=q(i+o);n[r>>2]=p-e;i=q(o-i);b=q(d-b);n[c>>2]=i+b;d=q(m-g);f=q(l-f);n[k>>2]=d+f;n[j>>2]=f-d;n[a>>2]=p+e;n[h>>2]=i-b}function sAa(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+24|0]=0;h[a+25|0]=0;h[a+26|0]=0;h[a+27|0]=0;h[a+28|0]=0;h[a+29|0]=0;h[a+30|0]=0;h[a+31|0]=0;h[a+16|0]=0;h[a+17|0]=0;h[a+18|0]=0;h[a+19|0]=0;h[a+20|0]=0;h[a+21|0]=0;h[a+22|0]=0;h[a+23|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;h[a+15|0]=0;Za=b+16|0}function eca(a){a=a|0;var b=0;j[114626]=0;N(2081,a|0);b=j[114626];j[114626]=0;if((b|0)!=1){j[a+24>>2]=0;b=j[a+28>>2];if(b){bb[j[j[b>>2]+4>>2]](b)}j[a+28>>2]=0;b=j[a+20>>2];if(b){Cb(b);j[a+20>>2]=0}Cb(a);return}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37293,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)!=1){Q();return}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function uo(a,b,c){var d=0,e=0;a=Me(a);d=nb(b);j[114626]=0;F(113,a|0,d|0);d=j[114626];j[114626]=0;if((d|0)!=1){a:{if(nb(b)){while(1){d=k[Ub(b,e)|0];b:{if(d>>>0<256){d=j[(d<<2)+c>>2];j[114626]=0;F(112,a|0,d|0);d=j[114626];j[114626]=0;if((d|0)!=1){break b}break a}j[114626]=0;F(112,a|0,65533);d=j[114626];j[114626]=0;if((d|0)==1){break a}}e=e+1|0;if(nb(b)>>>0>e>>>0){continue}break}}return}}b=D()|0;C()|0;pc(a);G(b|0);z()}function qO(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+22|0]=0;h[a+23|0]=0;h[a+24|0]=0;h[a+25|0]=0;h[a+26|0]=0;h[a+27|0]=0;h[a+28|0]=0;h[a+29|0]=0;h[a+16|0]=0;h[a+17|0]=0;h[a+18|0]=0;h[a+19|0]=0;h[a+20|0]=0;h[a+21|0]=0;h[a+22|0]=0;h[a+23|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;h[a+15|0]=0;Za=b+16|0}function qda(a,b){a=a|0;b=+b;var c=0;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){c=j[a+24>>2];j[114626]=0;b=+Va(2016,c|0,+b);c=j[114626];j[114626]=0;if((c|0)!=1){break b}}c=J(0)|0;C()|0;O(c|0)|0;j[114626]=0;L(1982,35152,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return+b}a=D()|0;C()|0;j[114626]=0;M(20);c=j[114626];j[114626]=0;if((c|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function jwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0;b=Za-16|0;Za=b;g=j[a+24>>2];h=j[a+20>>2];k=j[a+16>>2];e=j[a+4>>2];f=j[a>>2];j[b+8>>2]=f;j[b+12>>2]=e;l=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=l;if(d){while(1){e=i[(e<<1)+k>>1];j[c>>2]=j[c>>2]+p(e,h);j[c+4>>2]=j[c+4>>2]+p(e,g);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=j[b+12>>2];continue}break}f=j[b+8>>2];e=j[b+12>>2]}j[a>>2]=f;j[a+4>>2]=e;Za=b+16|0}function V9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Za-16|0;Za=f;a:{b:{c:{if(!(e?d:0)){b=R(8)|0;j[114626]=0;c=E(85,f|0,38690)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}Rh(a,b,2);c=_v(a,c,d,e,0,0);o[a+16>>3]=+(c>>>0)/+(b|0)+o[a+16>>3];Za=f+16|0;return c|0}a=D()|0;C()|0;S(b|0)}G(a|0)}z()}function S9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Za-16|0;Za=f;a:{b:{c:{if(!(e?d:0)){b=R(8)|0;j[114626]=0;c=E(85,f|0,38690)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}Rh(a,b,2);c=Zv(a,c,d,e,0,0);o[a+16>>3]=+(c>>>0)/+(b|0)+o[a+16>>3];Za=f+16|0;return c|0}a=D()|0;C()|0;S(b|0)}G(a|0)}z()}function Koa(a,b,c){var d=0,e=0,f=0,g=0,i=0;a:{if(c){h[b+836|0]=c;break a}c=k[b+836|0]}b:{c:{d:{e=c&240;d=c&15;if(!(!e|(d|0)!=15)){if(!(k[a+480209|0]&16)){break b}break d}f=j[a+480208>>2]&4096;if(!(!d|(e|0)!=240)){if(!f){break b}c=0-d|0;break c}if(f){break b}if(!d){break d}c=0-d|0;if(!e){break c}if(j[a+480180>>2]&25690144){break b}break c}c=(c&255)>>>4|0;if(!c){break b}}g=b,i=Gb(j[b+760>>2]+c|0,0,64),j[g+760>>2]=i}}function FA(a){var b=0;a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=1179340888|(k[a+8|0]|k[a+9|0]<<8|(k[a+10|0]<<16|k[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))){break a}a=a+12|0;if(!(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))){break a}a=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);return(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0>27}return 0}function BX(){var a=0,b=0,c=0,d=0,e=0,f=0;a=Za-48|0;Za=a;a:{b=j[115933];if(b){c=b+48|0;if(OB(c)){d=a;if(j[c>>2]==1126902529&j[c+4>>2]==1129074247){c=j[b+44>>2]}else{c=b+80|0}j[d+44>>2]=c;d=j[b>>2];b=j[d+4>>2];if(bb[j[j[17843]+16>>2]](71372,d,a+44|0)|0){break a}j[a+20>>2]=b;j[a+16>>2]=j[21344];z()}j[a+32>>2]=j[21344];z()}z()}c=j[21344];d=j[a+44>>2];e=a,f=bb[j[j[d>>2]+8>>2]](d)|0,j[e+8>>2]=f;j[a+4>>2]=b;j[a>>2]=c;z()}function uda(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2012,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35016,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=-1}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function sCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;fi(e+24|0,e+16|0,c);j[114626]=0;I(869,e+36|0,e+8|0,d|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){j[114626]=0;F(669,e|0,e+24|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(517,a|0,b|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}Ne(e+24|0);Za=e+48|0;return}c=D()|0;C()|0;gb(e+24|0);break a}c=D()|0;C()|0;Ne(e+24|0)}G(c|0);z()}function kwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,i=0,k=0,l=0;b=Za-16|0;Za=b;g=j[a+24>>2];i=j[a+20>>2];k=j[a+16>>2];e=j[a+4>>2];f=j[a>>2];j[b+8>>2]=f;j[b+12>>2]=e;l=j[a+12>>2];j[b>>2]=j[a+8>>2];j[b+4>>2]=l;if(d){while(1){e=h[e+k|0]<<8;j[c>>2]=j[c>>2]+p(e,i);j[c+4>>2]=j[c+4>>2]+p(e,g);Bb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=j[b+12>>2];continue}break}f=j[b+8>>2];e=j[b+12>>2]}j[a>>2]=f;j[a+4>>2]=e;Za=b+16|0}function dta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;ez(e+24|0,e+16|0,c);j[114626]=0;I(668,e+36|0,e+8|0,d|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){j[114626]=0;F(669,e|0,e+24|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(517,a|0,b|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}Ne(e+24|0);Za=e+48|0;return}c=D()|0;C()|0;gb(e+24|0);break a}c=D()|0;C()|0;Ne(e+24|0)}G(c|0);z()}function Uka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,l=0;d=Za-32|0;Za=d;bt(d,2,a+2|0);qc(d+16|0,d);j[114626]=0;E(369,b+492|0,d+16|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){gb(d+16|0);e=b+236|0;f=c+1|0;c=0;while(1){g=k[(a+c|0)+31|0];h=Oc(e,c),l=f+g|0,i[h>>1]=l;c=c+1|0;if(c>>>0<120){continue}break}c=a+223|0;j[b>>2]=(k[c|0]|k[c+1|0]<<8)<<5;Kka(a+158|0,b);Za=d+32|0;return}a=D()|0;C()|0;gb(d+16|0);G(a|0);z()}function M5(a,b){var c=0,d=0,e=0;a:{b:{c:{c=k[a+3|0];e=c>>>6|0;switch(e-1|0){case 2:break a;case 0:break c;default:break b}}d=(c>>>2&12)+4|0;break a}d=32}c=k[a+1|0];d:{if((c&6)==6){a=32;c=50188;break d}if(!(c&8)){a=30;c=50191;break d}c=k[a+2|0]>>>2&3;a=Kv(a)>>>((e|0)!=3)|0;a=a?a:192;if(a>>>0<=55){a=(c|0)==2?12:8;c=50212;break d}a=(c|0)!=1?a>>>0>95?30:27:27;c=50200}h[b+768|0]=a;h[b+769|0]=(a|0)<(d|0)?a:d;return c}function uu(a,b,c,d,e,f,g,i){var k=0,l=0,m=0;k=Za-16|0;Za=k;if((b^-1)-17>>>0>=c>>>0){l=zb(a);a:{if(b>>>0<2147483623){j[k+8>>2]=b<<1;j[k+12>>2]=b+c;c=Dk(j[Gc(k+12|0,k+8|0)>>2]);break a}c=-18}m=c+1|0;c=Sh(m);if(e){lh(c,l,e)}if(g){lh(c+e|0,i,g)}d=d-f|0;i=d-e|0;if(i){lh((c+e|0)+g|0,(e+l|0)+f|0,i)}b=b+1|0;if((b|0)!=11){Yf(a,l,b)}lf(a,c);jg(a,m);b=a;a=d+g|0;ee(b,a);h[k+7|0]=0;Td(a+c|0,k+7|0);Za=k+16|0;return}kg();z()}function sda(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2014,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35084,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function _1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;a:{b:{if((a|0)!=(b|0)){g=j[114600];j[114600]=0;d=mD(a,e+12|0,d,Wd());a=ab;f=j[114600];c:{if(f){if(j[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}j[114600]=g;if(j[e+12>>2]==(b|0)){break a}}}j[c>>2]=4;d=0;a=0;break a}j[c>>2]=4;if((a|0)>0?1:(a|0)>=0?d>>>0>=1:0){d=-1;a=2147483647;break a}d=0;a=-2147483648}Za=e+16|0;ab=a;return d|0}function Zca(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2037,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35764,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Xca(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2038,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35797,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Wca(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2039,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35830,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Vca(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2040,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35863,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Uca(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2041,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35898,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Tca(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2042,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35929,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Mca(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2048,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36200,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Lca(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2049,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36232,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Kca(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2050,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36264,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Jca(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2051,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36294,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Ica(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2052,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36326,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Hca(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;b=H(2053,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,36361,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();b=0}return b|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function sJa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;Ll(e+24|0,e+16|0,c);j[114626]=0;I(240,e+36|0,e+8|0,d|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){j[114626]=0;F(78,e|0,e+24|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(72,a|0,b|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}Ne(e+24|0);Za=e+48|0;return}c=D()|0;C()|0;gb(e+24|0);break a}c=D()|0;C()|0;Ne(e+24|0)}G(c|0);z()}function pLa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;Xz(e+24|0,e+16|0,c);j[114626]=0;I(444,e+36|0,e+8|0,d|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){j[114626]=0;F(78,e|0,e+24|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(72,a|0,b|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}Ne(e+24|0);Za=e+48|0;return}c=D()|0;C()|0;gb(e+24|0);break a}c=D()|0;C()|0;Ne(e+24|0)}G(c|0);z()}function fs(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=Za-16|0;Za=d;j[b+40>>2]=0;j[b+44>>2]=0;e=b- -64|0;j[e>>2]=0;j[e+4>>2]=0;j[b+56>>2]=0;j[b+60>>2]=0;j[b+48>>2]=0;j[b+52>>2]=0;while(1){mL(b,o[uk(c,0)>>3]);f=f+1|0;if((f|0)!=1e4){continue}break}g=d,h=Lb(c),j[g+8>>2]=h;g=d,h=Mb(c),j[g>>2]=h;if(rb(d+8|0,d)){while(1){e=j[d+8>>2];g=e,i=mL(b,o[e>>3]),o[g>>3]=i;Jx(d+8|0);if(rb(d+8|0,d)){continue}break}}Ora(a,c);Za=d+16|0}function FGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;Ll(e+24|0,e+16|0,c);j[114626]=0;I(224,e+36|0,e+8|0,d|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){j[114626]=0;F(78,e|0,e+24|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(72,a|0,b|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}Ne(e+24|0);Za=e+48|0;return}c=D()|0;C()|0;gb(e+24|0);break a}c=D()|0;C()|0;Ne(e+24|0)}G(c|0);z()}function Cv(a){var b=0,c=0,d=0;a:{b:{if(!j[a+1384>>2]){b=j[a+1380>>2];if((b|0)==-1){j[a+1388>>2]=j[a+1116>>2]-1;if(!Wq(a)){j[a+1384>>2]=1;return 0}if(!(h[a+1375|0]&1)){break b}b=j[a+1380>>2]}d=b+1|0;j[a+1380>>2]=d;c=k[(a+b|0)+1120|0];if((c|0)!=255){j[a+1388>>2]=b;j[a+1384>>2]=1}if(j[a+1116>>2]<=(d|0)){j[a+1380>>2]=-1}if(k[a+1376|0]){break a}h[a+1376|0]=c}return c}Nb(a,32);return 0}X(50614,50496,1549,50635);z()}function zW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;fi(e+24|0,e+16|0,c);j[114626]=0;I(224,e+36|0,e+8|0,d|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){j[114626]=0;F(78,e|0,e+24|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(72,a|0,b|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}Ne(e+24|0);Za=e+48|0;return}c=D()|0;C()|0;gb(e+24|0);break a}c=D()|0;C()|0;Ne(e+24|0)}G(c|0);z()}function gaa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=Za+ -64|0;Za=d;e=j[a>>2];f=j[a+4>>2];g=j[a+12>>2];a=j[a+8>>2];j[d+16>>2]=a;j[d+20>>2]=g;j[d+40>>2]=a;j[d+44>>2]=g;j[d+32>>2]=e;j[d+36>>2]=f;j[d+8>>2]=e;j[d+12>>2]=f;eG(d+48|0,d+8|0,0);a=fo(d+24|0,c);j[114626]=0;b=+la(2153,d+48|0,+b,a|0);c=j[114626];j[114626]=0;if((c|0)!=1){Hc(a);jb(d+48|0);Za=d- -64|0;return+b}c=D()|0;C()|0;Hc(a);jb(d+48|0);G(c|0);z()}function dea(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0;f=j[a+4160>>2];g=j[a+4156>>2];if(d){k=j[a+4164>>2];e=j[a+4168>>2];while(1){h=j[b>>2];i=j[b+4>>2];e=e-i|0;f=(((e|0)/1024|0)-e|0)+f|0;j[c+4>>2]=f+j[c+4>>2];e=k-h|0;e=(((e|0)/1024|0)-e|0)+g|0;j[c>>2]=e+j[c>>2];f=f+((f|0)/-512|0)|0;g=e+((e|0)/-512|0)|0;c=c+8|0;b=b+8|0;e=i;k=h;d=d-1|0;if(d){continue}break}}j[a+4168>>2]=i;j[a+4164>>2]=h;j[a+4160>>2]=f;j[a+4156>>2]=g}function BAa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;$N(e+24|0,e+16|0,c);j[114626]=0;I(77,e+36|0,e+8|0,d|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){j[114626]=0;F(78,e|0,e+24|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(72,a|0,b|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}Ne(e+24|0);Za=e+48|0;return}c=D()|0;C()|0;gb(e+24|0);break a}c=D()|0;C()|0;Ne(e+24|0)}G(c|0);z()}function rda(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;c=+$(2015,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35116,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();c=0}return+c}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function pda(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;c=+$(2017,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35188,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();c=0}return+c}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function _ca(a){a=a|0;var b=0,c=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=j[a+24>>2];j[114626]=0;c=+$(2036,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,35723,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();c=0}return+c}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function F1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0;e=Za-32|0;Za=e;a:{if((b|0)!=(c|0)){k=j[114600];j[114600]=0;rY(e,b,e+28|0);b=j[e+8>>2];f=j[e+12>>2];g=j[e>>2];h=j[e+4>>2];i=j[114600];b:{if(i){if(j[e+28>>2]!=(c|0)){break b}if((i|0)!=68){break a}j[d>>2]=4;break a}j[114600]=k;if(j[e+28>>2]==(c|0)){break a}}}j[d>>2]=4;g=0;h=0;b=0;f=0}j[a>>2]=g;j[a+4>>2]=h;j[a+8>>2]=b;j[a+12>>2]=f;Za=e+32|0}function jF(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;a:{b:{c:{d:{if((b|0)>=0){if((Qk(a+8|0)|0)>(b|0)){break d}}a=R(8)|0;j[114626]=0;c=E(85,c|0,40657)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;gb(c);break b}Za=c+16|0;return+(+j[(j[a+32>>2]+p(b,896)|0)+1075744>>2]*.015625)}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function EGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;zia(e+24|0,c);j[114626]=0;I(668,e+36|0,e+8|0,d|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){j[114626]=0;F(669,e|0,e+24|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(517,a|0,b|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}Ne(e+24|0);Za=e+48|0;return}c=D()|0;C()|0;gb(e+24|0);break a}c=D()|0;C()|0;Ne(e+24|0)}G(c|0);z()}function lka(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0;g=Za-16|0;Za=g;i=j[a+4>>2];d=p((i-d|0)/6|0,6)+b|0;e=np(g,a,(c-d|0)/6|0);a:{if(c>>>0>d>>>0){f=d;while(1){h=hb(a);k=j[e+4>>2];j[114626]=0;I(1559,h|0,k|0,f|0);h=j[114626];j[114626]=0;if((h|0)==1){break a}j[e+4>>2]=j[e+4>>2]+6;f=f+6|0;if(f>>>0<c>>>0){continue}break}}ub(e);a=d-b|0;if(a){Bi(p((a|0)/-6|0,6)+i|0,b,a)}Za=g+16|0;return}a=D()|0;C()|0;ub(e);G(a|0);z()}function ge(a){var b=0,c=0,d=0;b=Za-16|0;Za=b;YMa(+a);d=VMa(1)|0;VMa(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Yn(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(CE(a,b)&3){case 0:c=Yn(o[b>>3],o[b+8>>3]);break a;case 1:c=-Zn(o[b>>3],o[b+8>>3],1);break a;case 2:c=-Yn(o[b>>3],o[b+8>>3]);break a;default:break b}}c=Zn(o[b>>3],o[b+8>>3],1)}a=c;Za=b+16|0;return a}function e4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0,k=0,l=0;e=Za-16|0;Za=e;while(1){a:{if((c|0)<=(f|0)){break a}d=j[a+28>>2];g=j[a+24>>2];if(d>>>0<=g>>>0){if(((k=a,l=gg(h[b|0]),i=j[j[a>>2]+52>>2],bb[i](k|0,l|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{j[e+12>>2]=d-g;j[e+8>>2]=c-f;d=j[Pd(e+12|0,e+8|0)>>2];lh(j[a+24>>2],b,d);j[a+24>>2]=d+j[a+24>>2];f=f+d|0;b=b+d|0}continue}break}Za=e+16|0;return f|0}function daa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=Za-32|0;Za=b;j[b+24>>2]=e;j[b+28>>2]=f;a:{a=Jr(a,ml(b+16|0,lb(c),d),b+24|0);if(a+1>>>0>=3){a=R(8)|0;j[114626]=0;b=E(85,b|0,38633)|0;c=j[114626];j[114626]=0;b:{if((c|0)!=1){Wb(a,b);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}d=D()|0;C()|0;gb(b);break b}d=D()|0;C()|0;S(a|0)}G(d|0);z()}Za=b+32|0;return a|0}z()}function Zu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0;e=Za-160|0;Za=e;Ab(e+16|0,0,144);j[e+92>>2]=-1;j[e+60>>2]=b;j[e+24>>2]=-1;j[e+20>>2]=b;Hg(e+16|0,0,0);DD(e,e+16|0,d,1);d=j[e+8>>2];g=j[e+12>>2];h=j[e>>2];i=j[e+4>>2];if(c){k=c;f=b;b=j[e+20>>2]-j[e+24>>2]|0;l=b;c=b+j[e+136>>2]|0;b=j[e+140>>2]+(b>>31)|0;b=c>>>0<l>>>0?b+1|0:b;j[k>>2]=!(b|c)?f:f+c|0}j[a>>2]=h;j[a+4>>2]=i;j[a+8>>2]=d;j[a+12>>2]=g;Za=e+160|0}function xoa(a,b){var c=0,d=0;a=Db(a);c=nb(b);j[114626]=0;F(111,a|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){a:{if(nb(b)){while(1){c=j[Li(b,d)>>2];b:{if(c>>>0<=127){j[114626]=0;F(110,a|0,c<<24>>24);c=j[114626];j[114626]=0;if((c|0)!=1){break b}break a}j[114626]=0;F(110,a|0,63);c=j[114626];j[114626]=0;if((c|0)==1){break a}}d=d+1|0;if(nb(b)>>>0>d>>>0){continue}break}}return}}b=D()|0;C()|0;gb(a);G(b|0);z()}function ooa(a,b){var c=0,d=0;a=Db(a);c=nb(b);j[114626]=0;F(111,a|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){a:{if(nb(b)){while(1){c=j[Li(b,d)>>2];b:{if(c>>>0<=255){j[114626]=0;F(110,a|0,c<<24>>24);c=j[114626];j[114626]=0;if((c|0)!=1){break b}break a}j[114626]=0;F(110,a|0,63);c=j[114626];j[114626]=0;if((c|0)==1){break a}}d=d+1|0;if(nb(b)>>>0>d>>>0){continue}break}}return}}b=D()|0;C()|0;gb(a);G(b|0);z()}function hF(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;a:{b:{c:{d:{if((b|0)>=0){if((Qk(a+8|0)|0)>(b|0)){break d}}a=R(8)|0;j[114626]=0;c=E(85,c|0,40657)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;gb(c);break b}Za=c+16|0;return(k[(j[a+32>>2]+p(b,896)|0)+1075073|0]&4)>>>2|0}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function dga(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=Za-16|0;Za=b;f=b,g=Lb(a),j[f+8>>2]=g;f=b,g=Mb(a),j[f>>2]=g;if(rb(b+8|0,b)){while(1){e=j[b+8>>2];a:{while(1){c=j[e>>2];d=j[c>>2];if(!d){break a}c=j[j[d>>2]+8>>2];j[114626]=0;N(c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}b=J(0)|0;C()|0;ow(a);ib(b);z()}qb(c+20|0);qb(c+8|0);Cb(c);Id(b+8|0);if(rb(b+8|0,b)){continue}break}}ow(a);Za=b+16|0;return a}function WKa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;cS(e+24|0,c);j[114626]=0;I(224,e+36|0,e+8|0,d|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){j[114626]=0;F(78,e|0,e+24|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}j[114626]=0;I(72,a|0,b|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}Ne(e+24|0);Za=e+48|0;return}c=D()|0;C()|0;gb(e+24|0);break a}c=D()|0;C()|0;Ne(e+24|0)}G(c|0);z()}function WJa(a,b){var c=0,d=0,e=0;up(a);h[a+8|0]=0;j[a+4>>2]=b;j[a>>2]=76448;b=ri(a+12|0);h[a+24|0]=0;j[114626]=0;E(35,a+28|0,0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){b=a+40|0;c=b+192|0;while(1){j[b>>2]=0;j[b+4>>2]=0;h[b+8|0]=0;b=b+12|0;if((c|0)!=(b|0)){continue}break}if(k[a+24|0]){a=a+232|0;b=0;while(1){d=Be(a,b),e=b,j[d>>2]=e;b=b+1|0;if((b|0)!=16){continue}break}}return}a=D()|0;C()|0;wg(b);G(a|0);z()}function M4(a){var b=q(0),c=q(0),d=0;c=(WMa(2,(ZMa(a),VMa(2))&-2147483648|1056964608),_Ma());d=(ZMa(a),VMa(2))&2147483647;b=(WMa(2,d),_Ma());a:{if(d>>>0<=1118925334){b=J4(b);if(d>>>0<=1065353215){if(d>>>0<964689920){break a}return q(c*q(q(b+b)-q(q(b*b)/q(b+q(1)))))}return q(c*q(b+q(b/q(b+q(1)))))}a=q(q(c+c)*q(q(N4(q(b+q(-162.88958740234375)))*q(1.661534994731145e+35))*q(1.661534994731145e+35)))}return a}function vk(a){var b=0,c=0;hn(a,1,10879);j[114626]=0;b=T(228)|0;c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[a+12>>2]=b;j[114626]=0;b=T(229)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}h[a+16|0]=b;j[114626]=0;b=T(230)|0;c=j[114626];j[114626]=0;if((c|0)==1){break a}h[a+18|0]=0;h[a+17|0]=b;j[114626]=0;N(231,a+20|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}return}b=D()|0;C()|0;gb(a);G(b|0);z()}function iaa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=Za-32|0;Za=b;j[b+24>>2]=e;j[b+28>>2]=f;a:{a=Jr(a,ml(b+16|0,c,d),b+24|0);if(a+1>>>0>=3){a=R(8)|0;j[114626]=0;b=E(85,b|0,38633)|0;c=j[114626];j[114626]=0;b:{if((c|0)!=1){Wb(a,b);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}d=D()|0;C()|0;gb(b);break b}d=D()|0;C()|0;S(a|0)}G(d|0);z()}Za=b+32|0;return a|0}z()}function W9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;a:{b:{c:{if(!d){b=R(8)|0;j[114626]=0;c=E(85,e|0,38690)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}Rh(a,b,1);c=_v(a,c,d,0,0,0);o[a+16>>3]=+(c>>>0)/+(b|0)+o[a+16>>3];Za=e+16|0;return c|0}a=D()|0;C()|0;S(b|0)}G(a|0)}z()}function T9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;a:{b:{c:{if(!d){b=R(8)|0;j[114626]=0;c=E(85,e|0,38690)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}Rh(a,b,1);c=Zv(a,c,d,0,0,0);o[a+16>>3]=+(c>>>0)/+(b|0)+o[a+16>>3];Za=e+16|0;return c|0}a=D()|0;C()|0;S(b|0)}G(a|0)}z()}function iO(a){var b=0;a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=808604749){break a}b=a+8|0;if((k[b|0]|k[b+1|0]<<8)>>>0<512|(k[b|0]|k[b+1|0]<<8)>>>0>767){break a}b=a+112|0;if(!(k[b|0]|k[b+1|0]<<8)|(k[b|0]|k[b+1|0]<<8)>>>0>64){break a}b=a+106|0;if((k[b|0]|k[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((k[b|0]|k[b+1|0]<<8)>>>0>255){break a}a=a+124|0;return(k[a|0]|k[a+1|0]<<8)>>>0<4e3}return 0}function JE(a,b){var c=0,d=0,e=0;if(!k[b+21|0]){Nb(a,21);return-1}if(j[a+1396>>2]<=9){Dj(a)}c=j[a+1392>>2];e=i[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=k[e+j[b+8>>2]|0];j[a+1392>>2]=d>>>c;c=j[a+1396>>2]-c|0;d=(c|0)<0;j[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=Mk(a,b)}if(!((c|0)>=j[b+2092>>2]?k[b+23|0]:0)){if(!((c|0)>-1|(j[a+1384>>2]?!k[a+1376|0]:0))){Nb(a,21)}return c}X(50824,50496,1778,50846);z()}function gna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;fna(a,b);b=0;a:{b:{c:{while(1){d=j[a>>2];j[114626]=0;i[c+14>>1]=b;e=E(2,c|0,(b<<2)+20768|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break c}j[114626]=0;I(1419,d|0,c+14|0,e|0);d=j[114626];j[114626]=0;if((d|0)==1){break b}gb(e);b=b+1|0;if((b|0)!=12){continue}break}Za=c+16|0;return}b=D()|0;C()|0;break a}b=D()|0;C()|0;gb(e)}Jf(a);G(b|0);z()}function Vna(a,b){var c=0,d=0;a=Me(a);c=nb(b);j[114626]=0;F(113,a|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){a:{if(nb(b)){while(1){c=h[Ub(b,d)|0];b:{if((c|0)>=0){j[114626]=0;F(112,a|0,c&255);c=j[114626];j[114626]=0;if((c|0)!=1){break b}break a}j[114626]=0;F(112,a|0,65533);c=j[114626];j[114626]=0;if((c|0)==1){break a}}d=d+1|0;if(nb(b)>>>0>d>>>0){continue}break}}return}}b=D()|0;C()|0;pc(a);G(b|0);z()}function Q9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;a:{b:{c:{if(!d){b=R(8)|0;j[114626]=0;c=E(85,e|0,38690)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}Rh(a,b,2);c=gG(a,c,2,d);o[a+16>>3]=+(c>>>0)/+(b|0)+o[a+16>>3];Za=e+16|0;return c|0}a=D()|0;C()|0;S(b|0)}G(a|0)}z()}function P9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;a:{b:{c:{if(!d){b=R(8)|0;j[114626]=0;c=E(85,e|0,38690)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}Rh(a,b,4);c=gG(a,c,4,d);o[a+16>>3]=+(c>>>0)/+(b|0)+o[a+16>>3];Za=e+16|0;return c|0}a=D()|0;C()|0;S(b|0)}G(a|0)}z()}function O9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;a:{b:{c:{if(!d){b=R(8)|0;j[114626]=0;c=E(85,e|0,38690)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}Rh(a,b,2);c=fG(a,c,2,d);o[a+16>>3]=+(c>>>0)/+(b|0)+o[a+16>>3];Za=e+16|0;return c|0}a=D()|0;C()|0;S(b|0)}G(a|0)}z()}function Naa(a){var b=0,c=0;c=Za-16|0;Za=c;b=3;a:{b:{if(!a|(a|0)>7){break b}b=2;if((a|0)>2){break b}b=1;if((a|0)==2){break b}b=0;if((a|0)>0){break b}b=R(8)|0;j[114626]=0;c=E(85,c|0,39884)|0;a=j[114626];j[114626]=0;c:{if((a|0)!=1){Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break c}a=D()|0;C()|0;S(b|0)}G(a|0);z()}Za=c+16|0;return b}z()}function N9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;a:{b:{c:{if(!d){b=R(8)|0;j[114626]=0;c=E(85,e|0,38690)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(b,c);j[114626]=0;I(2002,b|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}Rh(a,b,4);c=fG(a,c,4,d);o[a+16>>3]=+(c>>>0)/+(b|0)+o[a+16>>3];Za=e+16|0;return c|0}a=D()|0;C()|0;S(b|0)}G(a|0)}z()}function Ar(a){var b=0,c=0,d=0;b=k[a+4266|0];n[a+4236>>2]=q(b>>>0)*q(.00390625);j[a+4228>>2]=(p(j[a+4232>>2],k[a+4264|0])+250>>>0)/500;n[a+4240>>2]=q(256-b|0)*q(.00390625);c=k[a+4267|0];b=k[a+4265|0];n[a+4244>>2]=q(p(c,b)|0)*q(152587890625e-16);d=c|-256;n[a+4256>>2]=q(p(d,b|-256)|0)*q(152587890625e-16);n[a+4252>>2]=q(p(b,d)|0)*q(152587890625e-16);n[a+4248>>2]=q(p(256-b|0,c)|0)*q(152587890625e-16)}function fM(){var a=0,b=0;a=Za-240|0;Za=a;a:{b:{if(h[85544]&1){break b}if(!fd(85544)){break b}j[114626]=0;T(102)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(103,a+120|0,85392);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;E(104,85424,Vb(a,a+120|0,120)|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}ed(85544)}Za=a+240|0;return 85424}a=D()|0;C()|0;Zd(85544);G(a|0);z()}function Xx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=Za-32|0;Za=f;j[f+8>>2]=c;g=f,h=ef(b),j[g+28>>2]=h;Ee(f+8|0,b,j[tb(f+8|0,f+28|0)>>2]);j[114626]=0;b=H(412,f+8|0)|0;c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}c=j[f+8>>2];j[114626]=0;a=U(440,a|0,b|0,c|0,d|0,e|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}lc(f+8|0);Za=f+32|0;return a|0}a=D()|0;C()|0;lc(f+8|0);G(a|0);z()}function Kh(a){var b=0,c=0;b=Za-16|0;Za=b;YMa(+a);c=VMa(1)|0;VMa(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Zn(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(CE(a,b)&3){case 0:a=Zn(o[b>>3],o[b+8>>3],1);break a;case 1:a=Yn(o[b>>3],o[b+8>>3]);break a;case 2:a=-Zn(o[b>>3],o[b+8>>3],1);break a;default:break b}}a=-Yn(o[b>>3],o[b+8>>3])}Za=b+16|0;return a}function CN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;e=kp(a);f=d,g=Lb(b),j[f+8>>2]=g;f=d,g=Mb(b),j[f>>2]=g;a:{if(rb(d+8|0,d)){while(1){a=j[d+8>>2];if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))==(c|0)){a=hb(a);j[114626]=0;F(601,e|0,a|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}}fk(d+8|0);if(rb(d+8|0,d)){continue}break}}Za=d+16|0;return}a=D()|0;C()|0;Sc(e);G(a|0);z()}function lGa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-48|0;Za=c;MEa(c+24|0,b);j[114626]=0;F(702,c+8|0,c+24|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[114626]=0;F(703,c+16|0,c+8|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[c+16>>2];d=j[c+20>>2];j[114626]=0;K(704,a|0,b|0,d|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}lc(c+24|0);Za=c+48|0;return}a=D()|0;C()|0;lc(c+24|0);G(a|0);z()}function R4(a,b){var c=0;a:{b:{if((a^b)&3){break b}if(b&3){while(1){c=k[b|0];h[a|0]=c;if(!c){break a}a=a+1|0;b=b+1|0;if(b&3){continue}break}}c=j[b>>2];if((c^-1)&c-16843009&-2139062144){break b}while(1){j[a>>2]=c;c=j[b+4>>2];a=a+4|0;b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}c=k[b|0];h[a|0]=c;if(!c){break a}while(1){c=k[b+1|0];h[a+1|0]=c;a=a+1|0;b=b+1|0;if(c){continue}break}}}function qF(a,b){a=a|0;b=+b;var c=0,d=0;c=Za-16|0;Za=c;a:{b:{c:{if(!(b<=4?!(b<=0):0)){d=R(8)|0;j[114626]=0;c=E(85,c|0,40593)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(d,c);j[114626]=0;I(2002,d|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}d=Yj(65536/b);a=a+32|0;j[j[a>>2]+480244>>2]=d;qo(j[a>>2]);Za=c+16|0;return}a=D()|0;C()|0;S(d|0)}G(a|0)}z()}function oF(a,b){a=a|0;b=+b;var c=0,d=0;c=Za-16|0;Za=c;a:{b:{c:{if(!(b<=4?!(b<=0):0)){d=R(8)|0;j[114626]=0;c=E(85,c|0,40614)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(d,c);j[114626]=0;I(2002,d|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}d=Yj(b*65536);a=a+32|0;j[j[a>>2]+480240>>2]=d;qo(j[a>>2]);Za=c+16|0;return}a=D()|0;C()|0;S(d|0)}G(a|0)}z()}function Sw(a,b,c){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=t(c,.999);c=d*32768;h=d*3.141592653589793;j=Gr(b);while(1){k=a;l=c;e=((f<<12^-1)&28672)+(f>>>3|0)|0;if((e|0)!=16384){g=+(e-16384|0);d=g*.000244140625;g=Gr(y(g*-152587890625e-16*d+1)*b);d=h*d;d=g*Kh(d)/(d*j)}else{d=1}d=v(l*d+.5);a:{if(r(d)<2147483648){e=~~d;break a}e=-2147483648}i[k>>1]=e;a=a+2|0;f=f+1|0;if((f|0)!=32768){continue}break}}function Dda(a){a=a|0;var b=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;if((b|0)!=1){b=j[a+24>>2];if(b){Cb(gr(b))}j[a+24>>2]=0;b=j[a+20>>2];if(b){Cb(b);j[a+20>>2]=0}Cb(a);return}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,34780,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)!=1){Q();return}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function _6(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=Za-16|0;Za=c;d=j[b+4>>2];b=j[b>>2];j[c+12>>2]=0;j[c+8>>2]=0;j[c+4>>2]=0;Q6(Pv(1970,1,1)+PMa(b,d,86400,0)|0,c+12|0,c+8|0,c+4|0);tF(a);j[a+20>>2]=j[c+12>>2]-1900;j[a+16>>2]=j[c+8>>2]-1;e=j[c+4>>2];g=a,h=QMa(PMa(b,d,3600,0),ab,24),j[g+8>>2]=h;j[a+12>>2]=e;d=PMa(b,d,60,0);e=ab;g=a,h=QMa(d,e,60),j[g+4>>2]=h;f=a;a=OMa(d,e,60,0);j[f>>2]=b-a;Za=c+16|0}function NE(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,k=0;d=(b<<2)+a|0;e=d+1068|0;g=c<<1&-4;i=e,k=Ad(a,g),j[i>>2]=k;f=d+1076|0;i=f,k=Ad(a,g),j[i>>2]=k;h=d+1084|0;d=Ad(a,c&-4);j[h>>2]=d;a:{b:{e=j[e>>2];if(!(!e|!d)){f=j[f>>2];if(f){break b}}break a}V4(c,e,f,d);d=(b<<2)+a|0;b=Ad(a,g);j[d+1092>>2]=b;if(!b){break a}T4(c,b);b=Ad(a,c>>2&-2);j[d+1100>>2]=b;if(!b){break a}S4(c,b);return 1}Nb(a,3);return 0}function yu(a,b,c){var d=0,e=0,f=0;f=j[c+16>>2];a:{if(f){d=f}else{if(bX(c)){break a}d=j[c+16>>2]}f=j[c+20>>2];if(d-f>>>0<b>>>0){return bb[j[c+36>>2]](c,a,b)|0}b:{if(h[c+75|0]<0){break b}d=b;while(1){e=d;if(!e){e=0;break b}d=e-1|0;if(k[d+a|0]!=10){continue}break}d=bb[j[c+36>>2]](c,a,e)|0;if(d>>>0<e>>>0){break a}a=a+e|0;b=b-e|0;f=j[c+20>>2]}Vb(f,a,b);j[c+20>>2]=j[c+20>>2]+b;d=b+e|0}return d}function sW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Za-32|0;Za=c;a:{b:{c:{d:{if(!(d=!Ec(b),e=0,f=j[b+12>>2],f?d:e)){Qc(a);break d}rW(c+16|0,b);j[114626]=0;F(234,c|0,b+12|0);b=j[114626];j[114626]=0;if((b|0)==1){break c}j[114626]=0;I(3,a|0,c+16|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}gb(c);gb(c+16|0)}Za=c+32|0;return}b=D()|0;C()|0;break a}b=D()|0;C()|0;gb(c)}gb(c+16|0);G(b|0);z()}function $E(a,b,c,d,e,f){var g=0,h=0;if((d|0)>=1){while(1){O5(p(g,2304)+b|0,c);g=g+1|0;if((g|0)!=(d|0)){continue}break}}f=Vb(f,a,3840);if((c|0)>=1){h=d<<5;g=0;while(1){N5((g<<2)+b|0,(p(g,h)<<1)+e|0,d,f+(g<<8)|0);g=g+2|0;if((g|0)<(c|0)){continue}break}}b=c<<6;a:{if((d|0)==1){g=0;while(1){n[(g<<2)+a>>2]=n[f+(b+g<<2)>>2];c=g>>>0<958;g=g+2|0;if(c){continue}break}break a}Vb(a,f+(b<<2)|0,3840)}}function xda(a,b){a=a|0;b=b|0;var c=0;j[114626]=0;N(2008,a|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){j[a+16>>2]=b;b=j[a+20>>2];if(!b){break b}Cb(b);j[a+20>>2]=0;return}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,34929,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}return}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function r$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za+ -64|0;Za=e;j[e+56>>2]=b;f=e+48|0;a:{b:while(1){if(c>>>0<d>>>0){j[e+8>>2]=c;if((bb[j[j[a>>2]+12>>2]](a,e+48|0,c,d,e+8|0,e+16|0,f,e+12|0)|0)==2){break a}b=e+16|0;if(j[e+8>>2]==(c|0)){break a}while(1)if(m[e+12>>2]<=b>>>0){c=j[e+8>>2];continue b}else{MC(e+56|0,b);b=b+1|0;continue}}break}Za=e- -64|0;return j[e+56>>2]}Sl(62980);z()}function oT(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;j[d+12>>2]=b;c=j[a+4>>2];a:{if(!c){c=j[a>>2];break a}j[d+8>>2]=32-c;b=tb(d+8|0,d+12|0);c=j[a>>2];b=j[b>>2];j[c>>2]=j[c>>2]&(-1<<j[a+4>>2]&-1>>>j[d+8>>2]-b^-1);b=j[d+12>>2]-b|0;j[d+12>>2]=b;c=c+4|0;j[a>>2]=c}e=c;c=b>>>5<<2;Ab(e,0,c);b=j[d+12>>2]-(b&-32)|0;j[d+12>>2]=b;if(b){e=a;a=c+j[a>>2]|0;j[e>>2]=a;j[a>>2]=j[a>>2]&(-1>>>32-b^-1)}Za=d+16|0}function A2(a){var b=0,c=0;a:{if(a&3){while(1){b=k[a|0];if(!b|(b|0)==61){break a}a=a+1|0;if(a&3){continue}break}}b=j[a>>2];b:{if((b^-1)&b-16843009&-2139062144){break b}while(1){b=b^1027423549;if((b^-1)&b-16843009&-2139062144){break b}b=j[a+4>>2];a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}while(1){b=a;c=k[b|0];if(c){a=b+1|0;if((c|0)!=61){continue}}break}return b}return a}function My(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;mP(a,b);e=b+8|0;e=k[e|0]|k[e+1|0]<<8|(k[e+2|0]<<16|k[e+3|0]<<24);xc(a,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+504|0);lP(a,d);a:{b=b+32|0;if(!(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))){break a}b=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);if(!xc(a,b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))){break a}an(a,c);return}Ab(c,0,80)}function rL(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=Gr(b);d=Sra(a);a=0;a:{while(1){c=1;if((a|0)!=1024){j[114626]=0;c=+(a-1024|0);f=+Xa(1209,+(y(c*c*-9.5367431640625e-7+1)*b));g=j[114626];j[114626]=0;if((g|0)==1){break a}c=c*.0372006759294457;c=f*Kh(c)/(c*e)}h=uk(d,a),i=c*.011841342921061943,o[h>>3]=i;a=a+1|0;if((a|0)!=2048){continue}break}return}a=D()|0;C()|0;sf(d);G(a|0);z()}function RB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-32|0;Za=d;c=Eb(d,c);j[114626]=0;I(2834,d+16|0,b|0,c|0);e=j[114626];j[114626]=0;a:{b:{if((e|0)!=1){j[114626]=0;E(2835,a|0,d+16|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break b}gb(d+16|0);gb(c);j[a>>2]=70724;c=j[b+4>>2];j[a+8>>2]=j[b>>2];j[a+12>>2]=c;Za=d+32|0;return a|0}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+16|0)}gb(c);G(a|0);z()}function Bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Uh(a,b,c,d);j[a+4224>>2]=1049951732;c=a+4216|0;j[c>>2]=1065353216;j[c+4>>2]=1049951732;j[a+4208>>2]=1060320051;j[a+4212>>2]=1041865114;j[a>>2]=80788;j[114626]=0;K(1632,a+44|0,2,2)|0;c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;N(1633,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}return a|0}a=D()|0;C()|0;we(b);G(a|0);z()}function Iya(a,b){var c=0,d=0,e=0;c=qN(a,b);j[114626]=0;e=E(985,a+12|0,b+12|0)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){j[114626]=0;E(986,a+24|0,b+24|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}c=j[b+40>>2];j[a+36>>2]=j[b+36>>2];j[a+40>>2]=c;i[a+52>>1]=l[b+52>>1];c=j[b+48>>2];j[a+44>>2]=j[b+44>>2];j[a+48>>2]=c;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;Od(e)}Od(c);G(a|0);z()}function nw(a){var b=q(0),c=q(0),d=0,e=q(0),f=0;b=q(xe(j[a+16>>2])>>>0);c=q(q(bb[j[j[a>>2]+200>>2]](a))*b);d=a,e=q(q(c*q(2.0480000972747803))*q(bb[j[j[a>>2]+192>>2]](a))),n[d+4248>>2]=e;d=a,f=qh(q(q(c*q(4.0960001945495605))+q(8192))),j[d+4256>>2]=f;c=q(bb[j[j[a>>2]+204>>2]](a));n[a+4252>>2]=c;b=q(c/b);if(!(bb[j[j[a>>2]+188>>2]](a)|0)){b=EE(q(b*q(3.1415927410125732)))}n[a+4244>>2]=b+b}function _pa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>3;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){lb(k[b|0]);lb(k[b+1|0]);f=a,g=lb(k[b+2|0])|lb(k[b+3|0])<<8,i[f>>1]=g;lb(k[b+4|0]);lb(k[b+5|0]);f=a,g=lb(k[b+6|0])|lb(k[b+7|0])<<8,i[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<3}function Zpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>3;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){lb(k[b+3|0]);lb(k[b+2|0]);f=a,g=lb(k[b+1|0])|lb(k[b|0])<<8,i[f>>1]=g;lb(k[b+7|0]);lb(k[b+6|0]);f=a,g=lb(k[b+5|0])|lb(k[b+4|0])<<8,i[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<3}function Lha(a){a=a|0;var b=0,c=0;b=j[a+20>>2];j[b+148>>2]=-1;j[114626]=0;F(507,b+4|0,8);b=j[114626];j[114626]=0;if((b|0)!=1){c=j[j[a+20>>2]+4>>2];b=j[a+4264>>2];a=j[a+4260>>2];h[c|0]=a;h[c+1|0]=a>>>8;h[c+2|0]=a>>>16;h[c+3|0]=a>>>24;h[c+4|0]=b;h[c+5|0]=b>>>8;h[c+6|0]=b>>>16;h[c+7|0]=b>>>24;return}b=J(71396)|0;if((C()|0)==(W(71396)|0)){O(b|0)|0;_r(j[a+20>>2]+4|0);Q();return}G(b|0);z()}function Hp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,i=0;c=Za-16|0;Za=c;e=j[a+4>>2];d=j[a>>2];h[c+12|0]=0;Fr(d,d+e|0,c+12|0);d=zb(b);e=zb(b);g=c,i=nb(b),j[g+12>>2]=i;j[c+8>>2]=j[a+4>>2]-1;Pe(d,e+j[tb(c+12|0,c+8|0)>>2]|0,j[a>>2]);d=j[a>>2];g=c,i=nb(b),j[g+12>>2]=i;j[c+8>>2]=j[a+4>>2]-1;b=j[tb(c+12|0,c+8|0)>>2];e=j[a+4>>2];f=j[a>>2];h[c+7|0]=0;Fr(b+d|0,e+f|0,c+7|0);Za=c+16|0;return a|0}function kZ(){var a=0;a:{if(h[462280]&1){break a}if(!fd(462280)){break a}a=462112;while(1){a=Db(a)+12|0;if((a|0)!=462280){continue}break}ed(462280)}vc(462112,67168);vc(462124,67175);vc(462136,67182);vc(462148,67190);vc(462160,67200);vc(462172,67209);vc(462184,67216);vc(462196,67225);vc(462208,67229);vc(462220,67233);vc(462232,67237);vc(462244,67241);vc(462256,67245);vc(462268,67249)}function gZ(){var a=0;a:{if(h[462456]&1){break a}if(!fd(462456)){break a}a=462288;while(1){a=Me(a)+12|0;if((a|0)!=462456){continue}break}ed(462456)}Kc(462288,67256);Kc(462300,67284);Kc(462312,67312);Kc(462324,67344);Kc(462336,67384);Kc(462348,67420);Kc(462360,67448);Kc(462372,67484);Kc(462384,67500);Kc(462396,67516);Kc(462408,67532);Kc(462420,67548);Kc(462432,67564);Kc(462444,67580)}function dF(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;a:{b:{c:{if(b>>>0>=256){a=R(8)|0;j[114626]=0;c=E(85,c|0,40657)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;gb(c);break b}a=j[a+32>>2]+p(b,896)|0;j[a+1075e3>>2]=0;j[a+1075060>>2]=0;Za=c+16|0;return}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function Yx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-32|0;Za=e;j[e+8>>2]=c;f=e,g=ef(b),j[f+28>>2]=g;Ee(e+8|0,b,j[tb(e+8|0,e+28|0)>>2]);j[114626]=0;b=H(412,e+8|0)|0;c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}c=j[e+8>>2];j[114626]=0;P(1057,a|0,b|0,c|0,d|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}lc(e+8|0);Za=e+32|0;return 1}a=D()|0;C()|0;lc(e+8|0);G(a|0);z()}function $3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;while(1){a:{if((c|0)<=(e|0)){break a}f=j[a+24>>2];g=j[a+28>>2];if(f>>>0>=g>>>0){if((bb[j[j[a>>2]+52>>2]](a,j[b>>2])|0)==-1){break a}e=e+1|0;b=b+4|0}else{j[d+12>>2]=g-f>>2;j[d+8>>2]=c-e;f=j[Pd(d+12|0,d+8|0)>>2];Jh(j[a+24>>2],b,f);g=f<<2;j[a+24>>2]=g+j[a+24>>2];e=e+f|0;b=b+g|0}continue}break}Za=d+16|0;return e|0}function wda(a){a=a|0;var b=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){j[a+16>>2]=0;b=j[a+20>>2];if(!b){break b}Cb(b);j[a+20>>2]=0;return}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,34959,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q()}return}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function pT(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;j[d+12>>2]=b;c=j[a+4>>2];a:{if(!c){c=j[a>>2];break a}j[d+8>>2]=32-c;b=tb(d+8|0,d+12|0);c=j[a>>2];b=j[b>>2];j[c>>2]=j[c>>2]|-1<<j[a+4>>2]&-1>>>j[d+8>>2]-b;b=j[d+12>>2]-b|0;j[d+12>>2]=b;c=c+4|0;j[a>>2]=c}e=c;c=b>>>5<<2;Ab(e,255,c);b=j[d+12>>2]-(b&-32)|0;j[d+12>>2]=b;if(b){e=a;a=c+j[a>>2]|0;j[e>>2]=a;j[a>>2]=j[a>>2]|-1>>>32-b}Za=d+16|0}function gL(a,b,c){var d=0,e=0,f=0,g=0;d=Za-32|0;Za=d;j[a+4>>2]=0;a:{if(b){b:{if(zs(a)>>>0>=b>>>0){j[a+4>>2]=b;break b}hb(a);e=py(d+16|0);j[114626]=0;f=E(928,a|0,b|0)|0;g=j[114626];j[114626]=0;if((g|0)==1){break a}j[114626]=0;F(929,e|0,f|0);f=j[114626];j[114626]=0;if((f|0)==1){break a}j[e+4>>2]=b;oy(a,e);Vd(e)}Xi(d,a);Fp(d,b,k[c|0])}Za=d+32|0;return}a=D()|0;C()|0;Vd(e);G(a|0);z()}function gGa(a,b){var c=0,d=0;c=Za-48|0;Za=c;$y(c+24|0,b);j[114626]=0;F(702,c+8|0,c+24|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[114626]=0;F(703,c+16|0,c+8|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}b=j[c+16>>2];d=j[c+20>>2];j[114626]=0;K(704,a|0,b|0,d|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}lc(c+24|0);Za=c+48|0;return}a=D()|0;C()|0;lc(c+24|0);G(a|0);z()}function n7(a){var b=0,c=0,d=0,e=0;e=Za-16|0;Za=e;b=Pv(j[a+20>>2]+1900|0,j[a+16>>2]+1|0,j[a+12>>2])-Pv(1970,1,1)|0;c=OMa(b,b>>31,86400,0);b=p(j[a+8>>2],3600);d=b;c=c+b|0;b=ab+(b>>31)|0;b=c>>>0<d>>>0?b+1|0:b;d=p(j[a+4>>2],60);c=d+c|0;b=(d>>31)+b|0;b=c>>>0<d>>>0?b+1|0:b;a=j[a>>2];d=a;c=a+c|0;a=(a>>31)+b|0;a=BF(e+8|0,c,c>>>0<d>>>0?a+1|0:a);b=j[a>>2];Za=e+16|0;ab=j[a+4>>2];return b}function yda(a){a=a|0;var b=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){a=j[a+20>>2];if(!a){break b}return Gd(a)|0}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,34891,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();return 0}return Gd(34181)|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function xza(a,b){a=a|0;b=b|0;var c=0;b=Za-32|0;Za=b;c=-1;a:{if(!tz(a,b+16|0)){break a}c=0;if(!DN(b+16|0)){break a}c=-1;if(!hj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))){break a}a=b+8|0;c=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);a=b+8|0;c=(c|0)==((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))&2139062143)}a=c;Za=b+32|0;return a|0}function k6(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=j[((k[b|0]^a&255)<<2)+40816>>2]^a>>>8;a=a>>>8^j[((k[b+1|0]^a&255)<<2)+40816>>2];a=a>>>8^j[((k[b+2|0]^a&255)<<2)+40816>>2];a=a>>>8^j[((k[b+3|0]^a&255)<<2)+40816>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=j[((k[b|0]^a&255)<<2)+40816>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function cW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-48|0;Za=d;a:{b:{e=_V(zb(b),nb(b),zb(c),nb(c));if((e|0)!=-1){f=d,g=nd(b),j[f+32>>2]=g;c=Cd(d+40|0,d+32|0);f=d,g=nd(b),j[f+8>>2]=g;f=d,g=$e(d+8|0,e),j[f+16>>2]=g;e=Cd(d+24|0,d+16|0);Ex(b,j[c>>2],j[e>>2]);break b}if(!nb(b)){break b}if((ZV(zb(b),nb(b),zb(c),nb(c))|0)!=(nb(b)-1|0)){break b}Qc(a);break a}Nc(a,b)}Za=d+48|0}function BQ(a){var b=0,c=0,d=0;a:{if((k[a+60|0]|k[a+61|0]<<8|(k[a+62|0]<<16|k[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((k[b|0]|k[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if((k[b|0]|k[b+1|0]<<8)>>>0>255){break a}b=a+576|0;a=a- -64|0;while(1){c=0;b:{switch(k[a+15|0]){case 0:case 1:d=1;break;case 2:break b;default:break a}}c=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}return c&1}function Rh(a,b,c){var d=0,e=0,f=0,g=0,i=0;d=Za-48|0;Za=d;e=a+24|0;f=j[j[e>>2]+24620>>2];a:{if(!((f|0)!=(b|0)|j[j[e>>2]+24624>>2]!=(c|0))){if(k[a+29|0]){break a}kJ(j[e>>2],1);break a}Vb(d+8|0,j[e>>2]+24604|0,40);g=j[d+40>>2];i=j[d+44>>2];j[d+28>>2]=c;j[d+24>>2]=b;Wk(d+8|0,g);Km(d+8|0,i);ax(j[e>>2],d+8|0);if((b|0)==(f|0)){break a}rna(j[e>>2]);qna(j[e>>2])}h[a+29|0]=1;Za=d+48|0}function Iw(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,i=0;f=Za-16|0;Za=f;a:{while(1){i=g&255;if(Kw(b,c,i>>>0>1)){h[f+15|0]=0;h[f+14|0]=0;xI(a,f+15|0,f+14|0);break a}Tg(b,d);Tg(c,e);g=g+1|0;if(i>>>0<3){continue}break}if(wm(k[b|0])>>>0>wm(k[d|0])>>>0){Tg(b,d);Tg(c,e)}h[f+11|0]=k[b|0];xI(f+12|0,f+11|0,c);h[b|0]=0;h[c|0]=0;b=l[f+12>>1];h[a|0]=b;h[a+1|0]=b>>>8}Za=f+16|0}function nla(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0;e=Za-32|0;Za=e;a:{if(me(b)>>>0>c>>>0){f=j[d>>2];g=j[d+4>>2];while(1){d=h&65535;if(th(te(b,d))){i=Lb(te(b,d));k=Mb(te(b,d));d=e;j[d+24>>2]=f;j[d+28>>2]=g;j[d+8>>2]=f;j[d+12>>2]=g;mla(d+16|0,i,k,d+8|0)}h=h+1|0;if((h&65535)>>>0<=c>>>0){continue}break}j[a>>2]=f;j[a+4>>2]=g;break a}b=j[d+4>>2];j[a>>2]=j[d>>2];j[a+4>>2]=b}Za=e+32|0}function aia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=Za-16|0;Za=e;d=ue(64);j[114626]=0;f=H(1420,d|0)|0;g=j[114626];j[114626]=0;a:{if((g|0)!=1){d=gx(e+8|0,f);f=j[d>>2];j[114626]=0;b=K(1627,f|0,b|0,c|0)|0;c=j[114626];j[114626]=0;b:{c:{if((c|0)!=1){if((b|0)==1){break c}fx(a);break b}a=D()|0;C()|0;Jf(d);break a}hp(a,d)}Jf(d);Za=e+16|0;return}a=D()|0;C()|0;Cb(d)}G(a|0);z()}function TQ(a){var b=0,c=0;a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=777268804){break a}b=a+4|0;c=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<14){break a}b=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>256){break a}a=a+8|0;return!(k[a|0]|k[a+1|0]<<8)}return 0}function Pta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-32|0;Za=d;j[d+24>>2]=b;a:{b=wh(d+8|0,a+8|0,Ota(b,c));if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];f=j[d+24>>2];j[114626]=0;I(766,c|0,e|0,f|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}j[b>>2]=j[b>>2]+4;Id(d+24|0);if(j[b>>2]!=j[b+4>>2]){continue}break}}dc(b);Za=d+32|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function CJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-32|0;Za=d;j[d+24>>2]=b;a:{b=vl(d+8|0,a+8|0,Bz(b,c));if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];f=j[d+24>>2];j[114626]=0;I(521,c|0,e|0,f|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}j[b>>2]=j[b>>2]+2;je(d+24|0);if(j[b>>2]!=j[b+4>>2]){continue}break}}dc(b);Za=d+32|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function Fh(a,b,c,d,e){var f=0,g=0;f=Za-16|0;Za=f;j[f+8>>2]=b;a:{if(Ii(a,f+8|0)){j[c>>2]=j[c>>2]|6;b=0;break a}b=Bj(a);if(!ng(d,2048,b)){j[c>>2]=j[c>>2]|4;b=0;break a}b=Vl(d,b);while(1){b:{Ik(a);b=b-48|0;if(!Tn(a,f+8|0)|(e|0)<2){break b}g=Bj(a);if(!ng(d,2048,g)){break a}e=e-1|0;b=Vl(d,g)+p(b,10)|0;continue}break}if(!Ii(a,f+8|0)){break a}j[c>>2]=j[c>>2]|2}Za=f+16|0;return b}function Eh(a,b,c,d,e){var f=0,g=0;f=Za-16|0;Za=f;j[f+8>>2]=b;a:{if(yj(a,f+8|0)){j[c>>2]=j[c>>2]|6;b=0;break a}b=Gk(a);if(!zj(d,2048,b)){j[c>>2]=j[c>>2]|4;b=0;break a}b=Tl(d,b);while(1){b:{cm(a);b=b-48|0;if(!Hq(a,f+8|0)|(e|0)<2){break b}g=Gk(a);if(!zj(d,2048,g)){break a}e=e-1|0;b=Tl(d,g)+p(b,10)|0;continue}break}if(!yj(a,f+8|0)){break a}j[c>>2]=j[c>>2]|2}Za=f+16|0;return b}function mF(a,b){a=a|0;b=+b;var c=0,d=0;c=Za-16|0;Za=c;a:{b:{c:{if(!(b<=1?!(b<0):0)){d=R(8)|0;j[114626]=0;c=E(85,c|0,40635)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(d,c);j[114626]=0;I(2002,d|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);break b}d=Yj(b*256);j[j[a+32>>2]+1074444>>2]=d;Za=c+16|0;return}a=D()|0;C()|0;S(d|0)}G(a|0)}z()}function $ga(a,b){a=a|0;b=b|0;var c=q(0);a:{switch(b|0){case 0:return q(n[a+4220>>2]);case 1:return q(n[a+4224>>2]);case 2:return q(n[a+4228>>2]);case 3:return q(k[a+4240|0]?q(1):q(0));case 4:return q(q(q(j[a+4232>>2])*q(.03125)));case 5:return q(k[a+4241|0]?q(1):q(0));case 6:return q(k[a+4242|0]?q(1):q(0));case 7:c=k[a+4244|0]?q(1):q(0);break;default:break a}}return q(c)}function lta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Za-16|0;Za=d;j[d+12>>2]=b;a:{if(_g(a)>>>0>=b>>>0){g=d,h=de(a),j[g+8>>2]=h;e=j[a>>2];b=c;f=j[tb(d+12|0,d+8|0)>>2];if(f){while(1){e=Ata(e,b)+32|0;f=f-1|0;if(f){continue}break}}b=j[d+12>>2];e=j[d+8>>2];if(b>>>0>e>>>0){Px(a,b-e|0,c);break a}WL(a,j[a>>2]+(b<<5)|0);break a}kta(a);jta(a,El(a,b));Px(a,b,c)}Za=d+16|0}function asa(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+23|0]=0;h[a+24|0]=0;h[a+25|0]=0;h[a+26|0]=0;h[a+16|0]=0;h[a+17|0]=0;h[a+18|0]=0;h[a+19|0]=0;h[a+20|0]=0;h[a+21|0]=0;h[a+22|0]=0;h[a+23|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;h[a+15|0]=0;Za=b+16|0}function ux(a,b,c,d){a:{if(j[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=p(b,896)+a|0;j[c+1075680>>2]=0;d=c+1074992|0;j[d>>2]=0;j[d+4>>2]=0;d=c+1075072|0;c=j[d>>2]|4096;j[d>>2]=c;break b}c=p(b,896)+a|0;j[c+1075672>>2]=0;c=j[c+1075072>>2]}d=p(b,896)+a|0;j[d+1075072>>2]=c|2097152;Mj(a,b,255,0);if(!(k[d+1075073|0]&2)){break a}a=a+1304392|0;if(!bd(a)){break a}bi(j[a>>2],b,0)}}function h7(a,b,c,d,e){var f=0,g=0,h=0,j=0,k=0,l=0,m=0;g=Za-16|0;Za=g;if(e){while(1){h=0;if(d){while(1){f=o[Jg(b,h,j)>>3];Pb(c,h);o[g+8>>3]=f;pf(g+8|0,-1,1);f=o[g+8>>3]*32768;o[g+8>>3]=f;f=zd(f);a:{if(r(f)<2147483648){k=~~f;break a}k=-2147483648}k=Dc(k);l=jm(a,h,j),m=k,i[l>>1]=m;h=h+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}Za=g+16|0}function L7(a,b,c,d,e){var f=0,g=0,h=0,j=0,k=0,l=0,m=0;g=Za-16|0;Za=g;if(e){while(1){h=0;if(d){while(1){f=o[Jg(b,h,j)>>3];Pb(c,h);o[g+8>>3]=f;pf(g+8|0,-1,1);f=o[g+8>>3]*32768;o[g+8>>3]=f;f=zd(f);a:{if(r(f)<2147483648){k=~~f;break a}k=-2147483648}k=Dc(k);l=lm(a,h,j),m=k,i[l>>1]=m;h=h+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}Za=g+16|0}function dCa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=q(0),h=0,j=0,k=0,l=0;f=Za-16|0;Za=f;if(d){a=(e<<1)+a|0;e=0;c=c<<1;while(1){n[f+12>>2]=n[b>>2];Kd(f+12|0,q(-1));g=q(n[f+12>>2]*q(32768));n[f+12>>2]=g;j=a;g=Sd(g);a:{if(q(r(g))<q(2147483648)){h=~~g;break a}h=-2147483648}k=j,l=Dc(h),i[k>>1]=l;b=b+4|0;a=a+c|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}Za=f+16|0}function K5(a,b,c,d,e,f){var g=0,i=0,j=0,l=0,m=0,n=0;while(1){g=k[d+j|0];if(g){a:{if(f&8){Vb(a,b,g);break a}l=k[c+j|0];if(!l){Ab(a,0,g);Ab(b,0,g);break a}n=(f|0)>-1?-1:-1<<l^-1;i=0;while(1){m=Bd(e,l);h[b+i|0]=(m|0)==(n|0)?-1:m;h[a+i|0]=m;i=i+1|0;if((i|0)!=(g|0)){continue}break}}f=f<<1;a=a+g|0;b=b+g|0;j=j+1|0;if((j|0)!=4){continue}}break}h[a+2|0]=0;h[a|0]=0;h[a+1|0]=0}function cqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=(c>>>0)/6;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){lb(k[b|0]);f=a,g=lb(k[b+1|0])|lb(k[b+2|0])<<8,i[f>>1]=g;lb(k[b+3|0]);f=a,g=lb(k[b+4|0])|lb(k[b+5|0])<<8,i[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return p(d,6)|0}function bqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=(c>>>0)/6;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){lb(k[b+2|0]);f=a,g=lb(k[b+1|0])|lb(k[b|0])<<8,i[f>>1]=g;lb(k[b+5|0]);f=a,g=lb(k[b+4|0])|lb(k[b+3|0])<<8,i[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return p(d,6)|0}function _H(a,b){var c=0,d=0,e=0,f=q(0),g=0,h=q(0);c=Za-16|0;Za=c;e=0;a:{if(!mf(j[j[a>>2]-12>>2]+a|0)){break a}j[c+12>>2]=0;ii(a,c+12|0);d=j[c+12>>2];e=0;if(d>>>0>65535){break a}Sk(b,d);if(j[c+12>>2]){d=0;while(1){j[c+8>>2]=0;ho(a,c+8|0);f=n[c+8>>2];g=xb(b,d),h=f,n[g>>2]=h;d=d+1|0;if(d>>>0<m[c+12>>2]){continue}break}}e=mf(j[j[a>>2]-12>>2]+a|0)}d=e;Za=c+16|0;return d}function ZH(a,b){var c=0,d=0,e=0,f=q(0),g=0,h=q(0);c=Za-16|0;Za=c;e=0;a:{if(!mf(j[j[a>>2]-12>>2]+a|0)){break a}i[c+14>>1]=0;cf(a,c+14|0);d=l[c+14>>1];e=0;if(d>>>0>65535){break a}Sk(b,d);if(l[c+14>>1]){d=0;while(1){j[c+8>>2]=0;ho(a,c+8|0);f=n[c+8>>2];g=xb(b,d),h=f,n[g>>2]=h;d=d+1|0;if(d>>>0<l[c+14>>1]){continue}break}}e=mf(j[j[a>>2]-12>>2]+a|0)}a=e;Za=c+16|0;return a}function Nk(a){if((a|0)>=0){if((a|0)<=16383){if((a|0)<=15){return h[a+50656|0]}if((a|0)<=511){return h[(a>>>5|0)+50656|0]+5|0}return h[(a>>>10|0)+50656|0]+10|0}if((a|0)<=16777215){if((a|0)<=524287){return h[(a>>>15|0)+50656|0]+15|0}return h[(a>>>20|0)+50656|0]+20|0}if((a|0)<=536870911){return h[(a>>>25|0)+50656|0]+25|0}a=h[(a>>>30|0)+50656|0]+30|0}else{a=0}return a}function k5(a,b){var c=0,d=0,e=q(0),f=0;d=v(zv(+q(q(Xn(+q(a|0)))/q(b|0))));a:{if(r(d)<2147483648){c=~~d;break a}c=-2147483648}f=c;d=v(uv(+q(q(c|0)+q(1)),b));b:{if(r(d)<2147483648){c=~~d;break b}c=-2147483648}c=f+((c|0)<=(a|0))|0;e=q(c|0);if(!(uv(+q(e+q(1)),b)<=+(a|0))){d=v(uv(+e,b));c:{if(r(d)<2147483648){b=~~d;break c}b=-2147483648}return(b|0)>(a|0)?-1:c}return-1}function g6(a){var b=0;if(!a){return-2}j[a+44>>2]=0;j[a+48>>2]=0;j[a+52>>2]=0;j[a+20>>2]=0;j[a+24>>2]=0;j[a+8>>2]=0;b=j[a+32>>2];if(!b){j[a+32>>2]=2291;b=2291}if(!j[a+36>>2]){j[a+36>>2]=2292}b=bb[b|0](j[a+40>>2],1,43784)|0;if(!b){return-4}j[a+28>>2]=b;j[b+43780>>2]=1;j[b+10992>>2]=0;j[b+10996>>2]=0;j[b>>2]=0;j[b+11008>>2]=15;j[b+11e3>>2]=1;j[b+11004>>2]=0;return 0}function sq(a,b,c){var d=0,e=0;if(c&2048){h[a|0]=43;a=a+1|0}if(c&1024){h[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){h[a|0]=46;h[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=k[b|0];if(e){h[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}h[a|0]=b;return(d|0)!=260}function Ypa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>3;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){lb(k[b|0]);lb(k[b+1|0]);lb(k[b+2|0]);lb(k[b+3|0]);lb(k[b+4|0]);lb(k[b+5|0]);f=a,g=lb(k[b+6|0])|lb(k[b+7|0])<<8,i[f>>1]=g;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<3}function Xpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>3;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){lb(k[b+7|0]);lb(k[b+6|0]);lb(k[b+5|0]);lb(k[b+4|0]);lb(k[b+3|0]);lb(k[b+2|0]);f=a,g=lb(k[b+1|0])|lb(k[b|0])<<8,i[f>>1]=g;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<3}function WC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=Za-16|0;Za=e;f=j[Rb(a)>>2];d=j[c>>2]-j[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=j[b>>2];i=j[a>>2];g=gq((f|0)==2474?0:j[a>>2],d);if(g){if((f|0)!=2474){ud(a)}j[e+4>>2]=2412;f=yd(e+8|0,g,e+4|0);TC(a,f);mc(f);j[b>>2]=j[a>>2]+(h-i|0);j[c>>2]=j[a>>2]+(d&-4);Za=e+16|0;return}Ku();z()}function a5(a,b,c,d,e,f){var g=0,h=0;a:{if(f){g=1;if((e|0)<1){break a}f=0;while(1){if(!Y4(a,b,(d<<2)+c|0,e-f|0)){return 0}h=j[b>>2];d=h+d|0;f=f+h|0;if((f|0)<(e|0)){continue}break}break a}g=1;f=(e|0)/j[b>>2]|0;if((f|0)<1){break a}c=(d<<2)+c|0;e=e-d|0;g=0;d=0;while(1){if(!X4(a,b,c+(d<<2)|0,e-d|0,f)){break a}d=d+1|0;if((f|0)!=(d|0)){continue}break}return 1}return g}function FE(a,b){a:{if((b|0)>=128){a=q(a*q(1.7014118346046923e+38));if((b|0)<255){b=b-127|0;break a}a=q(a*q(1.7014118346046923e+38));b=((b|0)<381?b:381)-254|0;break a}if((b|0)>-127){break a}a=q(a*q(1.1754943508222875e-38));if((b|0)>-253){b=b+126|0;break a}a=q(a*q(1.1754943508222875e-38));b=((b|0)>-378?b:-378)+252|0}return q(a*(WMa(2,(b<<23)+1065353216|0),_Ma()))}function rF(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;a:{b:{c:{if(b-32>>>0>=481){a=R(8)|0;j[114626]=0;c=E(85,c|0,40579)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;gb(c);break b}j[j[a+32>>2]+1074420>>2]=p(b,1e4);Za=c+16|0;return}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function caa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Za-32|0;Za=b;a:{a=Jr(a,ml(b+24|0,lb(c),d),0);if(a+1>>>0>=3){a=R(8)|0;j[114626]=0;b=E(85,b+8|0,38633)|0;c=j[114626];j[114626]=0;b:{if((c|0)!=1){Wb(a,b);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}d=D()|0;C()|0;gb(b);break b}d=D()|0;C()|0;S(a|0)}G(d|0);z()}Za=b+32|0;return a|0}z()}function Ija(a,b,c){var d=0,e=0;e=Za-32|0;Za=e;a:{b:{if((j[hb(a)>>2]-j[a+4>>2]|0)/52>>>0>=b>>>0){Dw(a,b,c);break b}d=hb(a);d=wja(e+8|0,oI(a,df(a)+b|0),df(a),d);j[114626]=0;I(1578,d|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(1579,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}gI(d)}Za=e+32|0;return}a=D()|0;C()|0;gI(d);G(a|0);z()}function Aja(a,b){var c=0,d=0,e=0;e=zja(a,b);j[a+20>>2]=j[b+20>>2];c=j[b+16>>2];j[a+12>>2]=j[b+12>>2];j[a+16>>2]=c;j[114626]=0;c=E(1582,a+24|0,b+24|0)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){j[114626]=0;E(120,a+36|0,b+36|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break b}j[a+48>>2]=j[b+48>>2];return}a=D()|0;C()|0;break a}a=D()|0;C()|0;Ud(c)}kl(e);G(a|0);z()}function Wqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0;g=Za-16|0;Za=g;i=j[a+4>>2];d=(i-d|0)+b|0;e=yh(g,a,c-d>>1);a:{if(c>>>0>d>>>0){f=d;while(1){h=hb(a);k=j[e+4>>2];j[114626]=0;I(1243,h|0,k|0,f|0);h=j[114626];j[114626]=0;if((h|0)==1){break a}j[e+4>>2]=j[e+4>>2]+2;f=f+2|0;if(f>>>0<c>>>0){continue}break}}ub(e);ht(b,d,i);Za=g+16|0;return}a=D()|0;C()|0;ub(e);G(a|0);z()}function UJa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0;g=Za-16|0;Za=g;i=j[a+4>>2];d=(i-d|0)+b|0;e=yh(g,a,c-d>>1);a:{if(c>>>0>d>>>0){f=d;while(1){h=hb(a);k=j[e+4>>2];j[114626]=0;I(521,h|0,k|0,f|0);h=j[114626];j[114626]=0;if((h|0)==1){break a}j[e+4>>2]=j[e+4>>2]+2;f=f+2|0;if(f>>>0<c>>>0){continue}break}}ub(e);BJa(b,d,i);Za=g+16|0;return}a=D()|0;C()|0;ub(e);G(a|0);z()}function Ada(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;j[114626]=0;N(2008,a|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[a+16>>2]=0;j[a+12>>2]=c;j[a+8>>2]=b;return}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,34831,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)!=1){Q();return}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function Do(a,b,c,d){a:{if(j[a+480180>>2]==4){if(c){h[b+830|0]=k[b+830|0]&15|c<<4;break a}c=k[b+830|0]>>>4|0;break a}if(d){if(c){h[b+854|0]=c;break a}c=k[b+854|0];break a}if(c){h[b+830|0]=c;break a}c=k[b+830|0]}b:{if(!(h[b+872|0]&1)){break b}c=j[b+688>>2]+((c&255)<<2)|0;j[b+688>>2]=(c|0)<256?c:256;if(!(j[a+480180>>2]&1)){break b}j[b+88>>2]=j[b+88>>2]|2097152}}function Bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Uh(a,b,c,d);j[a+4272>>2]=1065353216;j[a+4216>>2]=1056964608;j[a+4208>>2]=1056880300;j[a+4212>>2]=1050733080;j[a>>2]=81836;j[114626]=0;K(1632,a+44|0,2,2)|0;c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;N(1633,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}return a|0}a=D()|0;C()|0;we(b);G(a|0);z()}function $ta(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0;g=Za-16|0;Za=g;i=j[a+4>>2];d=(i-d|0)+b|0;e=_d(g,a,c-d>>2);a:{if(c>>>0>d>>>0){f=d;while(1){h=hb(a);k=j[e+4>>2];j[114626]=0;I(766,h|0,k|0,f|0);h=j[114626];j[114626]=0;if((h|0)==1){break a}j[e+4>>2]=j[e+4>>2]+4;f=f+4|0;if(f>>>0<c>>>0){continue}break}}ub(e);ht(b,d,i);Za=g+16|0;return}a=D()|0;C()|0;ub(e);G(a|0);z()}function YM(a){var b=0;a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=860902483){break a}b=a+4|0;b=k[b|0]|k[b+1|0]<<8;if((b<<24|b<<8&16711680)>>>16>>>0>2|k[a+6|0]>128){break a}b=a+200|0;b=k[b|0]|k[b+1|0]<<8;if((b<<24|b<<8&16711680)>>>16>>>0>3999){break a}b=a+140|0;if(!(k[b|0]|k[b+1|0]<<8)){break a}a=a+148|0;return(k[a|0]|k[a+1|0]<<8)==12800}return 0}function Q$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=Za-16|0;Za=e;f=j[Rb(a)>>2];d=j[c>>2]-j[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=j[b>>2];i=j[a>>2];g=gq((f|0)==2474?0:j[a>>2],d);if(g){if((f|0)!=2474){ud(a)}j[e+4>>2]=2412;f=yd(e+8|0,g,e+4|0);TC(a,f);mc(f);j[b>>2]=j[a>>2]+(h-i|0);j[c>>2]=d+j[a>>2];Za=e+16|0;return}Ku();z()}function M6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-32|0;Za=e;c=fo(e+24|0,c);j[114626]=0;f=j[b+12>>2];j[e+16>>2]=j[b+8>>2];j[e+20>>2]=f;f=j[b+4>>2];j[e+8>>2]=j[b>>2];j[e+12>>2]=f;P(2006,a+8|0,e+8|0,c|0,d|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Hc(c);wF(a);b=vF(a+88|0);j[a>>2]=84344;j[b>>2]=84432;Za=e+32|0;return a|0}a=D()|0;C()|0;Hc(c);G(a|0);z()}function oM(a,b,c,d){var e=0,f=0,g=0,h=0;f=Za-16|0;Za=f;if(Wi(a)){e=k[(Ld(k[a+819|0])?819:821)+a|0];mb(f+8|0,d+1074308|0,34);a:{if(!kb(f+8|0)){break a}if(e){if(e>>>0>120){break a}e=k[Pb(j[a+656>>2]+108|0,e-1|0)|0];break a}e=0}g=a,h=di(q(q(q(j[a+704>>2]<<4)*b)*Via(j[j[a+656>>2]+44>>2],(c+e<<16)-3997696>>16,j[a+876>>2]+j[a+768>>2]|0))),j[g+700>>2]=h}Za=f+16|0}function hGa(a,b,c){var d=0,e=0;e=Za-32|0;Za=e;a:{b:{if((j[hb(a)>>2]-j[a+4>>2]|0)/6>>>0>=b>>>0){bz(a,b,c);break b}d=hb(a);d=KP(e+8|0,Sy(a,Kf(a)+b|0),Kf(a),d);j[114626]=0;I(707,d|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(708,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Qs(d)}Za=e+32|0;return}a=D()|0;C()|0;Qs(d);G(a|0);z()}function bia(a,b,c){var d=0,e=0,f=0,g=0;e=Za-16|0;Za=e;d=ue(64);j[114626]=0;f=H(1420,d|0)|0;g=j[114626];j[114626]=0;a:{if((g|0)!=1){d=gx(e+8|0,f);f=j[d>>2];j[114626]=0;b=K(1626,f|0,b|0,c|0)|0;c=j[114626];j[114626]=0;b:{c:{if((c|0)!=1){if((b|0)==1){break c}fx(a);break b}a=D()|0;C()|0;Jf(d);break a}hp(a,d)}Jf(d);Za=e+16|0;return}a=D()|0;C()|0;Cb(d)}G(a|0);z()}function F5(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=Za-80|0;Za=f;if((c|0)>=1){g=f|8;h=f|4;while(1){d=Vb(f,a,72);e=j[b+20>>2];j[a+16>>2]=j[b+16>>2];j[a+20>>2]=e;e=j[b+12>>2];j[a+8>>2]=j[b+8>>2];j[a+12>>2]=e;e=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=e;e=d;d=b+24|0;Hv(e,a+24|0,d);Hv(h,a+48|0,d);Hv(g,b,d);a=a+72|0;b=b+36|0;d=(c|0)>1;c=c-1|0;if(d){continue}break}}Za=f+80|0}function tpa(a,b,c){var d=0,e=q(0),f=q(0),g=0,h=0;d=Za-16|0;Za=d;e=q(p(c+256|0,b)>>>0);b=d;a:{if(j[a+480180>>2]!=33554432){f=q(110);e=q(q(e/(k[a+480209|0]&128?q(10240):q(12288)))+q(.25));break a}f=q(125);e=q(e*q(9227362170349807e-20))}g=b,h=qh(q(Yd(q(2),e)*f)),j[g+12>>2]=h;Md(d+12|0,120,2e4);Za=d+16|0;a=j[a+24620>>2];b=j[d+12>>2];return(a|0)<b<<1?a>>>1|0:b}function mja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=Za-16|0;Za=b;i[a>>1]=0;c=Ij(a+4|0);d=Ij(a+16|0);j[a+36>>2]=0;e=Qc(a+40|0);f=lja(a+52|0);Xh(c);i[a+28>>1]=65472;j[114626]=0;j[b+12>>2]=1065353216;I(1585,c|0,128,b+12|0);g=j[114626];j[114626]=0;if((g|0)!=1){j[a+32>>2]=0;i[a+30>>1]=0;Xh(d);Za=b+16|0;return a|0}a=D()|0;C()|0;$P(f);gb(e);xf(d);xf(c);G(a|0);z()}function ija(a,b,c){var d=0,e=0;e=Za-32|0;Za=e;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>2>>>0>=b>>>0){yw(a,b,c);break b}d=hb(a);d=Aw(e+8|0,ie(a,sb(a)+b|0),sb(a),d);j[114626]=0;I(1589,d|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(1590,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}um(d)}Za=e+32|0;return}a=D()|0;C()|0;um(d);G(a|0);z()}function Tsa(a,b,c){var d=0,e=0;e=Za-32|0;Za=e;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>5>>>0>=b>>>0){Px(a,b,c);break b}d=hb(a);d=ML(e+8|0,El(a,de(a)+b|0),de(a),d);j[114626]=0;I(1188,d|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(1175,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}hs(d)}Za=e+32|0;return}a=D()|0;C()|0;hs(d);G(a|0);z()}function Mda(a,b,c,d,e,f,g,h,i,k){j[114626]=0;a=xa(1999,a|0,b|0,c|0,d|0)|0;b=j[114626];j[114626]=0;a:{if((b|0)==1){a=J(0)|0;C()|0;O(a|0)|0;j[114626]=0;Z(1993,34641,e|0,f|0,g|0,h|0,i|0,k|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();a=-255}return a}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function sF(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;a:{b:{c:{if(b-1>>>0>=65535){a=R(8)|0;j[114626]=0;c=E(85,c|0,40560)|0;b=j[114626];j[114626]=0;if((b|0)==1){break c}Wb(a,c);j[114626]=0;I(2002,a|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}b=D()|0;C()|0;gb(c);break b}j[j[a+32>>2]+1074416>>2]=b;Za=c+16|0;return}b=D()|0;C()|0;S(a|0)}G(b|0)}z()}function Xl(a,b,c){var d=0,e=0,f=0;d=Za-16|0;Za=d;hc(d+8|0,b);j[114626]=0;b=H(2442,d+8|0)|0;e=j[114626];j[114626]=0;a:{if((e|0)==1){break a}j[114626]=0;e=H(2452,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}j[c>>2]=e;j[114626]=0;F(2453,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}wb(d+8|0);Za=d+16|0;return}a=D()|0;C()|0;wb(d+8|0);G(a|0);z()}function uMa(a,b,c){var d=0,e=0;e=Za-32|0;Za=e;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>1>>>0>=b>>>0){Dt(a,b,c);break b}d=hb(a);d=Ct(e+8|0,ej(a,bc(a)+b|0),bc(a),d);j[114626]=0;I(379,d|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(380,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}lk(d)}Za=e+32|0;return}a=D()|0;C()|0;lk(d);G(a|0);z()}function sra(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if((j[hb(a)>>2]-j[a+4>>2]|0)/12>>>0>=b>>>0){hra(a,b);break b}c=hb(a);c=gra(d+8|0,Sn(a,cc(a)+b|0),cc(a),c);j[114626]=0;F(1229,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(1230,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}ZK(c)}Za=d+32|0;return}a=D()|0;C()|0;ZK(c);G(a|0);z()}function iJ(a,b){var c=0,d=0;a:{if(l[a+480188>>1]<=b>>>0){break a}b:{c:{c=p(b,896)+a|0;d=k[c+1075797|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(k[a+480209|0]&16)){break a}}c=h[c+1075799|0];if((c|0)>=0){aK(a,b,(d|0)==32,((k[(p(b,896)+a|0)+1075848|0]<<5)+a|0)+901692|0,c&255);return}aK(a,b,(d|0)==32,(((c&127)<<5)+a|0)+902204|0,0)}}function cCa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=q(0),i=0,j=0,k=0,l=0;f=Za-16|0;Za=f;if(d){a=a+e|0;e=0;while(1){n[f+12>>2]=n[b>>2];Kd(f+12|0,q(-1));g=q(n[f+12>>2]*q(128));n[f+12>>2]=g;j=a;g=Sd(g);a:{if(q(r(g))<q(2147483648)){i=~~g;break a}i=-2147483648}k=j,l=UBa(i),h[k|0]=l;a=a+c|0;b=b+4|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}Za=f+16|0}function Zl(a,b,c){var d=0,e=0,f=0;d=Za-16|0;Za=d;hc(d+8|0,b);j[114626]=0;b=H(2408,d+8|0)|0;e=j[114626];j[114626]=0;a:{if((e|0)==1){break a}j[114626]=0;e=H(2423,b|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break a}h[c|0]=e;j[114626]=0;F(2424,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}wb(d+8|0);Za=d+16|0;return}a=D()|0;C()|0;wb(d+8|0);G(a|0);z()}function Nda(a,b,c,d,e,f,g,h,i,k,l,m){j[114626]=0;a=JB(1998,a,b,c,d,e,f);b=j[114626];j[114626]=0;a:{if((b|0)==1){a=J(0)|0;C()|0;O(a|0)|0;j[114626]=0;Z(1993,34615,g|0,h|0,i|0,k|0,l|0,m|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();a=-255}return a}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function xq(a,b,c,d){var e=0,f=0;e=Za-160|0;Za=e;Vb(e+8|0,58128,144);a:{b:{if(b-1>>>0>=2147483647){if(b){break b}b=1;a=e+159|0}j[e+52>>2]=a;j[e+28>>2]=a;f=-2-a|0;b=b>>>0>f>>>0?f:b;j[e+56>>2]=b;a=a+b|0;j[e+36>>2]=a;j[e+24>>2]=a;a=xE(e+8|0,c,d,2295,2296);if(!b){break a}b=j[e+28>>2];h[b-((b|0)==j[e+24>>2])|0]=0;break a}j[114600]=61;a=-1}Za=e+160|0;return a}function uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Uh(a,b,c,d);c=a+4216|0;j[c>>2]=1051372203;j[c+4>>2]=0;j[a+4208>>2]=1065353216;j[a+4212>>2]=1065353216;j[a>>2]=82040;j[114626]=0;K(1632,a+44|0,2,2)|0;c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;N(1633,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}return a|0}a=D()|0;C()|0;we(b);G(a|0);z()}function uFa(a,b,c){var d=0,e=0;e=Za-32|0;Za=e;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>2>>>0>=b>>>0){IS(a,b,c);break b}d=hb(a);d=ds(e+8|0,ie(a,sb(a)+b|0),sb(a),d);j[114626]=0;I(735,d|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(96,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Qj(d)}Za=e+32|0;return}a=D()|0;C()|0;Qj(d);G(a|0);z()}function l7(a,b,c,d,e){var f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0;if(e){l=c+16|0;while(1){g=0;if(d){while(1){f=j[uf(b,g,h)>>2];k=Be(c,g);f=f+(j[k>>2]>>1)|0;m=f;f=ar(l)+f&-4096;j[k>>2]=m-f;f=f-2147481600>>>12|0;f=f>>>0>491520?f:491520;n=jm(a,g,h),o=(f|0)<557055?f:557055,i[n>>1]=o;g=g+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}}function jEa(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if((j[hb(a)>>2]-j[a+4>>2]|0)/33>>>0>=b>>>0){hEa(a,b);break b}c=hb(a);c=fEa(d+8|0,gEa(a,_j(a)+b|0),_j(a),c);j[114626]=0;F(762,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(763,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}AP(c)}Za=d+32|0;return}a=D()|0;C()|0;AP(c);G(a|0);z()}function O7(a,b,c,d,e){var f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0;if(e){l=c+16|0;while(1){g=0;if(d){while(1){f=j[uf(b,g,h)>>2];k=Be(c,g);f=f+(j[k>>2]>>1)|0;m=f;f=ar(l)+f&-4096;j[k>>2]=m-f;f=f-2147481600>>>12|0;f=f>>>0>491520?f:491520;n=lm(a,g,h),o=(f|0)<557055?f:557055,i[n>>1]=o;g=g+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}}function Kxa(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if((j[hb(a)>>2]-j[a+4>>2]|0)/12>>>0>=b>>>0){yxa(a,b);break b}c=hb(a);c=ey(d+8|0,Sn(a,cc(a)+b|0),cc(a),c);j[114626]=0;F(1014,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(1015,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}QM(c)}Za=d+32|0;return}a=D()|0;C()|0;QM(c);G(a|0);z()}function $Ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;a=kp(a);e=d,f=Lb(b),j[e+8>>2]=f;e=d,f=Mb(b),j[e>>2]=f;a:{if(rb(d+8|0,d)){while(1){b=j[d+8>>2];if((nk(b)|0)==(c|0)){b=hb(b);j[114626]=0;F(601,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}}fk(d+8|0);if(rb(d+8|0,d)){continue}break}}Za=d+16|0;return}b=D()|0;C()|0;Sc(a);G(b|0);z()}function vha(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>11>>>0>=b>>>0){rha(a,b);break b}c=hb(a);c=GH(d+8|0,qha(a,Te(a)+b|0),Te(a),c);j[114626]=0;F(1641,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(1637,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}zr(c)}Za=d+32|0;return}a=D()|0;C()|0;zr(c);G(a|0);z()}function sGa(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if((j[hb(a)>>2]-j[a+4>>2]|0)/48>>>0>=b>>>0){gFa(a,b);break b}c=hb(a);c=ZQ(d+8|0,_Q(a,ni(a)+b|0),ni(a),c);j[114626]=0;F(697,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(558,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}dt(c)}Za=d+32|0;return}a=D()|0;C()|0;dt(c);G(a|0);z()}function nGa(a,b,c){var d=0,e=0;e=Za-32|0;Za=e;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>>0>=b>>>0){gt(a,b,c);break b}d=hb(a);d=sl(e+8|0,ql(a,tc(a)+b|0),tc(a),d);j[114626]=0;I(701,d|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(364,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Jp(d)}Za=e+32|0;return}a=D()|0;C()|0;Jp(d);G(a|0);z()}function maa(a){a=a|0;var b=0,c=0,d=0,e=0;b=Za-32|0;Za=b;a=Mg(a);j[114626]=0;F(2148,b+16|0,0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){c=Lb(b+16|0);d=Mb(b+16|0);e=j[zc(b+8|0,a)>>2];j[114626]=0;K(2149,c|0,d|0,e|0)|0;c=j[114626];j[114626]=0;if((c|0)==1){break b}Tw(b+16|0);Za=b+32|0;return}c=D()|0;C()|0;break a}c=D()|0;C()|0;Tw(b+16|0)}Uc(a);G(c|0);z()}function iS(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=k[b|0]|k[b+1|0]<<8;c=OMa(k[a+3|0],0,18,0);d=d+c|0;b=ab;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=k[b|0]|k[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=k[a|0]|k[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;if(b>>>0<3){a=a+1|0}ab=a;return b}function Bda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;j[114626]=0;N(2008,a|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[a+4>>2]=c;j[a>>2]=b?b:1990;return}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,34803,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)!=1){Q();return}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function LP(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=j[a>>2];b:{if(!b){break b}c=j[a+8>>2];if(!c){break b}a=j[a+12>>2];if(!a){break b}e=bb[a|0](b)|0;d=ab;f=d;if((d|0)<0){break b}if((bb[c|0](b,0,0,0)|0)<=-1){break a}if((bb[c|0](b,0,0,2)|0)<=-1){break a}d=bb[a|0](b)|0;a=ab;bb[c|0](b,e,f,0)|0;if((a|0)<0){break b}g=yQ(d,a)}return g}bb[c|0](b,e,f,0)|0;return 0}function Jw(a,b,c,d){var e=0,f=0;a:{e=k[a|0];f=k[c|0];b:{if(!(k[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){h[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(k[b|0]|(e-5&255)>>>0>1){break a}h[a|0]=(e|0)==5?7:6;h[b|0]=k[d|0];break b}if(!((e|0)!=10|(f|0)!=20|k[d|0]!=159)){h[a|0]=39;break b}if((f|0)!=10|(e|0)!=20|k[b|0]!=159){break a}h[a|0]=39;h[b|0]=k[d|0]}h[c|0]=0}}function $2(){var a=0;j[114626]=0;H(2384,460776)|0;a=j[114626];j[114626]=0;a:{if((a|0)==1){break a}j[114626]=0;H(2385,460860)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}j[114626]=0;H(2384,461112)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}j[114626]=0;H(2385,461196)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}return}a=J(0)|0;C()|0;ib(a);z()}function uha(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>2>>>0>=b>>>0){hha(a,b);break b}c=hb(a);c=EH(d+8|0,ie(a,sb(a)+b|0),sb(a),c);j[114626]=0;F(1642,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(1639,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}yr(c)}Za=d+32|0;return}a=D()|0;C()|0;yr(c);G(a|0);z()}function oAa(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>3>>>0>=b>>>0){nAa(a,b);break b}c=hb(a);c=lAa(d+8|0,mAa(a,fg(a)+b|0),fg(a),c);j[114626]=0;F(920,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(921,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}YN(c)}Za=d+32|0;return}a=D()|0;C()|0;YN(c);G(a|0);z()}function eja(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>2>>>0>=b>>>0){yia(a,b);break b}c=hb(a);c=Aw(d+8|0,ie(a,sb(a)+b|0),sb(a),c);j[114626]=0;F(1591,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(1590,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}um(c)}Za=d+32|0;return}a=D()|0;C()|0;um(c);G(a|0);z()}function uta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-32|0;Za=d;j[d+16>>2]=b;e=d,f=yy(a,b,c),j[e+24>>2]=f;a:{if(!rb(d+24|0,d+16|0)){break a}j[d+8>>2]=j[d+24>>2];if(!rb(je(d+8|0),d+16|0)){break a}while(1){if(l[j[d+8>>2]>>1]!=l[c>>1]){i[j[d+24>>2]>>1]=l[j[d+8>>2]>>1];je(d+24|0)}if(rb(je(d+8|0),d+16|0)){continue}break}}Za=d+32|0;return j[d+24>>2]}function mFa(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>2>>>0>=b>>>0){kFa(a,b);break b}c=hb(a);c=jFa(d+8|0,ie(a,sb(a)+b|0),sb(a),c);j[114626]=0;F(738,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(739,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}RP(c)}Za=d+32|0;return}a=D()|0;C()|0;RP(c);G(a|0);z()}function _M(a){var b=0,c=0;a:{if(k[a+29|0]!=2){break a}b=k[a+28|0];if(k[a+30|0]!=2|((b|0)!=2?(b|0)!=26:0)){break a}b=k[a+31|0];if(b>>>0>21|!(1<<b&3146753)|k[a+33|0]>64){break a}b=k[a+34|0];if((b|0)!=88?b>>>0>=65:0){break a}b=a+28|0;a=a+20|0;while(1){c=k[a|0]-32|0;if((c&255)>>>0<=94){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0<95}return c}function TCa(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>2>>>0>=b>>>0){SCa(a,b);break b}c=hb(a);c=RCa(d+8|0,ie(a,sb(a)+b|0),sb(a),c);j[114626]=0;F(818,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(819,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}ZO(c)}Za=d+32|0;return}a=D()|0;C()|0;ZO(c);G(a|0);z()}function KCa(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>1>>>0>=b>>>0){JCa(a,b);break b}c=hb(a);c=ICa(d+8|0,ej(a,bc(a)+b|0),bc(a),c);j[114626]=0;F(825,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(826,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}UO(c)}Za=d+32|0;return}a=D()|0;C()|0;UO(c);G(a|0);z()}function ALa(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>1>>>0>=b>>>0){zLa(a,b);break b}c=hb(a);c=yLa(d+8|0,ej(a,bc(a)+b|0),bc(a),c);j[114626]=0;F(423,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(424,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}qS(c)}Za=d+32|0;return}a=D()|0;C()|0;qS(c);G(a|0);z()}function $na(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=Za-192|0;Za=c;Vb(c+144|0,b,44);d=j[b+44>>2];if(d){Vb(c+44|0,b,44);g=c,h=n7(c+44|0),j[g+96>>2]=h;j[c+100>>2]=ab;b=j[c+100>>2];f=j[c+96>>2];e=Sqa(zd(+(d>>>0)*.054945054945054944));d=f+e|0;b=ab+b|0;_6(c+96|0,BF(c+88|0,d,d>>>0<e>>>0?b+1|0:b));Vb(c+144|0,c+96|0,44)}b=a;a=Vb(c,c+144|0,44);D6(b,a);Za=a+192|0}function r_(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[kq(a)>>2]-j[a+4>>2]>>2>>>0>=b>>>0){GC(a,b);break b}c=Ck(a);c=xY(d+8|0,zY(a,sb(a)+b|0),sb(a),c);j[114626]=0;F(2554,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(2555,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}cC(c)}Za=d+32|0;return}a=D()|0;C()|0;cC(c);G(a|0);z()}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Za-16|0;Za=d;a:{if(!(k[c+1|0]&4)){break a}c=j[c+4>>2];g=d,h=nd(b),j[g+8>>2]=h;b:{if(!nb(b)){break b}if(k[Ub(b,0)|0]==43){Xf(d+8|0);c=c+1|0;break b}if(k[Ub(b,0)|0]!=45){break b}Xf(d+8|0);c=c+1|0}if(nb(b)>>>0>=c>>>0){break a}e=Cd(d,d+8|0);f=nb(b);Yv(b,j[e>>2],c-f|0,48)}Nc(a,b);Za=d+16|0}function Eza(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>2>>>0>=b>>>0){LN(a,b);break b}c=hb(a);c=Dza(d+8|0,ie(a,sb(a)+b|0),sb(a),c);j[114626]=0;F(946,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(947,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}EN(c)}Za=d+32|0;return}a=D()|0;C()|0;EN(c);G(a|0);z()}function qAa(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+24|0]=0;h[a+25|0]=0;h[a+16|0]=0;h[a+17|0]=0;h[a+18|0]=0;h[a+19|0]=0;h[a+20|0]=0;h[a+21|0]=0;h[a+22|0]=0;h[a+23|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;h[a+15|0]=0;Za=b+16|0}function lEa(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>4>>>0>=b>>>0){GS(a,b);break b}c=hb(a);c=OQ(d+8|0,eq(a,Xc(a)+b|0),Xc(a),c);j[114626]=0;F(760,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(609,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}$s(c)}Za=d+32|0;return}a=D()|0;C()|0;$s(c);G(a|0);z()}function aY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=Za-16|0;Za=f;j[f+8>>2]=e;j[f+12>>2]=c;c=nb(a);if(!((e|0)==-1|c>>>0<b>>>0)){j[f>>2]=c-b;g=f,h=j[tb(f+12|0,f)>>2],j[g+4>>2]=h;b=zm(zb(a)+b|0,d,j[tb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=j[f+4>>2];c=j[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}Za=f+16|0;return b|0}Pl();z()}function aMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-48|0;Za=d;a:{b:{e=UM(b,c);if((e|0)!=-1){f=d,g=nd(b),j[f+16>>2]=g;f=d,g=$e(d+16|0,e),j[f+24>>2]=g;f=d,g=$e(d+24|0,1),j[f+32>>2]=g;c=Cd(d+40|0,d+32|0);f=d,g=_e(b),j[f>>2]=g;e=Cd(d+8|0,d);Ex(b,j[c>>2],j[e>>2]);break b}if(!nb(b)){break b}if(PK(b,c)){break b}Qc(a);break a}Nc(a,b)}Za=d+48|0}function Zka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-48|0;Za=d;a:{b:{e=UM(b,c);if((e|0)!=-1){f=d,g=nd(b),j[f+16>>2]=g;f=d,g=$e(d+16|0,e),j[f+24>>2]=g;f=d,g=$e(d+24|0,1),j[f+32>>2]=g;c=Cd(d+40|0,d+32|0);f=d,g=_e(b),j[f>>2]=g;e=Cd(d+8|0,d);Ex(b,j[c>>2],j[e>>2]);break b}if(!nb(b)){break b}if(PK(b,c)){break b}Db(a);break a}Nc(a,b)}Za=d+48|0}function YLa(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>1>>>0>=b>>>0){uS(a,b);break b}c=hb(a);c=Ct(d+8|0,ej(a,bc(a)+b|0),bc(a),c);j[114626]=0;F(410,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(380,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}lk(c)}Za=d+32|0;return}a=D()|0;C()|0;lk(c);G(a|0);z()}function Vqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{c=vl(e,a+8|0,Dx(b,c));if(j[c>>2]!=j[c+4>>2]){while(1){d=j[a+16>>2];f=j[c>>2];j[114626]=0;I(1244,d|0,f|0,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[c>>2]+2|0;j[c>>2]=d;b=b+2|0;if((d|0)!=j[c+4>>2]){continue}break}}dc(c);Za=e+16|0;return}a=D()|0;C()|0;dc(c);G(a|0);z()}function Kha(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((tc(j[a+20>>2]+4|0)|0)!=8){break b}c=j[j[a+20>>2]+4>>2];if((k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))!=1869112133){break b}b=j[j[a+20>>2]+4>>2];c=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);b=k[b+4|0]|k[b+5|0]<<8|(k[b+6|0]<<16|k[b+7|0]<<24);j[a+4260>>2]=c;j[a+4264>>2]=b;break a}oH(a,b)}Ar(a)}function HT(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>2>>>0>=b>>>0){uT(a,b);break b}c=hb(a);c=sn(d+8|0,ie(a,sb(a)+b|0),sb(a),c);j[114626]=0;F(367,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(368,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}xh(c)}Za=d+32|0;return}a=D()|0;C()|0;xh(c);G(a|0);z()}function Co(a,b,c,d){a:{if(j[a+480180>>2]==4){d=k[b+830|0];if(c){h[b+830|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){h[b+854|0]=c;break a}c=k[b+854|0];break a}if(c){h[b+830|0]=c;break a}c=k[b+830|0]}b:{if(!(h[b+872|0]&1)){break b}c=j[b+688>>2]-((c&255)<<2)|0;j[b+688>>2]=(c|0)>0?c:0;if(!(j[a+480180>>2]&1)){break b}j[b+88>>2]=j[b+88>>2]|2097152}}function CY(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>4>>>0>=b>>>0){JW(a,b);break b}c=hb(a);c=IW(d+8|0,eq(a,Xc(a)+b|0),Xc(a),c);j[114626]=0;F(211,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(212,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}GB(c)}Za=d+32|0;return}a=D()|0;C()|0;GB(c);G(a|0);z()}function Bh(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e+307;if((b|0)<2047){b=b-1023|0;break a}a=a*8.98846567431158e+307;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.2250738585072014e-308;if((b|0)>-2045){b=b+1022|0;break a}a=a*2.2250738585072014e-308;b=((b|0)>-3066?b:-3066)+2044|0}WMa(0,0);WMa(1,b+1023<<20);return a*+XMa()}function ul(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;h[d+15|0]=b;a:{b:{c:{d:{if(qe(a)){c=Lj(a)-1|0;e=j[a+4>>2];if((c|0)==(e|0)){break d}break b}e=10;c=10;b=k[a+11|0];if((b|0)!=10){break c}}tl(a,c,1,c,c,0,0);b=e;if(qe(a)){break b}}c=a;Ue(a,b+1|0);break a}c=j[a>>2];ee(a,e+1|0);b=e}a=b+c|0;Td(a,d+15|0);h[d+14|0]=0;Td(a+1|0,d+14|0);Za=d+16|0}function jqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c>>>2;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=(lb(k[b|0])|lb(k[b+1|0])<<8)^32768,i[f>>1]=g;f=a,g=(lb(k[b+2|0])|lb(k[b+3|0])<<8)^32768,i[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e<<2}function gqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c>>>2;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=(lb(k[b+1|0])|lb(k[b|0])<<8)^32768,i[f>>1]=g;f=a,g=(lb(k[b+3|0])|lb(k[b+2|0])<<8)^32768,i[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e<<2}function loa(a,b,c,d){var e=0,f=0,g=0,i=0,k=0;e=Za-16|0;Za=e;b=Rb(b);a=koa(a,$b(20,4),$j(e+8|0,b));f=j[a>>2];j[114626]=0;f=H(1374,f+14|0)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;V(1377,b|0,f|0,20485,c|0,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}i=Rb(a),k=1,h[i+4|0]=k;Za=e+16|0;return}b=D()|0;C()|0;SJ(a);G(b|0);z()}function Fba(a,b,c,d){var e=0,f=0,g=0,i=0,k=0;e=Za-16|0;Za=e;b=Rb(b);a=Mqa(a,$b(40,4),$j(e+8|0,b));f=j[a>>2];j[114626]=0;f=H(1251,f+16|0)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;V(2101,b|0,f|0,38127,c|0,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}i=Rb(a),k=1,h[i+4|0]=k;Za=e+16|0;return}b=D()|0;C()|0;VK(a);G(b|0);z()}function CMa(a,b){if(!xMa(a,b)){a=Za-16|0;Za=a;h[b|0]=0;h[b+1|0]=0;h[b+2|0]=0;h[b+3|0]=0;h[b+4|0]=0;h[b+5|0]=0;h[b+6|0]=0;h[b+7|0]=0;h[b+24|0]=0;h[b+16|0]=0;h[b+17|0]=0;h[b+18|0]=0;h[b+19|0]=0;h[b+20|0]=0;h[b+21|0]=0;h[b+22|0]=0;h[b+23|0]=0;h[b+8|0]=0;h[b+9|0]=0;h[b+10|0]=0;h[b+11|0]=0;h[b+12|0]=0;h[b+13|0]=0;h[b+14|0]=0;h[b+15|0]=0;Za=a+16|0}}function yY(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>>0>=b>>>0){DW(a,b);break b}c=hb(a);c=sl(d+8|0,ql(a,tc(a)+b|0),tc(a),c);j[114626]=0;F(213,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(209,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Ul(c)}Za=d+32|0;return}a=D()|0;C()|0;Ul(c);G(a|0);z()}function uia(a,b,c,d){var e=0,f=0,g=0,i=0,k=0;e=Za-16|0;Za=e;b=Rb(b);a=tia(a,$b(32,4),$j(e+8|0,b));f=j[a>>2];j[114626]=0;f=H(732,f+16|0)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;V(1615,b|0,f|0,32530,c|0,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}i=Rb(a),k=1,h[i+4|0]=k;Za=e+16|0;return}b=D()|0;C()|0;UH(a);G(b|0);z()}function VI(a,b){var c=0,d=0,e=0,f=0;if(b){Wra(a+327720|0);Sw(a+131112|0,9.6377,.97);Sw(a+196648|0,8.5,.5);Sw(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(d=0,e=UI(c,a),f=b,f?d:e)){jla(a+24|0,o[a+8>>3],k[a+16|0]);b=j[a+20>>2];j[c+16>>2]=j[a+16>>2];j[c+20>>2]=b;b=j[a+12>>2];j[c+8>>2]=j[a+8>>2];j[c+12>>2]=b;b=j[a+4>>2];j[c>>2]=j[a>>2];j[c+4>>2]=b}}function VB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;j[d+12>>2]=b;a:{b:{c:{d:{if(qe(a)){c=Lj(a)-1|0;e=j[a+4>>2];if((c|0)==(e|0)){break d}break b}e=1;c=1;b=k[a+11|0];if((b|0)!=1){break c}}WB(a,c,1,c,c);b=e;if(qe(a)){break b}}c=a;Ue(a,b+1|0);break a}c=j[a>>2];ee(a,e+1|0);b=e}a=(b<<2)+c|0;ze(a,d+12|0);j[d+8>>2]=0;ze(a+4|0,d+8|0);Za=d+16|0}function NT(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>>0>=b>>>0){vA(a,b);break b}c=hb(a);c=sl(d+8|0,ql(a,tc(a)+b|0),tc(a),c);j[114626]=0;F(363,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(364,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Jp(c)}Za=d+32|0;return}a=D()|0;C()|0;Jp(c);G(a|0);z()}function XIa(a,b,c){var d=0,e=0,f=0,g=0;e=Za-32|0;Za=e;f=hb(a);d=vIa(e+8|0,gk(a,pd(a)+1|0),pd(a),f);g=j[d+8>>2];j[114626]=0;L(559,f|0,g|0,b|0,c|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[d+8>>2]=j[d+8>>2]+24;j[114626]=0;F(560,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}WQ(d);Za=e+32|0;return}a=D()|0;C()|0;WQ(d);G(a|0);z()}function WN(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=k[b|0]|k[b+1|0]<<8;b=OMa(k[a+30|0],0,37,0);c=ab;d=b;b=a+24|0;b=OMa(k[b|0]|k[b+1|0]<<8,0,192,0);d=d+b|0;c=ab+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;e=d;a=k[a+26|0];c=a>>>26|0;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;if(b>>>0<192){a=a+1|0}ab=a;return b}function VIa(a,b){var c=0,d=0;d=Za-32|0;Za=d;a:{b:{if(j[hb(a)>>2]-j[a+4>>2]>>>0>=b>>>0){uR(a,b);break b}c=hb(a);c=sl(d+8|0,ql(a,tc(a)+b|0),tc(a),c);j[114626]=0;F(41,c|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}j[114626]=0;F(40,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Et(c)}Za=d+32|0;return}a=D()|0;C()|0;Et(c);G(a|0);z()}function L5(a,b,c,d,e){var f=0,g=0,h=0,i=q(0),j=0,l=0,m=0;if((d|0)>=1){while(1){f=k[b|0];g=0;a:{if(!f){break a}g=19>>>k[c+h|0]&3|4}b=b+1|0;m=p(f,3)-6|0;f=4;i=q(0);while(1){if(f&g){j=Bd(a,6);l=(j|0)/3|0;i=q(n[((j-p(l,3)|0)+m<<2)+50224>>2]*q(2097152>>>l|0))}n[e>>2]=i;e=e+4|0;f=f>>1;if(f){continue}break}h=h+1|0;if((h|0)!=(d|0)){continue}break}}}function EFa(a,b,c,d){var e=0,f=0,g=0,i=0,k=0;e=Za-16|0;Za=e;b=Rb(b);a=CFa(a,$b(32,4),$j(e+8|0,b));f=j[a>>2];j[114626]=0;f=H(728,f+16|0)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;V(729,b|0,f|0,14646,c|0,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}i=Rb(a),k=1,h[i+4|0]=k;Za=e+16|0;return}b=D()|0;C()|0;aQ(a);G(b|0);z()}function DCa(a,b,c,d){var e=0,f=0,g=0,i=0,k=0;e=Za-16|0;Za=e;b=Rb(b);a=CCa(a,$b(20,4),$j(e+8|0,b));f=j[a>>2];j[114626]=0;f=H(822,f+14|0)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;V(828,b|0,f|0,15166,c|0,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}i=Rb(a),k=1,h[i+4|0]=k;Za=e+16|0;return}b=D()|0;C()|0;TO(a);G(b|0);z()}function tX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za+ -64|0;Za=d;e=1;a:{if(Rf(a,b,0)){break a}e=0;if(!b){break a}b=Du(b,71928,71976);e=0;if(!b){break a}Ab(d+8|4,0,52);j[d+56>>2]=1;j[d+20>>2]=-1;j[d+16>>2]=a;j[d+8>>2]=b;bb[j[j[b>>2]+28>>2]](b,d+8|0,j[c>>2],1);a=j[d+32>>2];if((a|0)==1){j[c>>2]=j[d+24>>2]}e=(a|0)==1}a=e;Za=d- -64|0;return a|0}function le(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{if(!nb(a)|(c-b|0)<5){break a}On(b,c);e=c-4|0;c=zb(a);f=c+nb(a)|0;while(1){b:{a=h[c|0];if(b>>>0>=e>>>0){break b}if((a|0)<1|(a|0)>=127|j[b>>2]==h[c|0]){c=(f-c|0)>1?c+1|0:c;b=b+4|0;continue}else{j[d>>2]=4;return}}break}if((a|0)<1|(a|0)>=127|h[c|0]>>>0>j[e>>2]-1>>>0){break a}j[d>>2]=4}}function iqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>2;j[e+8>>2]=j[a>>2];f=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(f){a=j[a+20>>2];c=f;g=d;while(1){g=(lb(k[b|0])|lb(k[b+1|0])<<8)+g|0;i[a>>1]=g;d=(lb(k[b+2|0])|lb(k[b+3|0])<<8)+d|0;i[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return f<<2}function fqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>2;j[e+8>>2]=j[a>>2];f=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(f){a=j[a+20>>2];c=f;g=d;while(1){g=(lb(k[b+1|0])|lb(k[b|0])<<8)+g|0;i[a>>1]=g;d=(lb(k[b+3|0])|lb(k[b+2|0])<<8)+d|0;i[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return f<<2}function eoa(a,b,c,d){var e=0,f=0,g=0,i=0,k=0;e=Za-16|0;Za=e;b=Rb(b);a=doa(a,TJ(1),$j(e+8|0,b));f=j[a>>2];j[114626]=0;f=H(1379,f+16|0)|0;g=j[114626];j[114626]=0;a:{if((g|0)==1){break a}j[114626]=0;V(1381,b|0,f|0,20485,c|0,d|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}i=Rb(a),k=1,h[i+4|0]=k;Za=e+16|0;return}b=D()|0;C()|0;QJ(a);G(b|0);z()}function gP(a,b,c,d){var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=a;f=+(p(a,d)>>>0)*2500;a:{if(!(!c|b)){break a}b:{if(!(!a|!b)){kc(e+12|0,10);a=k[j[e+12>>2]+15155|0];j[e+12>>2]=a;break b}if(a-1>>>0>9){break b}f=7338401.379310345/+(a>>>0);break a}f=+(a>>>0)*37878.78787878787}g=f;c:{if(f<4294967296&f>=0){a=~~g>>>0;break c}a=0}Za=e+16|0;return a}function eh(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0;h=e;e=0;i=e;f=c;c=0;e=OMa(h,e,f,c);k=ab;g=b;l=OMa(d,0,b,0);b=ab;d=OMa(d,m,f,c);c=b+d|0;b=ab;b=c>>>0<d>>>0?b+1|0:b;f=b;d=b+e|0;b=k;b=d>>>0<f>>>0?b+1|0:b;f=d;e=b;b=OMa(g,n,h,i)+c|0;d=ab;d=b>>>0<c>>>0?d+1|0:d;g=d;d=d+f|0;j[a+8>>2]=d;j[a+12>>2]=d>>>0<g>>>0?e+1|0:e;j[a>>2]=l;j[a+4>>2]=b}function Y9(a){var b=0,c=0;b=Za-16|0;Za=b;a:{b:{c:{if(a>>>0>=6){c=R(8)|0;j[114626]=0;b=E(85,b|0,39833)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}Wb(c,b);j[114626]=0;I(2002,c|0,83632,2010);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(b);break b}Za=b+16|0;return j[(a<<24>>24<<2)+40536>>2]}a=D()|0;C()|0;S(c|0)}G(a|0)}z()}function H5(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;j[d+8>>2]=-1;j[d>>2]=-1;j[d+4>>2]=-1;if((c|0)>=1){while(1){h=b+e|0;f=k[h|0];a:{if(!f){f=0;break a}g=0;while(1){i=g<<2;if(!(n[i+a>>2]!=q(0)|n[(i|4)+a>>2]!=q(0))){g=g+2|0;if(g>>>0<f>>>0){continue}break a}break}j[((e>>>0)%3<<2)+d>>2]=e;f=k[h|0]}a=(f<<2)+a|0;e=e+1|0;if((e|0)!=(c|0)){continue}break}}}function rca(a,b){a=a|0;b=b|0;var c=0;if(m[a+24>>2]>m[a+44>>2]){j[a+44>>2]=j[a+24>>2]}a:{if(m[a+8>>2]>=m[a+12>>2]){break a}if(ce(b,-1)){sm(a,j[a+8>>2],j[a+12>>2]-1|0,j[a+44>>2]);return jr(b)|0}if(!(k[a+48|0]&16)){if(!ce(rm(b),h[j[a+12>>2]-1|0])){break a}}sm(a,j[a+8>>2],j[a+12>>2]-1|0,j[a+44>>2]);c=rm(b);h[j[a+12>>2]]=c;return b|0}return-1}function mz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,m=0,n=0;f=Za-16|0;Za=f;j[f+12>>2]=c;kc(f+12|0,256);kc(f+12|0,65535);h=l[f+12>>1];bg(a,h);if(h){c=0;while(1){g=k[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}m=mk(a,c),n=g,i[m>>1]=n;c=c+1|0;if((h|0)!=(c|0)){continue}break}}Za=f+16|0;return 1}function Bu(a,b,c,d){h[a+53|0]=1;a:{if(j[a+4>>2]!=(c|0)){break a}h[a+52|0]=1;c=j[a+16>>2];if(!c){j[a+36>>2]=1;j[a+24>>2]=d;j[a+16>>2]=b;if((d|0)!=1|j[a+48>>2]!=1){break a}h[a+54|0]=1;return}if((b|0)==(c|0)){c=j[a+24>>2];if((c|0)==2){j[a+24>>2]=d;c=d}if(j[a+48>>2]!=1|(c|0)!=1){break a}h[a+54|0]=1;return}h[a+54|0]=1;j[a+36>>2]=j[a+36>>2]+1}}function tl(a,b,c,d,e,f,g){var h=0,i=0,k=0;h=Za-16|0;Za=h;if(-17-b>>>0>=c>>>0){i=zb(a);a:{if(b>>>0<2147483623){j[h+8>>2]=b<<1;j[h+12>>2]=b+c;c=Dk(j[Gc(h+12|0,h+8|0)>>2]);break a}c=-18}k=c+1|0;c=Sh(k);if(e){lh(c,i,e)}d=(d-f|0)-e|0;if(d){lh((c+e|0)+g|0,(e+i|0)+f|0,d)}b=b+1|0;if((b|0)!=11){Yf(a,i,b)}lf(a,c);jg(a,k);Za=h+16|0;return}kg();z()}function nma(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-16|0;Za=c;a:{if(!Yw(a,b,1)){break a}e=j[b+656>>2];d=a+1074308|0;mb(c+8|0,d,31);b:{if(kb(c+8|0)){a=j[b+740>>2];if(a){break b}break a}a=j[b+740>>2]}mb(c+8|0,d,31);d=To(e+68|0,a-kb(c+8|0)|0,64,64)-32|0;a=j[b+684>>2];f=b,g=Gb(((p(d,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),j[f+684>>2]=g}Za=c+16|0}function eG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-48|0;Za=d;e=j[b+12>>2];j[d+8>>2]=j[b+8>>2];j[d+12>>2]=e;e=j[b+4>>2];j[d>>2]=j[b>>2];j[d+4>>2]=e;e=QP(d);a:{if(e){faa(d+24|0,b);au(d+32|0,d+24|0);break a}eaa(d+16|0,b);au(d+32|0,d+16|0)}b=a;a=Gl(d+40|0,d+32|0);RA(b,a,c);jb(a);jb(d+32|0);b:{if(!e){jb(d+16|0);break b}jb(d+24|0)}Za=d+48|0}function _oa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=roa(d+8|0,El(a,de(a)+1|0),de(a),e);f=j[c+8>>2];j[114626]=0;I(1365,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+32;j[114626]=0;F(1366,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}UJ(c);Za=d+32|0;return}a=D()|0;C()|0;UJ(c);G(a|0);z()}function Zy(a,b,c){var d=0,e=0,f=0,g=0,i=0,l=0;a:{if(k[a+20|0]){break a}b=(-1-b>>>0<c>>>0?-1-b|0:c)+b|0;if(b>>>0<=m[a+16>>2]){break a}b=gz(b,4096);rQ(a,b-j[a+16>>2]|0);d=a,e=(g=a,i=fc(a+4|0,j[a+16>>2]),l=b-j[a+16>>2]|0,f=j[j[a>>2]+48>>2],bb[f](g|0,i|0,l|0)|0)+j[a+16>>2]|0,j[d+16>>2]=e;if(!(bb[j[j[a>>2]+44>>2]](a)|0)){break a}h[a+20|0]=1}}function Cka(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=Bka(d+8|0,gk(a,pd(a)+1|0),pd(a),e);f=j[c+8>>2];j[114626]=0;I(1554,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+24;j[114626]=0;F(1555,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}EI(c);Za=d+32|0;return}a=D()|0;C()|0;EI(c);G(a|0);z()}function vL(a){h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+23|0]=0;h[a+24|0]=0;h[a+25|0]=0;h[a+26|0]=0;h[a+16|0]=0;h[a+17|0]=0;h[a+18|0]=0;h[a+19|0]=0;h[a+20|0]=0;h[a+21|0]=0;h[a+22|0]=0;h[a+23|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;h[a+15|0]=0}function tna(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=Dma(d+8|0,ie(a,sb(a)+1|0),sb(a),e);f=j[c+8>>2];j[114626]=0;I(1414,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+4;j[114626]=0;F(1415,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}mJ(c);Za=d+32|0;return}a=D()|0;C()|0;mJ(c);G(a|0);z()}function mEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;if(k[a+40|0]){e=0}else{a:{b:{d=j[a+28>>2];if(d){if(!c){break a}d=bb[d|0](j[a+24>>2],b,c)|0;if(!d){break b}while(1){e=d+e|0;f=e>>>0<d>>>0?f+1|0:f;c=c-d|0;if(!c){break a}b=b+d|0;d=bb[j[a+28>>2]](j[a+24>>2],b,c)|0;if(d){continue}break}break b}h[a+40|0]=1;return 0}h[a+40|0]=1}}return e|0}function fza(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=Kya(d+8|0,Lya(a,Vj(a)+1|0),Vj(a),e);f=j[c+8>>2];j[114626]=0;I(973,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+56;j[114626]=0;F(974,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}rN(c);Za=d+32|0;return}a=D()|0;C()|0;rN(c);G(a|0);z()}function fta(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=ML(d+8|0,El(a,de(a)+1|0),de(a),e);f=j[c+8>>2];j[114626]=0;I(1174,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+32;j[114626]=0;F(1175,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}hs(c);Za=d+32|0;return}a=D()|0;C()|0;hs(c);G(a|0);z()}function Zla(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=Qla(d+8|0,ie(a,sb(a)+1|0),sb(a),e);f=j[c+8>>2];j[114626]=0;I(1511,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+4;j[114626]=0;F(1512,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}RI(c);Za=d+32|0;return}a=D()|0;C()|0;RI(c);G(a|0);z()}function Yza(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-48|0;Za=c;a:{if(zs(a)>>>0<b>>>0){hb(a);d=py(c+32|0);j[114626]=0;F(932,d|0,b|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}Xi(c+16|0,a);Wj(c+8|0,a);j[114626]=0;I(933,d|0,c+16|0,c+8|0);b=j[114626];j[114626]=0;if((b|0)==1){break a}oy(a,d);Vd(d)}Za=c+48|0;return}a=D()|0;C()|0;Vd(d);G(a|0);z()}function Yha(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=Xha(d+8|0,ie(a,sb(a)+1|0),sb(a),e);f=j[c+8>>2];j[114626]=0;I(1628,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+4;j[114626]=0;F(1629,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}PH(c);Za=d+32|0;return}a=D()|0;C()|0;PH(c);G(a|0);z()}function Taa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=h8(d+8|0,eq(a,Xc(a)+1|0),Xc(a),e);f=j[c+8>>2];j[114626]=0;I(2119,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+16;j[114626]=0;F(2120,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}KF(c);Za=d+32|0;return}a=D()|0;C()|0;KF(c);G(a|0);z()}function Pqa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=TK(d+8|0,Sn(a,cc(a)+1|0),cc(a),e);f=j[c+8>>2];j[114626]=0;I(1249,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+12;j[114626]=0;F(1250,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}$r(c);Za=d+32|0;return}a=D()|0;C()|0;$r(c);G(a|0);z()}function Jwa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=Awa(d+8|0,ie(a,sb(a)+1|0),sb(a),e);f=j[c+8>>2];j[114626]=0;I(1052,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+4;j[114626]=0;F(1053,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}DM(c);Za=d+32|0;return}a=D()|0;C()|0;DM(c);G(a|0);z()}function Iaa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=b8(d+8|0,gk(a,pd(a)+1|0),pd(a),e);f=j[c+8>>2];j[114626]=0;I(2124,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+24;j[114626]=0;F(2125,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}IF(c);Za=d+32|0;return}a=D()|0;C()|0;IF(c);G(a|0);z()}function Hxa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=ey(d+8|0,Sn(a,cc(a)+1|0),cc(a),e);f=j[c+8>>2];j[114626]=0;I(1016,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+12;j[114626]=0;F(1011,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}ss(c);Za=d+32|0;return}a=D()|0;C()|0;ss(c);G(a|0);z()}function ega(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=kH(d+8|0,ie(a,sb(a)+1|0),sb(a),e);f=j[c+8>>2];j[114626]=0;I(1755,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+4;j[114626]=0;F(1752,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}sr(c);Za=d+32|0;return}a=D()|0;C()|0;sr(c);G(a|0);z()}function Sya(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=Rya(d+8|0,gk(a,pd(a)+1|0),pd(a),e);f=j[c+8>>2];j[114626]=0;I(982,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+24;j[114626]=0;F(983,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}tN(c);Za=d+32|0;return}a=D()|0;C()|0;tN(c);G(a|0);z()}function PDa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=MDa(d+8|0,gk(a,pd(a)+1|0),pd(a),e);f=j[c+8>>2];j[114626]=0;I(768,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+24;j[114626]=0;F(769,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}qP(c);Za=d+32|0;return}a=D()|0;C()|0;qP(c);G(a|0);z()}function OHa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=MHa(d+8|0,gk(a,pd(a)+1|0),pd(a),e);f=j[c+8>>2];j[114626]=0;I(605,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+24;j[114626]=0;F(606,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}PQ(c);Za=d+32|0;return}a=D()|0;C()|0;PQ(c);G(a|0);z()}function MJa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=IJa(d+8|0,gk(a,pd(a)+1|0),pd(a),e);f=j[c+8>>2];j[114626]=0;I(528,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+24;j[114626]=0;F(529,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}xR(c);Za=d+32|0;return}a=D()|0;C()|0;xR(c);G(a|0);z()}function Fia(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=Aw(d+8|0,ie(a,sb(a)+1|0),sb(a),e);f=j[c+8>>2];j[114626]=0;I(1597,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+4;j[114626]=0;F(1590,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}um(c);Za=d+32|0;return}a=D()|0;C()|0;um(c);G(a|0);z()}function Asa(a,b,c){var d=0,e=0,f=0,g=0;d=j[a+4>>2];e=j[a>>2];if((d|0)>=(e|0)){f=a+14|0;g=a+12|0;while(1){j[a+8>>2]=j[a+12>>2];ysa(a,g,f);e=j[a>>2];d=j[a+4>>2]-e|0;j[a+4>>2]=d;if((d|0)>=(e|0)){continue}break}}f=b;b=e-d|0;i[f>>1]=(p(i[a+12>>1],d)+p(b,i[a+8>>1])|0)/(e|0);i[c>>1]=(p(i[a+14>>1],d)+p(b,i[a+10>>1])|0)/(e|0);j[a+4>>2]=d+49716}function xx(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;a:{if(j[b+480180>>2]&64671904){b=k[c+4|0];h[e|0]=0;j[a>>2]=k[(b&15)+20832|0];h[a+4|0]=k[e|0];break a}h[e+15|0]=0;f=k[c+4|0];if(!(k[c+3|0]!=4|j[b+480180>>2]!=4)){h[e+15|0]=1;f=f<<1}mb(e,b+1074308|0,66);if(!(!d|!kb(e))){j[e>>2]=0;hi(a,e,e+15|0);break a}j[e>>2]=f<<4;hi(a,e,e+15|0)}Za=e+16|0}function vja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=tja(e,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){d=j[a+16>>2];f=j[b>>2];j[114626]=0;I(1574,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b>>2]+52|0;j[b>>2]=d;if((d|0)!=j[b+4>>2]){continue}break}}dc(b);Za=e+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function ZIa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=ZQ(d+8|0,_Q(a,ni(a)+1|0),ni(a),e);f=j[c+8>>2];j[114626]=0;I(557,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+48;j[114626]=0;F(558,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}dt(c);Za=d+32|0;return}a=D()|0;C()|0;dt(c);G(a|0);z()}function Hsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=Gsa(e,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){d=j[a+16>>2];f=j[b>>2];j[114626]=0;I(1172,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b>>2]+32|0;j[b>>2]=d;if((d|0)!=j[b+4>>2]){continue}break}}dc(b);Za=e+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function HFa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=cE(d+8|0,Sn(a,cc(a)+1|0),cc(a),e);f=j[c+8>>2];j[114626]=0;I(727,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+12;j[114626]=0;F(205,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Gq(c);Za=d+32|0;return}a=D()|0;C()|0;Gq(c);G(a|0);z()}function EHa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=OQ(d+8|0,eq(a,Xc(a)+1|0),Xc(a),e);f=j[c+8>>2];j[114626]=0;I(608,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+16;j[114626]=0;F(609,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}$s(c);Za=d+32|0;return}a=D()|0;C()|0;$s(c);G(a|0);z()}function nU(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=aB(d+8|0,El(a,de(a)+1|0),de(a),e);f=j[c+8>>2];j[114626]=0;I(347,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+32;j[114626]=0;F(267,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Xp(c);Za=d+32|0;return}a=D()|0;C()|0;Xp(c);G(a|0);z()}function l4(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=cE(d+8|0,Sn(a,cc(a)+1|0),cc(a),e);f=j[c+8>>2];j[114626]=0;I(204,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+12;j[114626]=0;F(205,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Gq(c);Za=d+32|0;return}a=D()|0;C()|0;Gq(c);G(a|0);z()}function TDa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=sn(d+8|0,ie(a,sb(a)+1|0),sb(a),e);f=j[c+8>>2];j[114626]=0;I(766,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+4;j[114626]=0;F(368,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}xh(c);Za=d+32|0;return}a=D()|0;C()|0;xh(c);G(a|0);z()}function QKa(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=Ct(d+8|0,ej(a,bc(a)+1|0),bc(a),e);f=j[c+8>>2];j[114626]=0;I(381,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+2;j[114626]=0;F(380,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}lk(c);Za=d+32|0;return}a=D()|0;C()|0;lk(c);G(a|0);z()}function ID(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Za-16|0;Za=b;e=b+16|0;a:{while(1){c=j[a+36>>2];f=bb[j[j[c>>2]+20>>2]](c,j[a+40>>2],b+8|0,e,b+4|0)|0;c=-1;d=j[b+4>>2]-(b+8|0)|0;if((d|0)!=(Ai(b+8|0,1,d,j[a+32>>2])|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}c=Sq(j[a+32>>2])?-1:0}Za=b+16|0;return c|0}function C9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=UK(a);a:{if(!j[b+4>>2]){break a}c=j[b+4>>2];j[114626]=0;F(2172,a|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){c=j[b>>2];e=j[b>>2];f=p(j[b+4>>2],12);b=j[b+4>>2];j[114626]=0;L(2173,a|0,c|0,e+f|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;HA(d);G(a|0);z()}return a|0}function AT(a,b,c){var d=0,e=0;c=BT(a,b,c);if(!c){return 0}if(!((k[a+550|0]|k[a+551|0]<<8|(k[a+552|0]<<16|k[a+553|0]<<24))!=1297110104?(k[a+550|0]|k[a+551|0]<<8|(k[a+552|0]<<16|k[a+553|0]<<24))!=1481920589:0)){c=b+236|0;b=0;while(1){e=k[(a+b|0)+554|0];d=Oc(c,b);i[d>>1]=l[d>>1]|e<<8;b=b+1|0;if((b|0)!=120){continue}break}c=674}return c}function pU(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=IA(d+8|0,ie(a,sb(a)+1|0),sb(a),e);f=j[c+8>>2];j[114626]=0;I(346,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+4;j[114626]=0;F(343,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Rp(c);Za=d+32|0;return}a=D()|0;C()|0;Rp(c);G(a|0);z()}function kra(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=ds(d+8|0,ie(a,sb(a)+1|0),sb(a),e);f=j[c+8>>2];j[114626]=0;I(411,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+4;j[114626]=0;F(96,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Qj(c);Za=d+32|0;return}a=D()|0;C()|0;Qj(c);G(a|0);z()}function j0(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=sl(d+8|0,ql(a,tc(a)+1|0),tc(a),e);f=j[c+8>>2];j[114626]=0;I(210,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+1;j[114626]=0;F(209,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Ul(c);Za=d+32|0;return}a=D()|0;C()|0;Ul(c);G(a|0);z()}function WB(a,b,c,d,e){var f=0,g=0,h=0;f=Za-16|0;Za=f;if(1073741807-b>>>0>=c>>>0){g=zb(a);a:{if(b>>>0<536870887){j[f+8>>2]=b<<1;j[f+12>>2]=b+c;c=Ql(j[Gc(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=Ak(h);if(e){Jh(c,g,e)}d=d-e|0;if(d){e=e<<2;Jh(e+c|0,e+g|0,d)}b=b+1|0;if((b|0)!=2){Kn(g,b)}lf(a,c);jg(a,h);Za=f+16|0;return}kg();z()}function NEa(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;a:{if(!b){break a}if(!yb(a,b)){break a}while(1){h[c+11|0]=0;b:{if(b>>>0>d>>>0){Df(a,c+11|0);e=h[c+11|0];f=e>>>31|0;break b}e=0-f|0}h[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}j[c+4>>2]=j[c+12>>2];a=c+4|0;d=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24)}Za=c+16|0;return d}function Cia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=wh(e,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){d=j[a+16>>2];f=j[b>>2];j[114626]=0;I(1597,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b>>2]+4|0;j[b>>2]=d;if((d|0)!=j[b+4>>2]){continue}break}}dc(b);Za=e+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function $Ea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=ZEa(e,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){d=j[a+16>>2];f=j[b>>2];j[114626]=0;I(706,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b>>2]+6|0;j[b>>2]=d;if((d|0)!=j[b+4>>2]){continue}break}}dc(b);Za=e+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function vN(a){var b=0;a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=-28486832|k[a+63|0]!=26){break a}b=a+65|0;if(k[a- -64|0]&3|(k[a+66|0]|(k[b|0]!=1?k[b|0]!=16:0))){break a}b=a+78|0;if((k[b|0]|k[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((k[a|0]|k[a+1|0]<<8)>>>0>127){break a}a=Uya(b,a);return(k[a|0]|k[a+1|0]<<8)!=0}return 0}function tFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=wh(e,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){d=j[a+16>>2];f=j[b>>2];j[114626]=0;I(411,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b>>2]+4|0;j[b>>2]=d;if((d|0)!=j[b+4>>2]){continue}break}}dc(b);Za=e+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function sMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=vl(e,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){d=j[a+16>>2];f=j[b>>2];j[114626]=0;I(381,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b>>2]+2|0;j[b>>2]=d;if((d|0)!=j[b+4>>2]){continue}break}}dc(b);Za=e+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function aFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=Js(e,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){d=j[a+16>>2];f=j[b>>2];j[114626]=0;I(571,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b>>2]+1|0;j[b>>2]=d;if((d|0)!=j[b+4>>2]){continue}break}}dc(b);Za=e+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function ZHa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Za-32|0;Za=e;j[e+28>>2]=d;a:{if(k[a+8|0]){d=a+12|0;g=e,h=tc(d)-c|0,j[g+24>>2]=h;a=j[tb(e+24|0,e+28|0)>>2];g=e,h=Lb(d),j[g+24>>2]=h;f=$e(e+24|0,c);g=e,h=Lb(d),j[g+8>>2]=h;g=e,h=$e(e+8|0,c),j[g+16>>2]=h;aj(f,$e(e+16|0,a),b);break a}a=BHa(a,b,c,d)}Za=e+32|0;return a|0}function Dva(a,b){var c=0,d=0,e=0,f=0;d=Za-32|0;Za=d;e=hb(a);c=ds(d+8|0,ie(a,sb(a)+1|0),sb(a),e);f=j[c+8>>2];j[114626]=0;I(95,e|0,f|0,b|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){break a}j[c+8>>2]=j[c+8>>2]+4;j[114626]=0;F(96,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Qj(c);Za=d+32|0;return}a=D()|0;C()|0;Qj(c);G(a|0);z()}function QLa(a,b){var c=0,d=0,e=0;c=Za-32|0;Za=c;j[c+16>>2]=b;j[c+24>>2]=a;d=c,e=sLa(a,b),j[d+24>>2]=e;if(rb(c+24|0,c+16|0)){j[c>>2]=j[c+24>>2];Id(c);if(rb(Id(c),c+16|0)){while(1){if(!al(j[c+24>>2],j[c>>2])){a=j[j[c>>2]>>2];d=j[Id(c+24|0)>>2],e=a,j[d>>2]=e}if(rb(Id(c),c+16|0)){continue}break}}Id(c+24|0)}Za=c+32|0;return j[c+24>>2]}function gt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=rl(e,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){d=hb(a);f=j[b+4>>2];j[114626]=0;I(571,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b+4>>2]+1|0;j[b+4>>2]=d;if((d|0)!=j[b+8>>2]){continue}break}}ub(b);Za=e+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function bz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=np(e,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){d=hb(a);f=j[b+4>>2];j[114626]=0;I(706,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b+4>>2]+6|0;j[b+4>>2]=d;if((d|0)!=j[b+8>>2]){continue}break}}ub(b);Za=e+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function Ura(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;hb(b);f=lL(a,c+8|0);a:{d=fg(b);if(!d){break a}j[114626]=0;F(1215,a|0,d|0);e=j[114626];j[114626]=0;if((e|0)!=1){e=j[b+4>>2];b=j[b>>2];j[114626]=0;L(1216,a|0,b|0,e|0,d|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;Ix(f);G(a|0);z()}Za=c+16|0;return a|0}function IT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=rl(e,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){d=hb(a);f=j[b+4>>2];j[114626]=0;I(366,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b+4>>2]+1|0;j[b+4>>2]=d;if((d|0)!=j[b+8>>2]){continue}break}}ub(b);Za=e+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function IS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=_d(e,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){d=hb(a);f=j[b+4>>2];j[114626]=0;I(411,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b+4>>2]+4|0;j[b+4>>2]=d;if((d|0)!=j[b+8>>2]){continue}break}}ub(b);Za=e+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function Dt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=yh(e,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){d=hb(a);f=j[b+4>>2];j[114626]=0;I(381,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b+4>>2]+2|0;j[b+4>>2]=d;if((d|0)!=j[b+8>>2]){continue}break}}ub(b);Za=e+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function vv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=Za-240|0;Za=f;j[f>>2]=a;g=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;h=e-j[(i<<2)+d>>2]|0;if((bb[b|0](a,h)|0)>=0){if((bb[b|0](a,e)|0)>-1){break a}}a=(bb[b|0](h,e)|0)>-1;e=a?h:e;j[(g<<2)+f>>2]=e;g=g+1|0;c=a?c-1|0:i;if((c|0)<2){break a}a=j[f>>2];continue}}qE(f,g);Za=f+240|0}function kqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c>>>2;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=lb(k[b|0])|lb(k[b+1|0])<<8,i[f>>1]=g;f=a,g=lb(k[b+2|0])|lb(k[b+3|0])<<8,i[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e<<2}function hqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c>>>2;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=lb(k[b+1|0])|lb(k[b|0])<<8,i[f>>1]=g;f=a,g=lb(k[b+3|0])|lb(k[b+2|0])<<8,i[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e<<2}function dU(a){var b=0;a:{b:{c:{d:{if((a|0)<=-1){a=R(8)|0;j[114626]=0;H(352,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break c}break d}if(a>>>0<56){break a}a=R(8)|0;j[114626]=0;H(352,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break b}}b=D()|0;C()|0;S(a|0);G(b|0);z()}Y(a|0,77416,265);z()}Y(a|0,77416,265);z()}return k[a+11680|0]}function RV(a){var b=0,c=0,d=0,e=0;d=Za-32|0;Za=d;c=hb(a);b=aB(d+8|0,El(a,de(a)+1|0),de(a),c);e=j[b+8>>2];j[114626]=0;F(266,c|0,e|0);c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[b+8>>2]=j[b+8>>2]+32;j[114626]=0;F(267,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Xp(b);Za=d+32|0;return}a=D()|0;C()|0;Xp(b);G(a|0);z()}function tw(a){var b=0,c=0,d=0,e=0;b=Bg(+n[a+4228>>2]*8)*.25+ -.25;o[a+4248>>3]=b;if(k[a+4240|0]){e=a;if(b<=45e-5){b=0}else{b=Xn(b)*1.4426950408889634;d=v(b);b=b-d;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=.5849625007211562;if(b<.792481250360578){break a}c=1}b=Bg(c+d)*.5}o[e+4248>>3]=b}xr(a)}function qN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;hb(b);f=oN(a,c+8|0);a:{d=tc(b);if(!d){break a}j[114626]=0;F(563,a|0,d|0);e=j[114626];j[114626]=0;if((e|0)!=1){e=j[b+4>>2];b=j[b>>2];j[114626]=0;L(987,a|0,b|0,e|0,d|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;Mp(f);G(a|0);z()}Za=c+16|0;return a|0}function cH(a){a=a|0;var b=0,c=0;c=Za-16|0;Za=c;b=(xe(j[a+16>>2])|0)/5|0;b=ic(b,b>>31);j[a+4272>>2]=b;j[114626]=0;j[c+12>>2]=0;I(1640,a+4256|0,b<<1,c+12|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){b=J(71396)|0;if((C()|0)!=(W(71396)|0)){break a}O(b|0)|0;j[a+4272>>2]=0;Q()}j[a+4276>>2]=0;j[a+4268>>2]=0;Za=c+16|0;return}G(b|0);z()}function _G(a){var b=q(0),c=0,d=q(0),e=0;b=n[a+4224>>2];n[a+4260>>2]=y(q(q(1)-q(b*b)));h[a+4264|0]=n[a+4236>>2]>q(.5);c=a;d=q(j[a+4256>>2]<<1>>>0);b=q(n[a+4228>>2]*d);a:{if(b<q(4294967296)&b>=q(0)){e=~~b>>>0;break a}e=0}j[c+4248>>2]=e;c=a+4252|0;b=q(n[a+4232>>2]*d);b:{if(b<q(4294967296)&b>=q(0)){a=~~b>>>0;break b}a=0}j[c>>2]=a}function MS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;hb(b);f=ES(a,c+8|0);a:{d=sb(b);if(!d){break a}j[114626]=0;F(404,a|0,d|0);e=j[114626];j[114626]=0;if((e|0)!=1){e=j[b+4>>2];b=j[b>>2];j[114626]=0;L(408,a|0,b|0,e|0,d|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;os(f);G(a|0);z()}Za=c+16|0;return a|0}function h5(a){var b=0,c=0;a:{b:{c:{if(j[a+1380>>2]!=-1){break c}b=he(a);if(j[a+96>>2]){break b}if((b|0)!=79){break a}if((he(a)|0)!=103){break a}if((he(a)|0)!=103){break a}if((he(a)|0)!=83){break a}if(!ME(a)){break b}if(!(h[a+1375|0]&1)){break c}h[a+1376|0]=0;j[a+1384>>2]=0;Nb(a,32);return 0}c=Dv(a)}return c}Nb(a,30);return 0}function FQ(a){a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=-28490681|k[a+68|0]!=13|(k[a+69|0]!=10|k[a+70|0]!=26)){break a}if(k[a+76|0]|((k[a+71|0]|k[a+72|0]<<8|(k[a+73|0]<<16|k[a+74|0]<<24))!=1397116231|k[a+75|0]!=1)){break a}a=a+116|0;if((k[a|0]|k[a+1|0]<<8)>>>0>=10){break a}return(k[a|0]|k[a+1|0]<<8)!=0}return 0}function pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=lha(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(1643,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+2048|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function ne(a){var b=0,c=0,d=0;a:{b:{b=a;if(!(b&3)){break b}if(!k[a|0]){return 0}while(1){b=b+1|0;if(!(b&3)){break b}if(k[b|0]){continue}break}break a}while(1){c=b;b=b+4|0;d=j[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=k[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function m7(a,b,c,d,e){var f=0,g=0,h=0,k=0,l=0,m=0;if(e){k=c+4|0;while(1){g=0;if(d){while(1){f=j[uf(b,g,h)>>2];Pb(c,g);f=(f+((br(k)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;f=f>>>0>491520?f:491520;l=jm(a,g,h),m=(f|0)<557055?f:557055,i[l>>1]=m;g=g+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}}function WBa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=LBa(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(877,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+20|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}



function P7(a,b,c,d,e){var f=0,g=0,h=0,k=0,l=0,m=0;if(e){k=c+4|0;while(1){g=0;if(d){while(1){f=j[uf(b,g,h)>>2];Pb(c,g);f=(f+((br(k)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;f=f>>>0>491520?f:491520;l=lm(a,g,h),m=(f|0)<557055?f:557055,i[l>>1]=m;g=g+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}}function mm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=qr(a+60|0);j[a>>2]=76976;j[d>>2]=76996;j[114626]=0;e=a+8|0;K(175,a|0,77008,e|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){a:{j[a>>2]=76976;j[d>>2]=76996;j[114626]=0;K(176,e|0,b|0,c|8)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}return a|0}}a=D()|0;C()|0;og(d);G(a|0);z()}function dW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-32|0;Za=d;b=Mf(d,b);j[114626]=0;I(253,d+16|0,b|0,c|0);e=j[114626];j[114626]=0;a:{b:{if((e|0)!=1){j[114626]=0;I(5,a|0,d+16|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}gb(d+16|0);gb(b);Za=d+32|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(d+16|0)}gb(b);G(a|0);z()}function Cy(a,b,c,d,e){var f=0;f=Za-32|0;Za=f;xO(a,b);ABa(b,c,e);on(f,3,b);qc(f+16|0,f);j[114626]=0;E(369,d|0,f+16|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){a=d+32|0;gb(f+16|0);while(1){if((k[d|0]-1&255)>>>0<=30){h[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=Dy(b);Za=f+32|0;return a}a=D()|0;C()|0;gb(f+16|0);G(a|0);z()}function CR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-32|0;Za=d;f=d+8|0;g=b;if(Fz(b,d+24|0)){e=KJa(d+24|0)}cd(f,g,e);a=Ez(a,d+24|0,d+8|0);jb(d+8|0);a:{if(!c){break a}e=(e>>>0)%(c>>>0)|0;if(!e){break a}j[114626]=0;E(338,b|0,c-e|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break a}b=D()|0;C()|0;Re(a);G(b|0);z()}Za=d+32|0}function zN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-32|0;Za=d;f=d+8|0;g=b;if(Fz(b,d+24|0)){e=my(d+24|0)}cd(f,g,e);a=Ez(a,d+24|0,d+8|0);jb(d+8|0);a:{if(!c){break a}e=(e>>>0)%(c>>>0)|0;if(!e){break a}j[114626]=0;E(338,b|0,c-e|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break a}b=D()|0;C()|0;Re(a);G(b|0);z()}Za=d+32|0}function s5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,i=0;f=Za-1520|0;Za=f;r5(f+8|0,e);h[f+56|0]=1;j[f+48>>2]=a+b;j[f+40>>2]=a;a:{b:{if(!q5(f+8|0)){j[d>>2]=j[f+104>>2]?1:j[f+108>>2];break b}b=Ad(f+8|0,1512);if(b){g=c,i=j[Vb(b,f+8|0,1512)+32>>2]-a|0,j[g>>2]=i;j[d>>2]=0;break a}TE(f+8|0)}b=0}Za=f+1520|0;return b|0}function qE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=Za-256|0;Za=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;j[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;Vb(c,j[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;Vb(j[g>>2],j[(c<<2)+a>>2],f);j[g>>2]=j[g>>2]+f;if((b|0)!=(c|0)){continue}break}d=d-f|0;if(!d){break a}c=j[h>>2];continue}}Za=e+256|0}function MFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;De(b);j[d+12>>2]=0;f=!ii(a,d+12|0);g=c;c=j[d+12>>2];a:{if(f|g>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{h[d+11|0]=0;if(!Cg(a,d+11|0)){break b}ul(b,h[d+11|0]);e=1;c=c+1|0;if((c|0)!=j[d+12>>2]){continue}break a}break}e=0}Za=d+16|0;return e|0}function xxa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=PM(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(1019,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+12|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function fra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=PM(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(1232,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+12|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function fFa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=dFa(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(741,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+48|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function eEa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=$Da(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(764,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+33|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function QQ(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+14|0]=0;h[a+15|0]=0;h[a+16|0]=0;h[a+17|0]=0;h[a+18|0]=0;h[a+19|0]=0;h[a+20|0]=0;h[a+21|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;h[a+15|0]=0;Za=b+16|0}function QP(a){var b=0,c=0,d=0,e=0,f=0;a:{b=j[a>>2];b:{if(!b){break b}c=j[a+8>>2];if(!c){break b}a=j[a+12>>2];if(!a){break b}e=bb[a|0](b)|0;d=ab;if((d|0)<0){break b}if((bb[c|0](b,0,0,0)|0)<=-1){break a}if((bb[c|0](b,0,0,2)|0)<=-1){break a}bb[a|0](b)|0;a=ab;bb[c|0](b,e,d,0)|0;f=(a|0)>-1}return f}bb[c|0](b,e,d,0)|0;return 0}function KFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;De(b);h[d+15|0]=0;f=!Cg(a,d+15|0);g=c;c=k[d+15|0];a:{if(f|g>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{h[d+14|0]=0;if(!Cg(a,d+14|0)){break b}ul(b,h[d+14|0]);e=1;c=c+1|0;if(k[d+15|0]!=(c&255)){continue}break a}break}e=0}Za=d+16|0;return e|0}function DI(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+16|0]=0;h[a+17|0]=0;h[a+18|0]=0;h[a+19|0]=0;h[a+20|0]=0;h[a+21|0]=0;h[a+22|0]=0;h[a+23|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;h[a+15|0]=0;Za=b+16|0}function xia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=wh(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(1614,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+4|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function kAa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=iAa(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(922,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+8|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function gha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=wh(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(1645,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+4|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function Xna(a){a=a|0;var b=0,c=0,d=0,e=0;d=Za-896|0;Za=d;b=Ab(a,0,66);j[b+72>>2]=0;j[b+76>>2]=0;j[b+68>>2]=256;i[b+66>>1]=65535;j[b+80>>2]=0;j[b+84>>2]=0;h[b+88|0]=1;e=b+229984|0;c=b+608|0;a=c;while(1){a=HJ(a)+896|0;if((e|0)!=(a|0)){continue}break}a=Ab(d,0,896);Qma(c,((c+229376|0)-c|0)/896|0,HJ(a));Za=a+896|0;return b|0}function GDa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=DB(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(418,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+16|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function Cra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=Nl(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(1225,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+16|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function zda(a){a=a|0;var b=0;j[114626]=0;N(2008,a|0);b=j[114626];j[114626]=0;if((b|0)!=1){return j[a+16>>2]}b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,34861,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)!=1){Q();return-1}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function xLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=vl(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(425,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+2|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function iFa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=wh(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(740,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+4|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function Wja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=np(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(1572,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+6|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function QCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=wh(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(820,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+4|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function Nia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=q(0),f=0,g=0,h=q(0);c=Za-32|0;Za=c;lj(a,c+24|0);f=c,g=Wc(j[c+24>>2],j[c+28>>2]),j[f+16>>2]=g;j[c+12>>2]=256;Sk(b,j[tb(c+16|0,c+12|0)>>2]);if(sb(b)){while(1){j[c+16>>2]=0;ho(a,c+16|0);e=n[c+16>>2];f=xb(b,d),h=e,n[f>>2]=h;d=d+1|0;if(sb(b)>>>0>d>>>0){continue}break}}Za=c+32|0}function Lwa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=_d(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(1051,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+4|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function Ira(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=Up(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(1222,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+8|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function HW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=DB(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(216,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+16|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function HLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=vl(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(420,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+2|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function HCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=vl(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(827,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+2|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function Cza(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=wh(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(944,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+4|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function tT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=wh(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(371,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+4|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function nX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Rf(a,j[b+8>>2],e)){Au(b,c,d);return}a:{if(!Rf(a,j[b>>2],e)){break a}if(!(j[b+20>>2]!=(c|0)?j[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}j[b+32>>2]=1;return}j[b+20>>2]=c;j[b+32>>2]=d;j[b+40>>2]=j[b+40>>2]+1;if(!(j[b+36>>2]!=1|j[b+24>>2]!=2)){h[b+54|0]=1}j[b+44>>2]=4}}function hea(a,b,c){var d=0,e=0,f=0,g=0,h=0,k=0,l=0,m=0;e=j[a+4144>>2];f=j[a+4140>>2];if(c){h=i[a+4188>>1];while(1){d=g<<3;k=(d|4)+b|0;m=j[k>>2];d=b+d|0;l=j[d>>2]>>12;f=(p(l-f|0,h)>>15)+l|0;j[d>>2]=f;d=m>>12;e=(p(d-e|0,h)>>15)+d|0;j[k>>2]=e;g=g+1|0;if((g|0)!=(c|0)){continue}break}}j[a+4144>>2]=e;j[a+4140>>2]=f;return c}function dca(a){a=a|0;var b=0;j[114626]=0;N(2081,a|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){b=J(0)|0;C()|0;O(b|0)|0;j[114626]=0;L(1982,37320,a|0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();a=0}return a|0}a=D()|0;C()|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;if((b|0)!=1){G(a|0);z()}a=J(0)|0;C()|0;ib(a);z()}function ZBa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=_d(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(875,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+4|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function XCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=Js(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(38,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+1|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function MT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=Js(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(365,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+1|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function LIa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=np(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(569,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+6|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function GS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=Nl(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(418,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+16|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function CW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=Js(d,a+8|0,b);if(j[b>>2]!=j[b+4>>2]){while(1){c=j[a+16>>2];e=j[b>>2];j[114626]=0;F(218,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b>>2]+1|0;j[b>>2]=c;if((c|0)!=j[b+4>>2]){continue}break}}dc(b);Za=d+16|0;return}a=D()|0;C()|0;dc(b);G(a|0);z()}function zF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;j[e+40>>2]=c;j[e+44>>2]=b;j[e+36>>2]=d;b=j[a+8>>2];j[e+28>>2]=e+36;j[e+24>>2]=e+40;c=j[e+28>>2];j[e+8>>2]=j[e+24>>2];j[e+12>>2]=c;j[e+16>>2]=a;j[e+20>>2]=e+44;c=j[e+20>>2];j[e>>2]=j[e+16>>2];j[e+4>>2]=c;r7(b,e);j[a+4>>2]=j[a+4>>2]+j[e+36>>2];Za=e+48|0}function yF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;j[e+40>>2]=c;j[e+44>>2]=b;j[e+36>>2]=d;b=j[a+8>>2];j[e+28>>2]=e+36;j[e+24>>2]=e+40;c=j[e+28>>2];j[e+8>>2]=j[e+24>>2];j[e+12>>2]=c;j[e+16>>2]=a;j[e+20>>2]=e+44;c=j[e+20>>2];j[e>>2]=j[e+16>>2];j[e+4>>2]=c;c7(b,e);j[a+4>>2]=j[a+4>>2]+j[e+36>>2];Za=e+48|0}function xF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;j[e+40>>2]=c;j[e+44>>2]=b;j[e+36>>2]=d;b=j[a+8>>2];j[e+28>>2]=e+36;j[e+24>>2]=e+40;c=j[e+28>>2];j[e+8>>2]=j[e+24>>2];j[e+12>>2]=c;j[e+16>>2]=a;j[e+20>>2]=e+44;c=j[e+20>>2];j[e>>2]=j[e+16>>2];j[e+4>>2]=c;b7(b,e);j[a+4>>2]=j[a+4>>2]+j[e+36>>2];Za=e+48|0}function vA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=rl(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(365,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+1|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function uS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=yh(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(420,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+2|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function eL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-16|0;Za=e;a:{if(bc(Jo(a))>>>0<=b>>>0){break a}b:{c:{if(cc(a)>>>0>b>>>0){if(m[Zc(a,b)+4>>2]>c>>>0){break c}}if(!d){break a}Fx(a,b,c,1);break b}Nd(e+8|0,Zc(a,b),c);f=kb(e+8|0);if(f|!d){break a}Nd(e+8|0,Zc(a,b),c);Qd(e+8|0,1);fL(a,b,c)}f=0}Za=e+16|0;return f|0}function Vfa(a){a=a|0;var b=0,c=0;c=Za-16|0;Za=c;b=xe(j[a+16>>2]);b=ic(PMa(OMa(b,b>>31,3840,0),ab,1e3,0),ab);j[a+4276>>2]=b;j[114626]=0;j[c+12>>2]=0;I(1640,a+4260|0,b|0,c+12|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){b=J(71396)|0;if((C()|0)!=(W(71396)|0)){break a}O(b|0)|0;j[a+4276>>2]=0;Q()}Za=c+16|0;return}G(b|0);z()}function MV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=Up(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(270,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+8|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function LN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=_d(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(944,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+4|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function GF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;j[e+40>>2]=c;j[e+44>>2]=b;j[e+36>>2]=d;b=j[a+8>>2];j[e+28>>2]=e+36;j[e+24>>2]=e+40;c=j[e+28>>2];j[e+8>>2]=j[e+24>>2];j[e+12>>2]=c;j[e+16>>2]=a;j[e+20>>2]=e+44;c=j[e+20>>2];j[e>>2]=j[e+16>>2];j[e+4>>2]=c;U7(b,e);j[a+4>>2]=j[a+4>>2]+j[e+36>>2];Za=e+48|0}function FF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;j[e+40>>2]=c;j[e+44>>2]=b;j[e+36>>2]=d;b=j[a+8>>2];j[e+28>>2]=e+36;j[e+24>>2]=e+40;c=j[e+28>>2];j[e+8>>2]=j[e+24>>2];j[e+12>>2]=c;j[e+16>>2]=a;j[e+20>>2]=e+44;c=j[e+20>>2];j[e>>2]=j[e+16>>2];j[e+4>>2]=c;T7(b,e);j[a+4>>2]=j[a+4>>2]+j[e+36>>2];Za=e+48|0}function DF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;j[e+40>>2]=c;j[e+44>>2]=b;j[e+36>>2]=d;b=j[a+8>>2];j[e+28>>2]=e+36;j[e+24>>2]=e+40;c=j[e+28>>2];j[e+8>>2]=j[e+24>>2];j[e+12>>2]=c;j[e+16>>2]=a;j[e+20>>2]=e+44;c=j[e+20>>2];j[e>>2]=j[e+16>>2];j[e+4>>2]=c;F7(b,e);j[a+4>>2]=j[a+4>>2]+j[e+36>>2];Za=e+48|0}function D8(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;j[d+12>>2]=j[a+4>>2];c=j[b+4>>2];j[114626]=0;j[d+8>>2]=c;c=E(33,d+12|0,d+8|0)|0;e=j[114626];j[114626]=0;if((e|0)!=1){c=zm(j[a>>2],j[b>>2],j[c>>2]);a:{if(c){break a}c=0;if(j[a+4>>2]==j[b+4>>2]){break a}c=m[a+4>>2]<m[b+4>>2]?-1:1}Za=d+16|0;return c}a=J(0)|0;C()|0;ib(a);z()}function CF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;j[e+40>>2]=c;j[e+44>>2]=b;j[e+36>>2]=d;b=j[a+8>>2];j[e+28>>2]=e+36;j[e+24>>2]=e+40;c=j[e+28>>2];j[e+8>>2]=j[e+24>>2];j[e+12>>2]=c;j[e+16>>2]=a;j[e+20>>2]=e+44;c=j[e+20>>2];j[e>>2]=j[e+16>>2];j[e+4>>2]=c;E7(b,e);j[a+4>>2]=j[a+4>>2]+j[e+36>>2];Za=e+48|0}function AF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-48|0;Za=e;j[e+40>>2]=c;j[e+44>>2]=b;j[e+36>>2]=d;b=j[a+8>>2];j[e+28>>2]=e+36;j[e+24>>2]=e+40;c=j[e+28>>2];j[e+8>>2]=j[e+24>>2];j[e+12>>2]=c;j[e+16>>2]=a;j[e+20>>2]=e+44;c=j[e+20>>2];j[e>>2]=j[e+16>>2];j[e+4>>2]=c;s7(b,e);j[a+4>>2]=j[a+4>>2]+j[e+36>>2];Za=e+48|0}function uR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=rl(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(38,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+1|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function fT(a){var b=0,c=0,d=0;a:{if(k[a+110|0]>64|((k[a|0]|k[a+1|0]<<8)!=20042?(k[a|0]|k[a+1|0]<<8)!=26217:0)|(h[a+112|0]<0|k[a+111|0]>128)){break a}while(1){b=a+c|0;d=h[b+113|0];if(!(((d&255)>>>0<254?(d|0)<=-1:0)|(k[b+241|0]?0:(d|0)>=0)|k[b+369|0]>=64)){b=1;c=c+1|0;if((c|0)!=128){continue}break a}break}b=0}return b}function dA(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;a:{if(!b){break a}if(!yb(a,b)){break a}while(1){h[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Df(a,c+11|0);e=k[c+11|0]}else{e=0}h[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}j[c+4>>2]=j[c+12>>2];a=c+4|0;d=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24)}Za=c+16|0;return d}function R5(a,b){var c=0,d=0,e=0,f=q(0),g=q(0),h=q(0),i=q(0);if((b|0)>=1){while(1){d=0;while(1){c=d<<2;e=c+a|0;c=c+48720|0;f=n[c>>2];g=n[e+72>>2];h=n[c+32>>2];c=(17-d<<2)+a|0;i=n[c>>2];n[e+72>>2]=q(f*g)-q(h*i);n[c>>2]=q(h*g)+q(f*i);d=d+1|0;if((d|0)!=8){continue}break}a=a+72|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function MI(a){var b=0,c=0;a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=-1641380927){break a}b=a+12|0;if(!(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))){break a}b=a+20|0;if(!(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))){break a}a=a+28|0;c=(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=0}return c}function MG(a){var b=0;j[a+4116>>2]=0;j[a+4132>>2]=0;j[a+4136>>2]=0;i[a+4128>>1]=0;j[a+4104>>2]=0;j[a+4108>>2]=0;b=a+4140|0;j[b>>2]=0;j[b+4>>2]=0;b=a+4148|0;j[b>>2]=0;j[b+4>>2]=0;LG(a+4164|0);LG(a+4156|0);vo(a+54060|0);vo(a+62252|0);vo(a+70444|0);vo(a+78636|0);Ab(a+4332|0,0,32768);Zx(a+37100|0);Ab(a+37612|0,0,16384)}function zja(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;hb(b);f=iI(a,c+8|0);a:{d=Kf(b);if(!d){break a}j[114626]=0;F(680,a|0,d|0);e=j[114626];j[114626]=0;if((e|0)!=1){e=j[b+4>>2];b=j[b>>2];j[114626]=0;L(1583,a|0,b|0,e|0,d|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;Vs(f);G(a|0);z()}Za=c+16|0;return a}function lua(a,b,c,d){var e=0,f=0,g=0;a:{e=j[c>>2];f=j[d>>2];if(e|f){if(!b){break a}while(1){j[c>>2]=e-(((-2147483648-e>>>31|0)-1&255)+e>>8);j[d>>2]=j[d>>2]-(((-2147483648-f>>>31|0)-1&255)+f>>8);e=g<<3;j[e+a>>2]=j[c>>2];j[(e|4)+a>>2]=j[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}f=j[d>>2];e=j[c>>2];continue}}tM(a,b<<1)}}function Osa(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;hb(b);f=QL(a,c+8|0);a:{d=bc(b);if(!d){break a}j[114626]=0;F(916,a|0,d|0);e=j[114626];j[114626]=0;if((e|0)!=1){e=j[b+4>>2];b=j[b>>2];j[114626]=0;L(1190,a|0,b|0,e|0,d|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;xt(f);G(a|0);z()}Za=c+16|0;return a}function MEa(a,b){var c=0,d=0,e=0;d=ri(a+8|0);j[114626]=0;c=H(540,b|0)|0;e=j[114626];j[114626]=0;a:{b:{if((e|0)==1){break b}j[114626]=0;I(421,a|0,b|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break b}a=j[a>>2];j[114626]=0;E(338,b|0,a|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;wg(d);G(a|0);z()}}function Dw(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=Cja(e,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){d=hb(a);f=j[b+4>>2];j[114626]=0;I(1574,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b+4>>2]+52|0;j[b+4>>2]=d;if((d|0)!=j[b+8>>2]){continue}break}}ub(b);Za=e+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function cea(){var a=0,b=0;j[114626]=0;a=T(1981)|0;b=j[114626];j[114626]=0;a:{if((b|0)==1){a=J(0)|0;C()|0;O(a|0)|0;j[114626]=0;L(1982,34128,0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();a=0}return a|0}b=D()|0;C()|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)!=1){G(b|0);z()}a=J(0)|0;C()|0;ib(a);z()}function WJ(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=hk(e,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){d=hb(a);f=j[b+4>>2];j[114626]=0;I(1376,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b+4>>2]+24|0;j[b+4>>2]=d;if((d|0)!=j[b+8>>2]){continue}break}}ub(b);Za=e+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function Px(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=yn(e,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){d=hb(a);f=j[b+4>>2];j[114626]=0;I(1172,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b+4>>2]+32|0;j[b+4>>2]=d;if((d|0)!=j[b+8>>2]){continue}break}}ub(b);Za=e+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function Oda(){var a=0,b=0;j[114626]=0;a=T(1997)|0;b=j[114626];j[114626]=0;a:{if((b|0)==1){a=J(0)|0;C()|0;O(a|0)|0;j[114626]=0;L(1982,34568,0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();a=0}return a|0}b=D()|0;C()|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)!=1){G(b|0);z()}a=J(0)|0;C()|0;ib(a);z()}function $da(){var a=0,b=0;j[114626]=0;a=T(1985)|0;b=j[114626];j[114626]=0;a:{if((b|0)==1){a=J(0)|0;C()|0;O(a|0)|0;j[114626]=0;L(1982,34156,0,0,0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Q();a=0}return a|0}b=D()|0;C()|0;j[114626]=0;M(20);a=j[114626];j[114626]=0;if((a|0)!=1){G(b|0);z()}a=J(0)|0;C()|0;ib(a);z()}function yw(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;a:{b=_d(e,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){d=hb(a);f=j[b+4>>2];j[114626]=0;I(1597,d|0,f|0,c|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}d=j[b+4>>2]+4|0;j[b+4>>2]=d;if((d|0)!=j[b+8>>2]){continue}break}}ub(b);Za=e+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function jM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-16|0;Za=c;e=Xta(a);a=b+236|0;b=rs(a);a:{if((a|0)!=(b|0)){while(1){d=l[a>>1];i[c+14>>1]=d;if(d){j[114626]=0;I(1158,c|0,e|0,c+14|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}Za=c+16|0;return}a=D()|0;C()|0;cp(e);G(a|0);z()}function X5(a,b,c){var d=0,e=0,f=0;d=k[a+769|0];e=p(d,72)+c|0;Vb(e+2304|0,e,p(k[a+768|0]-d|0,72));if(k[a+768|0]){e=0;while(1){d=0;while(1){f=(d<<2)+c|0;n[f>>2]=n[f>>2]*n[b>>2];f=f+2304|0;n[f>>2]=n[f>>2]*n[b+12>>2];d=d+1|0;if((d|0)!=12){continue}break}b=b+24|0;c=c+72|0;e=e+1|0;if(e>>>0<k[a+768|0]){continue}break}}}function Rja(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;j[e+8>>2]=a;if((b|0)>=1){while(1){d=j[e+8>>2];a=c;f=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);h[d|0]=f;h[d+1|0]=f>>>8;h[d+2|0]=f>>>16;h[d+3|0]=f>>>24;a=k[a+4|0]|k[a+5|0]<<8;h[d+4|0]=a;h[d+5|0]=a>>>8;a=(b|0)>1;kk(e+8|0);b=b-1|0;if(a){continue}break}}Za=e+16|0}function xT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=a;a=b+18|0;d=b+46|0;b=Mc(e,k[a|0]&2?16:8,1,0,(k[d|0]^-1)&1);if(!(!(k[a|0]&4)|c>>>0<532)){lA(b)}if(k[a|0]&8){dj(b,k[d|0]&4?5:4);return}if(!(k[a|0]&2|k[d|0]!=255)){dj(b,11);return}if(k[d|0]&2){h[b+2|0]=1}if(k[d|0]&4){dj(b,2)}if(!(!(k[d|0]&8)|!(k[a|0]&2))){dj(b,9)}}function rha(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=oha(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(1643,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+2048|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function aqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>2;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){lb(k[b|0]);lb(k[b+1|0]);f=a,g=lb(k[b+2|0])|lb(k[b+3|0])<<8,i[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<2}function $pa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>2;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){lb(k[b+3|0]);lb(k[b+2|0]);f=a,g=lb(k[b+1|0])|lb(k[b|0])<<8,i[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return d<<2}function tma(a,b,c){var d=0,e=0;d=Za-16|0;Za=d;a=a+1074308|0;mb(d+8|0,a,28);a:{if(kb(d+8|0)){j[c>>2]=j[c>>2]+i[b+788>>1];Md(c,0,64);break a}mb(d+8|0,a,1);e=kb(d+8|0);a=i[b+788>>1];if(e){j[c>>2]=a+j[c>>2];Md(c,0,256);break a}j[b+688>>2]=a+j[b+688>>2];Md(b+688|0,0,256);j[c>>2]=j[b+688>>2];i[b+788>>1]=0}Za=d+16|0}function sLa(a,b){var c=0;c=Za-32|0;Za=c;j[c+16>>2]=b;j[c+24>>2]=a;a:{b:{if(!rb(c+24|0,c+16|0)){break b}j[c+8>>2]=j[c+24>>2];if(!rb(Id(c+8|0),c+16|0)){break b}while(1){if(al(j[c+24>>2],j[c+8>>2])){a=j[c+24>>2];break a}j[c+24>>2]=j[c+8>>2];if(rb(Id(c+8|0),c+16|0)){continue}break}}a=j[c+16>>2]}Za=c+32|0;return a}function rJa(a,b){a=a|0;b=b|0;var c=0;Gs(a,b);Yi(b);a=k[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=k[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}h[b+5|0]=159;h[b+3|0]=20;return}if((a|0)!=64){break a}h[b+3|0]=0;h[b|0]=254;return}h[b+3|0]=20;h[b+5|0]=a&15|160;return}h[b+3|0]=0}}function kua(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=j[a+96>>2];e=j[a+92>>2];if(d|e){if(c){while(1){f=g<<3;h=f+b|0;e=e-(((-2147483648-e>>>31|0)-1&255)+e>>8)|0;j[h>>2]=e+j[h>>2];f=(f|4)+b|0;d=d-(((-2147483648-d>>>31|0)-1&255)+d>>8)|0;j[f>>2]=d+j[f>>2];g=g+1|0;if((g|0)!=(c|0)){continue}break}}j[a+96>>2]=d;j[a+92>>2]=e}}function bAa(a,b){a=a|0;b=b|0;var c=0;b=Za-16|0;Za=b;c=-1;a:{if(!jf(a,8)){break a}c=0;if(!Mz(a,16628,8)){break a}c=-1;if(!hj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))){break a}c=!((k[b+8|0]|k[b+9|0]<<8|(k[b+10|0]<<16|k[b+11|0]<<24))&-2139062144)}a=c;Za=b+16|0;return a|0}function TU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-48|0;Za=e;Bn(a);j[a>>2]=77320;f=$g(e+40|0);NU(e+24|0,b,c,d);j[114626]=0;j[e+16>>2]=j[e+32>>2];b=j[e+28>>2];j[e+8>>2]=j[e+24>>2];j[e+12>>2]=b;K(287,a+12|0,f|0,e+8|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=e+48|0;return a|0}a=D()|0;C()|0;G(a|0);z()}function yxa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=Un(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(1019,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+12|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function hra(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=Un(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(1232,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+12|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function hEa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=cEa(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(764,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+33|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function h6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;a=_E(a,d+8|0);e=nb(b);f=nb(c);b=zb(b);j[114626]=0;L(195,a|0,b|0,e|0,e+f|0);b=j[114626];j[114626]=0;a:{if((b|0)!=1){b=zb(c);j[114626]=0;K(196,a|0,b|0,f|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break a}}b=D()|0;C()|0;gb(a);G(b|0);z()}Za=d+16|0}function yia(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=_d(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(1614,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+4|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function v4(a,b){var c=0,d=0,e=0,f=0,g=0;f=Za-16|0;Za=f;d=a+8|0;em(a,a+4|0,d);c=a+12|0;while(1){if((b|0)!=(c|0)){if(rd(c,d)){j[f+12>>2]=j[c>>2];g=c;while(1){a:{e=d;j[g>>2]=j[e>>2];if((a|0)==(e|0)){e=a;break a}g=e;d=e-4|0;if(rd(f+12|0,d)){continue}}break}j[e>>2]=j[f+12>>2]}d=c;c=c+4|0;continue}break}Za=f+16|0}function hha(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=_d(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(1645,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+4|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function gFa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=$Q(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(741,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+48|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function fY(a,b){var c=0,d=0,e=0;a:{b:{while(1){if(k[c+68640|0]!=(a|0)){d=87;c=c+1|0;if((c|0)!=87){continue}break b}break}d=c;if(c){break b}a=68736;break a}c=68736;while(1){e=k[c|0];a=c+1|0;c=a;if(e){continue}c=a;d=d-1|0;if(d){continue}break}}b=j[b+20>>2];if(b){b=C2(j[b>>2],j[b+4>>2],a)}else{b=0}return b?b:a}function JH(a){a=a|0;var b=0,c=0;c=Za-16|0;Za=c;b=j[a+4232>>2];b=(b>>>1)+(b>>>6)|0;j[a+4220>>2]=b;j[114626]=0;j[c+12>>2]=0;I(1640,a+4208|0,b<<1,c+12|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){b=J(71396)|0;if((C()|0)!=(W(71396)|0)){break a}O(b|0)|0;j[a+4220>>2]=0;Q()}j[a+4224>>2]=0;Za=c+16|0;return}G(b|0);z()}function $aa(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;hb(b);f=_aa(a,c+8|0);a:{d=Xc(b);if(!d){break a}j[114626]=0;F(2114,a|0,d|0);e=j[114626];j[114626]=0;if((e|0)!=1){e=j[b+4>>2];b=j[b>>2];j[114626]=0;L(2115,a|0,b|0,e|0,d|0);a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;wG(f);G(a|0);z()}Za=c+16|0}function zLa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=yh(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(425,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+2|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function uya(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Za-16|0;Za=b;e=ue(1);j[114626]=0;c=E(85,b|0,1434)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){j[114626]=0;d=E(86,e|0,c|0)|0;f=j[114626];j[114626]=0;if((f|0)==1){break b}Vxa(a,d);gb(c);Za=b+16|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(c)}Cb(e);G(a|0);z()}function pN(a,b){a=a|0;b=b|0;var c=0;c=Za-48|0;Za=c;j[a>>2]=0;j[a+4>>2]=0;j[c+44>>2]=0;hb(b);Ic(a+8|0,c+44|0,c+40|0);if(j[b+4>>2]){Gp(a,j[b+4>>2]);Xi(c+32|0,b);Wj(c+24|0,b);b=j[c+36>>2];j[c+16>>2]=j[c+32>>2];j[c+20>>2]=b;b=j[c+28>>2];j[c+8>>2]=j[c+24>>2];j[c+12>>2]=b;Gya(a,c+16|0,c+8|0)}Za=c+48|0;return a|0}function nAa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=Up(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(922,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+8|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function kFa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=_d(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(740,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+4|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function eqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=(c>>>0)/3;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){lb(k[b|0]);f=a,g=lb(k[b+1|0])|lb(k[b+2|0])<<8,i[f>>1]=g;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return p(d,3)|0}function dqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=(c>>>0)/3;j[e+8>>2]=j[a>>2];d=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(d){a=j[a+20>>2];c=d;while(1){lb(k[b+2|0]);f=a,g=lb(k[b+1|0])|lb(k[b|0])<<8,i[f>>1]=g;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return p(d,3)|0}function cY(a,b,c,d){var e=0,f=0,g=0,i=0,k=0;g=Za-16|0;Za=g;f=nb(a);if(f>>>0>=b>>>0){if(c){e=sc(a);a:{if(e-f>>>0>=c>>>0){e=zb(a);i=f-b|0;if(!i){break a}k=b+e|0;Fl(k+c|0,k,i);break a}tl(a,e,(c+f|0)-e|0,f,b,0,c);e=j[a>>2]}ky(b+e|0,c,d);b=a;a=c+f|0;Ag(b,a);h[g+15|0]=0;Td(a+e|0,g+15|0)}Za=g+16|0;return}Pl();z()}function SCa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=_d(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(820,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+4|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function Nja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=b;a:{if(Mi(a)>>>0>=b>>>0){f=d,g=df(a),j[f+8>>2]=g;Dja(j[a>>2],j[tb(d+12|0,d+8|0)>>2],c);e=j[d+8>>2];b=j[d+12>>2];if(e>>>0<b>>>0){Dw(a,b-e|0,c);break a}pI(a,j[a>>2]+p(b,52)|0);break a}Mja(a);Lja(a,oI(a,b));Dw(a,b,c)}Za=d+16|0}function M1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=q(0),f=0;d=Za-16|0;Za=d;a:{if((a|0)!=(b|0)){f=j[114600];j[114600]=0;Wd();e=p2(a,d+12|0);a=j[114600];b:{if(a){if(j[d+12>>2]!=(b|0)){break b}if((a|0)!=68){break a}j[c>>2]=4;break a}j[114600]=f;if(j[d+12>>2]==(b|0)){break a}}}j[c>>2]=4;e=q(0)}Za=d+16|0;return q(e)}function JW(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=Nl(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(216,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+16|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function JCa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=yh(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(827,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+2|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function xwa(a){var b=0,c=0;b=Za-80|0;Za=b;j[b+76>>2]=0;c=Eb(b- -64|0,18062);j[114626]=0;F(511,b+48|0,a|0);a=j[114626];j[114626]=0;a:{b:{c:{if((a|0)==1){break c}j[114626]=0;E(470,b+48|0,c|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break c}gb(c);break b}a=D()|0;C()|0;gb(c);break a}Za=b+80|0;return}G(a|0);z()}function uT(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=_d(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(371,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+4|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function DW(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b=rl(d,a,b);if(j[b+4>>2]!=j[b+8>>2]){while(1){c=hb(a);e=j[b+4>>2];j[114626]=0;F(218,c|0,e|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}c=j[b+4>>2]+1|0;j[b+4>>2]=c;if((c|0)!=j[b+8>>2]){continue}break}}ub(b);Za=d+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function DMa(a,b){var c=0;md(b,0);j[b+24>>2]=8363;c=a+13|0;j[b>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=a+17|0;j[b+4>>2]=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);a=a+21|0;a=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);a=a>>>0>m[b>>2]?j[b+4>>2]?a:0:a;j[b+8>>2]=a;if(a){i[b+34>>1]=2;Nm(b)}}function p0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=Za-32|0;Za=g;h=j[15603];j[g+24>>2]=j[15602];j[g+28>>2]=h;h=j[15601];j[g+16>>2]=j[15600];j[g+20>>2]=h;h=j[15599];j[g+8>>2]=j[15598];j[g+12>>2]=h;h=j[15597];j[g>>2]=j[15596];j[g+4>>2]=h;a=Ei(a,b,c,d,e,f,g,g+32|0);Za=g+32|0;return a|0}function Zoa(a,b,c){var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=b;a:{if(Ce(a)>>>0>=b>>>0){f=d,g=pd(a),j[f+8>>2]=g;uoa(j[a>>2],j[tb(d+12|0,d+8|0)>>2],c);e=j[d+8>>2];b=j[d+12>>2];if(e>>>0<b>>>0){WJ(a,b-e|0,c);break a}b=j[a>>2]+p(b,24)|0;pd(a);XJ(a,b);Xo(a);break a}woa(a);voa(a,gk(a,b));WJ(a,b,c)}Za=d+16|0}function Qr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=Za-16|0;Za=e;if(b){mb(e+8|0,a+1074308|0,73);k=kb(e+8|0)?c- -64|0:c;c=120;i=zo(a);l=i^-1;f=1;while(1){g=c>>>1|0;j=g+f|0;h=Zf(a,j,k,d);a:{if(!(h>>>0>b>>>0&l|!h|b>>>0>h>>>0&i)){c=g;break a}f=j+1|0;c=(g^-1)+c|0}if(c){continue}break}}Za=e+16|0;return f}function $H(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=b;a:{if(jd(a)>>>0>=b>>>0){f=d,g=sb(a),j[f+8>>2]=g;pia(j[a>>2],j[tb(d+12|0,d+8|0)>>2],c);e=j[d+8>>2];b=j[d+12>>2];if(e>>>0<b>>>0){yw(a,b-e|0,c);break a}Bw(a,j[a>>2]+(b<<2)|0);break a}Uia(a);Tia(a,ie(a,b));yw(a,b,c)}Za=d+16|0}function nJ(a,b,c){var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;e=ti(b,c);a:{if(e>>>0<=Af(a)>>>0){j[d+12>>2]=c;if(tc(a)>>>0<e>>>0){j[d+12>>2]=b;f=d,g=tc(a)+j[d+12>>2]|0,j[f+12>>2]=g;Pe(b,j[d+12>>2],j[a>>2]);iy(a,j[d+12>>2],c,e-tc(a)|0);break a}gR(a,Pe(b,c,j[a>>2]));break a}NK(a);qp(a,ql(a,e));iy(a,b,c,e)}Za=d+16|0}function fka(a,b,c){var d=0,e=0,f=0;d=Za-16|0;Za=d;e=(c-b|0)/6|0;a:{if(mi(a)>>>0>=e>>>0){j[d+12>>2]=c;if(Kf(a)>>>0<e>>>0){j[d+12>>2]=b;f=Kf(a);j[d+12>>2]=j[d+12>>2]+p(f,6);Gw(b,j[d+12>>2],j[a>>2]);Fw(a,j[d+12>>2],c,e-Kf(a)|0);break a}az(a,Gw(b,c,j[a>>2]));break a}sI(a);jQ(a,Sy(a,e));Fw(a,b,c,e)}Za=d+16|0}function Vf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=Za-16|0;Za=d;g=a;h=a;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=s(e);We(d,e,0,0,0,c+81|0);e=0+j[d+8>>2]|0;c=(j[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=j[d+4>>2];b=j[d>>2]}j[h>>2]=b;j[g+4>>2]=c;j[a+8>>2]=e;j[a+12>>2]=f;Za=d+16|0}function OZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Za-16|0;Za=f;j[e>>2]=c;a=Pu(f+12|0,0,b,j[a+8>>2]);c=2;a:{if(a+1>>>0<2){break a}b=a-1|0;c=1;if(b>>>0>d-j[e>>2]>>>0){break a}c=f+12|0;while(1){if(b){a=k[c|0];d=j[e>>2];j[e>>2]=d+1;h[d|0]=a;b=b-1|0;c=c+1|0;continue}break}c=0}Za=f+16|0;return c|0}function Gja(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-48|0;Za=c;d=c+40|0;b=l[b>>1];h[d|0]=b;h[d+1|0]=b>>>8;pk(c+16|0,c+40|0);b=lb(j[c+16>>2]);pk(c+8|0,c+40|0);b=Zh(c+24|0,b,lb(j[c+8>>2]+2|0));j[114626]=0;E(1187,a|0,b|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){gb(b);Za=c+48|0;return}a=D()|0;C()|0;gb(b);G(a|0);z()}function zqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c>>>1;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=lb(k[b|0])^128,h[f|0]=g;f=a,g=lb(k[b+1|0])^128,h[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e<<1}function yqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>1;j[e+8>>2]=j[a>>2];f=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(f){a=j[a+20>>2];c=f;g=d;while(1){g=lb(k[b|0])+g|0;h[a|0]=g;d=lb(k[b+1|0])+d|0;h[a+1|0]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return f<<1}function xd(a,b,c){var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;Il(b);b=u_(d+8|0,b);a:{a=a+16|0;if(sb(a)>>>0<=c>>>0){j[114626]=0;F(2551,a|0,c+1|0);e=j[114626];j[114626]=0;if((e|0)==1){break a}}if(j[xb(a,c)>>2]){Hl(j[xb(a,c)>>2])}e=ud(b);f=xb(a,c),g=e,j[f>>2]=g;tC(b);Za=d+16|0;return}a=D()|0;C()|0;tC(b);G(a|0);z()}function iK(a,b,c){var d=0,e=0,f=0,g=0,i=0;e=j[a+1074416>>2];a=j[a+1074392>>2];h[b+872|0]=k[b+872|0]|8;g=b;d=a?k[b+833|0]:0;i=(c|0)>-1?0-d|0:d;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(r(f)<2147483648){d=~~f;break a}d=-2147483648}j[g+876>>2]=i+(d+j[b+876>>2]|0);a=(a+1|0)==(e|0)?c:d;h[b+833|0]=(a|0)<0?0-a|0:a}function ev(a){var b=0,c=0,d=0,e=0;e=ne(a);a:{if(!j[115412]|!k[a|0]){break a}b=A2(a);if(k[b|0]==61?b:0){break a}b=j[j[115412]>>2];if(!b){break a}b:{while(1){d=Q4(a,b,e);b=j[115412];if(!d){d=j[b+(c<<2)>>2]+e|0;if(k[d|0]==61){break b}}c=c+1|0;b=j[b+(c<<2)>>2];if(b){continue}break}return 0}c=d+1|0}return c}function _ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Uh(a,b,c,d);j[a+4208>>2]=1017370378;j[a+4212>>2]=0;j[a>>2]=81428;j[114626]=0;K(1632,a+44|0,2,2)|0;c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;N(1633,b|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}return a|0}a=D()|0;C()|0;we(b);G(a|0);z()}function UB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;a=ew(a,d+8|0);e=ne(b);f=nb(c);j[114626]=0;L(2833,a|0,b|0,e|0,e+f|0);b=j[114626];j[114626]=0;a:{if((b|0)!=1){b=zb(c);j[114626]=0;K(2484,a|0,b|0,f|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break a}}b=D()|0;C()|0;gb(a);G(b|0);z()}Za=d+16|0}function rQ(a,b){var c=0,d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;c=a+4|0;a:{if(tc(c)>>>0>=j[a+16>>2]+b>>>0){break a}if(!tc(c)){ek(c,gz(j[a+16>>2]+b|0,65536));break a}f=d,g=tc(c),j[f+12>>2]=g;e=nQ(d+12|0);a=j[a+16>>2]+b|0;if(e>>>0<a>>>0){ek(c,gz(a,65536));break a}f=d,g=tc(c),j[f+8>>2]=g;ek(c,nQ(d+8|0))}Za=d+16|0}function ZKa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;a:{b:{if(!jf(a,7)){break b}c=0;if(!kS(a,12222)){break a}if(!jf(a,1)){break b}c=-1;if(!Fc(a,vt(a))){break a}c=d+8|0;e=CKa(a,c);if(!e){UR(c)}c=-1;if(!e){break a}c=0;if(!gS(d+8|0)){break a}c=Le(a,b,fS(d+8|0),ab);break a}c=-1}Za=d+16|0;return c|0}function FBa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Za+ -64|0;Za=c;b=-1;a:{if(!jf(a,1084)){break a}Xj(a,1080);FO(a,c+60|0);d=EO(c+40|0);b=0;if(!DO(c+60|0,d)){break a}Xj(a,20);b=1;while(1){CO(a,c+8|0);e=Dy(c+8|0)+e|0;f=b&65535;b=b+1|0;if(f>>>0<31){continue}break}b=m[d+4>>2]>=e>>>0}Za=c- -64|0;return b|0}function nra(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Za-16|0;Za=d;f=a+12|0;_L(d+8|0,f);bL(d,f);a:{if(!ks(d+8|0,d)|(c|0)==-1){break a}while(1){g=j[mra(d+8|0)>>2];Fx(a,b,g,0);e=d+8|0;h=j[e+4>>2];j[d>>2]=j[e>>2];j[d+4>>2]=h;aL(e+4|0);bL(d,f);e=ks(d+8|0,d);if((c|0)==(g|0)){break a}if(e){continue}break}}Za=d+16|0}function Sqa(a){if(!(a<0x8000000000000000)){ab=2147483647;return-1}if(!(a>-0x8000000000000000)){ab=-2147483648;return 0}if(r(a)<0x8000000000000000){ab=r(a)>=1?a>0?~~t(v(a*2.3283064365386963e-10),4294967295)>>>0:~~w((a- +(~~a>>>0>>>0))*2.3283064365386963e-10)>>>0:0;return~~a>>>0}ab=-2147483648;return 0}function Sd(a){var b=q(0),c=q(0),d=0,e=0;d=(ZMa(a),VMa(2));e=d>>>23&255;if(e>>>0<=149){if(e>>>0<=125){return q(a*q(0))}a=(d|0)>-1?a:q(-a);b=q(q(q(a+q(8388608))+q(-8388608))-a);a:{if(!(b>q(.5)^1)){c=q(q(a+b)+q(-1));break a}a=q(a+b);c=a;if(b<=q(-.5)^1){break a}c=q(a+q(1))}a=c;a=(d|0)>-1?a:q(-a)}return a}function rsa(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;a:{if(!k[a+530|0]){break a}f=OMa(d,0,6169,0);d=ab;d=Wc((d&65535)<<16|f>>>16,d>>>16|0);if(!c){break a}while(1){Asa(j[a>>2],e+14|0,e+12|0);j[b>>2]=j[b>>2]+p(d,i[e+14>>1]);j[b+4>>2]=j[b+4>>2]+p(d,i[e+12>>1]);b=b+8|0;c=c-1|0;if(c){continue}break}}Za=e+16|0}function qra(a,b,c,d){var e=0;e=Za-32|0;Za=e;a:{if(k[d|0]){d=j[b+4>>2];j[e+24>>2]=j[b>>2];j[e+28>>2]=d;b=ei(c,b);c=j[e+28>>2];j[e+8>>2]=j[e+24>>2];j[e+12>>2]=c;pra(a,e+8|0,b);break a}d=j[b+4>>2];j[e+16>>2]=j[b>>2];j[e+20>>2]=d;b=ei(c,b);c=j[e+20>>2];j[e>>2]=j[e+16>>2];j[e+4>>2]=c;ora(a,e,b)}Za=e+32|0}function pua(a,b,c,d,e){var f=q(0),g=0,h=0,i=0;if(d){while(1){h=c;f=q(n[a>>2]*e);a:{if(q(r(f))<q(2147483648)){g=~~f;break a}g=-2147483648}j[h>>2]=g;h=c;f=q(n[b>>2]*e);b:{if(q(r(f))<q(2147483648)){g=~~f;break b}g=-2147483648}j[h+4>>2]=g;c=c+8|0;b=b+4|0;a=a+4|0;i=i+1|0;if((i|0)!=(d|0)){continue}break}}}function fn(a,b,c,d,e){var f=0,g=0,h=0,m=0,n=0;f=Za-16|0;Za=f;j[f+12>>2]=c;kc(f+12|0,128);kc(f+12|0,65535);h=l[f+12>>1];bg(a,h);if(h){c=0;while(1){g=k[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}m=mk(a,c),n=g,i[m>>1]=n;c=c+1|0;if((h|0)!=(c|0)){continue}break}}Za=f+16|0}function Sna(a,b){var c=0,d=0;a=Me(a);c=nb(b);j[114626]=0;F(113,a|0,c|0);c=j[114626];j[114626]=0;if((c|0)!=1){a:{if(nb(b)){while(1){c=k[Ub(b,d)|0];j[114626]=0;F(112,a|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}d=d+1|0;if(nb(b)>>>0>d>>>0){continue}break}}return}}b=D()|0;C()|0;pc(a);G(b|0);z()}function NZ(a){a=a|0;var b=0,c=0;b=j[a+8>>2];j[114626]=0;b=P(2567,0,0,4,b|0)|0;c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}b:{if(b){a=-1}else{a=j[a+8>>2];if(a){break b}a=1}return a|0}j[114626]=0;a=H(2568,a|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}return(a|0)==1|0}a=J(0)|0;C()|0;ib(a);z()}function At(a,b,c,d,e){var f=0,g=0,h=0,m=0,n=0;f=Za-16|0;Za=f;j[f+12>>2]=c;kc(f+12|0,256);kc(f+12|0,65535);h=l[f+12>>1];bg(a,h);if(h){c=0;while(1){g=k[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}m=mk(a,c),n=g,i[m>>1]=n;c=c+1|0;if((h|0)!=(c|0)){continue}break}}Za=f+16|0}function lna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=b;a:{if(Af(a)>>>0>=b>>>0){f=d,g=tc(a),j[f+8>>2]=g;cj(j[a>>2],j[tb(d+12|0,d+8|0)>>2],c);e=j[d+8>>2];b=j[d+12>>2];if(e>>>0<b>>>0){gt(a,b-e|0,c);break a}Tt(a,b+j[a>>2]|0);break a}kna(a);qp(a,ql(a,b));gt(a,b,c)}Za=d+16|0}function jja(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;j[114626]=0;H(1587,a+4|0)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){j[114626]=0;j[c+12>>2]=0;K(1588,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Rb(a),j[e>>2]=f;Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function j9(a){a=a|0;var b=0,c=0;b=Za-32|0;Za=b;a:{b:{if(Qh(a)){eo(b+24|0);break b}om(b+8|0,a);j[114626]=0;F(2167,b+24|0,b+8|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}Ye(b+8|0)}c=a+36|0;c:{if(Qh(a)){break c}c=j[b+24>>2]}a=pd(c);Gj(b+24|0);Za=b+32|0;return a|0}a=D()|0;C()|0;Ye(b+8|0);G(a|0);z()}function Voa(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;j[114626]=0;H(1367,a+4|0)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){j[114626]=0;j[c+12>>2]=0;K(1368,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Rb(a),j[e>>2]=f;Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Uta(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;j[114626]=0;H(1159,a+4|0)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){j[114626]=0;j[c+12>>2]=0;K(1160,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Rb(a),j[e>>2]=f;Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Tla(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;j[114626]=0;H(1514,a+4|0)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){j[114626]=0;j[c+12>>2]=0;K(1515,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Rb(a),j[e>>2]=f;Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function SI(a,b,c){var d=0,e=0,f=0,g=0;f=Za-16|0;Za=f;e=ti(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){Ue(a,e);d=a;break a}g=Dk(e)+1|0;d=Sh(g);lf(a,d);jg(a,g);ee(a,e)}if((b|0)!=(c|0)){while(1){Td(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}h[f+15|0]=0;Td(d,f+15|0);Za=f+16|0;return}kg();z()}function Rqa(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;j[114626]=0;H(1247,a+4|0)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){j[114626]=0;j[c+12>>2]=0;K(1248,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Rb(a),j[e>>2]=f;Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Boa(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;j[114626]=0;H(1370,a+4|0)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){j[114626]=0;j[c+12>>2]=0;K(1371,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Rb(a),j[e>>2]=f;Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Jqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>1;j[e+8>>2]=j[a>>2];f=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(f){a=j[a+20>>2];c=f;while(1){g=lb(k[b|0])+d|0;d=g+lb(k[b+1|0])|0;i[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return f<<1}function J1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;a:{if((a|0)!=(b|0)){f=j[114600];j[114600]=0;Wd();e=o2(a,d+12|0);a=j[114600];b:{if(a){if(j[d+12>>2]!=(b|0)){break b}if((a|0)!=68){break a}j[c>>2]=4;break a}j[114600]=f;if(j[d+12>>2]==(b|0)){break a}}}j[c>>2]=4;e=0}Za=d+16|0;return+e}function uoa(a,b,c){var d=0,e=0,f=0;if(b){while(1){d=c;e=j[d+4>>2];j[a>>2]=j[d>>2];j[a+4>>2]=e;e=l[d+18>>1]|l[d+20>>1]<<16;f=l[d+14>>1]|l[d+16>>1]<<16;i[a+14>>1]=f;i[a+16>>1]=f>>>16;i[a+18>>1]=e;i[a+20>>1]=e>>>16;e=j[d+12>>2];j[a+8>>2]=j[d+8>>2];j[a+12>>2]=e;a=a+24|0;b=b-1|0;if(b){continue}break}}}function dDa(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;j[114626]=0;H(814,a+4|0)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){j[114626]=0;j[c+12>>2]=0;K(815,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Rb(a),j[e>>2]=f;Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function X4(a,b,c,d,e){var f=0,g=0,h=0,i=q(0),l=q(0);g=JE(a,b);a:{if((g|0)<0){break a}f=1;a=j[b>>2];h=(a|0)<(d|0)?a:d;if((h|0)<1){break a}a=p(a,g);d=0;while(1){f=(p(d,e)<<2)+c|0;l=q(n[j[b+28>>2]+(a+d<<2)>>2]+i);n[f>>2]=n[f>>2]+l;i=k[b+22|0]?l:i;f=1;d=d+1|0;if((h|0)!=(d|0)){continue}break}}return f}function NFa(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;j[114626]=0;H(725,a+4|0)|0;d=j[114626];j[114626]=0;a:{b:{if((d|0)!=1){j[114626]=0;j[c+12>>2]=0;K(726,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Rb(a),j[e>>2]=f;Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Di(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=Za-48|0;Za=c;a:{if(!b){b=1;if(gd(a,5)){break a}b=IC(c+32|0);e=j[a+8>>2];f=j[d>>2];j[b+4>>2]=f-e;Ve(c,j[a+28>>2]);PC(c+16|0,c,j[d>>2],j[d+4>>2]);j[b+8>>2]=j[c+24>>2]}j[a>>2]=j[a>>2]|134217728;j[a+20>>2]=j[a+20>>2]+1;b=0}Za=c+48|0;return b|0}function aKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-32|0;Za=d;fi(d+16|0,d+8|0,c);j[114626]=0;F(516,d|0,d+16|0);c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;I(517,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}qb(d+16|0);Za=d+32|0;return}a=D()|0;C()|0;qb(d+16|0);G(a|0);z()}function ZB(a,b,c){var d=0,e=0,f=0,g=0,i=0;g=Za-16|0;Za=g;d=nb(a);f=sc(a);a:{if(f-d>>>0>=c>>>0){if(!c){break a}e=zb(a);i=e;f=d;if(d){Fl(c+e|0,e,f);b=b>>>0>=e>>>0?d+e>>>0>b>>>0?b+c|0:b:b}Fl(i,b,c);b=c+d|0;Ag(a,b);h[g+15|0]=0;Td(b+e|0,g+15|0);break a}uu(a,f,(c+d|0)-f|0,d,0,0,c,b)}Za=g+16|0;return a}function AGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-32|0;Za=d;ez(d+16|0,d+8|0,c);j[114626]=0;F(516,d|0,d+16|0);c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;I(517,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}qb(d+16|0);Za=d+32|0;return}a=D()|0;C()|0;qb(d+16|0);G(a|0);z()}function Lg(a){var b=0,c=0,d=0;c=qr(a+56|0);j[a>>2]=76792;j[c>>2]=76812;j[114626]=0;b=a+4|0;K(126,a|0,76824,b|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){a:{j[a>>2]=76792;j[c>>2]=76812;j[114626]=0;E(127,b|0,16)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}return a}}a=D()|0;C()|0;og(c);G(a|0);z()}function Aqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c>>>1;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=Fm(k[b|0]),h[f|0]=g;f=a,g=Fm(k[b+1|0]),h[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e<<1}function zta(a,b,c){var d=0,e=0,f=0;d=Za-16|0;Za=d;e=Bz(b,c);a:{if(e>>>0<=Pf(a)>>>0){j[d+8>>2]=c;if(bc(a)>>>0<e>>>0){j[d+8>>2]=b;f=bc(a);j[d+8>>2]=j[d+8>>2]+(f<<1);aj(b,j[d+8>>2],j[a>>2]);aM(a,j[d+8>>2],c,e-bc(a)|0);break a}Bp(a,aj(b,c,j[a>>2]));break a}$L(a);ry(a,ej(a,e));aM(a,b,c,e)}Za=d+16|0}function vna(a,b){var c=0,d=0;c=b+4|0;d=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);c=j[a>>2]+20|0;if((d|0)==(k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24))){a=j[a>>2]+16|0;a=(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))==(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))}else{a=0}return a}function iMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-32|0;Za=d;Xz(d+16|0,d+8|0,c);j[114626]=0;F(71,d|0,d+16|0);c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;I(72,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}qb(d+16|0);Za=d+32|0;return}a=D()|0;C()|0;qb(d+16|0);G(a|0);z()}function Xza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-48|0;Za=d;f=j[a+4>>2];e=Uza(vd(d+40|0,b),vd(d+32|0,c))+j[a+4>>2]|0;j[a+4>>2]=e;if(!((e-1^f-1)>>>0<32?f:0)){g=j[a>>2];j[(e>>>0<33?g:(e-1>>>3&536870908)+g|0)>>2]=0}b=vd(d+24|0,b);c=vd(d+16|0,c);rn(d+8|0,a,f);Tza(d,b,c,d+8|0);Za=d+48|0}function CBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-32|0;Za=d;fi(d+16|0,d+8|0,c);j[114626]=0;F(71,d|0,d+16|0);c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;I(72,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}qb(d+16|0);Za=d+32|0;return}a=D()|0;C()|0;qb(d+16|0);G(a|0);z()}function yK(a,b,c,d){var e=0,f=0;f=Za-16|0;Za=f;e=-2147483648;e=!c|!(h[c+15|0]&1)?e:j[c+8>>2];a:{b:{if(!(!d|!(k[d+34|0]&32))){e=l[d+28>>1];break b}if((e|0)==-2147483648){break a}}ns(b,e,a);mb(f+8|0,a+1074308|0,10);if(!kb(f+8|0)|j[a+480208>>2]&16384){break a}j[b+88>>2]=j[b+88>>2]&-257}Za=f+16|0}function via(a,b,c){var d=0,e=0,f=0;d=se(a);e=Rb(a);a:{if(d){b:{while(1){c:{f=d+16|0;d:{if(Br(hb(a),c,f)){if(!j[d>>2]){break a}e=d;break d}if(!Br(hb(a),f,c)){break b}e=d+4|0;if(!j[d+4>>2]){break c}d=e;e=d}d=j[d>>2];continue}break}j[b>>2]=d;return e}j[b>>2]=d;return e}d=Rb(a)}j[b>>2]=d;return d}function nba(a){var b=0,c=0;b=Za-48|0;Za=b;vk(b);j[114626]=0;F(246,b+32|0,b|0);c=j[114626];j[114626]=0;a:{b:{if((c|0)!=1){j[114626]=0;I(9,a|0,0,b+32|0);a=j[114626];j[114626]=0;if((a|0)==1){break b}gb(b+32|0);Je(b);Za=b+48|0;return}a=D()|0;C()|0;break a}a=D()|0;C()|0;gb(b+32|0)}Je(b);G(a|0);z()}function moa(a,b,c){var d=0,e=0,f=0;d=se(a);e=Rb(a);a:{if(d){b:{while(1){c:{hb(a);f=d+14|0;d:{if(RJ(c,f)){if(!j[d>>2]){break a}e=d;break d}hb(a);if(!RJ(f,c)){break b}e=d+4|0;if(!j[d+4>>2]){break c}d=e;e=d}d=j[d>>2];continue}break}j[b>>2]=d;return e}j[b>>2]=d;return e}d=Rb(a)}j[b>>2]=d;return d}function foa(a,b,c){var d=0,e=0,f=0;d=se(a);e=Rb(a);a:{if(d){b:{while(1){c:{hb(a);f=d+16|0;d:{if(PJ(c,f)){if(!j[d>>2]){break a}e=d;break d}hb(a);if(!PJ(f,c)){break b}e=d+4|0;if(!j[d+4>>2]){break c}d=e;e=d}d=j[d>>2];continue}break}j[b>>2]=d;return e}j[b>>2]=d;return e}d=Rb(a)}j[b>>2]=d;return d}function fW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-32|0;Za=d;Ll(d+16|0,d+8|0,c);j[114626]=0;F(71,d|0,d+16|0);c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;I(72,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}qb(d+16|0);Za=d+32|0;return}a=D()|0;C()|0;qb(d+16|0);G(a|0);z()}function bH(a,b,c){var d=0,e=0,f=0,g=0;if(q(r(a))<q(2147483648)){d=~~a}else{d=-2147483648}f=d&-2147483648;e=f?0-d|0:d;a:{if(!((e|0)<0|(b|0)<1)){while(1){d=b-1|0;e=e<<1;if((e|0)<0){break a}g=(b|0)>1;b=d;if(g){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return q((f?b^-1|f:b)|0)}function Zk(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{c:{d:{e:{switch(c|0){case 1:break b;case 3:break c;case 0:break d;case 2:break e;default:break a}}e=tK(a,b,d);if(e-251>>>0<5){break d}if(e){break a}}return sK(a,b,d)}e=sK(a,b,d);if(e-251>>>0<5){break b}if(e){break a}}e=tK(a,b,d)}return e}function S6(a,b,c){var d=0,e=0;d=Za-32|0;Za=d;j[d+24>>2]=c;a:{if((a|0)!=(b|0)){while(1){c=Eb(d+8|0,j[a>>2]);j[114626]=0;E(2200,d+24|0,c|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break a}gb(c);a=a+4|0;if((b|0)!=(a|0)){continue}break}c=j[d+24>>2]}Za=d+32|0;return c}a=D()|0;C()|0;gb(c);G(a|0);z()}function Nqa(a,b,c){var d=0,e=0,f=0;d=se(a);e=Rb(a);a:{if(d){b:{while(1){c:{f=d+16|0;d:{if(as(hb(a),c,f)){if(!j[d>>2]){break a}e=d;break d}if(!as(hb(a),f,c)){break b}e=d+4|0;if(!j[d+4>>2]){break c}d=e;e=d}d=j[d>>2];continue}break}j[b>>2]=d;return e}j[b>>2]=d;return e}d=Rb(a)}j[b>>2]=d;return d}function Nla(a,b,c){var d=0,e=0,f=0;d=se(a);e=Rb(a);a:{if(d){b:{while(1){c:{f=d+16|0;d:{if(PI(hb(a),c,f)){if(!j[d>>2]){break a}e=d;break d}if(!PI(hb(a),f,c)){break b}e=d+4|0;if(!j[d+4>>2]){break c}d=e;e=d}d=j[d>>2];continue}break}j[b>>2]=d;return e}j[b>>2]=d;return e}d=Rb(a)}j[b>>2]=d;return d}function Lta(a,b,c){var d=0,e=0,f=0;d=se(a);e=Rb(a);a:{if(d){b:{while(1){c:{f=d+14|0;d:{if(vn(hb(a),c,f)){if(!j[d>>2]){break a}e=d;break d}if(!vn(hb(a),f,c)){break b}e=d+4|0;if(!j[d+4>>2]){break c}d=e;e=d}d=j[d>>2];continue}break}j[b>>2]=d;return e}j[b>>2]=d;return e}d=Rb(a)}j[b>>2]=d;return d}function FFa(a,b,c){var d=0,e=0,f=0;d=se(a);e=Rb(a);a:{if(d){b:{while(1){c:{f=d+16|0;d:{if(Zm(hb(a),c,f)){if(!j[d>>2]){break a}e=d;break d}if(!Zm(hb(a),f,c)){break b}e=d+4|0;if(!j[d+4>>2]){break c}d=e;e=d}d=j[d>>2];continue}break}j[b>>2]=d;return e}j[b>>2]=d;return e}d=Rb(a)}j[b>>2]=d;return d}function ECa(a,b,c){var d=0,e=0,f=0;d=se(a);e=Rb(a);a:{if(d){b:{while(1){c:{f=d+14|0;d:{if(Zm(hb(a),c,f)){if(!j[d>>2]){break a}e=d;break d}if(!Zm(hb(a),f,c)){break b}e=d+4|0;if(!j[d+4>>2]){break c}d=e;e=d}d=j[d>>2];continue}break}j[b>>2]=d;return e}j[b>>2]=d;return e}d=Rb(a)}j[b>>2]=d;return d}function ola(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,i=0;e=Za-16|0;Za=e;f=ti(b,c);d=sc(a);if(f>>>0>d>>>0){g=d;i=f-d|0;d=nb(a);tl(a,g,i,d,0,d,0)}d=zb(a);if((b|0)!=(c|0)){while(1){Td(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}h[e+15|0]=0;Td(d,e+15|0);Ag(a,f);Za=e+16|0;return a|0}function d3(a){var b=0,c=0;b=Za-16|0;Za=b;c=Mq(461284);j[115331]=461340;j[115329]=a;j[115321]=56904;h[461336]=0;j[115333]=-1;zq(b+8|0,c);a=j[j[115321]+8>>2];j[114626]=0;F(a|0,461284,b+8|0);a=j[114626];j[114626]=0;if((a|0)!=1){wb(b+8|0);Za=b+16|0;return}a=D()|0;C()|0;wb(b+8|0);Jk(c);G(a|0);z()}function cT(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Za-16|0;Za=d;j[d+12>>2]=c;kc(d+12|0,128);kc(d+12|0,65535);f=l[d+12>>1];bg(a,f);if(f){c=0;while(1){e=k[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=mk(a,c),h=e,i[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}Za=d+16|0}function cA(a,b){var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;a:{if(!b){break a}if(!yb(a,b)){break a}f=1;while(1){h[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){Df(a,c+13|0);d=k[c+13|0]}else{d=0}h[e|0]=d;d=1;e=f;f=0;if(e){continue}break}i[c+10>>1]=l[c+14>>1];a=c+10|0;d=k[a|0]|k[a+1|0]<<8}Za=c+16|0;return d}function b3(a){var b=0,c=0;b=Za-16|0;Za=b;c=fE(461348);j[115347]=461404;j[115345]=a;j[115337]=57044;h[461400]=0;j[115349]=-1;zq(b+8|0,c);a=j[j[115337]+8>>2];j[114626]=0;F(a|0,461348,b+8|0);a=j[114626];j[114626]=0;if((a|0)!=1){wb(b+8|0);Za=b+16|0;return}a=D()|0;C()|0;wb(b+8|0);Wn(c);G(a|0);z()}function LEa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if(!j[a+300>>2]){return 0}if((bb[j[a+304>>2]](j[a+296>>2],c,0,0)|0)>=0){while(1){a:{g=f;c=h;if(!d){break a}e=bb[j[a+300>>2]](j[a+296>>2],b,d)|0;d=d-e|0;b=b+e|0;f=e+g|0;c=f>>>0<e>>>0?c+1|0:c;h=c;if(e){continue}}break}}return g|0}function Fx(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;f=Jo(a);a:{if(bc(f)>>>0<=b>>>0){break a}if(Gx(a,l[ac(f,b)>>1])>>>0<=c>>>0){break a}b:{if(cc(a)>>>0>b>>>0){if(m[Zc(a,b)+4>>2]>c>>>0){break b}}Si(a,0);if(cc(a)>>>0<=b>>>0){break a}}Nd(e+8|0,Zc(a,b),c);Qd(e+8|0,d);if(!d){break a}fL(a,b,c)}Za=e+16|0}function ZG(a){a=a|0;var b=0,c=0;c=Za-16|0;Za=c;b=j[a+4256>>2];j[a+4240>>2]=b<<1;j[114626]=0;j[c+12>>2]=0;I(1640,a+4208|0,b<<2,c+12|0);b=j[114626];j[114626]=0;a:{if((b|0)==1){b=J(71396)|0;if((C()|0)!=(W(71396)|0)){break a}O(b|0)|0;j[a+4240>>2]=0;Q()}j[a+4244>>2]=0;Za=c+16|0;return}G(b|0);z()}function BM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Za-16|0;Za=c;d=j[b+4>>2];j[c+8>>2]=j[b>>2];j[c+12>>2]=d;e=c,f=nb(a),j[e+4>>2]=f;j[c>>2]=j[c+12>>2];a=zm(zb(a),j[c+8>>2],j[tb(c+4|0,c)>>2]);a:{if(a){break a}a=-1;b=j[c>>2];d=j[c+4>>2];if(b>>>0>d>>>0){break a}a=b>>>0<d>>>0}Za=c+16|0;return a|0}function wqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c>>>1;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=(lb(k[b|0])|lb(k[b+1|0])<<8)^32768,i[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e<<1}function tqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c>>>1;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=(lb(k[b+1|0])|lb(k[b|0])<<8)^32768,i[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e<<1}function _ta(a){var b=0,c=0,d=0;b=j[a+2496>>2];c=(b+1>>>0)%624|0;d=j[(c<<2)+a>>2];b=p(d&1,-1727483681)^(j[((b+397>>>0)%624<<2)+a>>2]^(d&2147483647|j[(b<<2)+a>>2]&-2147483648)>>>1);j[(j[a+2496>>2]<<2)+a>>2]=b;j[a+2496>>2]=c;a=b^b>>>11;a=a<<7&-1658038656^a;a=a<<15&-272236544^a;return a>>>18^a}function SAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-32|0;Za=d;eO(d+16|0,c);j[114626]=0;F(516,d|0,d+16|0);c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;I(517,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}qb(d+16|0);Za=d+32|0;return}a=D()|0;C()|0;qb(d+16|0);G(a|0);z()}function qwa(a){var b=0,c=0,d=0;d=a+32|0;while(1){b=k[a|0];a:{b:{if((b-97&255)>>>0<=5){c=b-32|0;break b}c=99;c:{if(b>>>0<=106){if(b-88>>>0<2){break c}if((b|0)==75){break b}break a}if(b-120>>>0<2){break c}if((b|0)==107){break b}break a}c=122}h[a|0]=c}a=a+1|0;if((d|0)!=(a|0)){continue}break}}function jR(a,b,c){var d=0;d=Za-32|0;Za=d;j[d+16>>2]=b;j[d+24>>2]=a;j[d+8>>2]=c;a:{if(!rb(d+24|0,d+16|0)){break a}while(1){a=j[d+24>>2];if(j[j[d+8>>2]>>2]==(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))){break a}fk(d+24|0);if(rb(d+24|0,d+16|0)){continue}break}}Za=d+32|0;return j[d+24>>2]}function iQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,i=0;if(!k[a+20|0]){if(!(bb[j[j[a>>2]+44>>2]](a)|0)){b=a+4|0;while(1){rQ(a,65536);c=a,d=(f=a,g=fc(b,j[a+16>>2]),i=65536,e=j[j[a>>2]+48>>2],bb[e](f|0,g|0,i|0)|0)+j[a+16>>2]|0,j[c+16>>2]=d;if(!(bb[j[j[a>>2]+44>>2]](a)|0)){continue}break}}h[a+20|0]=1}}function Zxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-32|0;Za=d;Nxa(d+16|0,c);j[114626]=0;F(71,d|0,d+16|0);c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;I(72,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}qb(d+16|0);Za=d+32|0;return}a=D()|0;C()|0;qb(d+16|0);G(a|0);z()}function zma(a,b,c){var d=0,e=0,f=0,g=0;e=Za-16|0;Za=e;g=c<<2;while(1){j[e>>2]=0;f=((d<<11)+a|0)+16396|0;MK(f,g+f|0,e);d=d+1|0;if((d|0)!=4){continue}break}d=0;while(1){j[(d<<2)+e>>2]=((d<<11)+a|0)+16396;d=d+1|0;if((d|0)!=4){continue}break}bb[j[j[b>>2]+8>>2]](b,e,j[a+24632>>2],c);Za=e+16|0}function we(a){a=a|0;var b=0,c=0;j[a>>2]=79872;b=j[a+12>>2];if(j[b>>2]==(a|0)){j[b>>2]=j[a+4>>2]}b=j[a+20>>2];if(b){j[b>>2]=0;j[a+20>>2]=0}b=j[a+4>>2];if(b){j[b+8>>2]=j[a+8>>2]}c=j[a+8>>2];if(c){j[c+4>>2]=b}j[a+4>>2]=0;j[a+8>>2]=0;b=a+44|0;ur(b+36|0);ur(b+24|0);tr(b+12|0);tr(b);return a|0}function iJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-32|0;Za=d;cS(d+16|0,c);j[114626]=0;F(71,d|0,d+16|0);c=j[114626];j[114626]=0;a:{if((c|0)==1){break a}j[114626]=0;I(72,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}qb(d+16|0);Za=d+32|0;return}a=D()|0;C()|0;qb(d+16|0);G(a|0);z()}function RD(a,b,c){var d=0,e=0,f=0,g=0,i=0;d=Za-16|0;Za=d;e=Mq(a);j[a+32>>2]=b;j[a>>2]=57144;zq(d+8|0,e);j[114626]=0;b=H(2382,d+8|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){wb(d+8|0);j[a+40>>2]=c;j[a+36>>2]=b;g=a,i=am(b),h[g+44|0]=i;Za=d+16|0;return}a=D()|0;C()|0;wb(d+8|0);Jk(e);G(a|0);z()}function QD(a,b,c){var d=0,e=0,f=0,g=0,i=0;d=Za-16|0;Za=d;e=fE(a);j[a+32>>2]=b;j[a>>2]=57248;zq(d+8|0,e);j[114626]=0;b=H(2383,d+8|0)|0;f=j[114626];j[114626]=0;if((f|0)!=1){wb(d+8|0);j[a+40>>2]=c;j[a+36>>2]=b;g=a,i=am(b),h[g+44|0]=i;Za=d+16|0;return}a=D()|0;C()|0;wb(d+8|0);Wn(e);G(a|0);z()}function Eoa(a){var b=0,c=0,d=0,e=0;c=a+1074412|0;a:{b:{b=a+484344|0;if(xp(b,l[a+1074436>>1])){if(FK(Ib(b,l[a+1074436>>1]))){break b}}j[a+1074408>>2]=j[a+480216>>2];a=j[a+480220>>2];break a}d=a+1074408|0,e=j[Ib(b,l[a+1074436>>1])+16>>2],j[d>>2]=e;a=j[Ib(b,l[a+1074436>>1])+20>>2]}j[c>>2]=a}function yI(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{c=a-12|0;d:{if(c>>>0>28){break d}a=1;d=1<<c;if(d&270014517){break b}if(d&65792){break c}if((c|0)!=7){break d}b=b&240;if(!b|(b|0)==96|(b|0)==224){break b}}return 0}a=0;b=(b&240)-96|0;if(b>>>0<144){break a}}return a|0}return 297>>>(b>>>4)&1}function _l(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=Za-16|0;Za=c;g=a;h=a;a:{if(!b){b=0;e=0;break a}d=b;b=s(b);We(c,d,0,0,0,b+81|0);d=0+j[c+8>>2]|0;b=(j[c+12>>2]^65536)+(16414-b<<16)|0;b=d>>>0<f>>>0?b+1|0:b;f=d;d=b;b=j[c+4>>2];e=j[c>>2]}j[h>>2]=e;j[g+4>>2]=b;j[a+8>>2]=f;j[a+12>>2]=d;Za=c+16|0}function GU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0;e=Za-16|0;Za=e;j[e+12>>2]=d;d=0;if(m[a+16>>2]>c>>>0){d=j[a+4>>2];f=j[a+12>>2];j[e+8>>2]=j[a+16>>2]-c;d=(h=d,i=b,k=c+f|0,l=j[tb(e+12|0,e+8|0)>>2],g=j[j[d>>2]+28>>2],bb[g](h|0,i|0,k|0,l|0)|0)}Za=e+16|0;return d|0}function rW(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;a=_E(a,c+8|0);d=nb(b);e=ne(7063);b=zb(b);j[114626]=0;L(195,a|0,b|0,d|0,d+e|0);b=j[114626];j[114626]=0;a:{if((b|0)!=1){j[114626]=0;K(196,a|0,7063,e|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break a}}b=D()|0;C()|0;gb(a);G(b|0);z()}Za=c+16|0}function pta(a,b,c){var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=b;a:{if(Pf(a)>>>0>=b>>>0){f=d,g=bc(a),j[f+8>>2]=g;Ky(j[a>>2],j[tb(d+12|0,d+8|0)>>2],c);e=j[d+8>>2];b=j[d+12>>2];if(e>>>0<b>>>0){Dt(a,b-e|0,c);break a}Bp(a,j[a>>2]+(b<<1)|0);break a}$L(a);ry(a,ej(a,b));Dt(a,b,c)}Za=d+16|0}function S5(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=b;f=k[c|0];if(f){d=a;while(1){i=f<<1;g=0;while(1){n[e>>2]=n[d>>2];n[e+4>>2]=n[(f<<2)+d>>2];h=i<<2;n[e+8>>2]=n[h+d>>2];d=d+4|0;e=e+12|0;g=g+1|0;if((g|0)!=(f|0)){continue}break}d=d+h|0;f=k[c+3|0];c=c+3|0;if(f){continue}break}}Vb(a,b,e-b|0)}function Dsa(a){j[a>>2]=0;j[a+4>>2]=0;j[a+68>>2]=0;j[a+72>>2]=0;j[a+24>>2]=0;j[a+28>>2]=0;i[a+20>>1]=511;j[a+16>>2]=-1;i[a+14>>1]=1;i[a+6>>1]=0;i[a+8>>1]=0;i[a+10>>1]=0;i[a+12>>1]=0;h[a+73|0]=0;h[a+74|0]=0;h[a+75|0]=0;h[a+76|0]=0;h[a+77|0]=0;h[a+78|0]=0;h[a+79|0]=0;h[a+80|0]=0;return a}function vqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>1;j[e+8>>2]=j[a>>2];f=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(f){a=j[a+20>>2];c=f;while(1){d=(lb(k[b|0])|lb(k[b+1|0])<<8)+d|0;i[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return f<<1}function sqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-16|0;Za=e;j[e+12>>2]=c>>>1;j[e+8>>2]=j[a>>2];f=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(f){a=j[a+20>>2];c=f;while(1){d=(lb(k[b+1|0])|lb(k[b|0])<<8)+d|0;i[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return f<<1}function Waa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-48|0;Za=d;j[d+44>>2]=b;Ni(d+8|0,0,c);b=d+24|0;j[b>>2]=j[d+44>>2];Nc(b+4|0,d+8|0);j[114626]=0;F(2118,a+4|0,d+24|0);a=j[114626];j[114626]=0;if((a|0)!=1){Ts(d+24|0);gb(d+8|0);Za=d+48|0;return}a=D()|0;C()|0;Ts(d+24|0);gb(d+8|0);G(a|0);z()}function PV(a,b,c){var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c;f=nb(a);if(f>>>0>=b>>>0){if(c){g=zb(a);e=f-b|0;j[d+8>>2]=e;c=j[tb(d+12|0,d+8|0)>>2];j[d+12>>2]=c;e=e-c|0;if(e){b=b+g|0;Fl(b,b+c|0,e);c=j[d+12>>2]}b=a;a=f-c|0;Ag(b,a);h[d+7|0]=0;Td(a+g|0,d+7|0)}Za=d+16|0;return}Pl();z()}function sma(a,b){var c=0;c=Za-16|0;Za=c;a=a+1074308|0;mb(c+8|0,a,28);a:{b:{if(!kb(c+8|0)){mb(c,a,1);if(!kb(c)){break b}}j[b+684>>2]=j[b+692>>2]+i[b+790>>1];Md(b+684|0,0,256);break a}j[b+692>>2]=j[b+692>>2]+i[b+790>>1];Md(b+692|0,0,256);i[b+790>>1]=0;j[b+684>>2]=j[b+692>>2]}Za=c+16|0}function g1(a,b){var c=0,d=0;c=Za-16|0;Za=c;hc(c+8|0,a);j[114626]=0;a=H(2441,c+8|0)|0;d=j[114626];j[114626]=0;a:{if((d|0)==1){break a}j[114626]=0;P(2455,a|0,62160,62186,b|0)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}wb(c+8|0);Za=c+16|0;return b}a=D()|0;C()|0;wb(c+8|0);G(a|0);z()}function IX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-16|0;Za=d;a:{if(j[b>>2]){if(!Ec(c)){vu(c,70712)}e=j[b+4>>2];bb[j[j[e>>2]+24>>2]](d,e,j[b>>2]);j[114626]=0;E(1245,c|0,d|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}gb(d)}Nc(a,c);Za=d+16|0;return}a=D()|0;C()|0;gb(d);G(a|0);z()}function xqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c>>>1;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=lb(k[b|0])|lb(k[b+1|0])<<8,i[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e<<1}function uqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c>>>1;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=lb(k[b+1|0])|lb(k[b|0])<<8,i[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e<<1}function GC(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-16|0;Za=d;b=_d(d,a,b);c=j[b+4>>2];a:{while(1){if(j[b+8>>2]==(c|0)){break a}Ck(a);c=j[b+4>>2];j[114626]=0;qs(c);c=j[114626];j[114626]=0;if((c|0)!=1){c=j[b+4>>2]+4|0;j[b+4>>2]=c;continue}break}a=D()|0;C()|0;ub(b);G(a|0);z()}ub(b);Za=d+16|0}function zd(a){var b=0,c=0,d=0,e=0;YMa(+a);b=VMa(1)|0;VMa(0)|0;e=b;b=b>>>20&2047;if(b>>>0<=1074){if(b>>>0<=1021){return a*0}a=(e|0)>-1?a:-a;c=a+4503599627370496+ -4503599627370496-a;a:{if(!(c>.5^1)){d=a+c+ -1;break a}a=a+c;d=a;if(c<=-.5^1){break a}d=a+1}a=d;a=(e|0)>-1?a:-a}return a}function lD(a,b,c){var d=0,e=0,f=0,g=0;f=Za-16|0;Za=f;e=Ks(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){Ue(a,e);d=a;break a}g=Ql(e)+1|0;d=Ak(g);lf(a,d);jg(a,g);ee(a,e)}while(1){if((b|0)!=(c|0)){ze(d,b);d=d+4|0;b=b+4|0;continue}break}j[f+12>>2]=0;ze(d,f+12|0);Za=f+16|0;return}kg();z()}function uQ(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=k[b|0]|k[b+1|0]<<8;b=a+38|0;e=k[b|0]|k[b+1|0]<<8;b=a+34|0;a=a+36|0;c=k[a|0]|k[a+1|0]<<8;b=(k[b|0]|k[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;ab=a;return b}function uJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;a:{b:{if(!Ld(c)|(!d|j[b+480180>>2]!=16777216)|l[b+480192>>1]<d>>>0){break b}d=j[((d<<2)+b|0)+900380>>2];if(!d){break b}d=j[d+44>>2];if(!d){break b}i[e+14>>1]=c-61;bja(a,d,e+14|0);break a}cna(a,c,j[b>>2])}Za=e+16|0}function s4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-32|0;Za=c;a=r4(c+8|0,a);d=j[a>>2];e=j[a+4>>2];a=j[b+4>>2];j[c>>2]=j[b>>2];j[c+4>>2]=a;e=j[c+4>>2]+e|0;b=j[c>>2];d=d+b|0;j[c+16>>2]=d;j[c+20>>2]=b>>>0>d>>>0?e+1|0:e;a=Sj(c+24|0,c+16|0);b=j[a+4>>2];a=j[a>>2];Za=c+32|0;ab=b;return a|0}function p4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-32|0;Za=c;a=o4(c+8|0,a);d=j[a>>2];e=j[a+4>>2];a=j[b+4>>2];j[c>>2]=j[b>>2];j[c+4>>2]=a;e=j[c+4>>2]+e|0;b=j[c>>2];d=d+b|0;j[c+16>>2]=d;j[c+20>>2]=b>>>0>d>>>0?e+1|0:e;a=Sj(c+24|0,c+16|0);b=j[a+4>>2];a=j[a>>2];Za=c+32|0;ab=b;return a|0}function o7(a,b,c,d,e){var f=0,g=0,h=0,k=0,l=0;if(e){while(1){g=0;if(d){while(1){f=j[uf(b,g,h)>>2];Pb(c,g);f=f-2147481600>>>12|0;f=f>>>0>491520?f:491520;k=jm(a,g,h),l=(f|0)<557055?f:557055,i[k>>1]=l;g=g+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}}function Q7(a,b,c,d,e){var f=0,g=0,h=0,k=0,l=0;if(e){while(1){g=0;if(d){while(1){f=j[uf(b,g,h)>>2];Pb(c,g);f=f-2147481600>>>12|0;f=f>>>0>491520?f:491520;k=lm(a,g,h),l=(f|0)<557055?f:557055,i[k>>1]=l;g=g+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}}function KZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=g>>>0){break a}f=1;b:{c:{h=JZ(c,d-c|0,b,j[a+8>>2]);switch(h+2|0){case 0:case 1:break a;case 2:break b;default:break c}}f=h}g=g+1|0;i=f+i|0;c=c+f|0;continue}break}return i|0}function mW(a){var b=0,c=0;c=Za-32|0;Za=c;a=Qc(a);j[114626]=0;N(236,c|0);b=j[114626];j[114626]=0;a:{b:{if((b|0)!=1){b=zg(c);j[114626]=0;E(237,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break b}Je(c);Za=c+32|0;return}b=D()|0;C()|0;break a}b=D()|0;C()|0;Je(c)}gb(a);G(b|0);z()}function iga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;j[a+4>>2]=b;j[a>>2]=0;b=is(a+8|0,e);j[114626]=0;E(1753,a+20|0,d|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){j[a+32>>2]=0;j[a+36>>2]=0;h[a+42|0]=0;h[a+40|0]=0;h[a+41|0]=k[a+41|0]&240|c|8;return a|0}a=D()|0;C()|0;qb(b);G(a|0);z()}function Loa(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:Coa(a,c);return;case 1:xoa(a,c);return;case 2:ooa(a,c);return;case 3:wo(a,c,1520);return;case 4:wo(a,c,2544);return;case 5:wo(a,c,3568);return;case 6:wo(a,c,4592);return;case 7:wo(a,c,5616);return;default:break a}}Db(a)}function fDa(a,b,c){var d=0,e=0;d=Za-16|0;Za=d;e=Ks(b,c);a:{if(e>>>0<=jd(a)>>>0){j[d+12>>2]=c;if(sb(a)>>>0<e>>>0){j[d+12>>2]=b;YO(d+12|0,sb(a));Pe(b,j[d+12>>2],j[a>>2]);yp(a,j[d+12>>2],c,e-sb(a)|0);break a}Pt(a,Pe(b,c,j[a>>2]));break a}XO(a);NCa(a,ie(a,e));yp(a,b,c,e)}Za=d+16|0}function b4(a,b,c,d){var e=0,f=0,g=0;e=Za-16|0;Za=e;d=d-c|0;a:{if(!d){b=a;break a}f=b-a|0;if((d|0)>(f|0)){break a}h[e+15|0]=k[c|0];g=1-d|0;while(1){a=An(a,f+g|0,e+15|0);if(!a){break a}if(!zm(a,c,d)){b=a;break a}a=a+1|0;f=b-a|0;if((d|0)<=(f|0)){continue}break}}Za=e+16|0;return b}function Vja(a,b,c){var d=0,e=0;d=Za-16|0;Za=d;e=Ks(b,c);a:{if(e>>>0<=jd(a)>>>0){j[d+12>>2]=c;if(sb(a)>>>0<e>>>0){j[d+12>>2]=b;YO(d+12|0,sb(a));Pe(b,j[d+12>>2],j[a>>2]);yp(a,j[d+12>>2],c,e-sb(a)|0);break a}YP(a,Pe(b,c,j[a>>2]));break a}Uja(a);KS(a,ie(a,e));yp(a,b,c,e)}Za=d+16|0}function Bd(a,b){var c=0,d=0,e=0,f=0;c=j[a+4>>2];d=c+b|0;j[a+4>>2]=d;if((d|0)<=j[a+8>>2]){d=j[a>>2]+(c>>3)|0;a=c&7;c=k[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=(a|0)>16;c=k[d+1|0];a=b;d=d+1|0;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function Sg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-32|0;Za=e;g=kj(a,c);Ve(e+8|0,j[a+28>>2]);f=j[e+20>>2];j[e+24>>2]=j[e+16>>2];j[e+28>>2]=f;a:{b:{if(!g){f=-1;if(!gd(a,5)){break b}break a}f=j[g+8>>2]}bb[d|0](j[a+28>>2],b,f)}a=Di(a,g,c,e+24|0);Za=e+32|0;return a|0}function gm(a,b,c){var d=0,e=0,f=0;a:{if(b>>>0<1){d=a;break a}while(1){d=RMa(a,b,10,0);e=ab;f=e;e=OMa(d,e,10,0);c=c-1|0;h[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;h[c|0]=d-p(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function i5(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0;if((b|0)>=1){h=(b<<1)+a|0;i=-1;k=65536;while(1){g=(f<<1)+a|0;e=l[g>>1];if(!((i|0)>=(e|0)|l[h>>1]<=e>>>0)){j[c>>2]=f;e=l[g>>1];i=e}if(!((e|0)>=(k|0)|l[h>>1]>=e>>>0)){j[d>>2]=f;k=l[g>>1]}f=f+1|0;if((f|0)!=(b|0)){continue}break}}}function Vsa(a,b){a=a|0;b=b|0;var c=0;c=Za-48|0;Za=c;h[c+40|0]=k[b|0];Tp(c+16|0,c+40|0);b=lb(j[c+16>>2]);Tp(c+8|0,c+40|0);b=Zh(c+24|0,b,lb(j[c+8>>2]+1|0));j[114626]=0;E(1187,a|0,b|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){gb(b);Za=c+48|0;return}a=D()|0;C()|0;gb(b);G(a|0);z()}function L6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Za-16|0;Za=f;d=fo(f+8|0,d);j[114626]=0;U(2007,a+8|0,b|0,c|0,d|0,e|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Hc(d);wF(a);b=vF(a+88|0);j[a>>2]=84344;j[b>>2]=84432;Za=f+16|0;return a|0}a=D()|0;C()|0;Hc(d);G(a|0);z()}function Eqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=Gb(Fm(k[b|0]),-64,63)<<1,h[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e|0}function DLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;j[a>>2]=0;j[a+4>>2]=0;if(!yb(b,c)){c=ef(b)}j[a>>2]=c;d=j[b>>2];if(bb[j[j[d>>2]+16>>2]](d)|0){c=a;a=j[b>>2];e=c,f=(bb[j[j[a>>2]+20>>2]](a)|0)+j[b+8>>2]|0,j[e+4>>2]=f;return}d=a+8|0;ek(d,j[a>>2]);if(!ad(d)){Vg(b,fc(d,0),c)}}function $U(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+16|0]=0;h[a+17|0]=0;h[a+18|0]=0;h[a+19|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;h[a+15|0]=0;Za=b+16|0}function zA(a,b,c,d){var e=0,f=0;b=j[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;j[a+1072>>2]=b;c=b+j[a+1076>>2]|0;j[a+1076>>2]=c;i[(j[a+1064>>2]<<1)+d>>1]=k[a+1080|0]?c:b;j[a+1060>>2]=j[a+1060>>2]+1;e=a,f=be(j[a+1056>>2])+j[a+1064>>2]|0,j[e+1064>>2]=f;j[a+1068>>2]=j[a+1068>>2]-1}function Mj(a,b,c,d){var e=0,f=0;a:{f=j[(p(b,896)+a|0)+1075640>>2];if(!f){break a}if(!ci(f)){break a}e=k[f+34|0];if(e-251>>>0<5|!e){break a}e=j[(p(e,160)+a|0)+906140>>2];if(!e){break a}bb[j[j[e>>2]+88>>2]](e,f,c,d,b);if(c>>>0>250){break a}i[(p(b,896)+a|0)+1075846>>1]=65535}}function w7(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=q(0);if(e){while(1){f=0;if(d){while(1){h=o[Jg(b,f,g)>>3];Pb(c,f);i=Vi(zd(h*134217728));j=Qm(a,f,g),k=q(+(i|0)*7.450580596923828e-9),n[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function v7(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=q(0);if(e){while(1){f=0;if(d){while(1){h=o[Jg(b,f,g)>>3];Be(c,f);i=Vi(zd(h*134217728));j=Qm(a,f,g),k=q(+(i|0)*7.450580596923828e-9),n[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function hfa(a,b,c){a=a|0;b=b|0;c=q(c);var d=0;d=Za-16|0;Za=d;n[d+12>>2]=c;if((b|0)<=6){Kd(d+12|0,q(0));c=n[d+12>>2];a:{if(!((b|0)!=1|c>=q(1))){j[d+12>>2]=0;c=q(0);break a}if((b|0)!=4){break a}c=q(Sd(q(c*q(4)))*q(.25));n[d+12>>2]=c}n[((b<<2)+a|0)+4208>>2]=c;nw(a)}Za=d+16|0}function Yfa(a,b,c){a=a|0;b=b|0;c=q(c);var d=0;d=Za-16|0;Za=d;n[d+12>>2]=c;if((b|0)<=6){Kd(d+12|0,q(0));c=n[d+12>>2];a:{if(!((b|0)!=3|c>=q(1))){j[d+12>>2]=0;c=q(0);break a}if((b|0)!=4){break a}c=q(Sd(q(c*q(4)))*q(.25));n[d+12>>2]=c}n[((b<<2)+a|0)+4208>>2]=c;nw(a)}Za=d+16|0}function U6(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=q(0);if(e){while(1){f=0;if(d){while(1){h=o[Jg(b,f,g)>>3];Pb(c,f);i=Vi(zd(h*134217728));j=uf(a,f,g),k=q(+(i|0)*7.450580596923828e-9),n[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function T6(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=q(0);if(e){while(1){f=0;if(d){while(1){h=o[Jg(b,f,g)>>3];Be(c,f);i=Vi(zd(h*134217728));j=uf(a,f,g),k=q(+(i|0)*7.450580596923828e-9),n[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function Exa(a,b){var c=0;c=Za-16|0;Za=c;a=kxa(c,a,b);b=j[a+4>>2];if((b|0)!=j[a+8>>2]){while(1){h[b|0]=0;h[b+1|0]=0;h[b+2|0]=0;h[b+3|0]=0;h[b+4|0]=0;h[b+5|0]=0;h[b+6|0]=0;h[b+7|0]=0;h[b+8|0]=0;b=j[a+4>>2]+9|0;j[a+4>>2]=b;if(j[a+8>>2]!=(b|0)){continue}break}}ub(a);Za=c+16|0}function xv(a){var b=0,c=0;a:{if(m[a+20>>2]<=m[a+28>>2]){break a}bb[j[a+36>>2]](a,0,0)|0;if(j[a+20>>2]){break a}return-1}b=j[a+4>>2];c=j[a+8>>2];if(b>>>0<c>>>0){b=b-c|0;bb[j[a+40>>2]](a,b,b>>31,1)|0}j[a+28>>2]=0;j[a+16>>2]=0;j[a+20>>2]=0;j[a+4>>2]=0;j[a+8>>2]=0;return 0}function rH(a,b){var c=0,d=0;c=Za-16|0;Za=c;hc(c+8|0,a);j[114626]=0;a=H(21,c+8|0)|0;d=j[114626];j[114626]=0;a:{if((d|0)==1){break a}j[114626]=0;a=E(22,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}wb(c+8|0);Za=c+16|0;return a}a=D()|0;C()|0;wb(c+8|0);G(a|0);z()}function wY(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;b=wh(c,a+8|0,b);a=j[b>>2];a:{while(1){if(j[b+4>>2]==(a|0)){break a}a=j[b>>2];j[114626]=0;qs(a);a=j[114626];j[114626]=0;if((a|0)!=1){a=j[b>>2]+4|0;j[b>>2]=a;continue}break}a=D()|0;C()|0;dc(b);G(a|0);z()}dc(b);Za=c+16|0}function e2(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d+8>>2]=0;j[d+4>>2]=4;xk(a,d+8|0,j[tb(d+12|0,d+4|0)>>2]);a=ab;if((a|0)>0?1:(a|0)>=0){j[d+4>>2]=4;j[tb(d+12|0,d+4|0)>>2]}j[d+4>>2]=j[d+8>>2];a=d+4|0;j[b>>2]=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);Za=d+16|0}function Zn(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+ -2.5050760253406863e-8)+(d*(d*27557313707070068e-22+ -.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+ -.16666666666666632)+a}return a-(d*(b*.5-e*f)-b+e*.16666666666666632)}function TLa(a,b){var c=0;c=Za-32|0;Za=c;j[c+16>>2]=b;j[c+24>>2]=a;a:{if(!rb(c+24|0,c+16|0)){break a}j[c>>2]=j[c+24>>2];if(!rb(je(c),c+16|0)){break a}while(1){if(DS(j[c+24>>2],j[c>>2])){j[c+24>>2]=j[c>>2]}if(rb(je(c),c+16|0)){continue}break}}Za=c+32|0;return j[c+24>>2]}function Oi(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(!(b?0:!(j[a+480180>>2]&1))){e=j[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;i[c+480286>>1]=64;d=c+480280|0;j[d>>2]=j[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;i[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function Iga(a){var b=q(0),c=0,d=0;b=q(1);c=j[a+20>>2];if(c){b=q(q(k[c+26|0])*q(.10000000149011612))}b=b<q(.10000000149011612)?q(1):b;c=a;if(bb[j[j[a>>2]+132>>2]](a)|0){d=tH(j[a+16>>2]);a=j[a+16>>2];b=q(q(b*q(m[a+480232>>2]))/q(n[d+8>>2]*n[tH(a)+20>>2]))}n[c+4196>>2]=b}function yA(a,b,c,d){var e=0,f=0;b=j[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;j[a+1072>>2]=b;c=b+j[a+1076>>2]|0;j[a+1076>>2]=c;h[j[a+1064>>2]+d|0]=k[a+1080|0]?c:b;j[a+1060>>2]=j[a+1060>>2]+1;e=a,f=be(j[a+1056>>2])+j[a+1064>>2]|0,j[e+1064>>2]=f;j[a+1068>>2]=j[a+1068>>2]-1}function Ze(a,b){var c=0,d=0,e=0,f=0;c=nb(a);a:{if((c|0)!=(nb(b)|0)){break a}d=zb(a);b=zb(b);b:{if(!qe(a)){if(c){break b}return 1}return!zm(d,b,c)}while(1){a=k[b|0];e=k[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function yE(a,b){var c=0,d=0,e=0;YMa(+a);c=VMa(1)|0;d=VMa(0)|0;e=c;c=c>>>20&2047;if((c|0)!=2047){if(!c){c=b;if(a==0){b=0}else{a=yE(a*0x10000000000000000,b);b=j[b>>2]+ -64|0}j[c>>2]=b;return a}j[b>>2]=c-1022;WMa(0,d|0);WMa(1,e&-2146435073|1071644672);a=+XMa()}return a}function wy(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;a:{if((d|0)==(a|0)){b=0;break a}f=b?224:240;b=0;while(1){a=c;e=a+16|0;if((a|0)!=(e|0)){while(1){b=((k[Pb(a,0)|0]&f)!=0)+b|0;a=a+4|0;if((e|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return b}function Jka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-32|0;Za=c;e=-1;d=a;a=c+8|0;d=uka(d,a);if(!d){DI(a)}a:{if(!d){break a}e=0;if(!HI(c+8|0)){break a}if(b){a=c+16|0;if(j[b>>2]!=(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))|j[b+4>>2]){break a}}e=1}Za=c+32|0;return e|0}function $sa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-32|0;Za=e;j[e+24>>2]=d;d=kj(a,c);Ve(e,j[a+28>>2]);f=j[e+12>>2];j[e+16>>2]=j[e+8>>2];j[e+20>>2]=f;a:{if(!d){b:{if(!gd(a,5)){break b}break a}}Zsa(e+24|0,j[a+28>>2],b)}a=Di(a,d,c,e+16|0);Za=e+32|0;return a|0}function ox(a,b){var c=0,d=0;a:{if(b){ox(a,j[b>>2]);ox(a,j[b+4>>2]);a=Rb(a);j[114626]=0;c=H(1379,b+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;F(1380,a|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}Es(a,b,1)}return}a=J(0)|0;C()|0;ib(a);z()}function gza(a,b){var c=0,d=0,e=0;e=Za-16|0;Za=e;c=e;j[c>>2]=a;d=j[a+4>>2];j[c+4>>2]=d;j[c+8>>2]=d+56;d=hb(a);a=j[c+4>>2];j[114626]=0;I(973,d|0,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+56;ub(c);Za=e+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function P2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!k[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=gg(h[b|0]),e=j[j[a>>2]+52>>2],bb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=Ai(b,1,c,j[a+32>>2])}return c|0}function Or(a,b){var c=0,d=0;a:{if(b){Or(a,j[b>>2]);Or(a,j[b+4>>2]);a=Rb(a);j[114626]=0;c=H(1374,b+14|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;F(1375,a|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}$o(a,b,1)}return}a=J(0)|0;C()|0;ib(a);z()}function SIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-16|0;Za=d;h[d+15|0]=1;h[d+14|0]=a>>>2;a=k[Wg(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){h[d+13|0]=1;h[d+12|0]=((a+b|0)-2|0)/(b-1|0);a=k[Wg(d+13|0,d+12|0)|0]}Za=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function Gqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=lb(k[b|0])^128,h[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e|0}function p9(a,b){a=a|0;b=b|0;var c=q(0),d=q(0);a:{if((b|0)<0){break a}a=a+24|0;if(l[j[a>>2]+480188>>1]<=(b|0)){break a}b=p(b,896);c=q(q(k[(b+j[a>>2]|0)+1075847|0])*q(.0078125));d=q(c*c);c=q(q(k[(b+j[a>>2]|0)+1075846|0])*q(.0078125));c=q(y(q(d+q(c*c))))}return q(c)}function Xy(a,b){var c=0,d=0;a:{if(b){Xy(a,j[b>>2]);Xy(a,j[b+4>>2]);a=Rb(a);j[114626]=0;c=H(732,b+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;F(733,a|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}Zg(a,b,1)}return}a=J(0)|0;C()|0;ib(a);z()}function Vy(a,b){var c=0,d=0;a:{if(b){Vy(a,j[b>>2]);Vy(a,j[b+4>>2]);a=Rb(a);j[114626]=0;c=H(728,b+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;F(731,a|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}Zg(a,b,1)}return}a=J(0)|0;C()|0;ib(a);z()}function Hy(a,b){var c=0,d=0;a:{if(b){Hy(a,j[b>>2]);Hy(a,j[b+4>>2]);a=Rb(a);j[114626]=0;c=H(822,b+14|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;F(823,a|0,c|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}$o(a,b,1)}return}a=J(0)|0;C()|0;ib(a);z()}function vi(a,b){var c=0,d=0,e=0,f=0;if(b){c=j[a>>2];while(1){a:{if(c){d=j[a+4>>2];break a}j[a>>2]=8;c=j[a+12>>2];if((c|0)!=j[a+8>>2]){c=c-1|0;j[a+12>>2]=c}d=k[c|0];c=8}c=c-1|0;j[a>>2]=c;j[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function vQ(a){var b=0;a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=778924148?(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=1297108297:0){break a}b=a+34|0;if((k[b|0]|k[b+1|0]<<8)>>>0>255){break a}a=a+36|0;return(k[a|0]|k[a+1|0]<<8)>>>0<4e3}return 0}function qEa(a,b,c){var d=0;d=Za-32|0;Za=d;j[d+16>>2]=b;j[d+24>>2]=a;j[d+8>>2]=c;a:{if(!rb(d+24|0,d+16|0)){break a}while(1){a=j[d+24>>2];if(j[j[d+8>>2]>>2]==(k[a|0]|k[a+1|0]<<8)){break a}fk(d+24|0);if(rb(d+24|0,d+16|0)){continue}break}}Za=d+32|0;return j[d+24>>2]}function goa(a,b){var c=0,d=0,e=0;a:{if(k[a+4|0]){c=j[a>>2];j[114626]=0;d=H(1374,b+14|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break a}j[114626]=0;F(1375,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}}if(b){$o(j[a>>2],b,1)}return}a=J(0)|0;C()|0;ib(a);z()}function aoa(a,b){var c=0,d=0,e=0;a:{if(k[a+4|0]){c=j[a>>2];j[114626]=0;d=H(1379,b+16|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break a}j[114626]=0;F(1380,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}}if(b){Es(j[a>>2],b,1)}return}a=J(0)|0;C()|0;ib(a);z()}function JC(a){a=a|0;var b=0,c=0,d=0;j[a>>2]=62536;b=j[a+8>>2];j[114626]=0;c=T(2437)|0;d=j[114626];j[114626]=0;a:{if((d|0)!=1){if((b|0)==(c|0)){break a}b=j[a+8>>2];j[114626]=0;bv(b);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=J(0)|0;C()|0;ib(a);z()}return a|0}function UEa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=j[b+12>>2];j[c+8>>2]=j[b+8>>2];j[c+12>>2]=d;d=j[b+4>>2];j[c>>2]=j[b>>2];j[c+4>>2]=d;WJa(a,LP(c));j[a>>2]=76564;d=j[b+4>>2];j[a+296>>2]=j[b>>2];j[a+300>>2]=d;d=j[b+12>>2];j[a+304>>2]=j[b+8>>2];j[a+308>>2]=d;Za=c+16|0}function T4(a,b){var c=q(0),d=0,e=0,f=0,g=q(0);if((a|0)>=2){a=a>>1;d=(a|0)>1?a:1;e=1/+(a|0);a=0;while(1){c=q(Kh((+(a|0)*1.5707963705062866+.7853981852531433)*e));f=(a<<2)+b|0,g=q(Kh(+q(c*c)*1.5707963705062866)),n[f>>2]=g;a=a+1|0;if((d|0)!=(a|0)){continue}break}}}function Roa(a,b){var c=0,d=0,e=0,f=0;c=Za-96|0;Za=c;OK(b,c,c+96|0);b=0;while(1){d=b<<3;e=d+a|0;f=j[c+d>>2];d=j[(d|4)+c>>2];j[e>>2]=f;j[e+4>>2]=d&65535;b=b+1|0;if((b|0)!=12){continue}break}j[a+104>>2]=0;j[a+96>>2]=!(j[a+88>>2]|j[a+92>>2]);j[a+100>>2]=0;Za=c+96|0}function GH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>2097151){oc(32651);z()}f=$b(d<<11,4)}j[a>>2]=f;c=(c<<11)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<11)+f|0,j[g>>2]=h;Za=e+16|0;return a|0}function EH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){oc(32651);z()}f=$b(d<<2,4)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a|0}function Cx(a,b){var c=0,d=0;a:{if(b){Cx(a,j[b>>2]);Cx(a,j[b+4>>2]);a=Rb(a);j[114626]=0;c=H(1251,b+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;F(1252,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Bx(b)}return}a=J(0)|0;C()|0;ib(a);z()}function zCa(a,b){var c=0,d=0,e=0;a:{if(k[a+4|0]){c=j[a>>2];j[114626]=0;d=H(822,b+14|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break a}j[114626]=0;F(823,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}}if(b){$o(j[a>>2],b,1)}return}a=J(0)|0;C()|0;ib(a);z()}function yFa(a,b){var c=0,d=0,e=0;a:{if(k[a+4|0]){c=j[a>>2];j[114626]=0;d=H(728,b+16|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break a}j[114626]=0;F(731,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}}if(b){Zg(j[a>>2],b,1)}return}a=J(0)|0;C()|0;ib(a);z()}function sia(a,b){var c=0,d=0,e=0;a:{if(k[a+4|0]){c=j[a>>2];j[114626]=0;d=H(732,b+16|0)|0;e=j[114626];j[114626]=0;if((e|0)==1){break a}j[114626]=0;F(733,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}}if(b){Zg(j[a>>2],b,1)}return}a=J(0)|0;C()|0;ib(a);z()}function nJa(a){var b=0,c=0,d=0,e=0;if(!k[a+8|0]){if(k[a+24|0]){h[a+24|0]=0;c=a+40|0;while(1){d=oi(c,b),e=0,h[d+8|0]=e;b=b+1|0;if((b|0)!=16){continue}break}b=a+28|0;ek(b,0);lR(b)}b=a+12|0;ek(b,j[a+4>>2]);bb[j[j[a>>2]+44>>2]](a,j[b>>2],0,j[a+4>>2])|0;h[a+8|0]=1}}function ita(a){a=a|0;var b=0,c=0,d=0;c=Za-32|0;Za=c;b=255;a:{if(rh(a)>>>0<=49){b=Rx(c,j[a+12>>2]);j[114626]=0;F(1173,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}dl(b);Oo(a,rh(a)-1&255);b=rh(a)-1|0}Za=c+32|0;return b&255}a=D()|0;C()|0;dl(b);G(a|0);z()}function No(a,b,c,d){var e=0,f=0,g=0,i=0;a:{e=Uj(a,b);if((e|0)==255){break a}if(Ti(a)){break a}b=oi(a+314|0,e);e=zL(e);if(!(f=0,g=!(h[Pb(b,10)|0]&1),i=d,i?f:g)){Og(j[a>>2],e- -64&65535,yL(c,k[Pb(b,2)|0]))}if(d){break a}Og(j[a>>2],e+67&65535,yL(c,k[Pb(b,3)|0]))}}function Hqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d+8>>2]=j[a>>2];e=j[tb(d+12|0,d+8|0)>>2];b=lb(b);if(e){a=j[a+20>>2];c=e;while(1){f=a,g=Fm(k[b|0]),h[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}Za=d+16|0;return e|0}function Fqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-16|0;Za=e;j[e+12>>2]=c;j[e+8>>2]=j[a>>2];f=j[tb(e+12|0,e+8|0)>>2];b=lb(b);if(f){a=j[a+20>>2];c=f;while(1){d=lb(k[b|0])+d|0;h[a|0]=d;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}Za=e+16|0;return f|0}function B2(){var a=0,b=0;a=Za-16|0;Za=a;a:{if(Ja(a+12|0,a+8|0)|0){break a}b=_c((j[a+12>>2]<<2)+4|0);j[115412]=b;if(!b){break a}b=_c(j[a+8>>2]);if(!b){j[115412]=0;break a}j[j[115412]+(j[a+12>>2]<<2)>>2]=0;if(!(Ia(j[115412],b|0)|0)){break a}j[115412]=0}Za=a+16|0}function J5(a){var b=0,c=0,d=q(0);if((a|0)<=128){return n[(a<<2)+48128>>2]}c=(a|0)<1024;a=c?a<<3:a;b=a<<1&64;d=q(q((a&63)-b|0)/q((a&-64)+b|0));return q(q(q(q(q(q(d*q(.2222222238779068))+q(1.3333333730697632))*d)+q(1))*(c?q(16):q(256)))*n[(a+b>>6<<2)+48128>>2])}function Dj(a){var b=0,c=0;a:{b=j[a+1396>>2];if((b|0)>24){break a}if(!b){j[a+1392>>2]=0}while(1){if(k[a+1376|0]?0:j[a+1384>>2]){break a}c=Xq(a);if((c|0)==-1){break a}b=j[a+1396>>2];j[a+1396>>2]=b+8;j[a+1392>>2]=j[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Cw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!df(a)){break a}while(1){if(!th(te(a,e))){break a}d=d+1|0;e=d&65535;if(df(a)>>>0>e>>>0){continue}break}}if(!(l[j[j[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0?c:0)){return(Wf(a,d&65535,b)?d:-1)&65535}return 65535}function rK(a,b,c){a:{switch(b|0){case 0:OJ(a,c);return;case 1:Vna(a,c);return;case 2:Sna(a,c);return;case 3:uo(a,c,1520);return;case 4:uo(a,c,2544);return;case 5:uo(a,c,3568);return;case 6:uo(a,c,4592);return;case 7:uo(a,c,5616);return;default:break a}}Me(a)}function pC(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-16|0;Za=c;j[b>>2]=0;h[c+15|0]=0;f=Cg(a,c+15|0);d=k[c+15|0];j[b>>2]=d>>>2;d=d&3;if(d){while(1){h[c+15|0]=0;g=Cg(a,c+15|0);e=e+1|0;j[b>>2]=j[b>>2]|k[c+15|0]<<(e<<3)-2;f=f&g;if((d|0)!=(e|0)){continue}break}}Za=c+16|0}function QB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-16|0;Za=c;d=R(16)|0;SB();a=Cc(c+8|0,a,85368);j[114626]=0;e=j[a+4>>2];j[c>>2]=j[a>>2];j[c+4>>2]=e;K(2836,d|0,c|0,b|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Y(d|0,70760,2837);z()}a=D()|0;C()|0;S(d|0);G(a|0);z()}function Dq(a,b){var c=0,d=0,e=0;c=-1;a:{if((a|0)==-1){break a}e=j[b+76>>2]>=0;b:{d=j[b+4>>2];c:{if(!d){SD(b);d=j[b+4>>2];if(!d){break c}}if(j[b+44>>2]-8>>>0<d>>>0){break b}}if(!e){break a}return-1}c=d-1|0;j[b+4>>2]=c;h[c|0]=a;j[b>>2]=j[b>>2]&-17;c=a}return c}function qX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Rf(a,j[b+8>>2],0)){Cu(b,c,d);return}e=j[a+12>>2];f=a+16|0;LB(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){LB(a,b,c,d);if(k[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function hMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Wx(a);a:{if(!b){break a}j[114626]=0;F(404,a|0,b|0);e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;I(405,a|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;os(d);G(a|0);z()}return a|0}function aGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-32|0;Za=e;j[e+24>>2]=d;d=kj(a,c);Ve(e,j[a+28>>2]);f=j[e+12>>2];j[e+16>>2]=j[e+8>>2];j[e+20>>2]=f;a:{if(!d){b:{if(!gd(a,5)){break b}break a}}Ysa(j[a+28>>2],b,j[e+24>>2])}Di(a,d,c,e+16|0);Za=e+32|0}function XI(a,b){var c=0,d=0,e=0,f=0;c=Za-32|0;Za=c;if(j[a+4>>2]==j[b+4>>2]){d=j[a+4>>2];e=j[a>>2];j[c+24>>2]=e;j[c+28>>2]=d;f=j[b+4>>2];a=c;b=j[b>>2];j[a+16>>2]=b;j[a+20>>2]=f;j[a+8>>2]=e;j[a+12>>2]=d;j[a>>2]=b;j[a+4>>2]=f;d=!gma(a+8|0,a)}Za=c+32|0;return d}function VU(a,b,c,d){var e=0,f=0,g=0;f=Za-48|0;Za=f;e=f+40|0;e=UU(f+24|0,XA(e,1),Cc(f+16|0,e,1));g=j[e>>2];j[114626]=0;P(285,g|0,b|0,c|0,d|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Cn(a,Ob(j[e>>2]),ud(e));QA(e);Za=f+48|0;return}a=D()|0;C()|0;QA(e);G(a|0);z()}function Usa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-32|0;Za=e;j[e+24>>2]=d;d=kj(a,c);Ve(e,j[a+28>>2]);f=j[e+12>>2];j[e+16>>2]=j[e+8>>2];j[e+20>>2]=f;a:{if(!d){b:{if(!gd(a,5)){break b}break a}}cta(j[a+28>>2],b,j[e+24>>2])}Di(a,d,c,e+16|0);Za=e+32|0}function RAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Wz(a);a:{if(!b){break a}j[114626]=0;F(916,a|0,b|0);e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;I(917,a|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;xt(d);G(a|0);z()}return a|0}function Pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-32|0;Za=e;j[e+24>>2]=d;d=kj(a,c);Ve(e,j[a+28>>2]);f=j[e+12>>2];j[e+16>>2]=j[e+8>>2];j[e+20>>2]=f;a:{if(!d){b:{if(!gd(a,5)){break b}break a}}Eia(j[a+28>>2],b,j[e+24>>2])}Di(a,d,c,e+16|0);Za=e+32|0}function qQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cz(a);a:{if(!b){break a}j[114626]=0;F(680,a|0,b|0);e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;I(681,a|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;Vs(d);G(a|0);z()}return a|0}function n0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Za-16|0;Za=g;j[g+8>>2]=b;hc(g,d);j[114626]=0;b=H(2441,g|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){wb(g);bD(a,f+24|0,g+8|0,c,e,b);Za=g+16|0;return j[g+8>>2]}a=D()|0;C()|0;wb(g);G(a|0);z()}function m0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Za-16|0;Za=g;j[g+8>>2]=b;hc(g,d);j[114626]=0;b=H(2441,g|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){wb(g);aD(a,f+16|0,g+8|0,c,e,b);Za=g+16|0;return j[g+8>>2]}a=D()|0;C()|0;wb(g);G(a|0);z()}function lt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Vt(a);a:{if(!b){break a}j[114626]=0;F(563,a|0,b|0);e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;I(564,a|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;Mp(d);G(a|0);z()}return a|0}function _R(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=WT(a);a:{if(!b){break a}j[114626]=0;F(467,a|0,b|0);e=j[114626];j[114626]=0;if((e|0)!=1){j[114626]=0;I(468,a|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;BA(d);G(a|0);z()}return a|0}function WX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=Za-16|0;Za=f;d=lq(a);e=nb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=zb(a);Jh(d+(e<<2)|0,b,c);b=c+e|0;Ag(a,b);j[f+12>>2]=0;ze(d+(b<<2)|0,f+12|0);break a}XB(a,d,(c+e|0)-d|0,e,e,0,c,b)}Za=f+16|0;return a|0}function Qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-32|0;Za=e;j[e+24>>2]=d;d=kj(a,c);Ve(e,j[a+28>>2]);f=j[e+12>>2];j[e+16>>2]=j[e+8>>2];j[e+20>>2]=f;a:{if(!d){b:{if(!gd(a,5)){break b}break a}}XH(j[a+28>>2],b,j[e+24>>2])}Di(a,d,c,e+16|0);Za=e+32|0}function wta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-32|0;Za=d;j[d+16>>2]=c;j[d+24>>2]=b;b=j[a>>2];e=d,f=Lb(a),j[e+8>>2]=f;b=b+(vp(d+24|0,d+8|0)<<1)|0;if(rb(d+24|0,d+16|0)){Bp(a,Pe(b+(vp(d+16|0,d+24|0)<<1)|0,j[a+4>>2],b))}a=Qe(b);Za=d+32|0;return a|0}function mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-32|0;Za=d;j[d+16>>2]=c;j[d+24>>2]=b;b=j[a>>2];e=d,f=Lb(a),j[e+8>>2]=f;b=b+p(Dr(d+24|0,d+8|0),6)|0;if(rb(d+24|0,d+16|0)){az(a,Gw(b+p(Dr(d+16|0,d+24|0),6)|0,j[a+4>>2],b))}a=Qe(b);Za=d+32|0;return a|0}function j8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;e=Mq(a);j[a>>2]=76896;f=ew(a+32|0,d+8|0);j[a+48>>2]=c;j[a+44>>2]=0;j[114626]=0;F(182,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a|0}a=D()|0;C()|0;gb(f);Jk(e);G(a|0);z()}function ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jH(a,b,c,d);j[a+4232>>2]=1056964608;b=a+4224|0;j[b>>2]=1056964608;j[b+4>>2]=1048406533;b=a+4216|0;j[b>>2]=1020054733;j[b+4>>2]=1065353216;j[a+4208>>2]=1056964608;j[a+4212>>2]=1065353216;j[a>>2]=81196;return a|0}function i2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=j[b>>2];g=j[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function bna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-16|0;Za=d;e=Za-16|0;Za=e;lJ(d,b,c<<24>>24);Za=e+16|0;b=d;c=zb(d);e=nb(d);j[114626]=0;K(196,a|0,c|0,e|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){gb(b);Za=d+16|0;return a|0}a=D()|0;C()|0;gb(b);G(a|0);z()}function ar(a){var b=0,c=0,d=0,e=0;b=Za-16|0;Za=b;j[b+12>>2]=12;j[b+8>>2]=32;if(j[tb(b+12|0,b+8|0)>>2]){while(1){e=Ao(a);j[b+8>>2]=32;c=c<<15^e;d=d+15|0;if(d>>>0<m[tb(b+12|0,b+8|0)>>2]){continue}break}}Za=b+16|0;a=j[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function X9(a,b){var c=0,d=0,e=0;c=Za-80|0;Za=c;j[c+40>>2]=j[b+32>>2];j[c>>2]=j[b+36>>2];e=j[zf(c+40|0,c)>>2];a:{if(j[b+32>>2]==j[Uo(c+40|0)+32>>2]){d=-1;if(j[b+36>>2]==j[Uo(c)+36>>2]){break a}}d=0;if((e|0)<1){break a}d=(e+500|0)/1e3|0}j[a>>2]=d;Za=c+80|0}function H0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Za-16|0;Za=g;j[g+8>>2]=b;hc(g,d);j[114626]=0;b=H(21,g|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){wb(g);eD(a,f+24|0,g+8|0,c,e,b);Za=g+16|0;return j[g+8>>2]}a=D()|0;C()|0;wb(g);G(a|0);z()}function F0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Za-16|0;Za=g;j[g+8>>2]=b;hc(g,d);j[114626]=0;b=H(21,g|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){wb(g);dD(a,f+16|0,g+8|0,c,e,b);Za=g+16|0;return j[g+8>>2]}a=D()|0;C()|0;wb(g);G(a|0);z()}function Cr(a,b,c){var d=0,e=0,f=0;d=Za-32|0;Za=d;a:{if(!(!b|!c)){e=Eb(d,b);j[114626]=0;I(1560,d+16|0,e|0,c|0);f=j[114626];j[114626]=0;if((f|0)==1){break a}ob(a+36|0,d+16|0);gb(d+16|0);gb(e)}Za=d+32|0;return(b|0)!=0&(c|0)!=0}a=D()|0;C()|0;gb(e);G(a|0);z()}function sK(a,b,c){var d=0,e=0;d=(c|0)==1;c=j[(p(b,896)+a|0)+1075072>>2];a:{if(d&(c&134218752)!=0|c&67108864){break a}if(l[a+480188>>1]<=b>>>0){c=l[(p(b,896)+a|0)+1075792>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=k[((b<<5)+a|0)+480288|0]}return e}function fS(a){var b=0,c=0,d=0,e=0;b=a+5|0;b=k[b|0]|k[b+1|0]<<8;c=b+k[a+2|0]|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;e=c;a=a+3|0;a=k[a|0]|k[a+1|0]<<8;d=a>>>30|0;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;if(b>>>0<47){a=a+1|0}ab=a;return b}function Cla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Za-16|0;Za=b;d=Xc(a);e=b,f=Lb(a),j[e+8>>2]=f;e=b,f=Mb(a),j[e>>2]=f;if(rb(b+8|0,b)){c=+(d>>>0);while(1){a=j[b+8>>2];o[a>>3]=o[a>>3]/c;o[a+8>>3]=o[a+8>>3]/c;yf(b+8|0);if(rb(b+8|0,b)){continue}break}}Za=b+16|0}function l2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=h[b|0];g=h[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function Qz(a,b,c){var d=0,e=0;a=a+3|0;a=(k[a|0]|k[a+1|0]<<8)>>>p(c,3)|0;d=a>>>2&1|k[b+12|0]&-4;e=d|a<<1&2;if(a&2){h[b+12|0]=e|4;return}h[b+12|0]=e&251;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=k[b+13|0]|k[b+14|0]<<8;h[b+15|0]=a;h[b+16|0]=a>>>8;h[b+12|0]=d|4}}function KMa(a,b,c,d){var e=0,f=0,g=0,h=0;e=b;f=e>>31;e=e>>31;a=a^e;g=a-e|0;h=(b^f)-((a>>>0<e>>>0)+f|0)|0;e=d;f=e>>31;e=e>>31;a=c^e;e=RMa(g,h,a-e|0,(d^f)-((a>>>0<e>>>0)+f|0)|0);b=b^d;c=b>>31;a=b>>31;b=e^a;d=b-a|0;ab=(c^ab)-((a>>>0>b>>>0)+c|0)|0;return d}function hka(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-32|0;Za=d;c=Jj(a);if(b){c=p(b,c);a:{b:{if(j[a+12>>2]!=(b|0)){break b}if((Kf(a)|0)!=(c|0)){break b}jka(a);break a}Ug(d+8|0);c=qQ(d+16|0,c,d+8|0);gka(a,c);kl(c);j[a+12>>2]=b}a=1}else{a=0}Za=d+32|0;return a|0}function gr(a){var b=0,c=0;c=a+24|0;b=j[c>>2];j[114626]=0;H(1396,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Uc(a+68|0);Ye(a+36|0);bf(a+32|0);kh(c);Hc(a+4|0);Hc(a);return a}b=J(0)|0;C()|0;Uc(a+68|0);Ye(a+36|0);bf(a+32|0);kh(c);Hc(a+4|0);Hc(a);ib(b);z()}function Ui(a){a=a|0;var b=0,c=0;b=Za-48|0;Za=b;if(!ad(a)){_L(b+32|0,a);ZL(b+24|0,a);c=j[b+36>>2];j[b+16>>2]=j[b+32>>2];j[b+20>>2]=c;c=j[b+28>>2];j[b+8>>2]=j[b+24>>2];j[b+12>>2]=c;tta(b+40|0,b+16|0,b+8|0);c=Bz(Lb(a),j[b+44>>2])}Za=b+48|0;return c&65535}function EDa(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+16|0]=0;h[a+17|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;h[a+15|0]=0;Za=b+16|0}function rna(a){var b=0,c=0;c=a+946300|0;b=a+906300|0;while(1){a=j[b>>2];a:{if(!a){break a}if(!(bb[j[j[a>>2]+112>>2]](a)|0)){break a}bb[j[j[a>>2]+104>>2]](a,0);bb[j[j[a>>2]+92>>2]](a);bb[j[j[a>>2]+120>>2]](a)}b=b+160|0;if((c|0)!=(b|0)){continue}break}}function Z6(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=q(0);if(e){while(1){f=0;if(d){while(1){h=j[uf(b,f,g)>>2];Be(c,f);i=uf(a,f,g),k=q(q(h|0)*q(7.450580596923828e-9)),n[i>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function SD(a){var b=0,c=0;b=k[a+74|0];h[a+74|0]=b-1|b;if(m[a+20>>2]>m[a+28>>2]){bb[j[a+36>>2]](a,0,0)|0}j[a+28>>2]=0;j[a+16>>2]=0;j[a+20>>2]=0;b=j[a>>2];if(b&4){j[a>>2]=b|32;return-1}c=j[a+44>>2]+j[a+48>>2]|0;j[a+8>>2]=c;j[a+4>>2]=c;return b<<27>>31}function B7(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=q(0);if(e){while(1){f=0;if(d){while(1){h=j[uf(b,f,g)>>2];Pb(c,f);i=Qm(a,f,g),k=q(q(h|0)*q(7.450580596923828e-9)),n[i>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function A7(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=q(0);if(e){while(1){f=0;if(d){while(1){h=j[uf(b,f,g)>>2];Be(c,f);i=Qm(a,f,g),k=q(q(h|0)*q(7.450580596923828e-9)),n[i>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function $6(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=q(0);if(e){while(1){f=0;if(d){while(1){h=j[uf(b,f,g)>>2];Pb(c,f);i=uf(a,f,g),k=q(q(h|0)*q(7.450580596923828e-9)),n[i>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function Yw(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;f=j[b+656>>2];d=0;a:{if(!f){break a}f=Gt(f,c);d=a+1074308|0;mb(e+8|0,d,31);a=0;if(!kb(e+8|0)){mb(e,d,93);a=kb(e)^1}if(!(h[aJ(b,c)|0]&1)){d=0;if(!(h[f+12|0]&1)|a){break a}}d=ad(f)^1}Za=e+16|0;return d}function Lqa(a,b){var c=0,d=0;a:{if(k[a+4|0]){a=j[a>>2];j[114626]=0;c=H(1251,b+16|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}j[114626]=0;F(1252,a|0,c|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}}if(b){Bx(b)}return}a=J(0)|0;C()|0;ib(a);z()}function BEa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-48|0;Za=c;a:{if(!yb(a,1)){break a}oEa(b);d=dd(a);if(!d){break a}while(1){d=d-1|0;b:{if(!iEa(a,c+8|0)){break b}e=k[c+8|0];if(e>>>0>63){break b}Vb(DP(b,e),c+8|0,33)}if(d&255){continue}break}}Za=c+48|0}function a6(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=j[b+4>>2];h=j[b+8>>2];e=j[a+6144>>2];f=e-d|0;e=(d|0)<(e|0)?d:e;f=Vb(c+12|0,(((f|0)>0?f:0)+a|0)+6156|0,e);i=j[b>>2]+(j[b+4>>2]/8|0)|0;b=(h-g|0)/8|0;Vb(e+f|0,i,b);aF(c,f,b+e|0);return j[a+6144>>2]>=(d|0)}function _Ja(a,b,c){var d=0;d=Za-32|0;Za=d;j[d+16>>2]=b;j[d+24>>2]=a;j[d+8>>2]=c;a:{if(!rb(d+24|0,d+16|0)){break a}while(1){if((nk(j[d+24>>2])|0)==j[j[d+8>>2]>>2]){break a}fk(d+24|0);if(rb(d+24|0,d+16|0)){continue}break}}Za=d+32|0;return j[d+24>>2]}function oCa(a,b){a=a|0;b=b|0;var c=0,d=0;c=$Ba(a);a:{if(!b){break a}j[114626]=0;F(870,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(871,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;KO(c);G(a|0);z()}return a|0}function o$(a,b){a=a|0;b=b|0;var c=0,d=0;c=C_(a);a:{if(!b){break a}j[114626]=0;F(2546,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(2547,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;FC(c);G(a|0);z()}return a|0}function lCa(a,b){a=a|0;b=b|0;var c=0,d=0;c=YBa(a);a:{if(!b){break a}j[114626]=0;F(872,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(873,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;JO(c);G(a|0);z()}return a|0}function l0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=Za-16|0;Za=a;j[a+8>>2]=b;hc(a,d);j[114626]=0;b=H(2441,a|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){wb(a);$C(f+20|0,a+8|0,c,e,b);Za=a+16|0;return j[a+8>>2]}b=D()|0;C()|0;wb(a);G(b|0);z()}function bGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-32|0;Za=e;j[e+24>>2]=d;d=kj(a,c);Ve(e,j[a+28>>2]);f=j[e+12>>2];j[e+16>>2]=j[e+8>>2];j[e+20>>2]=f;a:{if(!d){if(gd(a,5)){break a}}hQ(j[a+28>>2],b,j[e+24>>2],0)}Di(a,d,c,e+16|0);Za=e+32|0}function Vwa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Wx(a);a:{if(!b){break a}j[114626]=0;F(404,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(1049,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;os(c);G(a|0);z()}return a|0}function vj(a,b,c,d){var e=0;if(d&2048){h[a|0]=43;a=a+1|0}if(d&512){h[a|0]=35;a=a+1|0}while(1){e=k[b|0];if(e){h[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;a:{if((e|0)==64){break a}b=d&16384?88:120;if((e|0)==8){break a}b=c?100:117}h[a|0]=b}function faa(a,b){var c=0,d=0,e=0;c=Za-48|0;Za=c;d=x8(c+24|0,$b(324,4),Cc(c+16|0,c+40|0,1));e=j[d>>2];j[114626]=0;E(2155,e|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Cn(a,Ob(j[d>>2]),ud(d));RF(d);Za=c+48|0;return}a=D()|0;C()|0;RF(d);G(a|0);z()}function dMa(a,b){a=a|0;b=b|0;var c=0,d=0;c=HS(a);a:{if(!b){break a}j[114626]=0;F(406,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(407,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;FS(c);G(a|0);z()}return a|0}function cGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-32|0;Za=e;j[e+24>>2]=d;d=kj(a,c);Ve(e,j[a+28>>2]);f=j[e+12>>2];j[e+16>>2]=j[e+8>>2];j[e+20>>2]=f;a:{if(!d){if(gd(a,5)){break a}}TEa(j[a+28>>2],b,j[e+24>>2])}Di(a,d,c,e+16|0);Za=e+32|0}function Gn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=Za-16|0;Za=f;d=sc(a);e=nb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=zb(a);lh(d+e|0,b,c);b=c+e|0;Ag(a,b);h[f+15|0]=0;Td(b+d|0,f+15|0);break a}uu(a,d,(c+e|0)-d|0,e,e,0,c,b)}Za=f+16|0;return a|0}function zna(a,b,c,d){var e=0;e=Za-16|0;Za=e;a:{b:{if((b|0)==(c|0)){b=a;a=zb(d);Zh(b,a,nb(d)+a|0);break b}rK(e,c,d);j[114626]=0;I(115,a|0,b|0,e|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}pc(e)}Za=e+16|0;return}a=D()|0;C()|0;pc(e);G(a|0);z()}function hz(a,b){a=a|0;b=b|0;var c=0,d=0;c=Vt(a);a:{if(!b){break a}j[114626]=0;F(563,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(670,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;Mp(c);G(a|0);z()}return a|0}function eaa(a,b){var c=0,d=0,e=0;c=Za-48|0;Za=c;d=v8(c+24|0,$b(56,4),Cc(c+16|0,c+40|0,1));e=j[d>>2];j[114626]=0;E(2156,e|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Cn(a,Ob(j[d>>2]),ud(d));OF(d);Za=c+48|0;return}a=D()|0;C()|0;OF(d);G(a|0);z()}function Mla(a,b,c){var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;b=Rb(b);a=Kla(a,$b(28,4),$j(d+8|0,b));e=j[a>>2];j[114626]=0;I(1519,b|0,e+16|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){f=Rb(a),g=1,h[f+4|0]=g;Za=d+16|0;return}b=D()|0;C()|0;OI(a);G(b|0);z()}function Kta(a,b,c){var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;b=Rb(b);a=Jta(a,$b(16,4),$j(d+8|0,b));e=j[a>>2];j[114626]=0;I(1162,b|0,e+14|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){f=Rb(a),g=1,h[f+4|0]=g;Za=d+16|0;return}b=D()|0;C()|0;hM(a);G(b|0);z()}function Isa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;i[d+10>>1]=0;j[d+4>>2]=2;xk(a,d+10|0,j[tb(d+12|0,d+4|0)>>2]);a=ab;if((a|0)>0?1:(a|0)>=0){j[d+4>>2]=2;j[tb(d+12|0,d+4|0)>>2]}i[d+4>>1]=l[d+10>>1];a=d+4|0;i[b>>1]=k[a|0]|k[a+1|0]<<8;Za=d+16|0}function E0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=Za-16|0;Za=a;j[a+8>>2]=b;hc(a,d);j[114626]=0;b=H(21,a|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){wb(a);cD(f+20|0,a+8|0,c,e,b);Za=a+16|0;return j[a+8>>2]}b=D()|0;C()|0;wb(a);G(b|0);z()}function _0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;j[e+12>>2]=b;j[e+8>>2]=d;b=ch(e,e+12|0);j[114626]=0;a=K(2462,a|0,c|0,j[e+8>>2])|0;c=j[114626];j[114626]=0;if((c|0)!=1){pe(b);Za=e+16|0;return a|0}a=D()|0;C()|0;pe(b);G(a|0);z()}function Yn(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+ -.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+ -2.7557314351390663e-7))-a*b))}function LJa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gA(a);a:{if(!b){break a}j[114626]=0;F(36,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(37,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;XS(c);G(a|0);z()}return a|0}function pIa(a,b){a=a|0;b=b|0;var c=0;b=Za-32|0;Za=b;c=-1;a:{if(!tz(a,b+16|0)){break a}c=0;if(!VQ(b+16|0)){break a}if(j[b+16>>2]==1179472708){c=-1;if(!Fc(a,4)){break a}}c=-1;if(!hj(a,b+8|0)){break a}c=j[b+8>>2]==1196314451}Za=b+32|0;return c|0}function nD(a,b,c,d,e){var f=0;f=Za-144|0;Za=f;j[f+44>>2]=a;j[f+4>>2]=a;j[f>>2]=0;j[f+76>>2]=-1;j[f+8>>2]=(a|0)<0?-1:a+2147483647|0;Hg(f,0,0);c=BD(f,c,1,d,e);d=ab;if(b){j[b>>2]=((j[f+4>>2]+j[f+120>>2]|0)-j[f+8>>2]|0)+a}Za=f+144|0;ab=d;return c}function Wd(){var a=0,b=0;a:{b:{if(h[461832]&1){break b}if(!fd(461832)){break b}j[114626]=0;a=K(2439,2147483647,62453,0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}j[115457]=a;ed(461832)}return j[115457]}a=D()|0;C()|0;Zd(461832);G(a|0);z()}function Tja(a,b,c){var d=0,e=0;if(b){while(1){d=c;e=k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24);h[a|0]=e;h[a+1|0]=e>>>8;h[a+2|0]=e>>>16;h[a+3|0]=e>>>24;d=k[d+4|0]|k[d+5|0]<<8;h[a+4|0]=d;h[a+5|0]=d>>>8;a=a+6|0;b=b-1|0;if(b){continue}break}}}function JEa(a){a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=(nk(14647)|0)){break a}a=a+4|0;if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))>>>0>259){break a}return(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))>>>0>255}return 0}function FV(a,b){var c=0,d=0,e=0;c=Za-48|0;Za=c;d=EV(c+24|0,$b(24,4),Cc(c+16|0,c+40|0,1));e=j[d>>2];j[114626]=0;E(273,e|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Cn(a,Ob(j[d>>2]),ud(d));jB(d);Za=c+48|0;return}a=D()|0;C()|0;jB(d);G(a|0);z()}function AL(a){a=a|0;var b=0,c=0,d=0;b=Za-16|0;Za=b;if(k[a+530|0]){while(1){d=c&65535;bi(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}h[a+530|0]=0}h[b+15|0]=0;cj(a+4|0,18,b+15|0);Ky(a+22|0,18,20106);h[b+14|0]=255;cj(a+58|0,256,b+14|0);Za=b+16|0}function vIa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>178956970){oc(12706);z()}f=$b(p(d,24),4)}j[a>>2]=f;c=p(c,24)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,24)+f|0,j[g>>2]=h;Za=e+16|0;return a}function qpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;j[a>>2]=b;c=a+4|0;Doa(c,DK(ue(229984),b+1074376|0));b=apa(a+8|0);d=a+20|0;Aoa(d);j[114626]=0;N(1335,a|0);e=j[114626];j[114626]=0;if((e|0)!=1){return a|0}a=D()|0;C()|0;BK(d);ZJ(b);bf(c);G(a|0);z()}function gra(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>357913941){oc(20181);z()}f=$b(p(d,12),4)}j[a>>2]=f;c=p(c,12)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,12)+f|0,j[g>>2]=h;Za=e+16|0;return a}function gq(a,b){var c=0,d=0;if(!a){return _c(b)}if(b>>>0>=4294967232){j[114600]=48;return 0}c=gX(a-8|0,b>>>0<11?16:b+11&-8);if(c){return c+8|0}c=_c(b);if(!c){return 0}d=j[a-4>>2];d=(d&3?-4:-8)+(d&-8)|0;Vb(c,a,b>>>0>d>>>0?d:b);Cb(a);return c}function fEa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>130150524){oc(14703);z()}f=$b(p(d,33),1)}j[a>>2]=f;c=p(c,33)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,33)+f|0,j[g>>2]=h;Za=e+16|0;return a}function Rya(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>178956970){oc(16924);z()}f=$b(p(d,24),4)}j[a>>2]=f;c=p(c,24)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,24)+f|0,j[g>>2]=h;Za=e+16|0;return a}function MHa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>178956970){oc(12852);z()}f=$b(p(d,24),4)}j[a>>2]=f;c=p(c,24)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,24)+f|0,j[g>>2]=h;Za=e+16|0;return a}function MDa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>178956970){oc(14703);z()}f=$b(p(d,24),4)}j[a>>2]=f;c=p(c,24)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,24)+f|0,j[g>>2]=h;Za=e+16|0;return a}function IJa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>178956970){oc(12489);z()}f=$b(p(d,24),4)}j[a>>2]=f;c=p(c,24)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,24)+f|0,j[g>>2]=h;Za=e+16|0;return a}function Bka(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>178956970){oc(31753);z()}f=$b(p(d,24),4)}j[a>>2]=f;c=p(c,24)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,24)+f|0,j[g>>2]=h;Za=e+16|0;return a}function hd(a,b){var c=0,d=0,e=0,f=0,g=0;a:{c=l[a+20>>1];if(c){d=l[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=l[e+28>>1]+b|0;i[e+28>>1]=f;if((f&65535)>>>0>=2048){break a}c=c+1|0;if((g|0)!=(c|0)){continue}break}}return}i[a+20>>1]=c-d}function ey(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>357913941){oc(17388);z()}f=$b(p(d,12),4)}j[a>>2]=f;c=p(c,12)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,12)+f|0,j[g>>2]=h;Za=e+16|0;return a}function b8(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>178956970){oc(39501);z()}f=$b(p(d,24),8)}j[a>>2]=f;c=p(c,24)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,24)+f|0,j[g>>2]=h;Za=e+16|0;return a}function Kya(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>76695844){oc(16924);z()}f=$b(p(d,56),4)}j[a>>2]=f;c=p(c,56)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,56)+f|0,j[g>>2]=h;Za=e+16|0;return a}function KK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;a:{if(!c){break a}j[b+40>>2]=c;if(j[a+480180>>2]!=256){break a}j[d+12>>2]=c>>>4;j[d+8>>2]=1;e=b,f=j[Gc(d+12|0,d+8|0)>>2],j[e+40>>2]=f;e=b,f=zK(c&255),j[e+44>>2]=f}Za=d+16|0}function GKa(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+16|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;h[a+15|0]=0;Za=b+16|0}function Bna(a,b,c){var d=0;d=Za-32|0;Za=d;j[d+16>>2]=b;j[d+24>>2]=a;j[d+8>>2]=c;a:{if(!rb(d+24|0,d+16|0)){break a}while(1){if(vna(d+8|0,j[j[d+24>>2]>>2])){break a}Id(d+24|0);if(rb(d+24|0,d+16|0)){continue}break}}Za=d+32|0;return j[d+24>>2]}function cE(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>357913941){oc(6863);z()}f=$b(p(d,12),4)}j[a>>2]=f;c=p(c,12)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,12)+f|0,j[g>>2]=h;Za=e+16|0;return a}function ZQ(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>89478485){oc(12706);z()}f=$b(p(d,48),4)}j[a>>2]=f;c=p(c,48)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,48)+f|0,j[g>>2]=h;Za=e+16|0;return a}function XE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-16|0;Za=e;if(d>>>0<=4294967279){a:{if(d>>>0<=10){Ue(a,c);d=a;break a}f=Dk(d)+1|0;d=Sh(f);lf(a,d);jg(a,f);ee(a,c)}lh(d,b,c);h[e+15|0]=0;Td(c+d|0,e+15|0);Za=e+16|0;return}kg();z()}function yLa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>2147483647){oc(12065);z()}f=$b(d<<1,1)}j[a>>2]=f;c=(c<<1)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<1)+f|0,j[g>>2]=h;Za=e+16|0;return a}function kV(a){var b=0,c=0,d=0;b=Za-48|0;Za=b;c=jV(b+24|0,$b(16,4),Cc(b+16|0,b+40|0,1));d=j[c>>2];j[114626]=0;H(279,d|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){Cn(a,Ob(j[c>>2]),ud(c));_A(c);Za=b+48|0;return}a=D()|0;C()|0;_A(c);G(a|0);z()}function jFa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){oc(14480);z()}f=$b(d<<2,1)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function _B(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(a-b>>2>>>0<c>>>0){while(1){c=c-1|0;d=c<<2;j[d+a>>2]=j[b+d>>2];if(c){continue}break a}}if(!c){break a}d=a;while(1){j[d>>2]=j[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function Xha(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){oc(32555);z()}f=$b(d<<2,4)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function RCa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){oc(15088);z()}f=$b(d<<2,1)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function Qla(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){oc(30794);z()}f=$b(d<<2,4)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function ICa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>2147483647){oc(15088);z()}f=$b(d<<1,1)}j[a>>2]=f;c=(c<<1)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<1)+f|0,j[g>>2]=h;Za=e+16|0;return a}function Dma(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){oc(20588);z()}f=$b(d<<2,4)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function Awa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){oc(17993);z()}f=$b(d<<2,1)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function zR(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>2147483647){oc(12489);z()}f=$b(d<<1,1)}j[a>>2]=f;c=(c<<1)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<1)+f|0,j[g>>2]=h;Za=e+16|0;return a}function vla(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-32|0;Za=c;a:{if(Hf(a)>>>0<b>>>0){d=hb(a);b=TK(c+8|0,b,cc(a),d);j[114626]=0;F(1250,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}$r(b)}Za=c+32|0;return}a=D()|0;C()|0;$r(b);G(a|0);z()}function lga(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-32|0;Za=c;a:{if(jd(a)>>>0<b>>>0){d=hb(a);b=kH(c+8|0,b,sb(a),d);j[114626]=0;F(1752,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}sr(b)}Za=c+32|0;return}a=D()|0;C()|0;sr(b);G(a|0);z()}function lba(a){var b=0,c=0;b=Za-48|0;Za=b;vk(b+16|0);a:{if(j[b+28>>2]){c=j[b+28>>2];j[114626]=0;j[b+12>>2]=c;F(2110,a|0,b+12|0);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;Je(b+16|0);G(a|0);z()}Db(a)}Je(b+16|0);Za=b+48|0}function lAa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>536870911){oc(16520);z()}f=$b(d<<3,1)}j[a>>2]=f;c=(c<<3)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<3)+f|0,j[g>>2]=h;Za=e+16|0;return a}function kH(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){oc(33245);z()}f=$b(d<<2,4)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function Uxa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-32|0;Za=c;a:{if(Hf(a)>>>0<b>>>0){d=hb(a);b=ey(c+8|0,b,cc(a),d);j[114626]=0;F(1011,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}ss(b)}Za=c+32|0;return}a=D()|0;C()|0;ss(b);G(a|0);z()}function Lo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=1/(o[j[a+4>>2]-8>>3]-o[j[a>>2]>>3]);while(1){d=-zd(o[uk(a,c)>>3]*131072*f);a:{if(r(d)<2147483648){e=~~d;break a}e=-2147483648}g=Be(b,c),h=e,j[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function KT(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>2147483647){oc(11736);z()}f=$b(d<<1,2)}j[a>>2]=f;c=(c<<1)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<1)+f|0,j[g>>2]=h;Za=e+16|0;return a}function IA(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){oc(11561);z()}f=$b(d<<2,4)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function nDa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-32|0;Za=c;a:{if(Pf(a)>>>0<b>>>0){d=hb(a);b=Ct(c+8|0,b,bc(a),d);j[114626]=0;F(380,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}lk(b)}Za=c+32|0;return}a=D()|0;C()|0;lk(b);G(a|0);z()}function EY(a){var b=0,c=0,d=0;b=j[a>>2];j[114626]=0;c=T(2437)|0;d=j[114626];j[114626]=0;a:{if((d|0)==1){break a}if((b|0)!=(c|0)){a=j[a>>2];j[114626]=0;bv(a);a=j[114626];j[114626]=0;if((a|0)==1){break a}}return}a=J(0)|0;C()|0;ib(a);z()}function wU(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-32|0;Za=c;a:{if(jd(a)>>>0<b>>>0){d=hb(a);b=IA(c+8|0,b,sb(a),d);j[114626]=0;F(343,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Rp(b)}Za=c+32|0;return}a=D()|0;C()|0;Rp(b);G(a|0);z()}function pL(a,b){var c=0,d=0;c=Era(a);a:{if(!b){break a}j[114626]=0;F(1218,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(1219,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;jL(c);G(a|0);z()}return a}function jua(a,b,c,d){var e=0,f=0,g=0,h=0;a:{if((d|0)==65536){break a}c=p(b,c);if(!c){break a}b=d;f=d>>31;d=0;while(1){e=j[a>>2];g=a,h=ic(PMa(OMa(e,e>>31,b,f),ab,65536,0),ab),j[g>>2]=h;a=a+4|0;d=d+1|0;if((c|0)!=(d|0)){continue}break}}}function _T(a,b){var c=0,d=0,e=0;j[a>>2]=0;j[a+4>>2]=0;j[a+8>>2]=0;j[a+12>>2]=0;if(j[b+16>>2]){EA(a,b);c=j[b+12>>2];d=c>>31;e=d+j[b+8>>2]|0;b=c>>31;c=b+c|0;c=e>>>0<d>>>0?c+1|0:c;b=b^c;j[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}return a}function Xfa(a){a=a|0;var b=0;bb[j[j[a>>2]+124>>2]](a);nw(a);j[a+4236>>2]=0;h[a+4202|0]=1;b=bb[j[j[a>>2]+188>>2]](a)|0;j[a+4272>>2]=0;n[a+4240>>2]=b?q(.5):q(1);b=j[a+4256>>2];j[a+4292>>2]=b;j[a+4288>>2]=b;j[a+4284>>2]=b;j[a+4280>>2]=b}function XEa(a,b){var c=0,d=0,e=0;c=ri(a+8|0);j[114626]=0;d=H(540,b|0)|0;e=j[114626];j[114626]=0;a:{if((e|0)==1){break a}j[114626]=0;I(421,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}return}a=D()|0;C()|0;wg(c);G(a|0);z()}function Nca(a){a=a|0;if(m[a+24>>2]>m[a+44>>2]){j[a+44>>2]=j[a+24>>2]}a:{if(!(k[a+48|0]&8)){break a}if(m[a+16>>2]<m[a+44>>2]){sm(a,j[a+8>>2],j[a+12>>2],j[a+44>>2])}if(m[a+12>>2]>=m[a+16>>2]){break a}return gg(h[j[a+12>>2]])|0}return-1}function Jea(a,b,c){a=a|0;b=b|0;c=q(c);var d=0;d=Za-16|0;Za=d;n[d+12>>2]=c;if((b|0)<=12){Kd(d+12|0,q(0));c=n[d+12>>2];if((b|0)==12){c=q(Sd(q(c*q(3)))*q(.3333333432674408));n[d+12>>2]=c}n[((b<<2)+a|0)+4208>>2]=c;h[a+5046|0]=1}Za=d+16|0}function IW(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){d=b;if(b>>>0>268435455){oc(6967);z()}f=$b(d<<4,4)}j[a>>2]=f;c=(c<<4)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<4)+f|0,j[g>>2]=h;Za=e+16|0;return a}function vta(a,b){var c=0,d=0;c=Wz(a);a:{if(!b){break a}j[114626]=0;F(916,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(1168,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;xt(c);G(a|0);z()}return a}function bka(a,b){var c=0,d=0;c=cz(a);a:{if(!b){break a}j[114626]=0;F(680,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(1561,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;Vs(c);G(a|0);z()}return a}function _I(a,b,c){var d=0,e=0,f=0,g=0,h=0;if(b){g=c;h=c>>31;c=0;while(1){d=j[a>>2];e=j[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=ic(PMa(OMa(d,d>>31,g,h),ab,256,0),ab);j[a+4>>2]=f-d;j[a>>2]=d+f;a=a+8|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function W$(a,b,c,d,e,f){var g=0;g=Za-144|0;Za=g;j[g+28>>2]=g+132;_C(a,g+32|0,g+28|0,d,e,f);j[g+16>>2]=0;j[g+20>>2]=0;j[g+12>>2]=g+32;a=V$(b,g+12|0,WO(b,j[c>>2]),g+16|0,j[a>>2]);if((a|0)==-1){Sl(62980);z()}j[c>>2]=(a<<2)+b;Za=g+144|0}function Oza(a,b){var c=0,d=0;c=Kza(a);a:{if(!b){break a}j[114626]=0;F(941,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(942,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;KN(c);G(a|0);z()}return a}function Gta(a){var b=0,c=0,d=0,e=0;b=Za-16|0;Za=b;e=b+8|0;d=j[a+24>>2];c=0;a:{if(!d){break a}c=Mm(Xn(+(d>>>0)*.00011957431543704412)*2215.9795828054475)}pE(e,Gb(c,-16384,16383),128);h[a+36|0]=j[b+8>>2];h[a+37|0]=j[b+12>>2];Za=b+16|0}function oea(a){var b=0;j[a>>2]=8;j[a+4>>2]=0;i[a+4128>>1]=0;b=a+4120|0;j[b>>2]=0;j[b+4>>2]=0;b=a+4112|0;j[b>>2]=0;j[b+4>>2]=0;j[a+4104>>2]=0;j[a+4108>>2]=0;Ab(a+4132|0,0,40);tM(a+8|0,1024);Ab(a+4172|0,0,49824);Ab(a+53996|0,0,32832)}function hJ(a,b){var c=0,d=0;a:{if(!(k[a+89|0]&16)){break a}c=j[a+656>>2];if(!c){break a}c=j[c>>2];if(c){d=a;a=j[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;j[d+696>>2]=a;j[b>>2]=(p(a,j[b>>2])|0)/65536;return}if(j[a+696>>2]){break a}j[b>>2]=0}}function Tf(a,b,c){c=j[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=k[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(k[a+1|0]|32)!=120){break a}a=a+2|0}return a}function RGa(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;a:{if(b){Eb(c,b);break a}Db(c)}j[114626]=0;F(666,c+16|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){Nc(a,c+16|0);gb(c+16|0);gb(c);Za=c+32|0;return a|0}a=D()|0;C()|0;gb(c);G(a|0);z()}function Q4(a,b,c){var d=0,e=0,f=0;if(!c){return 0}d=k[a|0];a:{if(!d){break a}while(1){b:{e=k[b|0];if((e|0)!=(d|0)){break b}c=c-1|0;if(!c|!e){break b}b=b+1|0;d=k[a+1|0];a=a+1|0;if(d){continue}break a}break}f=d}return(f&255)-k[b|0]|0}function YIa(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;d=hk(e,a,1);a=hb(a);f=j[d+4>>2];j[114626]=0;L(559,a|0,f|0,b|0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[d+4>>2]=j[d+4>>2]+24;ub(d);Za=e+16|0;return}a=D()|0;C()|0;ub(d);G(a|0);z()}function UV(a,b){var c=0,d=0;c=OV(a);a:{if(!b){break a}j[114626]=0;F(262,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(263,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;mB(c);G(a|0);z()}return a}function Mma(a,b,c){var d=0;d=Za-16|0;Za=d;a:{b:{if(!b){b=a;a=zb(c);Zh(b,a,nb(c)+a|0);break b}OJ(d,c);j[114626]=0;I(115,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}pc(d)}Za=d+16|0;return}a=D()|0;C()|0;pc(d);G(a|0);z()}function M2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!k[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((bb[j[j[a>>2]+52>>2]](a,j[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=Ai(b,4,c,j[a+32>>2])}return c|0}function H7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=q(0);e=Za-16|0;Za=e;f=j[a+4>>2];DF(a,b,c,d);g=n[a+28>>2];b=j[a+24>>2];j[e+8>>2]=j[a+20>>2];j[e+12>>2]=b;b=j[a+16>>2];j[e>>2]=j[a+12>>2];j[e+4>>2]=b;tba(e,f,c,d,g);Za=e+16|0}function _U(a,b,c,d){var e=0;a:{if((a|0)==(b|0)){break a}while(1){e=c;if((e|0)!=(d|0)){while(1){if(bb[26](h[a|0],h[e|0])|0){break a}e=e+1|0;if((e|0)!=(d|0)){continue}break}}a=a+1|0;if((b|0)!=(a|0)){continue}break}return b}return a}function Mo(a){var b=0,c=0,d=0,e=0;b=Za-16|0;Za=b;c=Kra(Lb(a),Mb(a));d=b,e=Lb(a),j[d+8>>2]=e;d=b,e=Mb(a),j[d>>2]=e;if(rb(b+8|0,b)){c=-c;while(1){a=j[b+8>>2];c=o[a>>3]+c;o[a>>3]=c;Jx(b+8|0);if(rb(b+8|0,b)){continue}break}}Za=b+16|0}function wB(){var a=0,b=0,c=0;b=Za-16|0;Za=b;a=Eb(b,10940);a:{if(!nb(a)){break a}c=1;if((Ff(a,10946)|0)!=-1){break a}if((Ff(a,10948)|0)!=-1){break a}if((Ff(a,10952)|0)!=-1){break a}c=(Ff(a,10954)|0)!=-1}gb(a);Za=b+16|0;return c|0}function v0(a,b,c,d,e,f){a=bb[j[j[a+8>>2]+8>>2]](a+8|0)|0;if((nb(a)|0)==(0-nb(a+12|0)|0)){j[e>>2]=j[e>>2]|4;return}a=wq(c,d,a,a+24|0,f,e,0)-a|0;c=j[b>>2];if(!(a|(c|0)!=12)){j[b>>2]=0;return}if(!((a|0)!=12|(c|0)>11)){j[b>>2]=c+12}}function rLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;c=-1;a:{if(!jf(a,7)){break a}c=0;if(!kS(a,12168)){break a}c=d;e=JKa(a,d);if(!e){YR(c)}c=-1;if(!e){break a}c=0;if(!jS(d)){break a}c=Le(a,b,iS(d),ab)}Za=d+16|0;return c|0}function qf(a,b){var c=0,d=0,e=0,f=0;c=l[a+24>>1]<<17;e=l[a+20>>1];if(e){d=l[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-p(j[Be(b,l[c+28>>1])>>2],i[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function dna(a,b,c){var d=0;d=Za-16|0;Za=d;a:{b:{if(!b){b=a;a=zb(c);Zh(b,a,nb(c)+a|0);break b}rK(d,b,c);j[114626]=0;F(116,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}pc(d)}Za=d+16|0;return}a=D()|0;C()|0;pc(d);G(a|0);z()}function b0(a,b,c,d,e,f){a=bb[j[j[a+8>>2]+8>>2]](a+8|0)|0;if((nb(a)|0)==(0-nb(a+12|0)|0)){j[e>>2]=j[e>>2]|4;return}a=uq(c,d,a,a+24|0,f,e,0)-a|0;c=j[b>>2];if(!(a|(c|0)!=12)){j[b>>2]=0;return}if(!((a|0)!=12|(c|0)>11)){j[b>>2]=c+12}}function EK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Za-16|0;Za=a;d=j[b+104>>2];if(d){j[b+88>>2]=j[b+88>>2]&-131|128;d=j[d>>2];j[b+76>>2]=d;j[a+12>>2]=c<<8;j[a+8>>2]=d-1;c=d+(j[tb(a+12|0,a+8|0)>>2]^-1)|0;j[b>>2]=0;j[b+4>>2]=c}Za=a+16|0}function qIa(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;h[a+15|0]=0;Za=b+16|0}function nsa(a,b,c){var d=0,e=0;b=Uj(a,b);a:{if((b|0)==255){break a}if(Ti(a)){break a}d=k[Pb(oi(a+314|0,b),10)|0];e=j[a>>2];a=d&-49;a=(c|0)<171?a|16:a;a=((c|0)>84?a|32:a)&255;Og(e,gs(b)|192,a);d=(a>>>5&1)+(a<<27>>31)|0}return d}function nN(a,b){var c=0,d=0,e=0,f=0;c=Za-32|0;Za=c;d=j[a+4>>2];e=j[a>>2];j[c+24>>2]=e;j[c+28>>2]=d;f=j[b+4>>2];a=j[b>>2];j[c+16>>2]=a;j[c+20>>2]=f;j[c+8>>2]=e;j[c+12>>2]=d;j[c>>2]=a;j[c+4>>2]=f;a=SN(c+8|0,c);Za=c+32|0;return a}function WEa(a,b,c){var d=0;d=Za-32|0;Za=d;j[d+28>>2]=c;h[d+27|0]=0;j[d+20>>2]=1;xk(a,d+27|0,j[tb(d+28|0,d+20|0)>>2]);a=ab;if((a|0)>0?1:(a|0)>=0){j[d+16>>2]=1;j[tb(d+28|0,d+16|0)>>2]}h[d+8|0]=k[d+27|0];h[b|0]=k[d+8|0];Za=d+32|0}function HHa(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+7|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;Za=b+16|0}function ELa(a,b,c){var d=0;d=ri(a+8|0);j[114626]=0;I(421,a|0,b|0,c|0);c=j[114626];j[114626]=0;a:{if((c|0)!=1){a=j[a>>2];j[114626]=0;E(338,b|0,a|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;wg(d);G(a|0);z()}}function gta(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=yn(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(1174,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+32;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function Uaa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=Nl(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(2119,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+16;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function Qqa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=Un(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(1249,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+12;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function Jaa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=hk(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(2124,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+24;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function Ixa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=Un(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(1016,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+12;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function Dpa(a,b){var c=0;c=Za-2496|0;Za=c;OK(b,c,c+2496|0);b=Vb(a,c,2496);j[b+2496>>2]=0;a:{if(j[b>>2]<=-1){break a}a=1;while(1){if(j[b+(a<<2)>>2]){break a}a=a+1|0;if((a|0)!=624){continue}break}j[b>>2]=-2147483648}Za=c+2496|0}function Dka(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=hk(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(1554,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+24;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function $oa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=yn(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(1365,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+32;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function ws(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=Za-16|0;Za=f;if(b){e=sc(a);d=nb(a);g=d+b|0;if(e-d>>>0<b>>>0){tl(a,e,g-e|0,d,d,0,0)}e=d;d=zb(a);ky(e+d|0,b,c);Ag(a,g);h[f+15|0]=0;Td(d+g|0,f+15|0)}Za=f+16|0;return a|0}function una(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=_d(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(1414,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+4;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function l9(a,b){a=a|0;b=b|0;var c=q(0);a:{if((b|0)<0){break a}a=a+24|0;if(l[j[a>>2]+480188>>1]<=(b|0)){break a}b=p(b,896);if(!(h[(b+j[a>>2]|0)+1075073|0]&1)){break a}c=q(q(k[(b+j[a>>2]|0)+1075846|0])*q(.0078125))}return q(c)}function k9(a,b){a=a|0;b=b|0;var c=q(0);a:{if((b|0)<0){break a}a=a+24|0;if(l[j[a>>2]+480188>>1]<=(b|0)){break a}b=p(b,896);if(!(h[(b+j[a>>2]|0)+1075073|0]&1)){break a}c=q(q(k[(b+j[a>>2]|0)+1075847|0])*q(.0078125))}return q(c)}function fga(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=_d(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(1755,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+4;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function cB(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;h[a+12|0]=0;h[a+13|0]=0;Za=b+16|0}function bJ(a){var b=0,c=0,d=0;b=Za-16|0;Za=b;j[b+12>>2]=7;j[b+8>>2]=32;if(j[tb(b+12|0,b+8|0)>>2]){while(1){d=Ao(a);j[b+12>>2]=7;j[b+8>>2]=32;c=c+15|0;if(c>>>0<m[tb(b+12|0,b+8|0)>>2]){continue}break}c=d&127}Za=b+16|0;return c}function _la(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=_d(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(1511,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+4;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function _Ia(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=$Q(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(557,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+48;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function Zha(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=_d(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(1628,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+4;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function WIa(a,b){var c=0,d=0;c=NIa(a);a:{if(!b){break a}j[114626]=0;F(561,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)!=1){j[114626]=0;F(562,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){break a}}a=D()|0;C()|0;cR(c);G(a|0);z()}}function VQ(a){if(!((k[a+8|0]|k[a+9|0]<<8|(k[a+10|0]<<16|k[a+11|0]<<24))==1179472708?(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))==1179011410:0)){return(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))==1179472708}return 1}function Tya(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=hk(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(982,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+24;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function QDa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=hk(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(768,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+24;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function PHa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=hk(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(605,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+24;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function NJa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=hk(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(528,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+24;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function Kwa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=_d(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(1052,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+4;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function IFa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=Un(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(727,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+12;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function Gia(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=_d(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(1597,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+4;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function FHa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=Nl(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(608,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+16;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function u4(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=Un(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(204,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+12;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function qna(a){var b=0,c=0;c=a+946300|0;b=a+906300|0;while(1){a=j[b>>2];a:{if(!a){break a}if(bb[j[j[a>>2]+112>>2]](a)|0){break a}bb[j[j[a>>2]+104>>2]](a,1);bb[j[j[a>>2]+116>>2]](a)}b=b+160|0;if((c|0)!=(b|0)){continue}break}}function oU(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=yn(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(347,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+32;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function lra(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=_d(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(411,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+4;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function VJa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=yh(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(520,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+2;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function RKa(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=yh(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(381,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+2;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function JMa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=p(e,f);g=c&65535;h=a&65535;i=p(g,h);f=(i>>>16|0)+p(f,g)|0;e=(f&65535)+p(e,h)|0;a=(p(b,c)+j|0)+p(a,d)+(f>>>16)+(e>>>16)|0;b=i&65535|e<<16;ab=a;return b}function E8(a,b){var c=0,d=0,e=0;c=Za-32|0;Za=c;b=Zb(c+24|0,j[b>>2]);d=j[a>>2];a=j[d+4>>2];d=j[d>>2];j[c+16>>2]=d;j[c+20>>2]=a;e=j[b+4>>2];j[c+8>>2]=j[b>>2];j[c+12>>2]=e;j[c>>2]=d;j[c+4>>2]=a;a=nc(c+8|0,c);Za=c+32|0;return a}function w2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d+8>>2]=c;e=-1;c=xq(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=_c(c);j[f>>2]=a;if(!a){break a}e=xq(a,c,b,j[d+12>>2])}Za=d+16|0;return e|0}function vC(){var a=0;a:{b:{if(h[461844]&1){break b}if(!fd(461844)){break b}j[114626]=0;T(2553)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}j[115460]=461836;ed(461844)}return j[115460]}a=D()|0;C()|0;Zd(461844);G(a|0);z()}function uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-16|0;Za=d;e=d+8|0;j[e>>2]=83888;j[e>>2]=83844;j[114626]=0;a=P(2147,a|0,b|0,c|0,e|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a|0}a=D()|0;C()|0;G(a|0);z()}function tP(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=_d(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(766,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+4;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function qU(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=_d(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(346,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+4;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function q0(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=rl(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(210,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+1;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function p_(){var a=0;a:{b:{if(h[461856]&1){break b}if(!fd(461856)){break b}j[114626]=0;T(2557)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}j[115463]=461848;ed(461856)}return j[115463]}a=D()|0;C()|0;Zd(461856);G(a|0);z()}function Ova(a,b){var c=0,d=0,e=0;d=Za-16|0;Za=d;c=_d(d,a,1);a=hb(a);e=j[c+4>>2];j[114626]=0;I(95,a|0,e|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[c+4>>2]=j[c+4>>2]+4;ub(c);Za=d+16|0;return}a=D()|0;C()|0;ub(c);G(a|0);z()}function Kr(a,b){var c=0;c=79436;a:{b:{c:{switch(b-2|0){default:if((b|0)==16777216){break a}if((b|0)!=32){break b}c=79452;break a;case 2:c=79448;break a;case 1:break b;case 0:break c}}c=79444;break a}c=79440}j[a>>2]=j[c>>2]}function xra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;wra(a);d=a;e=Sm(a+12|0);h[a+30|0]=c;i[a+28>>1]=0;j[a+24>>2]=b;j[114626]=0;F(1227,a|0,1);b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Ud(e);iL(d);G(a|0);z()}function vg(a){a=a|0;var b=0,c=0;b=Za-16|0;Za=b;h[a+8|0]=0;j[a>>2]=0;j[a+4>>2]=4194432;c=Eb(b,11931);j[114626]=0;E(378,a+9|0,c|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){gb(c);Za=b+16|0;return}a=D()|0;C()|0;gb(c);G(a|0);z()}function qma(a,b,c){var d=0;d=Za-32|0;Za=d;j[d+16>>2]=b;j[d+24>>2]=a;j[d+8>>2]=c;if(rb(d+24|0,d+16|0)){while(1){a=bb[117](h[j[d+24>>2]])|0;h[j[d+8>>2]]=a;Xf(d+24|0);Xf(d+8|0);if(rb(d+24|0,d+16|0)){continue}break}}Za=d+32|0}function o9(a,b){a=a|0;b=b|0;var c=q(0);a:{if((b|0)<0){break a}a=a+24|0;if(l[j[a>>2]+480188>>1]<=(b|0)){break a}b=p(b,896);if(h[(b+j[a>>2]|0)+1075073|0]&1){break a}c=q(q(k[(b+j[a>>2]|0)+1075846|0])*q(.0078125))}return q(c)}function n9(a,b){a=a|0;b=b|0;var c=q(0);a:{if((b|0)<0){break a}a=a+24|0;if(l[j[a>>2]+480188>>1]<=(b|0)){break a}b=p(b,896);if(h[(b+j[a>>2]|0)+1075073|0]&1){break a}c=q(q(k[(b+j[a>>2]|0)+1075847|0])*q(.0078125))}return q(c)}function mia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-16|0;Za=c;a:{if(sb(a)){while(1){Mf(c,j[xb(a,d)>>2]+40|0);e=ip(c,b);gb(c);if(e){a=j[xb(a,d)>>2];break a}d=d+1|0;if(sb(a)>>>0>d>>>0){continue}break}}a=0}Za=c+16|0;return a|0}function fD(a,b){var c=0,d=0;c=Za-32|0;Za=c;a:{if(Af(a)>>>0<b>>>0){d=hb(a);b=sl(c+8|0,b,tc(a),d);j[114626]=0;F(209,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Ul(b)}Za=c+32|0;return}a=D()|0;C()|0;Ul(b);G(a|0);z()}function ana(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-16|0;Za=c;j[a+480180>>2]=b;DJ(c,to(a));d=j[c+12>>2];b=a+1074316|0;j[b>>2]=j[c+8>>2];j[b+4>>2]=d;b=j[c+4>>2];j[a+1074308>>2]=j[c>>2];j[a+1074312>>2]=b;Kr(a+8|0,to(a));Za=c+16|0}function Xma(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(l[j[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!j[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(l[j[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function VX(a,b,c){var d=0,e=0,f=0;d=Za-16|0;Za=d;if(b>>>0<=1073741807){a:{if(b>>>0<=1){Ue(a,b);e=a;break a}f=Ql(b)+1|0;e=Ak(f);lf(a,e);jg(a,f);ee(a,b)}YX(e,b,c);j[d+12>>2]=0;ze((b<<2)+e|0,d+12|0);Za=d+16|0;return}kg();z()}function $X(a,b,c){var d=0,e=0,f=0;d=Za-16|0;Za=d;if(c>>>0<=1073741807){a:{if(c>>>0<=1){Ue(a,c);e=a;break a}f=Ql(c)+1|0;e=Ak(f);lf(a,e);jg(a,f);ee(a,c)}Jh(e,b,c);j[d+12>>2]=0;ze((c<<2)+e|0,d+12|0);Za=d+16|0;return}kg();z()}function x7(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=q(0);if(e){while(1){f=0;if(d){while(1){h=o[Jg(b,f,g)>>3];Pb(c,f);i=Qm(a,f,g),j=q(h),n[i>>2]=j;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function iGa(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;d=2;e=j[a>>2];if((e|0)!=1){j[c+12>>2]=e>>>1;j[c+8>>2]=-1-j[a>>2];d=tb(c+12|0,c+8|0);j[c+12>>2]=j[a>>2]+j[d>>2];j[c+8>>2]=j[b>>2];d=j[tb(c+12|0,c+8|0)>>2]}Za=c+16|0;return d}function hL(a,b){var c=0,d=0;c=Za-32|0;Za=c;a:{if(jd(a)>>>0<b>>>0){d=hb(a);b=ds(c+8|0,b,sb(a),d);j[114626]=0;F(96,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}Qj(b)}Za=c+32|0;return}a=D()|0;C()|0;Qj(b);G(a|0);z()}function dxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-32|0;Za=d;e=me(b);c=LM(d+8|0,c);j[114626]=0;V(1025,a|0,b|0,0,e-1&65535,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){Vd(c);Za=d+32|0;return}a=D()|0;C()|0;Vd(c);G(a|0);z()}function V6(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=q(0);if(e){while(1){f=0;if(d){while(1){h=o[Jg(b,f,g)>>3];Pb(c,f);i=uf(a,f,g),j=q(h),n[i>>2]=j;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function JFa(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;d=c,e=xFa(a,b,se(a),Rb(a)),j[d+8>>2]=e;d=c,e=_i(a),j[d>>2]=e;a:{b:{if(!rb(c+8|0,c)){break b}if(Zm(hb(a),b,Rg(c+8|0))){break b}a=j[c+8>>2];break a}a=_i(a)}Za=c+16|0;return a}function D$(a,b,c){var d=0;d=Za-32|0;Za=d;j[d+16>>2]=b;j[d+24>>2]=a;j[d+8>>2]=c;while(1){a:{a=rb(d+24|0,d+16|0);if(!a){break a}if(!al(j[d+24>>2],j[d+8>>2])){break a}Id(d+24|0);Id(d+8|0);continue}break}Za=d+32|0;return a^1}function Cba(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;d=c,e=Aba(a,b,se(a),Rb(a)),j[d+8>>2]=e;d=c,e=_i(a),j[d>>2]=e;a:{b:{if(!rb(c+8|0,c)){break b}if(as(hb(a),b,Rg(c+8|0))){break b}a=j[c+8>>2];break a}a=_i(a)}Za=c+16|0;return a}function $ia(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;d=c,e=wia(a,b,se(a),Rb(a)),j[d+8>>2]=e;d=c,e=_i(a),j[d>>2]=e;a:{b:{if(!rb(c+8|0,c)){break b}if(Br(hb(a),b,Rg(c+8|0))){break b}a=j[c+8>>2];break a}a=_i(a)}Za=c+16|0;return a}function lZ(a){a=a|0;a:{b:{if(h[461932]&1){break b}if(!fd(461932)){break b}j[114626]=0;M(2572);a=j[114626];j[114626]=0;if((a|0)==1){break a}j[115482]=462112;ed(461932)}return j[115482]}a=D()|0;C()|0;Zd(461932);G(a|0);z()}function jY(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;a:{if(_s(b,68561)){UB(c,68574,b);a=zb(c);j[114626]=0;F(2302,44,a|0);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=D()|0;C()|0;gb(c);G(a|0);z()}Za=c+16|0;return a|0}z()}function iha(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-2048|0;j[a+8>>2]=d;j[114626]=0;F(1644,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function iZ(a){a=a|0;a:{b:{if(h[461940]&1){break b}if(!fd(461940)){break b}j[114626]=0;M(2574);a=j[114626];j[114626]=0;if((a|0)==1){break a}j[115484]=462288;ed(461940)}return j[115484]}a=D()|0;C()|0;Zd(461940);G(a|0);z()}function eZ(a){a=a|0;a:{b:{if(h[461948]&1){break b}if(!fd(461948)){break b}j[114626]=0;M(2576);a=j[114626];j[114626]=0;if((a|0)==1){break a}j[115486]=462464;ed(461948)}return j[115486]}a=D()|0;C()|0;Zd(461948);G(a|0);z()}function bZ(a){a=a|0;a:{b:{if(h[461956]&1){break b}if(!fd(461956)){break b}j[114626]=0;M(2578);a=j[114626];j[114626]=0;if((a|0)==1){break a}j[115488]=462768;ed(461956)}return j[115488]}a=D()|0;C()|0;Zd(461956);G(a|0);z()}function _Y(a){a=a|0;a:{b:{if(h[461964]&1){break b}if(!fd(461964)){break b}j[114626]=0;M(2580);a=j[114626];j[114626]=0;if((a|0)==1){break a}j[115490]=463072;ed(461964)}return j[115490]}a=D()|0;C()|0;Zd(461964);G(a|0);z()}function XY(a){a=a|0;a:{b:{if(h[461972]&1){break b}if(!fd(461972)){break b}j[114626]=0;M(2582);a=j[114626];j[114626]=0;if((a|0)==1){break a}j[115492]=463104;ed(461972)}return j[115492]}a=D()|0;C()|0;Zd(461972);G(a|0);z()}function Sra(a){var b=0,c=0;c=Jra(a);j[114626]=0;F(1215,a|0,2048);b=j[114626];j[114626]=0;a:{if((b|0)!=1){j[114626]=0;F(1217,a|0,2048);b=j[114626];j[114626]=0;if((b|0)!=1){break a}}a=D()|0;C()|0;Ix(c);G(a|0);z()}return a}function upa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=Za-16|0;Za=c;d=c,e=(j[a+480208>>2]&32768?28.85390081777927:34.624680981335125)*(Xn(b)+ -4.8737671609324025),o[d+8>>3]=e;pf(c+8|0,0,127);a=Ls(o[c+8>>3]);Za=c+16|0;return a|0}function rx(a,b){var c=0,d=0;c=p(b,896)+a|0;a:{if(j[c+1075072>>2]&134218752){break a}if(!Qi(c+1074984|0)){break a}b=k[j[(p(b,896)+a|0)+1075640>>2]+34|0];if((b+5&255)>>>0<6){break a}d=j[(p(b,160)+a|0)+906140>>2]}return d}function oua(a,b,c){var d=0,e=0,f=0;c=c-1|0;if((c|0)>-1){while(1){d=c<<4;e=c<<3;f=e|4;j[(d|12)+a>>2]=j[f+b>>2];j[(d|8)+a>>2]=j[b+e>>2];j[(d|4)+a>>2]=j[a+f>>2];j[a+d>>2]=j[a+e>>2];d=(c|0)>0;c=c-1|0;if(d){continue}break}}}function bN(a,b,c){var d=0;d=Za-16|0;Za=d;h[d+15|0]=a;a=0;if(!(c>>>0>108|b>>>0>108|(c>>>0<25|b>>>0<25)|b>>>0>=c>>>0)){h[d+14|0]=(l[(b<<1)+20798>>1]-l[(c<<1)+20798>>1]|0)/5;a=k[Yb(d+15|0,d+14|0)|0]}Za=d+16|0;return a&255}function Xq(a){var b=0;a:{b=k[a+1376|0];b:{if(!b){b=-1;if(j[a+1384>>2]){break b}if(!Cv(a)){break b}b=k[a+1376|0];if(!b){break a}}h[a+1376|0]=b-1;j[a+1400>>2]=j[a+1400>>2]+1;b=he(a)}return b}X(50578,50496,1563,50598);z()}function WDa(a){var b=0,c=0;c=Za-32|0;Za=c;a:{if(jd(a)>>>0<15){b=hb(a);b=sn(c+8|0,15,sb(a),b);j[114626]=0;F(368,a|0,b|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}xh(b)}Za=c+32|0;return}a=D()|0;C()|0;xh(b);G(a|0);z()}function UIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-16|0;Za=d;e=0;a:{if(!a){break a}e=a|-16;if(!(a>>>0<16&c?0:b>>>0>=2)){break a}h[d+15|0]=1;h[d+14|0]=(a|0)/(b-1|0);e=k[Wg(d+15|0,d+14|0)|0]}a=e;Za=d+16|0;return a&255}function Kka(a,b){var c=0,d=0,e=0,f=0;c=a+1|0;d=a+2|0;e=a+3|0;f=a+4|0;FI(k[a|0]&15,k[c|0]&15,k[d|0]&15,k[e|0]&15,k[f|0]&15,a+5|0,b+48|0);FI(k[a|0]>>>4|0,k[c|0]>>>4|0,k[d|0]>>>4|0,k[e|0]>>>4|0,k[f|0]>>>4|0,a+35|0,b+68|0)}function IM(a){var b=0,c=0,d=0;b=a- -64|0;d=k[b|0]|k[b+1|0]<<8;b=a+70|0;a=a+72|0;c=k[a|0]|k[a+1|0]<<8;a=(k[b|0]|k[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;ab=a;return b}function pxa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-12|0;j[a+8>>2]=d;j[114626]=0;F(1017,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function nxa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-12|0;j[a+8>>2]=d;j[114626]=0;F(1018,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function nja(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-52|0;j[a+8>>2]=d;j[114626]=0;F(1431,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function bra(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-12|0;j[a+8>>2]=d;j[114626]=0;F(1231,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function _ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;a:{if(!Ec(c)){yi(aI(a+52|0,b),c);break a}a=a+52|0;e=d,f=zw(a,b),j[e+8>>2]=f;e=d,f=ki(a),j[e>>2]=f;if(!ji(d+8|0,d)){break a}Zia(a,j[d+8>>2])}Za=d+16|0}function Tea(a,b){var c=0,d=0;c=Za-32|0;Za=c;d=j[b+48>>2];a:{if(d&16){if(m[b+24>>2]>m[b+44>>2]){j[b+44>>2]=j[b+24>>2]}Zh(a,j[b+20>>2],j[b+44>>2]);break a}if(d&8){Zh(a,j[b+8>>2],j[b+16>>2]);break a}ew(a,c+8|0)}Za=c+32|0}function SV(a){var b=0,c=0,d=0;c=Za-16|0;Za=c;b=yn(c,a,1);a=hb(a);d=j[b+4>>2];j[114626]=0;F(266,a|0,d|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[b+4>>2]=j[b+4>>2]+32;ub(b);Za=c+16|0;return}a=D()|0;C()|0;ub(b);G(a|0);z()}function MZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;j[e+12>>2]=d;d=ch(e+8|0,e+12|0);j[114626]=0;a=qD(a,b,c);b=j[114626];j[114626]=0;if((b|0)!=1){pe(d);Za=e+16|0;return a|0}a=D()|0;C()|0;pe(d);G(a|0);z()}function Jsa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-32|0;j[a+8>>2]=d;j[114626]=0;F(1189,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function Aka(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-24|0;j[a+8>>2]=d;j[114626]=0;F(1553,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function zwa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(1054,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function zHa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-16|0;j[a+8>>2]=d;j[114626]=0;F(426,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function xIa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-48|0;j[a+8>>2]=d;j[114626]=0;F(573,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function uIa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-24|0;j[a+8>>2]=d;j[114626]=0;F(572,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function sva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-32|0;Za=d;j[d+24>>2]=c;j[d+16>>2]=b;if(rb(d+16|0,d+24|0)){while(1){j[d+12>>2]=j[j[d+16>>2]>>2];ay(a,d+12|0);Id(d+16|0);if(rb(d+16|0,d+24|0)){continue}break}}Za=d+32|0}function noa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-32|0;j[a+8>>2]=d;j[114626]=0;F(891,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function lJ(a,b,c){var d=0,e=0,f=0;d=Za-16|0;Za=d;if(b>>>0<=4294967279){a:{if(b>>>0<=10){Ue(a,b);e=a;break a}f=Dk(b)+1|0;e=Sh(f);lf(a,e);jg(a,f);ee(a,b)}ky(e,b,c);h[d+15|0]=0;Td(b+e|0,d+15|0);Za=d+16|0;return}kg();z()}function fha(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(1646,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function eN(a){var b=0,c=0,d=0;b=a+32|0;d=k[b|0]|k[b+1|0]<<8;b=a+34|0;a=a+36|0;c=k[a|0]|k[a+1|0]<<8;a=(k[b|0]|k[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;ab=a;return b}function e8(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-16|0;j[a+8>>2]=d;j[114626]=0;F(2198,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function bga(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(1756,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function _7(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-24|0;j[a+8>>2]=d;j[114626]=0;F(2199,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function Yaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;d=Nl(e,a,d);a=hb(a);j[114626]=0;L(2117,a|0,b|0,c|0,d+4|0);a=j[114626];j[114626]=0;if((a|0)!=1){ub(d);Za=e+16|0;return}a=D()|0;C()|0;ub(d);G(a|0);z()}function YDa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-33|0;j[a+8>>2]=d;j[114626]=0;F(765,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function Wo(a,b,c){var d=0,e=0,f=0;d=Za-16|0;Za=d;if(c>>>0<=4294967279){a:{if(c>>>0<=10){Ue(a,c);e=a;break a}f=Dk(c)+1|0;e=Sh(f);lf(a,e);jg(a,f);ee(a,c)}lh(e,b,c);h[d+15|0]=0;Td(c+e|0,d+15|0);Za=d+16|0;return}kg();z()}function Uha(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(1432,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function Qya(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-24|0;j[a+8>>2]=d;j[114626]=0;F(980,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function Pla(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(1517,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function LHa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-24|0;j[a+8>>2]=d;j[114626]=0;F(604,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function Kqa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-12|0;j[a+8>>2]=d;j[114626]=0;F(348,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function IDa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-24|0;j[a+8>>2]=d;j[114626]=0;F(767,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function GJa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-24|0;j[a+8>>2]=d;j[114626]=0;F(527,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function Cya(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-56|0;j[a+8>>2]=d;j[114626]=0;F(984,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function Cma(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(1433,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function CL(a,b){a:{if(k[a+76|0]==(b|0)){break a}h[a+76|0]=b;if(b){b=0;if(l[a+24>>1]==15){i[a+20>>1]=0;b=1}j[a+8>>2]=0;j[a+16>>2]=b;return}b:{switch(j[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}j[a+16>>2]=3}}function yJa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-2|0;j[a+8>>2]=d;j[114626]=0;F(531,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function wLa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-2|0;j[a+8>>2]=d;j[114626]=0;F(422,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function sd(a){var b=0,c=0,d=0;b=Za-32|0;Za=b;j[b+12>>2]=0;j[b+8>>2]=2550;c=j[b+12>>2];j[b>>2]=j[b+8>>2];j[b+4>>2]=c;d=j[b+4>>2];c=b+16|0;j[c+4>>2]=j[b>>2];j[c+8>>2]=d;j[c>>2]=a;n_(a,c);Za=b+32|0;return j[a+4>>2]-1|0}function rMa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-2|0;j[a+8>>2]=d;j[114626]=0;F(382,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function rB(a){var b=0;a:{b=a+2|0;if(!(k[b|0]|k[b+1|0]<<8)){break a}a=a+4|0;if(!(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))){break a}return(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))>>>0<2147483649}return 0}function pqa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(107,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function lg(a){var b=0;j[114626]=0;a=H(1392,a|0)|0;b=j[114626];j[114626]=0;a:{if((b|0)==1){a=J(0)|0;C()|0;O(a|0)|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;a=0;if((b|0)==1){break a}}return a}a=J(0)|0;C()|0;ib(a);z()}function lY(a){var b=0;j[114626]=0;a=H(2828,a|0)|0;b=j[114626];j[114626]=0;a:{if((b|0)==1){a=J(0)|0;C()|0;O(a|0)|0;j[114626]=0;M(20);b=j[114626];j[114626]=0;a=0;if((b|0)==1){break a}}return a}a=J(0)|0;C()|0;ib(a);z()}function hFa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(737,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function hAa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-8|0;j[a+8>>2]=d;j[114626]=0;F(919,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function ela(a,b,c){var d=0;d=Za-32|0;Za=d;j[d+16>>2]=b;j[d+24>>2]=a;j[d+8>>2]=c;if(rb(d+24|0,d+16|0)){while(1){a=h[j[d+24>>2]];h[j[d+8>>2]]=a?a:32;Xf(d+24|0);Xf(d+8|0);if(rb(d+24|0,d+16|0)){continue}break}}Za=d+32|0}function bV(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-32|0;j[a+8>>2]=d;j[114626]=0;F(276,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function YEa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-6|0;j[a+8>>2]=d;j[114626]=0;F(736,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function PCa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(817,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function Nm(a){a=a|0;kc(a+16|0,j[a>>2]);kc(a+8|0,j[a>>2]);if(m[a+12>>2]>=m[a+16>>2]){j[a+12>>2]=0;j[a+16>>2]=0;i[a+34>>1]=l[a+34>>1]&65511}if(m[a+4>>2]>=m[a+8>>2]){j[a+4>>2]=0;j[a+8>>2]=0;i[a+34>>1]=l[a+34>>1]&65529}}function K2(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-12|0;j[a+8>>2]=d;j[114626]=0;F(206,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function GCa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-2|0;j[a+8>>2]=d;j[114626]=0;F(824,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function EW(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-16|0;j[a+8>>2]=d;j[114626]=0;F(217,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function Bza(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(945,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function Aia(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(734,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function A9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;d=Un(e,a,d);a=hb(a);j[114626]=0;L(2174,a|0,b|0,c|0,d+4|0);a=j[114626];j[114626]=0;if((a|0)!=1){ub(d);Za=e+16|0;return}a=D()|0;C()|0;ub(d);G(a|0);z()}function w8(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-16|0;Za=c;Bn(a);j[a>>2]=83912;d=$g(c+8|0);b=$g(b);j[114626]=0;K(2195,a+12|0,d|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a|0}a=D()|0;C()|0;G(a|0);z()}function u8(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-16|0;Za=c;Bn(a);j[a>>2]=83952;d=$g(c+8|0);b=$g(b);j[114626]=0;K(2197,a+12|0,d|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a|0}a=D()|0;C()|0;G(a|0);z()}function qT(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(372,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function iU(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-4|0;j[a+8>>2]=d;j[114626]=0;F(349,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function fLa(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-1|0;j[a+8>>2]=d;j[114626]=0;F(32,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function YW(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-1|0;j[a+8>>2]=d;j[114626]=0;F(215,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function SY(a){a=a|0;a:{b:{if(h[462004]&1){break b}if(!fd(462004)){break b}j[114626]=0;E(2585,461992,62728)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(462004)}return 461992}a=D()|0;C()|0;Zd(462004);G(a|0);z()}function OY(a){a=a|0;a:{b:{if(h[462036]&1){break b}if(!fd(462036)){break b}j[114626]=0;E(2585,462024,62776)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(462036)}return 462024}a=D()|0;C()|0;Zd(462036);G(a|0);z()}function LT(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-1|0;j[a+8>>2]=d;j[114626]=0;F(361,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function KY(a){a=a|0;a:{b:{if(h[462068]&1){break b}if(!fd(462068)){break b}j[114626]=0;E(2585,462056,62836)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(462068)}return 462056}a=D()|0;C()|0;Zd(462068);G(a|0);z()}function JT(a,b){var c=0,d=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}c=j[a+16>>2];d=j[a+8>>2]-2|0;j[a+8>>2]=d;j[114626]=0;F(362,c|0,d|0);c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function GY(a){a=a|0;a:{b:{if(h[462100]&1){break b}if(!fd(462100)){break b}j[114626]=0;E(2585,462088,62932)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(462100)}return 462088}a=D()|0;C()|0;Zd(462100);G(a|0);z()}function Dv(a){var b=0;a:{b:{while(1){if(j[a+1380>>2]!=-1){break b}b=0;if(!Wq(a)){break a}if(!(h[a+1375|0]&1)){continue}break}Nb(a,32);return 0}j[a+1396>>2]=0;j[a+1400>>2]=0;j[a+1384>>2]=0;h[a+1376|0]=0;b=1}return b}function ns(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;mb(d+8|0,c+1074308|0,102);a:{if(!kb(d+8|0)){break a}c=l[a+692>>1]+1|0;i[a+796>>1]=c;if(!(h[a+89|0]&1)){break a}i[a+796>>1]=c|32768}j[a+692>>2]=b;Za=d+16|0}function mL(a,b){var c=0,d=0,e=0,f=0;e=o[a+48>>3];c=o[a+40>>3];o[a+48>>3]=c;f=o[a+64>>3];d=o[a+56>>3];o[a+64>>3]=d;o[a+40>>3]=b;b=c*o[a+8>>3]+o[a>>3]*b+e*o[a+16>>3]-(f*o[a+32>>3]+d*o[a+24>>3]);o[a+56>>3]=b;return b}function kka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;ft(a);e=j[b+4>>2];d=b+4|0;IP(hb(a),j[a>>2],c,d);f=c;c=b+8|0;rI(hb(a),f,j[a+4>>2],c);Hb(a,d);Hb(a+4|0,c);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];jt(a,Kf(a));return e|0}function aua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;af(a);e=j[b+4>>2];d=b+4|0;uh(hb(a),j[a>>2],c,d);f=c;c=b+8|0;kn(hb(a),f,j[a+4>>2],c);Hb(a,d);Hb(a+4|0,c);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Oj(a,sb(a));return e|0}function YV(a,b){a=a|0;b=b|0;var c=0,d=0;b=Za-32|0;Za=b;c=b+16|0;d=vV(a,c);if(!d){eB(c)}c=-1;a:{if(!d){break a}c=0;if(!sB(b+16|0)){break a}c=b;a=uV(a,b);if(!a){cB(c)}c=-1;if(!a){break a}c=rB(b)}Za=b+32|0;return c|0}function DV(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-16|0;Za=c;Bn(a);j[a>>2]=77112;d=$g(c+8|0);b=$g(b);j[114626]=0;K(275,a+12|0,d|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a|0}a=D()|0;C()|0;G(a|0);z()}function yR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;wl(a);e=j[b+4>>2];d=b+4|0;uh(hb(a),j[a>>2],c,d);f=c;c=b+8|0;kn(hb(a),f,j[a+4>>2],c);Hb(a,d);Hb(a+4|0,c);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Rt(a,bc(a));return e|0}function kY(a,b){var c=0,d=0;c=Za-16|0;Za=c;b=b>>>0>4?b:4;a=a?a:1;a:{while(1){if(!eX(c+12|0,b,a)){break a}d=j[115935];if(d){bb[d|0]();continue}break}a=R(4)|0;zk(a);Y(a|0,71396,2001);z()}Za=c+16|0;return j[c+12>>2]}function hm(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=d*(c*.13339200271297674+.3333313950307914)+a;a=c*c;a=e+d*a*(c*.024528318116654728+.05338123784456704+a*(c*.009465647849436732+.002974357433599673));return q(b?-1/a:a)}function UY(a){a=a|0;a:{b:{if(h[461988]&1){break b}if(!fd(461988)){break b}j[114626]=0;E(85,461976,62716)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(461988)}return 461976}a=D()|0;C()|0;Zd(461988);G(a|0);z()}function QY(a){a=a|0;a:{b:{if(h[462020]&1){break b}if(!fd(462020)){break b}j[114626]=0;E(85,462008,62764)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(462020)}return 462008}a=D()|0;C()|0;Zd(462020);G(a|0);z()}function MY(a){a=a|0;a:{b:{if(h[462052]&1){break b}if(!fd(462052)){break b}j[114626]=0;E(85,462040,62812)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(462052)}return 462040}a=D()|0;C()|0;Zd(462052);G(a|0);z()}function IY(a){a=a|0;a:{b:{if(h[462084]&1){break b}if(!fd(462084)){break b}j[114626]=0;E(85,462072,62920)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(462084)}return 462072}a=D()|0;C()|0;Zd(462084);G(a|0);z()}function DH(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-2048|0;F(1644,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function zxa(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-12|0;F(1018,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function qza(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;yN(a,c+11|0);if((k[c+11|0]|k[c+12|0]<<8|(k[c+13|0]<<16|k[c+14|0]<<24))==1414807888){yN(a,c+11|0);h[b|0]=1;a=0}else{a=1}a=hza(a+(c+11|0)|0);Za=c+16|0;return a|0}function pv(a){a=a|0;var b=0;j[a>>2]=56200;j[114626]=0;F(2305,a|0,0);b=j[114626];j[114626]=0;if((b|0)!=1){wb(a+28|0);Cb(j[a+32>>2]);Cb(j[a+36>>2]);Cb(j[a+48>>2]);Cb(j[a+60>>2]);return a|0}a=J(0)|0;C()|0;ib(a);z()}function aEa(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=130150524;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function aDa(a,b,c,d,e){var f=0,g=0;f=Za-32|0;Za=f;g=ECa(b,f+28|0,c);c=j[g>>2];h[f+27|0]=0;if(!c){DCa(f+8|0,b,d,e);ak(b,j[f+28>>2],g,j[f+8>>2]);c=ud(f+8|0);h[f+27|0]=1;TO(f+8|0)}hi(a,zc(f+8|0,c),f+27|0);Za=f+32|0}function Yoa(a,b,c,d,e){var f=0,g=0;f=Za-32|0;Za=f;g=moa(b,f+28|0,c);c=j[g>>2];h[f+27|0]=0;if(!c){loa(f+8|0,b,d,e);ak(b,j[f+28>>2],g,j[f+8>>2]);c=ud(f+8|0);h[f+27|0]=1;SJ(f+8|0)}hi(a,zc(f+8|0,c),f+27|0);Za=f+32|0}function Yia(a,b,c,d,e){var f=0,g=0;f=Za-32|0;Za=f;g=via(b,f+28|0,c);c=j[g>>2];h[f+27|0]=0;if(!c){uia(f+8|0,b,d,e);ak(b,j[f+28>>2],g,j[f+8>>2]);c=ud(f+8|0);h[f+27|0]=1;UH(f+8|0)}hi(a,zc(f+8|0,c),f+27|0);Za=f+32|0}function Uoa(a,b,c,d,e){var f=0,g=0;f=Za-32|0;Za=f;g=foa(b,f+28|0,c);c=j[g>>2];h[f+27|0]=0;if(!c){eoa(f+8|0,b,d,e);ak(b,j[f+28>>2],g,j[f+8>>2]);c=ud(f+8|0);h[f+27|0]=1;QJ(f+8|0)}hi(a,zc(f+8|0,c),f+27|0);Za=f+32|0}function St(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=2147483647;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function MBa(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=214748364;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function Lna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-32|0;Za=d;a=j[a+1304560>>2];a:{if(a){bb[j[j[a>>2]+8>>2]](a,b,c);break a}if(j[19104]<(b|0)){break a}EJ(d+8|0,20495,20516,132);vB(d+24|0,d+8|0,b,20486,c)}Za=d+32|0}function Jm(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=1073741823;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function IK(a,b,c){var d=0,e=0;d=Za-16|0;Za=d;e=c&15;if(e){h[b+844|0]=e}c=c&240;if(c){h[b+843|0]=c>>>4}j[b+88>>2]=j[b+88>>2]|131072;mb(d+8|0,a+1074308|0,80);if(!(!e|!kb(d+8|0))){h[b+844|0]=k[b+844|0]<<2}Za=d+16|0}function Gda(a,b,c,d,e){var f=0,g=0;f=Za-32|0;Za=f;g=Nqa(b,f+28|0,c);c=j[g>>2];h[f+27|0]=0;if(!c){Fba(f+8|0,b,d,e);ak(b,j[f+28>>2],g,j[f+8>>2]);c=ud(f+8|0);h[f+27|0]=1;VK(f+8|0)}hi(a,zc(f+8|0,c),f+27|0);Za=f+32|0}function GFa(a,b,c,d,e){var f=0,g=0;f=Za-32|0;Za=f;g=FFa(b,f+28|0,c);c=j[g>>2];h[f+27|0]=0;if(!c){EFa(f+8|0,b,d,e);ak(b,j[f+28>>2],g,j[f+8>>2]);c=ud(f+8|0);h[f+27|0]=1;aQ(f+8|0)}hi(a,zc(f+8|0,c),f+27|0);Za=f+32|0}function Eka(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-24|0;F(1553,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function Ara(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-16|0;F(1226,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function wR(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=178956970;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function vz(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=715827882;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function pJ(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-52|0;F(1431,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function i8(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-16|0;F(2198,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function hn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;a:{if(c){Eb(d,c);break a}Db(d)}j[114626]=0;I(13,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(d);Za=d+16|0;return}a=D()|0;C()|0;gb(d);G(a|0);z()}function fu(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=536870911;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function dq(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=268435455;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function d8(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-24|0;F(2199,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function cBa(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-32|0;F(891,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function ax(a,b){var c=0;c=j[b+24>>2];c=c?c:1;j[a+24628>>2]=c>>>0<512?c:512;a:{if(!(j[b+16>>2]!=j[a+24620>>2]|j[b+20>>2]!=j[a+24624>>2])){c=0;if(j[b+12>>2]==j[a+24616>>2]){break a}}c=1}Vb(a+24604|0,b,40);kJ(a,c)}function aga(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(1756,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function _K(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-12|0;F(1231,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function Yya(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-24|0;F(980,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function YA(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=134217727;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function XJ(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-24|0;F(1373,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function SK(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=357913941;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function SHa(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-24|0;F(604,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function SDa(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-24|0;F(767,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function Rla(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(1517,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function RM(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-12|0;F(1017,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function RL(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-32|0;F(1189,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function Pya(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-56|0;F(984,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function OJa(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-24|0;F(527,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function Lma(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(1432,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function IBa(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-20|0;F(880,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function Gra(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-8|0;F(1223,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function Fya(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=76695844;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function Fsa(a,b){a=a|0;b=b|0;var c=0,d=0;d=a+808|0;c=a+16|0;while(1){c=Esa(c)+44|0;if((d|0)!=(c|0)){continue}break}d=a+3832|0;c=a+808|0;while(1){c=Dsa(c)+84|0;if((d|0)!=(c|0)){continue}break}Csa(a,b);return a|0}function FIa(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-24|0;F(572,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function Ema(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(1433,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function Dwa(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(1054,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function AIa(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=89478485;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function zP(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-33|0;F(765,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function z2(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-12|0;F(206,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function yV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-16|0;Za=e;j[e+12>>2]=d;d=0;f=j[a+8>>2];if(f>>>0>c>>>0){j[e+8>>2]=f-c;d=tb(e+8|0,e+12|0);a=j[a+4>>2]+c|0;d=j[d>>2];Pe(a,a+d|0,b)}Za=e+16|0;return d|0}function tV(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-32|0;F(276,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function nS(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-16|0;F(426,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function mha(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=2097151;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function kU(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-12|0;F(348,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function kI(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=82595524;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function hua(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(!(!d|e==q(1))){while(1){if(c){i=b+g|0;f=0;while(1){h=uf(a,f,i);n[h>>2]=n[h>>2]*e;f=f+1|0;if((f|0)!=(c|0)){continue}break}}g=g+1|0;if((g|0)!=(d|0)){continue}break}}}function gua(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(!(!d|e==q(1))){while(1){if(c){i=b+g|0;f=0;while(1){h=Qm(a,f,i);n[h>>2]=n[h>>2]*e;f=f+1|0;if((f|0)!=(c|0)){continue}break}}g=g+1|0;if((g|0)!=(d|0)){continue}break}}}function aR(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-48|0;F(573,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function OBa(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(879,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function IIa(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-6|0;F(570,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function FB(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-16|0;F(217,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function Ek(a,b){a=a|0;b=b|0;H1(a);j[a+28>>2]=b;iD(a+32|0);h1(a+44|0);j[a+72>>2]=0;j[a+76>>2]=0;j[a+64>>2]=0;j[a+56>>2]=0;j[a+60>>2]=0;j[a+80>>2]=0;j[a+84>>2]=0;j[a+88>>2]=0;j[a+92>>2]=0;j[a+96>>2]=0;return a|0}function DJa(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-2|0;F(531,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function AH(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(1646,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function wA(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-1|0;F(361,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function rS(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-2|0;F(422,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function lxa(){var a=0,b=0,c=0;a=Za-16|0;Za=a;j[a+12>>2]=477218588;j[114626]=0;j[a+8>>2]=2147483647;b=E(33,a+12|0,a+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=a+16|0;return j[b>>2]}a=J(0)|0;C()|0;ib(a);z()}function kA(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(372,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function jU(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(349,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function hza(a){var b=0,c=0,d=0;b=Za-16|0;Za=b;a:{b:{if(!a){a=0;break b}c=Eb(b,a);j[114626]=0;a=H(972,c|0)|0;d=j[114626];j[114626]=0;if((d|0)==1){break a}gb(c)}Za=b+16|0;return a}a=D()|0;C()|0;gb(c);G(a|0);z()}function _O(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(817,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function _N(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-8|0;F(919,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function ZU(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-8|0;F(283,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function ZS(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-2|0;F(382,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function ZP(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(734,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function WP(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-6|0;F(736,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function VO(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-2|0;F(824,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function Ssa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;j[e>>2]=c;j[e+8>>2]=b;if(rb(e+8|0,e)){while(1){zp(a,j[d>>2],j[e+8>>2]);je(e+8|0);j[d>>2]=j[d>>2]+2;if(rb(e+8|0,e)){continue}break}}Za=e+16|0}function SP(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(737,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function QT(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-1|0;F(360,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function PT(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-2|0;F(362,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function KL(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(107,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function FN(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-4|0;F(945,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function BB(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-1|0;F(215,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function $w(a,b){var c=0,d=0;c=j[b+4>>2];j[a+24648>>2]=j[b>>2];j[a+24652>>2]=c;d=j[b+20>>2];c=a+24664|0;j[c>>2]=j[b+16>>2];j[c+4>>2]=d;d=j[b+12>>2];c=a+24656|0;j[c>>2]=j[b+8>>2];j[c+4>>2]=d;jJ(a+24648|0);wJ(a)}function sl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=Sh(b)}j[a>>2]=f;c=c+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=b+f|0,j[g>>2]=h;Za=e+16|0;return a|0}function jKa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-16|0;Za=e;g=j[j[b>>2]+20>>2];f=j[c+12>>2];j[e+8>>2]=j[c+8>>2];j[e+12>>2]=f;f=j[c+4>>2];j[e>>2]=j[c>>2];j[e+4>>2]=f;bb[g|0](a,b,e,d);Za=e+16|0}function iC(a){var b=0,c=0;b=Za-16|0;Za=b;Ck(a);j[b+12>>2]=1073741823;j[114626]=0;j[b+8>>2]=2147483647;a=tb(b+12|0,b+8|0);c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function em(a,b,c){var d=0,e=0;d=rd(b,a);e=rd(c,b);a:{b:{if(!d){d=0;if(!e){break a}Hb(b,c);d=1;if(!rd(b,a)){break a}Hb(a,b);break b}if(e){Hb(a,c);return 1}Hb(a,b);d=1;if(!rd(c,b)){break a}Hb(b,c)}d=2}return d}function Sq(a){var b=0;if(a){if(j[a+76>>2]<=-1){return xv(a)}return xv(a)}if(j[21340]){b=Sq(j[21340])}a=j[114621];if(a){while(1){if(m[a+20>>2]>m[a+28>>2]){b=xv(a)|b}a=j[a+56>>2];if(a){continue}break}}return b}function Poa(a){var b=0,c=0;b=Za-16|0;Za=b;i[b+12>>1]=0;j[b+8>>2]=0;bj(b+8|0);c=l[b+12>>1];h[a+814|0]=c;h[a+815|0]=c>>>8;c=j[b+8>>2];h[a+810|0]=c;h[a+811|0]=c>>>8;h[a+812|0]=c>>>16;h[a+813|0]=c>>>24;Za=b+16|0}function Ola(a,b,c,d){var e=0,f=0;e=Za-32|0;Za=e;f=Nla(b,e+28|0,c);c=j[f>>2];h[e+27|0]=0;if(!c){Mla(e+8|0,b,d);ak(b,j[e+28>>2],f,j[e+8>>2]);c=ud(e+8|0);h[e+27|0]=1;OI(e+8|0)}hi(a,zc(e+8|0,c),e+27|0);Za=e+32|0}function Nta(a,b,c,d){var e=0,f=0;e=Za-32|0;Za=e;f=Lta(b,e+28|0,c);c=j[f>>2];h[e+27|0]=0;if(!c){Kta(e+8|0,b,d);ak(b,j[e+28>>2],f,j[e+8>>2]);c=ud(e+8|0);h[e+27|0]=1;hM(e+8|0)}hi(a,zc(e+8|0,c),e+27|0);Za=e+32|0}function FEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;j[d+12>>2]=c;e=d,f=qEa(Lb(b),Mb(b),d+12|0),j[e+8>>2]=f;e=d,f=Mb(b),j[e>>2]=f;a:{if(rb(d+8|0,d)){Ie(a,hb(j[d+8>>2]));break a}zh(a)}Za=d+16|0}function Cu(a,b,c){var d=0;d=j[a+16>>2];if(!d){j[a+36>>2]=1;j[a+24>>2]=c;j[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(j[a+24>>2]!=2){break a}j[a+24>>2]=c;return}h[a+54|0]=1;j[a+24>>2]=2;j[a+36>>2]=j[a+36>>2]+1}}function BS(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=hb(a);j[114626]=0;c=c-1|0;F(32,d|0,c|0);d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function tla(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=b,h=mh(a),j[g>>2]=h;mh(a);if(f>>>0>=60){Jb(a,4)}g=e,h=mh(a),j[g>>2]=h;Jb(a,4);b=mh(a);j[d>>2]=b;if((b|0)>=1){g=c,h=mh(a),j[g>>2]=h}}function poa(a,b){var c=0;c=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=c;c=j[b+28>>2];j[a+24>>2]=j[b+24>>2];j[a+28>>2]=c;c=j[b+20>>2];j[a+16>>2]=j[b+16>>2];j[a+20>>2]=c;c=j[b+12>>2];j[a+8>>2]=j[b+8>>2];j[a+12>>2]=c}function XU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;b=tk(e+8|0,b);j[114626]=0;L(284,a|0,b|0,c|0,d|0);a=j[114626];j[114626]=0;if((a|0)!=1){jb(b);Za=e+16|0;return}a=D()|0;C()|0;jb(b);G(a|0);z()}function Sea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Za-16|0;Za=f;b=ic(PMa(OMa(d,d>>31,b,b>>31),ab,1e3,0),ab);j[a+16>>2]=0;j[a+12>>2]=b+c;XG(a,e);b=j[a+12>>2];j[f+12>>2]=0;$H(a,b,f+12|0);Za=f+16|0}function LR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;j[d+12>>2]=c;e=d,f=_Ja(Lb(b),Mb(b),d+12|0),j[e+8>>2]=f;e=d,f=Mb(b),j[e>>2]=f;a:{if(rb(d+8|0,d)){Ie(a,hb(j[d+8>>2]));break a}zh(a)}Za=d+16|0}function yy(a,b,c){var d=0;d=Za-16|0;Za=d;j[d>>2]=b;j[d+8>>2]=a;a:{if(!rb(d+8|0,d)){break a}while(1){if(l[j[d+8>>2]>>1]==l[c>>1]){break a}je(d+8|0);if(rb(d+8|0,d)){continue}break}}Za=d+16|0;return j[d+8>>2]}function xz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;j[d+12>>2]=c;e=d,f=jR(Lb(b),Mb(b),d+12|0),j[e+8>>2]=f;e=d,f=Mb(b),j[e>>2]=f;a:{if(rb(d+8|0,d)){Ie(a,hb(j[d+8>>2]));break a}zh(a)}Za=d+16|0}function wJ(a){var b=0,c=0;b=Za-544|0;Za=b;if(!(!(k[a+480210|0]&128)|!j[a+24668>>2])){kL(b,xe(a));c=a+1304360|0;a=a+1074984|0;while(1){Vb(a+112|0,b,538);a=a+896|0;if((c|0)!=(a|0)){continue}break}}Za=b+544|0}function pA(a,b,c){var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;e=j[a+4>>2];f=e+b|0;j[a+4>>2]=f;if(!((f-1^e-1)>>>0<32?e:0)){g=j[a>>2];j[(f>>>0<33?g:(f-1>>>3&536870908)+g|0)>>2]=0}rn(d+8|0,a,e);Fp(d+8|0,b,c);Za=d+16|0}function TIa(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;j[c+12>>2]=1;j[c+8>>2]=a>>>4;b=Gb(128/(p(j[zf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);h[c+7|0]=1;h[c+6|0]=a&15;a=k[Wg(c+7|0,c+6|0)|0];Za=c+16|0;return a|b<<4&240}function kJ(a,b){var c=0;if(b){oo(a);c=a+24596|0;j[c>>2]=0;j[c+4>>2]=0;j[a+24588>>2]=0;j[a+24592>>2]=0;wJ(a)}jJ(a+24648|0);nea(a+393352|0,b,j[a+24620>>2]);b=a+1304392|0;if(bd(b)){BL(j[b>>2],j[a+24620>>2])}}function e7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=q(0);e=Za-16|0;Za=e;f=j[a+4>>2];yF(a,b,c,d);g=n[a+24>>2];j[e+8>>2]=j[a+20>>2];b=j[a+16>>2];j[e>>2]=j[a+12>>2];j[e+4>>2]=b;uba(e,f,c,d,g);Za=e+16|0}function _C(a,b,c,d,e,f){var g=0,i=0,k=0;g=Za-16|0;Za=g;h[g+15|0]=0;h[g+14|0]=f;h[g+13|0]=e;h[g+12|0]=37;if(f){Tg(g+13|0,g+14|0)}i=c,k=(Ha(b|0,US(b,j[c>>2])|0,g+12|0,d|0,j[a>>2])|0)+b|0,j[i>>2]=k;Za=g+16|0}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;a=j[a+24>>2];Ir(d,0,c);j[114626]=0;I(647,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(d);Za=d+16|0;return}a=D()|0;C()|0;gb(d);G(a|0);z()}function Kga(a){var b=0,c=0,d=0,e=0;b=vH(a);c=vH(a+12|0);d=uH(a+24|0);e=uH(a+36|0);j[114626]=0;K(1632,a|0,2,0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){return}a=D()|0;C()|0;ur(e);ur(d);tr(c);tr(b);G(a|0);z()}function Iwa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d>>2]=4896;c=j[tb(d+12|0,d)>>2];if(!yb(a,c)){c=ef(a)}Ty(d,b);Vg(a,j[d>>2],c);Ty(d,b);Ab(j[d>>2]+c|0,0,4896-c|0);Jb(a,j[d+12>>2]);Za=d+16|0;return c}function Yv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Za-32|0;Za=e;j[e+24>>2]=b;f=e,g=nd(a),j[f+16>>2]=g;b=En(e+24|0,e+16|0);cY(a,b,c,d);f=e,g=nd(a),j[f+8>>2]=g;a=$e(e+8|0,b);Za=e+32|0;return a|0}function Vta(){var a=0;a:{b:{if(h[85420]&1){break b}if(!fd(85420)){break b}j[114626]=0;H(100,85392)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(85420)}return 85392}a=D()|0;C()|0;Zd(85420);G(a|0);z()}function TI(){var a=0;a:{b:{if(h[457368]&1){break b}if(!fd(457368)){break b}j[114626]=0;E(1516,88664,1)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(457368)}return}a=D()|0;C()|0;Zd(457368);G(a|0);z()}function Rr(a,b){a=Vb(a,b,88);j[a+88>>2]=j[b+88>>2];Vb(a+92|0,b+92|0,576);j[a+668>>2]=j[b+668>>2];Vb(a+672|0,b+672|0,52);vx(a+724|0,b+724|0);vx(a+736|0,b+736|0);vx(a+748|0,b+748|0);Vb(a+760|0,b+760|0,135)}function Ox(a){var b=0,c=0,d=0;b=l[a+20>>1];i[a+28>>1]=l[a+22>>1]<<1|(k[j[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=j[c>>2];if(d){Lm(d);DL(j[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function $R(a){var b=0,c=0;b=Za-16|0;Za=b;hb(a);j[b+12>>2]=-1;j[114626]=0;j[b+8>>2]=2147483647;a=E(33,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return j[a>>2]}a=J(0)|0;C()|0;ib(a);z()}function xY(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=hC(j[a+16>>2],b)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function pM(a,b){var c=0;c=k[a+822|0];a:{if(c){break a}c=$i(k[a+819|0]-j[a+772>>2]|0);if(!b|!j[a+656>>2]){break a}if(!c){c=0;break a}if(c>>>0>=129){break a}c=k[Pb(j[a+656>>2]+108|0,c-1|0)|0]}return c&255}function of(a,b,c,d,e){var f=0;f=Za-256|0;Za=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Ab(f,b&255,d?c:256);if(!d){while(1){ve(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}ve(a,f,c)}Za=f+256|0}function ic(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;j[c+24>>2]=a;j[c+28>>2]=b;j[c+16>>2]=-2147483648;j[c+20>>2]=-1;j[c+8>>2]=2147483647;j[c+12>>2]=0;a=tQ(c+16|0,iz(c+24|0,c+8|0));Za=c+32|0;return j[a>>2]}function f3(){var a=0;a:{b:{if(h[461640]&1){break b}if(!fd(461640)){break b}j[114626]=0;H(2378,461636)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(461640)}return}a=D()|0;C()|0;Zd(461640);G(a|0);z()}function aB(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=XA(j[a+16>>2],b)}j[a>>2]=f;c=(c<<5)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<5)+f|0,j[g>>2]=h;Za=e+16|0;return a}function UN(a,b,c){var d=0,e=0,f=0,g=0;e=Za-16|0;Za=e;d=sc(a);a:{if(d>>>0>=c>>>0){d=zb(a);Fl(d,b,c);h[e+15|0]=0;Td(c+d|0,e+15|0);Ag(a,c);break a}f=d;g=c-d|0;d=nb(a);uu(a,f,g,d,0,d,c,b)}Za=e+16|0;return a}function Owa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d>>2]=263;c=j[tb(d+12|0,d)>>2];if(!yb(a,c)){c=ef(a)}EM(d,b);Vg(a,j[d>>2],c);EM(d,b);Ab(j[d>>2]+c|0,0,263-c|0);Jb(a,j[d+12>>2]);Za=d+16|0;return c}function M$(a,b,c){var d=0;d=Za-32|0;Za=d;j[d+16>>2]=b;j[d+24>>2]=a;j[d+8>>2]=c;while(1){a=rb(d+24|0,d+16|0);if(!(!a|k[j[d+24>>2]]!=k[j[d+8>>2]])){Xf(d+24|0);Xf(d+8|0);continue}break}Za=d+32|0;return a^1}function Hg(a,b,c){var d=0,e=0,f=0,g=0;j[a+112>>2]=b;j[a+116>>2]=c;d=j[a+8>>2];g=j[a+4>>2];e=d-g|0;f=e>>31;j[a+120>>2]=e;j[a+124>>2]=f;j[a+104>>2]=b|c?((c|0)<(f|0)?1:(c|0)<=(f|0)?b>>>0<e>>>0:0)?b+g|0:d:d}function sB(a){var b=0;b=a;if((k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))==1129474426&(k[b+4|0]|k[b+5|0]<<8|(k[b+6|0]<<16|k[b+7|0]<<24))==1634291279){a=a+8|0;return(k[a|0]|k[a+1|0]<<8)==14}return 0}function qI(a){var b=0,c=0,d=0;if(df(a)){while(1){b=a;d=c&65535;if(df(b)>>>0>d>>>0){b=te(b,d);j[b+20>>2]=0;j[b+12>>2]=0;j[b+16>>2]=0;vI(b);De(b+36|0)}c=c+1|0;if(df(a)>>>0>(c&65535)>>>0){continue}break}}}function nya(a,b){var c=0;c=Za-16|0;Za=c;j[c>>2]=b;j[c+8>>2]=a;if(rb(c+8|0,c)){while(1){a=j[c+8>>2];if(k[a+3|0]==31){h[a+3|0]=20;h[a+5|0]=k[a+5|0]|128}kk(c+8|0);if(rb(c+8|0,c)){continue}break}}Za=c+16|0}function fN(a){var b=0;a:{if((k[a+44|0]|k[a+45|0]<<8|(k[a+46|0]<<16|k[a+47|0]<<24))!=1297236819|k[a+29|0]!=16){break a}a=a+42|0;if((k[a|0]|k[a+1|0]<<8)!=2?(k[a|0]|k[a+1|0]<<8)!=1:0){break a}b=1}return b}function Ad(a,b){var c=0,d=0,e=0;b=b+7&-8;j[a+8>>2]=b+j[a+8>>2];d=j[a+80>>2];a:{if(d){c=b;b=j[a+88>>2];e=c+b|0;c=0;if((e|0)>j[a+92>>2]){break a}j[a+88>>2]=e;return b+d|0}if(!b){return 0}c=_c(b)}return c}function AQ(a){var b=0,c=0;b=a+36|0;c=OMa(k[b|0]|k[b+1|0]<<8,0,384,0);a=a+34|0;b=k[a|0]|k[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+ab|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;if(b>>>0<256){a=a+1|0}ab=a;return b}function yZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=Za-16|0;Za=a;j[a+12>>2]=c;j[a+8>>2]=f;b=xZ(c,d,a+12|0,f,g,a+8|0);j[e>>2]=j[a+12>>2];j[h>>2]=j[a+8>>2];Za=a+16|0;return b|0}function vFa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Za-16|0;Za=e;j[e+12>>2]=d;Zy(a,c,d);d=0;f=j[a+16>>2];if(f>>>0>c>>>0){j[e+8>>2]=f-c;d=j[tb(e+8|0,e+12|0)>>2];OFa(a,b,c,d)}Za=e+16|0;return d|0}function gDa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d>>2]=22;c=j[tb(d+12|0,d)>>2];if(!yb(a,c)){c=ef(a)}at(d,b);Vg(a,j[d>>2],c);at(d,b);Ab(j[d>>2]+c|0,0,22-c|0);Jb(a,j[d+12>>2]);Za=d+16|0;return c}function eDa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d>>2]=40;c=j[tb(d+12|0,d)>>2];if(!yb(a,c)){c=ef(a)}Jy(d,b);Vg(a,j[d>>2],c);Jy(d,b);Ab(j[d>>2]+c|0,0,40-c|0);Jb(a,j[d+12>>2]);Za=d+16|0;return c}function XBa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(MBa(a)>>>0<b>>>0){Jc();z()}hb(a);c=b;if(c>>>0>214748364){oc(15551);z()}c=$b(p(c,20),4);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=c+p(b,20)|0,j[d>>2]=e;_o(a);_o(a)}function X7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;HF(b,c,d,n[a+28>>2]);GF(a,b,c,d);b=j[a+24>>2];j[e+8>>2]=j[a+20>>2];j[e+12>>2]=b;b=j[a+16>>2];j[e>>2]=j[a+12>>2];j[e+4>>2]=b;Za=e+16|0}function Pp(a,b,c){a:{if(m[a+12>>2]<=b>>>0){a=R(8)|0;j[114626]=0;H(352,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break a}b=D()|0;C()|0;S(a|0);G(b|0);z()}h[j[a+8>>2]+b|0]=c;return}Y(a|0,77416,265);z()}function Oja(a){var b=0,c=0,d=0;b=Za+ -64|0;Za=b;qI(a);d=df(a);c=Ew(b+8|0,a);j[114626]=0;I(1573,a|0,d|0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){Xk(c);Za=b- -64|0;return}a=D()|0;C()|0;Xk(c);G(a|0);z()}function Oga(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d>>2]=33;c=j[tb(d+12|0,d)>>2];if(!yb(a,c)){c=ef(a)}Py(d,b);Vg(a,j[d>>2],c);Py(d,b);Ab(j[d>>2]+c|0,0,33-c|0);Jb(a,j[d+12>>2]);Za=d+16|0;return c}function HZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=Za-16|0;Za=a;j[a+12>>2]=c;j[a+8>>2]=f;b=GZ(c,d,a+12|0,f,g,a+8|0);j[e>>2]=j[a+12>>2];j[h>>2]=j[a+8>>2];Za=a+16|0;return b|0}function FZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=Za-16|0;Za=a;j[a+12>>2]=c;j[a+8>>2]=f;b=EZ(c,d,a+12|0,f,g,a+8|0);j[e>>2]=j[a+12>>2];j[h>>2]=j[a+8>>2];Za=a+16|0;return b|0}function BZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=Za-16|0;Za=a;j[a+12>>2]=c;j[a+8>>2]=f;b=AZ(c,d,a+12|0,f,g,a+8|0);j[e>>2]=j[a+12>>2];j[h>>2]=j[a+8>>2];Za=a+16|0;return b|0}function sta(a,b){var c=0;c=Za+ -64|0;Za=c;b=cpa(c+16|0,b);b=Xoa(c,b,b+48|0);j[114626]=0;K(106,a|0,b|0,0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Ud(b);Za=c- -64|0;return}a=D()|0;C()|0;Ud(b);G(a|0);z()}function mla(a,b,c,d){var e=0;e=Za-16|0;Za=e;j[e>>2]=c;j[e+8>>2]=b;if(rb(e+8|0,e)){while(1){lla(d,j[e+8>>2]);kk(e+8|0);if(rb(e+8|0,e)){continue}break}}b=j[d+4>>2];j[a>>2]=j[d>>2];j[a+4>>2]=b;Za=e+16|0}function c3(){var a=0,b=0;b=qr(460608);j[115150]=55908;j[b>>2]=55928;j[115151]=0;j[114626]=0;F(2380,j[13974]+460600|0,461284);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=D()|0;C()|0;og(b);G(a|0);z()}function a3(){var a=0,b=0;b=OD(460696);j[115172]=55956;j[b>>2]=55976;j[115173]=0;j[114626]=0;F(2381,j[13986]+460688|0,461348);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=D()|0;C()|0;og(b);G(a|0);z()}function RZ(a,b,c,d,e,f){var g=0;g=Za-16|0;Za=g;j[g+12>>2]=f;f=ch(g+8|0,g+12|0);j[114626]=0;a=tD(a,b,c,d,e);b=j[114626];j[114626]=0;if((b|0)!=1){pe(f);Za=g+16|0;return a}a=D()|0;C()|0;pe(f);G(a|0);z()}function PZ(a,b,c,d,e,f){var g=0;g=Za-16|0;Za=g;j[g+12>>2]=f;f=ch(g+8|0,g+12|0);j[114626]=0;a=sD(a,b,c,d,e);b=j[114626];j[114626]=0;if((b|0)!=1){pe(f);Za=g+16|0;return a}a=D()|0;C()|0;pe(f);G(a|0);z()}function AEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b&63;if(_j(c)>>>0>d>>>0){nEa(DP(c,d),a)}a:{b:{if(b<<24>>24>=0){b=a+12|0;break b}b=a+12|0;if(ad(a)){break b}a=k[a+12|0]|1;break a}a=k[a+12|0]&-2}h[b|0]=a}function zBa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-608|0;Za=c;b=c+8|0;d=aBa(a,b);if(!d){mO(b)}b=-1;a:{if(!d){break a}b=0;if(!wO(c+8|0)){break a}b=-1;if(!jf(a,1024)){break a}b=wBa(a)}Za=c+608|0;return b|0}function fsa(){var a=0;a:{b:{if(h[87620]&1){break b}if(!fd(87620)){break b}j[114626]=0;H(1204,87616)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(87620)}return}a=D()|0;C()|0;Zd(87620);G(a|0);z()}function Zza(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-16|0;Za=c;d=hA(a);if(d>>>0>=b>>>0){a=zs(a);if(a>>>0<d>>>1>>>0){j[c+12>>2]=a<<1;j[c+8>>2]=b+31&-32;d=j[Gc(c+12|0,c+8|0)>>2]}Za=c+16|0;return d|0}Jc();z()}function XL(a){a=a|0;var b=0,c=0;b=Za-32|0;Za=b;h[a+16|0]=0;c=Rx(b,j[a+12>>2]);j[114626]=0;I(1170,a|0,1,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){dl(c);Za=b+32|0;return}a=D()|0;C()|0;dl(c);G(a|0);z()}function ON(a){var b=0,c=0,d=0,e=0;ab=0;d=k[a+4|0];e=k[a+92|0];c=k[a+93|0];b=a+94|0;b=c+(k[b|0]|k[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function Jra(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1221,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Era(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1224,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function zsa(){var a=0;a:{b:{if(h[85552]&1){break b}if(!fd(85552)){break b}j[114626]=0;H(108,85548)|0;a=j[114626];j[114626]=0;if((a|0)==1){break a}ed(85552)}return}a=D()|0;C()|0;Zd(85552);G(a|0);z()}function xJ(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=j[a>>2];a:{if(!b){break a}if(!(bb[j[j[b>>2]+112>>2]](b)|0)){break a}bb[j[j[b>>2]+92>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function YGa(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=674;j[c>>2]=674;d=j[tb(c+12|0,c)>>2];if(!yb(a,d)){d=ef(a)}VP(c,b);Vg(a,j[c>>2],d);VP(c,b);Ab(j[c>>2]+d|0,0,674-d|0);Jb(a,j[c+12>>2]);Za=c+16|0}function YBa(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(876,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function WFa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d>>2]=b;j[d+8>>2]=a;a:{if(!rb(d+8|0,d)){break a}while(1){if(ip(j[d+8>>2],c)){break a}_m(d+8|0);if(rb(d+8|0,d)){continue}break}}Za=d+16|0;return j[d+8>>2]}function UK(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1254,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Tma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=Za-16|0;Za=c;cf(a,c+14|0);dz(b,l[c+14>>1],16777216);if(l[c+14>>1]){while(1){ii(a,xb(b,d));d=d+1|0;if(d>>>0<l[c+14>>1]){continue}break}}dx(b);Za=c+16|0}function NIa(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(568,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Kza(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(943,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function $Ba(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(874,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function py(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[b+12>>2]=0;j[114626]=0;K(931,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function eX(a,b,c){var d=0;a:{b:{if((b|0)==8){b=_c(c);break b}d=28;if(b&3|(SMa(b>>>2|0)|0)!=1){break a}d=48;if(-64-b>>>0<c>>>0){break a}b=fX(b>>>0>16?b:16,c)}if(!b){return 48}j[a>>2]=b;d=0}return d}function cz(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(705,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function bU(a,b){a:{if(m[a+12>>2]<=b>>>0){a=R(8)|0;j[114626]=0;H(352,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break a}b=D()|0;C()|0;S(a|0);G(b|0);z()}return k[j[a+8>>2]+b|0]}Y(a|0,77416,265);z()}function Wz(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(409,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function WT(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(354,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Vt(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(355,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function OV(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(269,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function LZ(a){a=a|0;var b=0,c=0,d=0;b=Za-16|0;Za=b;j[b+12>>2]=a;a=ch(b+8|0,b+12|0);j[114626]=0;c=pD();d=j[114626];j[114626]=0;if((d|0)!=1){pe(a);Za=b+16|0;return c|0}b=D()|0;C()|0;pe(a);G(b|0);z()}function HS(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(417,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Bs(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(927,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function nL(a,b,c,d,e,f){j[a+40>>2]=0;j[a+44>>2]=0;o[a+32>>3]=f;o[a+24>>3]=e;o[a+16>>3]=d;o[a+8>>3]=c;o[a>>3]=b;j[a+48>>2]=0;j[a+52>>2]=0;j[a+56>>2]=0;j[a+60>>2]=0;a=a- -64|0;j[a>>2]=0;j[a+4>>2]=0}function nC(a,b,c,d,e){var f=0;f=Za-16|0;Za=f;j[f+12>>2]=e;e=ch(f+8|0,f+12|0);j[114626]=0;a=Qn(a,b,c,d);b=j[114626];j[114626]=0;if((b|0)!=1){pe(e);Za=f+16|0;return a}a=D()|0;C()|0;pe(e);G(a|0);z()}function hBa(a,b,c,d){var e=0;e=Za-16|0;Za=e;j[e>>2]=b;j[e+8>>2]=a;if(rb(e+8|0,e)){while(1){if(l[j[e+8>>2]>>1]==l[c>>1]){i[j[e+8>>2]>>1]=l[d>>1]}je(e+8|0);if(rb(e+8|0,e)){continue}break}}Za=e+16|0}function gA(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(31,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Wx(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(94,a+8|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function V$(a,b,c,d,e){var f=0;f=Za-16|0;Za=f;j[f+12>>2]=e;e=ch(f+8|0,f+12|0);j[114626]=0;a=av(a,b,c,d);b=j[114626];j[114626]=0;if((b|0)!=1){pe(e);Za=f+16|0;return a}a=D()|0;C()|0;pe(e);G(a|0);z()}function If(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za+ -64|0;Za=c;d=Ew(c+8|0,a);j[114626]=0;I(1575,a|0,b|0,d|0);a=j[114626];j[114626]=0;if((a|0)!=1){Xk(d);Za=c- -64|0;return}a=D()|0;C()|0;Xk(d);G(a|0);z()}function wja(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=hI(b)}j[a>>2]=f;c=p(c,52)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,52)+f|0,j[g>>2]=h;Za=e+16|0;return a}function tK(a,b,c){var d=0,e=0;d=j[(p(b,896)+a|0)+1075640>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=j[(p(b,896)+a|0)+1075088>>2];if(!a){break b}if(k[a+35|0]&4){break a}}e=k[d+34|0]}return e}function qxa(a,b){var c=0;c=Za-16|0;Za=c;j[a>>2]=0;j[a+4>>2]=0;j[c+12>>2]=0;j[114626]=0;K(1021,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function cxa(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=64;j[c>>2]=66;d=j[tb(c+12|0,c)>>2];if(!yb(a,d)){d=ef(a)}et(c,b);Vg(a,j[c>>2],d);et(c,b);Ab(j[c>>2]+d|0,0,66-d|0);Jb(a,j[c+12>>2]);Za=c+16|0}function _aa(a,b){var c=0;c=Za-16|0;Za=c;j[a>>2]=0;j[a+4>>2]=0;j[c+12>>2]=0;j[114626]=0;K(2116,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Saa(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;a=j[a+24>>2];Ir(c,0,b);j[114626]=0;I(647,a|0,1,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(c);Za=c+16|0;return}a=D()|0;C()|0;gb(c);G(a|0);z()}function Ph(a){var b=0;b=32767;a:{if(a>=q(32766.5)){break a}b=32768;if(a<=q(-32767.5)){break a}a=q(a+q(.5));b:{if(q(r(a))<q(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Dy(a){var b=0,c=0;c=(k[a+24|0]>15)+(k[a+25|0]>64)|0;b=a+22|0;b=k[b|0]|k[b+1|0]<<8;a=a+26|0;a=k[a|0]|k[a+1|0]<<8;return c+((b<<24|b<<8&16711680)>>>15>>>0<(a<<8&16711680|a<<24)>>>16>>>0)|0}function Cq(a){var b=0;if(j[a+76>>2]<0){b=j[a+4>>2];if(b>>>0<m[a+8>>2]){j[a+4>>2]=b+1;return k[b|0]}return kv(a)}b=j[a+4>>2];a:{if(b>>>0<m[a+8>>2]){j[a+4>>2]=b+1;a=k[b|0];break a}a=kv(a)}return a}function lL(a,b){var c=0;c=Za-16|0;Za=c;j[a>>2]=0;j[a+4>>2]=0;j[c+12>>2]=0;j[114626]=0;K(1220,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function id(a,b){var c=0;if(l[a+24>>1]!=(b&65535)){i[a+22>>1]=l[a+22>>1]-1&127;if(l[a+20>>1]<128){i[a+20>>1]=l[a+20>>1]+1}c=(l[a+22>>1]<<2)+a|0;i[c+28>>1]=0;i[c+26>>1]=b-l[a+24>>1];i[a+24>>1]=b}}function iI(a,b){var c=0;c=Za-16|0;Za=c;j[a>>2]=0;j[a+4>>2]=0;j[c+12>>2]=0;j[114626]=0;K(1584,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function fBa(a,b){var c=0,d=0;d=Za-16|0;Za=d;a:{if((a|0)==(b|0)){break a}c=a+1|0;if((c|0)==(b|0)){break a}while(1){a=k[a|0]<k[c|0]?c:a;c=c+1|0;if((c|0)!=(b|0)){continue}break}}Za=d+16|0;return a}function dg(a,b){a:{if(m[a+4>>2]<=b>>>0){a=R(8)|0;j[114626]=0;H(352,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break a}b=D()|0;C()|0;S(a|0);G(b|0);z()}return k[j[a>>2]+b|0]}Y(a|0,77416,265);z()}function TK(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=RK(b)}j[a>>2]=f;c=p(c,12)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,12)+f|0,j[g>>2]=h;Za=e+16|0;return a}function QL(a,b){var c=0;c=Za-16|0;Za=c;j[a>>2]=0;j[a+4>>2]=0;j[c+12>>2]=0;j[114626]=0;K(1191,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function P6(a,b){var c=0;c=Za-16|0;Za=c;j[a>>2]=0;j[a+4>>2]=0;j[c+12>>2]=0;j[114626]=0;K(2201,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function MKa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d>>2]=192;c=j[tb(d+12|0,d)>>2];if(!yb(a,c)){c=ef(a)}tt(d,b);Vg(a,j[d>>2],c);tt(d,b);Ab(j[d>>2]+c|0,0,192-c|0);Jb(a,j[d+12>>2]);Za=d+16|0}function MIa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(vz(a)>>>0<b>>>0){Jc();z()}hb(a);c=b;if(c>>>0>715827882){oc(12706);z()}c=$b(p(c,6),1);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=c+p(b,6)|0,j[d>>2]=e;jt(a,0)}function yna(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1411,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function wra(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1228,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function wna(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1413,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function uga(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1735,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function txa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1020,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function tga(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1736,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function s9(a){a=a|0;var b=0;a=a+24|0;b=XF(j[a>>2]);if(Ui(Fb(j[a>>2]+484360|0))>>>0<=b>>>0){return l[j[a>>2]+1074436>>1]}b=l[ac(Fb(j[a>>2]+484360|0),b)>>1];return(xp(j[a>>2]+484344|0,b)?b:-1)|0}function roa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=TJ(b)}j[a>>2]=f;c=(c<<5)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<5)+f|0,j[g>>2]=h;Za=e+16|0;return a}function oN(a,b){var c=0;c=Za-16|0;Za=c;j[a>>2]=0;j[a+4>>2]=0;j[c+12>>2]=0;j[114626]=0;K(988,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function o6(a,b,c){var d=0;d=n6(a,b,c);if((d|0)==(b|0)){return b}a=d+2|0;if((b|0)!=(a|0)){while(1){if(l[a>>1]!=l[c>>1]){i[d>>1]=l[a>>1];d=d+2|0}a=a+2|0;if((b|0)!=(a|0)){continue}break}}return d}function mta(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1171,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function kja(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1586,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function gia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-16|0;Za=d;e=1;a=a+32|0;if(m[j[b>>2]>>2]<tc(a)>>>0){a=Rl(d,fc(a,j[j[b>>2]>>2]),l[j[b>>2]+12>>1]);b=Ru(c,a);qb(a);e=b^1}Za=d+16|0;return e|0}function gga(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1754,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function bpa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1364,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function _Ba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Jm(a)>>>0<b>>>0){Jc();z()}hb(a);c=b;if(c>>>0>1073741823){oc(15551);z()}c=$b(c<<2,1);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=c+(b<<2)|0,j[d>>2]=e;Oj(a,0)}function Rma(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1429,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Qta(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1161,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Qna(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1395,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Pwa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1050,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Pma(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1430,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Mxa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1013,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Kaa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(2123,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Hka(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1552,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Gp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(hA(a)>>>0<b>>>0){Jc();z()}hb(a);b=(b-1>>>5|0)+1|0;c=b;if(b>>>0>1073741823){oc(11804);z()}c=$b(c<<2,4);j[a+4>>2]=0;j[a>>2]=c;d=hb(a),e=b,j[d>>2]=e}function ES(a,b){var c=0;c=Za-16|0;Za=c;j[a>>2]=0;j[a+4>>2]=0;j[c+12>>2]=0;j[114626]=0;K(419,a+8|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Dza(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=GN(b)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function DG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ue(12);b=j[b>>2];c=j[c>>2];j[114626]=0;b=K(1994,d|0,b|0,c|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Pda(a,b);return}a=D()|0;C()|0;Cb(d);G(a|0);z()}function C_(a){var b=0,c=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[b+12>>2]=0;j[114626]=0;jC(a+16|0,b+12|0,b+8|0);c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Aoa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1372,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function $la(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(1510,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function vea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=lg(86224);if(!d){return 0}j[114626]=0;a=P(1958,d|0,a|0,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Cb(d);G(a|0);z()}function uGa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(696,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function sn(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=iA(b)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function r5(a,b){var c=0;c=Ab(a,0,1512);if(b){a=j[b+4>>2];j[c+80>>2]=j[b>>2];j[c+84>>2]=a;a=a&-8;j[c+92>>2]=a;j[c+84>>2]=a}j[c+96>>2]=0;j[c+100>>2]=0;j[c+1420>>2]=-1;j[c+124>>2]=0;j[c+32>>2]=0}function qfa(a,b,c){a=a|0;b=b|0;c=q(c);var d=0;d=Za-16|0;Za=d;n[d+12>>2]=c;if((b|0)<=4){Kd(d+12|0,q(0));c=n[d+12>>2];if((b|0)==4){c=Sd(c);n[d+12>>2]=c}n[((b<<2)+a|0)+4220>>2]=c;_G(a)}Za=d+16|0}function pEa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(759,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function mwa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;j[d>>2]=36;c=j[tb(d+12|0,d)>>2];if(!yb(a,c)){c=ef(a)}Qp(d,b);Vg(a,j[d>>2],c);Qp(d,b);Ab(j[d>>2]+c|0,0,36-c|0);Jb(a,j[d+12>>2]);Za=d+16|0}function iza(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(971,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function iDa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(813,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function h8(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=MF(b)}j[a>>2]=f;c=(c<<4)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<4)+f|0,j[g>>2]=h;Za=e+16|0;return a}function eC(a,b){var c=0,d=0;c=j[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}Ck(a);j[114626]=0;c=c-4|0;d=j[114626];j[114626]=0;if((d|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}j[a+4>>2]=b}function ds(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=QK(b)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function cDa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(816,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function axa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;j[e>>2]=c;j[e+8>>2]=b;if(rb(e+8|0,e)){while(1){$wa(d,j[e+8>>2]);kk(e+8|0);if(rb(e+8|0,e)){continue}break}}KM(a,d);Za=e+16|0}function aM(a,b,c,d){var e=0;e=Za-16|0;Za=e;d=yh(e,a,d);a=hb(a);j[114626]=0;L(1164,a|0,b|0,c|0,d+4|0);a=j[114626];j[114626]=0;if((a|0)!=1){ub(d);Za=e+16|0;return}a=D()|0;C()|0;ub(d);G(a|0);z()}function _X(a,b,c){var d=0,e=0,f=0;e=Za-16|0;Za=e;d=lq(a);a:{if(d>>>0>=c>>>0){d=zb(a);ZX(d,b,c);j[e+12>>2]=0;ze(d+(c<<2)|0,e+12|0);Ag(a,c);break a}f=a;a=nb(a);XB(f,d,c-d|0,a,0,a,c,b)}Za=e+16|0}function YJa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(519,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function YE(a,b){var c=0,d=0,e=0,f=q(0),g=q(0),h=0;if((b|0)>=1){h=a+2304|0;while(1){c=d<<2;e=c+a|0;c=c+h|0;f=n[c>>2];g=n[e>>2];n[e>>2]=f+g;n[c>>2]=g-f;d=d+1|0;if((d|0)!=(b|0)){continue}break}}}function Xea(a,b,c){a=a|0;b=b|0;c=q(c);var d=0;d=Za-16|0;Za=d;n[d+12>>2]=c;if((b|0)<=1){Kd(d+12|0,q(0));c=n[d+12>>2];if((b|0)==1){c=Sd(c);n[d+12>>2]=c}n[((b<<2)+a|0)+4208>>2]=c;YG(a)}Za=d+16|0}function VLa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(416,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Pu(a,b,c,d){var e=0;e=Za-16|0;Za=e;j[e+12>>2]=d;d=ch(e+8|0,e+12|0);j[114626]=0;a=Cj(a,b,c);b=j[114626];j[114626]=0;if((b|0)!=1){pe(d);Za=e+16|0;return a}a=D()|0;C()|0;pe(d);G(a|0);z()}function Psa(a,b){var c=0,d=0;c=Osa(a,b);j[114626]=0;E(4,a+12|0,b+12|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){j[a+24>>2]=j[b+24>>2];i[a+28>>1]=l[b+28>>1];return}a=D()|0;C()|0;ff(c);G(a|0);z()}function OQ(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=oS(b)}j[a>>2]=f;c=(c<<4)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<4)+f|0,j[g>>2]=h;Za=e+16|0;return a}function OIa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(567,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function ODa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(770,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Nra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(fu(a)>>>0<b>>>0){Jc();z()}hb(a);c=b;if(c>>>0>536870911){oc(20113);z()}c=$b(c<<3,8);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=c+(b<<3)|0,j[d>>2]=e;eu(a,0)}function NHa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(607,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function ML(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=OL(b)}j[a>>2]=f;c=(c<<5)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<5)+f|0,j[g>>2]=h;Za=e+16|0;return a}function KP(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=MP(b)}j[a>>2]=f;c=p(c,6)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=p(b,6)+f|0,j[g>>2]=h;Za=e+16|0;return a}function JZ(a,b,c,d){var e=0;e=Za-16|0;Za=e;j[e+12>>2]=d;d=ch(e+8|0,e+12|0);j[114626]=0;a=oD(a,b,c);b=j[114626];j[114626]=0;if((b|0)!=1){pe(d);Za=e+16|0;return a}a=D()|0;C()|0;pe(d);G(a|0);z()}function JJa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(530,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function EAa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(918,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Dra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(dq(a)>>>0<b>>>0){Jc();z()}hb(a);c=b;if(c>>>0>268435455){oc(20113);z()}c=$b(c<<4,8);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=c+(b<<4)|0,j[d>>2]=e;Ml(a,0)}function Ct(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=YS(b)}j[a>>2]=f;c=(c<<1)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<1)+f|0,j[g>>2]=h;Za=e+16|0;return a}function B8(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(2193,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Aw(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-16|0;Za=e;j[e+12>>2]=0;Bc(a+12|0,d);if(b){f=VH(b)}j[a>>2]=f;c=(c<<2)+f|0;j[a+8>>2]=c;j[a+4>>2]=c;g=Ob(a),h=(b<<2)+f|0,j[g>>2]=h;Za=e+16|0;return a}function $ya(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(979,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function y4(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(203,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function vaa(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;f=j[b+12>>2];j[e+8>>2]=j[b+8>>2];j[e+12>>2]=f;f=j[b+4>>2];j[e>>2]=j[b>>2];j[e+4>>2]=f;taa(a,e,c);n[a+28>>2]=d;j[a>>2]=84024;Za=e+16|0;return a}function ufa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=lg(4268);if(!d){return 0}j[114626]=0;a=P(1848,d|0,a|0,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Cb(d);G(a|0);z()}function saa(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;f=j[b+12>>2];j[e+8>>2]=j[b+8>>2];j[e+12>>2]=f;f=j[b+4>>2];j[e>>2]=j[b>>2];j[e+4>>2]=f;raa(a,e,c);n[a+28>>2]=d;j[a>>2]=84128;Za=e+16|0;return a}function rU(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(345,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function n1(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(207,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function jfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=lg(4296);if(!d){return 0}j[114626]=0;a=P(1872,d|0,a|0,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Cb(d);G(a|0);z()}function iea(a,b,c,d){var e=0,f=0,g=0;if(d){while(1){e=g<<3;f=e+a|0;j[f>>2]=j[f>>2]+p(j[b+e>>2]>>4,c);e=e|4;f=e+a|0;j[f>>2]=j[f>>2]+p(j[b+e>>2]>>4,c);g=g+1|0;if((g|0)!=(d|0)){continue}break}}}function h1(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(208,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=lg(4304);if(!d){return 0}j[114626]=0;a=P(1693,d|0,a|0,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Cb(d);G(a|0);z()}function VT(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[114626]=0;j[b+12>>2]=0;K(356,a+8|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Tha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=lg(4268);if(!d){return 0}j[114626]=0;a=P(1630,d|0,a|0,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Cb(d);G(a|0);z()}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=lg(5048);if(!d){return 0}j[114626]=0;a=P(1908,d|0,a|0,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Cb(d);G(a|0);z()}function Ofa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=lg(4280);if(!d){return 0}j[114626]=0;a=P(1801,d|0,a|0,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Cb(d);G(a|0);z()}function NV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(fu(a)>>>0<b>>>0){Jc();z()}hb(a);c=b;if(c>>>0>536870911){oc(11120);z()}c=$b(c<<3,1);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=c+(b<<3)|0,j[d>>2]=e;eu(a,0)}function I5(a){var b=0,c=0,d=0;b=Za-16|0;Za=b;zc(b+8|0,a+116|0);j[114626]=0;c=Ba(198,a|0)|0;a=C()|0;c=c|0;d=j[114626];j[114626]=0;if((d|0)!=1){Za=b+16|0;ab=a;return c}a=D()|0;C()|0;G(a|0);z()}function G4(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=a;b=j[a+112>>2];if((b|0)>=11){e=a;b=378;while(1){uE(e);c=f-(b>>>0<1)|0;b=b-1|0;f=c;if(b|c){continue}break}b=0}j[d+112>>2]=b+1;a=uE(a);return a|0}function Eg(a,b){var c=0,d=0;a=j[a>>2];b=sd(b);c=b;d=a+16|0;if(sb(d)>>>0>b>>>0){c=j[xb(d,c)>>2]!=0}else{c=0}if(!c){a=R(4)|0;pm(a);j[a>>2]=71820;Y(a|0,71880,2556);z()}return j[xb(a+16|0,b)>>2]}function Cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=lg(4276);if(!d){return 0}j[114626]=0;a=P(1825,d|0,a|0,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Cb(d);G(a|0);z()}function Cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=lg(4276);if(!d){return 0}j[114626]=0;a=P(1935,d|0,a|0,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Cb(d);G(a|0);z()}function $fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=lg(4296);if(!d){return 0}j[114626]=0;a=P(1768,d|0,a|0,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Cb(d);G(a|0);z()}function $ea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=lg(4228);if(!d){return 0}j[114626]=0;a=P(1885,d|0,a|0,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Cb(d);G(a|0);z()}function mma(a){var b=0,c=0,d=0,e=0,f=0;a:{b=j[a+656>>2];c=h[b+26|0];if(!c){break a}d=k[a+819|0];if(!d){break a}e=a,f=Gb(j[a+684>>2]+((p((k[b+27|0]^-1)+d|0,c)|0)/2|0)|0,0,256),j[e+684>>2]=f}}function ii(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=0;a=xk(a,c+12|0,4);j[c+8>>2]=j[c+12>>2];d=b;b=c+8|0;j[d>>2]=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);Za=c+16|0;return!ab&(a|0)==4}function go(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;d=c,e=ud(b),j[d+12>>2]=e;j[114626]=0;K(1995,a|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function fo(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;d=c,e=ud(b),j[d+12>>2]=e;j[114626]=0;K(2154,a|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function ex(a,b){var c=0;Jma(a,b);h[a+12|0]=k[b+12|0];c=k[b+13|0]|k[b+14|0]<<8|(k[b+15|0]<<16|k[b+16|0]<<24);h[a+13|0]=c;h[a+14|0]=c>>>8;h[a+15|0]=c>>>16;h[a+16|0]=c>>>24;h[a+17|0]=k[b+17|0]}function OFa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Za-32|0;Za=e;a=a+4|0;g=e,h=Lb(a),j[g+24>>2]=h;f=$e(e+24|0,c);g=e,h=Lb(a),j[g+8>>2]=h;g=e,h=$e(e+8|0,c),j[g+16>>2]=h;aj(f,$e(e+16|0,d),b);Za=e+32|0}function NP(a,b,c){a=a|0;b=b|0;c=c|0;a=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);h[b|0]=a;h[b+1|0]=a>>>8;h[b+2|0]=a>>>16;h[b+3|0]=a>>>24;a=k[c+4|0]|k[c+5|0]<<8;h[b+4|0]=a;h[b+5|0]=a>>>8}function NA(a){if(!((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=808603728|(k[a+4|0]-9&255)>>>0>6|((k[a+5|0]-9&255)>>>0>6|(k[a+6|0]-9&255)>>>0>6))){return(k[a+7|0]-9&255)>>>0<7}return 0}function Mf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-16|0;Za=d;c=a;a:{if(!qe(b)){j[c+8>>2]=j[b+8>>2];e=j[b+4>>2];j[c>>2]=j[b>>2];j[c+4>>2]=e;break a}Wo(a,j[b>>2],j[b+4>>2])}Za=d+16|0;return a|0}function CDa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za+ -64|0;Za=d;c=d+8|0;e=VCa(a,c);if(!e){aP(c)}c=-1;a:{if(!e){break a}c=0;if(!oP(d+8|0)){break a}c=Le(a,b,nP(d+8|0),ab)}Za=d- -64|0;return c|0}function qd(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;c=Za-16|0;Za=c;d=j[a>>2];e=a,f=(h=d,i=j[a+8>>2],k=Kb(c+8|0,b),g=j[j[d>>2]+32>>2],bb[g](h|0,i|0,k|0)|0)+j[a+8>>2]|0,j[e+8>>2]=f;Za=c+16|0}function k3(){var a=0,b=0;a=Za-16|0;Za=a;b=R(16)|0;a=j3(a+8|0);j[114626]=0;K(2330,b|0,56208,a|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Y(b|0,56280,2331);z()}a=D()|0;C()|0;S(b|0);G(a|0);z()}function hp(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;d=c,e=ud(b),j[d+12>>2]=e;j[114626]=0;K(724,a|0,c+12|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function N6(a,b){var c=0;a:{c=ne(a);if((c|0)==(nb(b)|0)){j[114626]=0;a=U(344,b|0,0,-1,a|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}a=J(0)|0;C()|0;ib(a);z()}function Maa(a,b){var c=0;c=Za-48|0;Za=c;a:{if((b|0)==-1){Wk(a,j[Uo(c+8|0)+32>>2]);Km(a,j[Uo(c+8|0)+36>>2]);break a}if((b|0)<=0){Wk(a,0);Km(a,0);break a}b=p(b,1e3);Wk(a,b);Km(a,b)}Za=c+48|0}function Dd(a,b){var c=0;a:{c=ne(b);if((c|0)==(nb(a)|0)){j[114626]=0;a=U(344,a|0,0,-1,b|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}a=J(0)|0;C()|0;ib(a);z()}function CM(a){var b=0,c=0;a:{b:{b=a&240;if((b|0)!=192){if((b|0)==240){break b}c=3;if((b|0)!=208){break a}}c=2;break a}c=1;a=a+15&255;if(a>>>0>2){break a}return 131842>>>(a<<3)&255}return c}function zD(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:h[a|0]=c;return;case 1:i[a>>1]=c;return;case 2:case 3:j[a>>2]=c;return;case 5:break b;default:break a}}j[a>>2]=c;j[a+4>>2]=d}}function xHa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-112|0;Za=d;c=d+8|0;e=tHa(a,c);if(!e){JQ(c)}c=-1;a:{if(!e){break a}c=0;if(!MQ(d+8|0)){break a}c=Le(a,b,LQ(d+8|0),ab)}Za=d+112|0;return c|0}function iV(a){a=a|0;var b=0,c=0;b=Za-16|0;Za=b;Bn(a);j[a>>2]=77216;j[114626]=0;K(281,a+12|0,b+8|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a|0}a=D()|0;C()|0;G(a|0);z()}function hU(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-48|0;Za=c;d=-1;a:{if(!KA(a,c+8|0)){break a}d=0;if(!FA(c+8|0)){break a}if(b){if(!gU(c+8|0,j[b>>2],j[b+4>>2])){break a}}d=1}Za=c+48|0;return d|0}function bla(a,b){a=a|0;b=b|0;var c=0;b=Za-16|0;Za=b;c=-1;a:{if(!hj(a,b+8|0)){break a}c=0;if(!KI(b+8|0)){break a}c=b;a=aN(a,b);if(!a){TP(c)}c=-1;if(!a){break a}c=JI(b)}Za=b+16|0;return c|0}function VHa(a,b){var c=0,d=0;d=Za-16|0;Za=d;a:{if((a|0)==(b|0)){break a}c=a+4|0;if((c|0)==(b|0)){break a}while(1){a=rd(c,a)?c:a;c=c+4|0;if((c|0)!=(b|0)){continue}break}}Za=d+16|0;return a}function PC(a,b,c,d){var e=0;e=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=e;e=j[b+12>>2];j[a+8>>2]=j[b+8>>2];j[a+12>>2]=e;b=j[a+8>>2];d=j[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;j[a+8>>2]=b-c;j[a+12>>2]=d}function Iy(a,b){var c=0;a:{if(b){Iy(a,j[b>>2]);Iy(a,j[b+4>>2]);a=Rb(a);j[114626]=0;F(821,a|0,b+14|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}zi(a,b,1)}return}a=J(0)|0;C()|0;ib(a);z()}function Fha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=j[b>>2];a:{if((Xg(b)|0)!=8){break a}d=c;if((k[d|0]|k[d+1|0]<<8|(k[d+2|0]<<16|k[d+3|0]<<24))!=1869112133){break a}Vb(a+4260|0,c,Xg(b));Ar(a)}}function FMa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-512|0;Za=d;c=d+8|0;e=AMa(a,c);if(!e){aT(c)}c=-1;a:{if(!e){break a}c=0;if(!fT(d+8|0)){break a}c=Le(a,b,eT(d+8|0),ab)}Za=d+512|0;return c|0}function Aha(a,b,c){a=a|0;b=b|0;c=q(c);var d=0,e=0,f=q(0);d=Za-16|0;Za=d;e=d,f=q(q(bb[j[j[a>>2]+48>>2]](a,b))+c),n[e+12>>2]=f;Kd(d+12|0,q(0));bb[j[j[a>>2]+44>>2]](a,b,n[d+12>>2]);Za=d+16|0}function $Ca(a,b){var c=0,d=0;d=Za-16|0;Za=d;a:{if((a|0)==(b|0)){break a}c=a+8|0;if((c|0)==(b|0)){break a}while(1){a=_z(a,c)?c:a;c=c+8|0;if((c|0)!=(b|0)){continue}break}}Za=d+16|0;return a}function w0(a,b,c,d){var e=0;e=Za-16|0;Za=e;j[e+8>>2]=b;while(1){a:{if(!Tn(a,e+8|0)){break a}if(!ng(d,8192,Bj(a))){break a}Ik(a);continue}break}if(Ii(a,e+8|0)){j[c>>2]=j[c>>2]|2}Za=e+16|0}function r0(a,b,c,d){var e=0;e=Za-16|0;Za=e;j[e+8>>2]=b;b=6;a:{b:{if(Ii(a,e+8|0)){break b}b=4;if((Vl(d,Bj(a))|0)!=37){break b}b=2;if(!Ii(Ik(a),e+8|0)){break a}}j[c>>2]=j[c>>2]|b}Za=e+16|0}function oG(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){if(N6(j[a>>2],j[d+8>>2])){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}Za=d+16|0;return a}function i_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}b:{if(m[c>>2]>127){break b}if(!(l[Mn()+(j[c>>2]<<1)>>1]&b)){break b}c=c+4|0;continue}break}d=c}return d|0}function cV(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;d=c,e=ud(b),j[d+12>>2]=e;j[114626]=0;K(282,a|0,c+12|0,b|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function c0(a,b,c,d){var e=0;e=Za-16|0;Za=e;j[e+8>>2]=b;while(1){a:{if(!Hq(a,e+8|0)){break a}if(!zj(d,8192,Gk(a))){break a}cm(a);continue}break}if(yj(a,e+8|0)){j[c>>2]=j[c>>2]|2}Za=e+16|0}function Z$(a,b,c,d){var e=0;e=Za-16|0;Za=e;j[e+8>>2]=b;b=6;a:{b:{if(yj(a,e+8|0)){break b}b=4;if((Tl(d,Gk(a))|0)!=37){break b}b=2;if(!yj(cm(a),e+8|0)){break a}}j[c>>2]=j[c>>2]|b}Za=e+16|0}function Pv(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+p(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((p(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function Dya(a,b){var c=0;mN(a,b);mN(a+12|0,b+12|0);hy(a+24|0,b+24|0);i[a+52>>1]=l[b+52>>1];c=j[b+48>>2];j[a+44>>2]=j[b+44>>2];j[a+48>>2]=c;c=j[b+40>>2];j[a+36>>2]=j[b+36>>2];j[a+40>>2]=c}function oMa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-48|0;Za=d;c=d+8|0;e=PLa(a,c);if(!e){CS(c)}c=-1;a:{if(!e){break a}c=0;if(!WS(d+8|0)){break a}c=Le(a,b,VS(d+8|0),ab)}Za=d+48|0;return c|0}function k_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;while(1){if((b|0)!=(c|0)){a=d;if(m[b>>2]<=127){e=l[Mn()+(j[b>>2]<<1)>>1]}else{e=0}i[a>>1]=e;d=d+2|0;b=b+4|0;continue}break}return c|0}function bX(a){var b=0;b=k[a+74|0];h[a+74|0]=b-1|b;b=j[a>>2];if(b&8){j[a>>2]=b|32;return-1}j[a+4>>2]=0;j[a+8>>2]=0;b=j[a+44>>2];j[a+28>>2]=b;j[a+20>>2]=b;j[a+16>>2]=b+j[a+48>>2];return 0}function HMa(a){var b=0;b=k[a+15|0];h[a+15|0]=0;h[a+60|0]=b>>>1&2|b<<1&4|(k[a+60|0]&240|b&1);h[a+80|0]=b>>>4&2|b>>>2&4|(k[a+80|0]&240|b>>>3&1);h[a+100|0]=b>>>5&4|(k[a+100|0]&224|b>>>6&1)}function Ega(a){var b=0,c=0,d=0,e=0;b=Za-16|0;Za=b;if(Te(a)){while(1){d=xl(a,c);e=xl(a,c);j[b+12>>2]=0;sga(d,(e+2048|0)-d>>2,b+12|0);c=c+1|0;if(Te(a)>>>0>c>>>0){continue}break}}Za=b+16|0}function yla(a){var b=0,c=0,d=0,e=0;d=vt(a);b=d&63;a:{if(!(d&64)){break a}c=6;while(1){e=vt(a);b=(e&127)<<c|b;if(c>>>0>24){break a}c=c+7|0;if(e&128){continue}break}}return d&128?0-b|0:b}function yk(a){var b=0,c=0;b=j[21345];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?(c|0)>=1:0){break a}if(a>>>0>aNa()<<16>>>0){if(!(Ea(a|0)|0)){break a}}j[21345]=a;return b}j[114600]=48;return-1}function x5(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;f=0;a:{if(!v5(a,c,e+8|0,d,e+4|0,e+12|0)){break a}f=u5(a,b,(p(j[e+12>>2],6)+a|0)+412|0,j[c>>2],j[d>>2],j[e+4>>2],c)}a=f;Za=e+16|0;return a}function Tra(a){var b=0,c=0,d=0;b=Qra(a)<<24;a=0;while(1){d=b<<1|c>>>31;c=c<<1;b=(b|0)>-1;c=b?c:c^-1798752855;b=b?d:d^-1382821323;a=a+1|0;if((a|0)!=8){continue}break}a=Lra(c,b);return a}function Tk(a,b){var c=0,d=q(0),e=0;e=i[a+28>>1];c=a+4|0;sb(c);d=q(1);a:{if((b|0)<(e|0)){break a}if((l[a+28>>1]+sb(c)<<16)-65536>>16<(b|0)){break a}d=n[xb(c,b-i[a+28>>1]|0)>>2]}return d}function Mh(a,b){var c=0,d=0;c=k[a|0];d=k[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=k[b+1|0];c=k[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function Kda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=Za-16|0;Za=f;j[f+8>>2]=j[a+8>>2];g=j[a+4>>2];j[f>>2]=j[a>>2];j[f+4>>2]=g;a=BG(f,b,c,d,0,0,0,0,e);Za=f+16|0;return a|0}function Fda(a,b){var c=0,d=0,e=0;c=Za-32|0;Za=c;d=c,e=Cba(a,b),j[d+24>>2]=e;d=c,e=_i(a),j[d+16>>2]=e;b=0;if(!al(c+24|0,c+16|0)){Bba(a,j[zc(c+8|0,j[c+24>>2])>>2]);b=1}Za=c+32|0;return b}function AX(){var a=0;j[114626]=0;a=j[114626];j[114626]=0;a:{if((a|0)!=1){a=j[115933];if(!a){break a}if(!OB(a+48|0)){break a}NB(j[a+12>>2]);z()}a=J(0)|0;C()|0;ib(a);z()}NB(j[21343]);z()}function zKa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-1968|0;Za=d;c=d+8|0;e=wKa(a,c);if(!e){PR(c)}c=-1;a:{if(!e){break a}c=0;if(!TR(d+8|0)){break a}c=Le(a,b,1024,0)}Za=d+1968|0;return c|0}function voa(a,b){var c=0,d=0,e=0;if(wR(a)>>>0<b>>>0){Jc();z()}hb(a);c=b;if(c>>>0>178956970){oc(20384);z()}c=$b(p(c,24),8);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=c+p(b,24)|0,j[d>>2]=e;pt(a,0)}function tDa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-16|0;Za=c;j[c+8>>2]=b;d=c,e=Lb(a),j[d>>2]=e;b=Ms(c+8|0,c);b=j[a>>2]+(b<<2)|0;Pt(a,Pe(b+4|0,j[a+4>>2],b));a=Qe(b);Za=c+16|0;return a|0}function mh(a){var b=0,c=0,d=0,e=0;d=dd(a);b=d&63;a:{if(!(d&64)){break a}c=6;while(1){e=dd(a);b=(e&127)<<c|b;if(c>>>0>24){break a}c=c+7|0;if(e&128){continue}break}}return d&128?0-b|0:b}function W5(a,b,c){var d=0,e=0,f=0;while(1){f=d;d=a+d|0;d=(f+Lv(d,c)|0)+ao(d)|0;if((d+4|0)>(b|0)){return(e|0)!=0}if(!bo(a,a+d|0)){return 0}e=e+1|0;if((e|0)!=10){continue}break}return 1}function RU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-32|0;Za=d;j[d+24>>2]=b;Yp(j[d+24>>2]);j[d+16>>2]=j[c+8>>2];b=j[c+4>>2];j[d+8>>2]=j[c>>2];j[d+12>>2]=b;QU(a,d+8|0);Za=d+32|0;return a|0}function JG(a,b){var c=0,d=0,e=0;if(a>q(.9999989867210388)){d=0}else{a=q(a*a);e=+a;c=ge(31415.926535897932/+b);d=Mm((32768-(y((1-c)*+q(a+a)+(c*c-1)*+q(a*a))+c*e)*32768)/(1-e))}return d}function $qa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(k[b+30|0]!=4){break a}d=b+31|0;if(k[d|0]&4|k[d|0]&2){break a}Mc(a,8,1,0,11);return}d=a;a=b+31|0;Mc(d,k[a|0]&4?16:8,k[a|0]&2|1,0,c^1)}function qv(a,b,c,d,e){var f=0;f=rv(a,b,c,d);if(rd(e,d)){Hb(d,e);if(!rd(d,c)){return f+1|0}Hb(c,d);if(!rd(c,b)){return f+2|0}Hb(b,c);if(!rd(b,a)){return f+3|0}Hb(a,b);f=f+4|0}return f}function qha(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=mha(a);if(d>>>0<=b>>>0){a=Hj(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function p5(a){a=a|0;var b=0,c=0;b=Za-16|0;Za=b;Ni(b,0,a);j[114626]=0;a=H(202,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){gb(b);Za=b+16|0;return a|0}a=D()|0;C()|0;gb(b);G(a|0);z()}



function j3(a){var b=0,c=0;b=Za-16|0;Za=b;a:{if(h[458512]&1){break a}if(!fd(458512)){break a}ed(458512)}Cc(b+8|0,1,85064);c=j[b+12>>2];j[a>>2]=j[b+8>>2];j[a+4>>2]=c;Za=b+16|0;return a}function gEa(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=aEa(a);if(d>>>0<=b>>>0){a=jl(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function fv(a,b,c,d,e,f,g,h,i){var k=0;k=Za-16|0;Za=k;Gf(k,b,c,d,e,f,g,h,i^-2147483648);b=j[k+4>>2];j[a>>2]=j[k>>2];j[a+4>>2]=b;b=j[k+12>>2];j[a+8>>2]=j[k+8>>2];j[a+12>>2]=b;Za=k+16|0}function _p(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=j[a>>2];b=(f=d,g=lb(b),h=j[a+8>>2],i=c,e=j[j[d>>2]+28>>2],bb[e](f|0,g|0,h|0,i|0)|0);j[a+8>>2]=b+j[a+8>>2];return b|0}function Sxa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Gxa(a);a:{if(b){j[114626]=0;F(1012,a|0,b|0);d=j[114626];j[114626]=0;if((d|0)==1){break a}Exa(a,b)}return a|0}a=D()|0;C()|0;cy(c);G(a|0);z()}function Lya(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=Fya(a);if(d>>>0<=b>>>0){a=Tm(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function s8(a,b){var c=0,d=0;c=Za-32|0;Za=c;j[c+24>>2]=b;b=j[c+24>>2];d=j[b+12>>2];j[c+16>>2]=j[b+8>>2];j[c+20>>2]=d;d=j[b+4>>2];j[c+8>>2]=j[b>>2];j[c+12>>2]=d;UEa(a,c+8|0);Za=c+32|0}function n8(a,b){var c=0,d=0;c=Za-32|0;Za=c;j[c+24>>2]=b;b=j[c+24>>2];d=j[b+12>>2];j[c+16>>2]=j[b+8>>2];j[c+20>>2]=d;d=j[b+4>>2];j[c+8>>2]=j[b>>2];j[c+12>>2]=d;CEa(a,c+8|0);Za=c+32|0}function mAa(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=fu(a);if(d>>>0<=b>>>0){a=wi(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function _Q(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=AIa(a);if(d>>>0<=b>>>0){a=nl(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function TEa(a,b,c){var d=0,e=0;d=Za-16|0;Za=d;e=Qc(d);j[114626]=0;P(694,b|0,a|0,e|0,c|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){gb(e);Za=d+16|0;return}a=D()|0;C()|0;gb(e);G(a|0);z()}function P5(a){var b=0,c=0,d=0;c=a+72|0;while(1){a=1;while(1){b=(a<<2)+c|0;n[b>>2]=-n[b>>2];b=a>>>0<16;a=a+2|0;if(b){continue}break}c=c+144|0;a=d>>>0<30;d=d+2|0;if(a){continue}break}}function zY(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=iC(a);if(d>>>0<=b>>>0){a=Bk(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function ql(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=$R(a);if(d>>>0<=b>>>0){a=Af(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function oI(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=kI(a);if(d>>>0<=b>>>0){a=Mi(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function ie(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=Jm(a);if(d>>>0<=b>>>0){a=jd(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function gk(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=wR(a);if(d>>>0<=b>>>0){a=Ce(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function fma(a,b,c,d){var e=0,f=0;ema(a,b,d);if((b|0)!=(c|0)){f=b-a>>1;e=b;while(1){if(no(d,l[e>>1],l[a>>1])){ZI(e,a);Ww(a,d,f,a)}e=e+2|0;if((e|0)!=(c|0)){continue}break}}dma(a,b,d)}function eq(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=dq(a);if(d>>>0<=b>>>0){a=Ah(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function ej(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=St(a);if(d>>>0<=b>>>0){a=Pf(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function ZY(){var a=0;a:{if(h[463096]&1){break a}if(!fd(463096)){break a}a=463072;while(1){a=Db(a)+12|0;if((a|0)!=463096){continue}break}ed(463096)}vc(463072,68248);vc(463084,68251)}function Yga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Za-16|0;Za=c;a=Ki(a);d=1;a:{if(!a){break a}d=(f=a,g=bh(c+8|0,b),e=j[j[a>>2]+72>>2],bb[e](f|0,g|0)|0)}a=d;Za=c+16|0;return a|0}function WY(){var a=0;a:{if(h[463128]&1){break a}if(!fd(463128)){break a}a=463104;while(1){a=Me(a)+12|0;if((a|0)!=463128){continue}break}ed(463128)}Kc(463104,68256);Kc(463116,68268)}function Sy(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=vz(a);if(d>>>0<=b>>>0){a=mi(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function Sn(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=SK(a);if(d>>>0<=b>>>0){a=Hf(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function SKa(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;d=yb(a,120);a:{if(d){e=Za-16|0;Za=e;Qb(c+8|0,b,120);Za=e+16|0;qd(a,c+8|0);break a}a=Za-16|0;Za=a;AKa(b);Za=a+16|0}Za=c+16|0;return d}function NDa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;c=0;a=bb[j[j[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){j[d+8>>2]=a-b;c=j[tb(d+12|0,d+8|0)>>2]}Za=d+16|0;return c|0}function Ita(a,b){var c=0;a:{if(k[a+4|0]){c=j[a>>2];j[114626]=0;F(821,c|0,b+14|0);c=j[114626];j[114626]=0;if((c|0)==1){break a}}if(b){zi(j[a>>2],b,1)}return}a=J(0)|0;C()|0;ib(a);z()}function Fxa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(lxa()>>>0<b>>>0){Jc();z()}c=b;if(c>>>0>=477218589){oc(17388);z()}c=$b(p(c,9),1);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=c+p(b,9)|0,j[d>>2]=e}function FG(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=Za-16|0;Za=f;j[f+8>>2]=j[a+8>>2];g=j[a+4>>2];j[f>>2]=j[a>>2];j[f+4>>2]=g;c=EG(f,b,c,d,e,0,0,0,0);Za=f+16|0;return+c}function El(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=b;b=YA(a);if(d>>>0<=b>>>0){a=_g(a);if(a>>>0<b>>>1>>>0){j[c+8>>2]=a<<1;b=j[Gc(c+8|0,c+12|0)>>2]}Za=c+16|0;return b}Jc();z()}function $ma(a){a=a|0;var b=0;b=1;a=j[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function zGa(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;j[c+24>>2]=0;j[c+28>>2]=0;j[c+16>>2]=0;j[c+20>>2]=0;j[c+8>>2]=0;j[c+12>>2]=0;j[c>>2]=0;j[c+4>>2]=0;lQ(b,c,32);kQ(a,c);Za=c+32|0}function zAa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,1030);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function uI(a,b){var c=0,d=0;d=a;c=b;if((a|0)!=(b|0)){fka(d,j[c>>2],j[c+4>>2])}j[a+12>>2]=j[b+12>>2];j[a+16>>2]=j[b+16>>2];j[a+20>>2]=j[b+20>>2];tI(a+24|0,b+24|0);yi(a+36|0,b+36|0)}function k8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){a=j[d>>2];while(1){j[a>>2]=j[b>>2];Mf(a+4|0,b+4|0);a=j[d>>2]+16|0;j[d>>2]=a;b=b+16|0;if((c|0)!=(b|0)){continue}break}}}function WU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-32|0;Za=e;j[e+24>>2]=d;j[e+28>>2]=c;VU(e+8|0,b,e+28|0,e+24|0);au(e+16|0,e+8|0);Gl(a,e+16|0);jb(e+16|0);jb(e+8|0);Za=e+32|0}function QGa(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;ys(c,b);j[114626]=0;I(647,a|0,4,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(c);Za=c+16|0;return}a=D()|0;C()|0;gb(c);G(a|0);z()}function LB(a,b,c,d){var e=0,f=0,g=0,h=0;f=j[a+4>>2];a=j[a>>2];g=a;h=b;e=0;a:{if(!c){break a}b=f>>8;e=b;if(!(f&1)){break a}e=j[b+j[c>>2]>>2]}bb[j[j[a>>2]+28>>2]](g,h,e+c|0,f&2?d:2)}function JI(a){var b=0;a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=1179012417){b=0;if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=538987841){break a}}b=1}return b}function zG(a){a=a|0;var b=0;a:{if(!a){a=R(8)|0;j[114626]=0;H(2009,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break a}b=D()|0;C()|0;S(a|0);G(b|0);z()}return}Y(a|0,83516,2010);z()}function xka(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,225);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function xAa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,274);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function wka(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,326);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function vAa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,106);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function sFa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,554);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function rHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,771);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function gw(a){a=a|0;var b=0;a:{if(!a){a=R(8)|0;j[114626]=0;H(2021,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){break a}b=D()|0;C()|0;S(a|0);G(b|0);z()}return}Y(a|0,83528,2010);z()}function Y$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=Za-128|0;Za=c;j[c+12>>2]=c+116;_C(a+8|0,c+16|0,c+12|0,e,f,g);a=qY(c+16|0,j[c+12>>2],b);Za=c+128|0;return a|0}function X$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=Za-416|0;Za=c;j[c+12>>2]=c+416;W$(a+8|0,c+16|0,c+12|0,e,f,g);a=pY(c+16|0,j[c+12>>2],b);Za=c+416|0;return a|0}function WCa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,284);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function UQ(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;h[a+11|0]=0;Za=b+16|0}function QBa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,422);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function PJa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,136);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function NBa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,826);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function $Ga(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,384);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function yka(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,73);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function xMa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,25);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function vka(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,60);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function uAa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,72);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function ty(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Za-16|0;Za=c;d=a,e=(g=a,h=j[a+12>>2],i=Kb(c+8|0,b),f=j[j[a>>2]+32>>2],bb[f](g|0,h|0,i|0)|0)+j[a+12>>2]|0,j[d+12>>2]=e;Za=c+16|0}function rAa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,26);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function o5(){var a=0,b=0,c=0;while(1){b=a<<24;c=0;while(1){b=b>>31&79764919^b<<1;c=c+1|0;if((c|0)!=8){continue}break}j[(a<<2)+457376>>2]=b;a=a+1|0;if((a|0)!=256){continue}break}}function kHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,62);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function exa(a,b){var c=0;c=Bs(a);h[a+16|0]=0;i[a+14>>1]=0;i[a+12>>1]=b;j[114626]=0;I(1024,c|0,b|0,0);b=j[114626];j[114626]=0;if((b|0)!=1){return a}a=D()|0;C()|0;Vd(c);G(a|0);z()}function YR(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+7|0]=0;h[a+8|0]=0;h[a+9|0]=0;h[a+10|0]=0;Za=b+16|0}function NLa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,37);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function IHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,15);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function HKa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,17);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function HDa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,91);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function GHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,34);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function FDa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,18);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function FCa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,42);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function EJa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,50);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function Aza(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,71);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function uY(a,b){var c=0;a:{while(1){if(j[a+8>>2]==(b|0)){break a}j[a+8>>2]=j[a+8>>2]-4;j[114626]=0;c=j[114626];j[114626]=0;if((c|0)!=1){continue}break}a=J(0)|0;C()|0;ib(a);z()}}function oBa(a,b){var c=0,d=0;c=Za-16|0;Za=c;if(qe(a)){Yf(a,j[a>>2],Lj(a))}j[a+8>>2]=j[b+8>>2];d=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=d;Ue(b,0);h[c+15|0]=0;Td(b,c+15|0);Za=c+16|0}function o3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-16|0;Za=d;e=j[c+4>>2];c=j[c>>2];j[d>>2]=c;j[d+4>>2]=e;j[d+8>>2]=c;j[d+12>>2]=e;RB(a,d,b);j[a>>2]=56180;Za=d+16|0;return a|0}function j_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){if(m[c>>2]>127){break a}if(!(l[Mn()+(j[c>>2]<<1)>>1]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function hya(a){var b=0,c=0;b=Za-16|0;Za=b;if(aN(a,b+8|0)){a=b+8|0;a=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);c=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}Za=b+16|0;return c}function aV(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;Qb(c+8|0,b,20);Za=d+16|0;b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function Rw(a,b){a:{if(b){Rw(a,j[b>>2]);Rw(a,j[b+4>>2]);a=Rb(a);j[114626]=0;F(1518,a|0,b+16|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}QI(b)}return}a=J(0)|0;C()|0;ib(a);z()}function PN(a){var b=0;a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=441273424|k[a+5|0]!=16){break a}b=a+54|0;if(!k[b|0]|k[b|0]>32){break a}return k[a+4|0]>95}return 0}function J0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Za-16|0;Za=g;j[g+8>>2]=624576549;j[g+12>>2]=1394948685;a=Fi(a,b,c,d,e,f,g+8|0,g+16|0);Za=g+16|0;return a|0}function Ej(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){if(E8(d+8|0,a)){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}Za=d+16|0;return a}function yya(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-608|0;Za=d;c=d;e=tya(a,d);if(!e){hN(c)}c=-1;a:{if(!e){break a}c=0;if(!jN(d)){break a}c=Le(a,b,iN(d),ab)}Za=d+608|0;return c|0}function uCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Za-16|0;Za=d;e=MO(d,b);b=Za-16|0;Za=b;RBa(d+8|0,MO(b,e));Za=b+16|0;lu(a,d+8|0);j[a+12>>2]=c;j[a+8>>2]=0;Za=d+16|0;return a|0}function nta(a,b){a=a|0;b=b|0;var c=0;mta(a);c=a;h[a+16|0]=0;j[a+12>>2]=b;j[114626]=0;N(1169,a|0);b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;js(c);G(a|0);z()}function lFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;Zy(a,b,c);c=0;a=j[a+16>>2];if(a>>>0>b>>>0){j[d+8>>2]=a-b;c=j[tb(d+8|0,d+12|0)>>2]}Za=d+16|0;return c|0}function jv(a,b){var c=0;c=qr(a+4|0);j[a>>2]=56004;j[c>>2]=56024;j[114626]=0;F(2380,j[13998]+a|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=D()|0;C()|0;og(c);G(a|0);z()}function jHa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-576|0;Za=d;c=d;e=bHa(a,d);if(!e){xQ(c)}c=-1;a:{if(!e){break a}c=0;if(!BQ(d)){break a}c=Le(a,b,AQ(d),ab)}Za=d+576|0;return c|0}function iv(a,b){var c=0;c=OD(a+4|0);j[a>>2]=56052;j[c>>2]=56072;j[114626]=0;F(2381,j[14010]+a|0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=D()|0;C()|0;og(c);G(a|0);z()}function cf(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-16|0;Za=c;i[c+14>>1]=0;a=xk(a,c+14|0,2);i[c+12>>1]=l[c+14>>1];d=b;b=c+12|0;i[d>>1]=k[b|0]|k[b+1|0]<<8;Za=c+16|0;return!ab&(a|0)==2}function _5(a,b){var c=0,d=0,e=0,f=0,g=0;d=j[b+8>>2]>>>3|0;e=j[b+4>>2]+7>>>3|0;c=d-e|0;f=(c|0)>511;g=f?511:c;if((c|0)>=1){Bi(a+6156|0,((f?d-511|0:e)+b|0)+12|0,g)}j[a+6144>>2]=g}function UGa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-192|0;Za=d;c=d;e=qFa(a,d);if(!e){UP(c)}c=-1;a:{if(!e){break a}c=0;if(!vQ(d)){break a}c=Le(a,b,uQ(d),ab)}Za=d+192|0;return c|0}function Tza(a,b,c,d){var e=0;e=Za-48|0;Za=e;a:{if(j[b+4>>2]==j[d+4>>2]){Sza(a,vd(e+40|0,b),vd(e+32|0,c),vd(e+24|0,d));break a}Rza(a,vd(e+16|0,b),vd(e+8|0,c),vd(e,d))}Za=e+48|0}function S4(a,b){var c=0,d=0,e=0,f=0;if((a|0)>=8){c=a>>3;c=(c|0)>1?c:1;d=36-Nk(a)|0;a=0;while(1){e=(a<<1)+b|0,f=Lk(a)>>>d<<2,i[e>>1]=f;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function RX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;bb[j[j[a>>2]+12>>2]](d+8|0,a,b);a=d+8|0;if(ce(j[a+4>>2],j[c+4>>2])){a=j[a>>2]==j[c>>2]}else{a=0}Za=d+16|0;return a|0}function Ou(a,b){var c=0,d=0;c=Za-16|0;Za=c;i[b>>1]=0;h[c+15|0]=0;Cg(a,c+15|0);d=k[c+15|0];i[b>>1]=d>>>1;if(d&1){h[c+15|0]=0;Cg(a,c+15|0);i[b>>1]=l[b>>1]|k[c+15|0]<<7}Za=c+16|0}function Dz(a){var b=0,c=0;b=Za-16|0;Za=b;if(Vp(a,b+8|0)){a=b+8|0;a=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);c=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}Za=b+16|0;return c}function vsa(a){var b=0,c=0;b=Za-16|0;Za=b;j[114626]=0;j[b+12>>2]=0;K(1193,a|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function u7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;HF(b,c,d,n[a+24>>2]);AF(a,b,c,d);j[e+8>>2]=j[a+20>>2];b=j[a+16>>2];j[e>>2]=j[a+12>>2];j[e+4>>2]=b;Za=e+16|0}function nI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!tg(a,b)){break a}c=Cw(a,j[te(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=te(a,b);uI(te(a,c),b);d=c}return d|0}function dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Za-16|0;Za=d;e=l[a+28>>1];i[d+8>>1]=e;f=d,g=(sb(a+4|0)+e|0)-1|0,i[f+10>>1]=g;a=bI(a,b,c,d+8|0);Za=d+16|0;return a|0}function Wna(a){var b=0,c=0;b=Za-16|0;Za=b;j[114626]=0;j[b+12>>2]=0;K(1393,a|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Una(a){var b=0,c=0;b=Za-16|0;Za=b;j[114626]=0;j[b+12>>2]=0;K(1394,a|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function K9(a,b){var c=0,d=0,e=0,f=0;c=P6(a,hb(b));j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];d=j[hb(b)>>2];e=hb(c),f=d,j[e>>2]=f;e=hb(b),f=0,j[e>>2]=f;j[b>>2]=0;j[b+4>>2]=0;return a}function C$(a,b){var c=0,d=0;c=Za-16|0;Za=c;if(qe(a)){Kn(j[a>>2],Lj(a))}j[a+8>>2]=j[b+8>>2];d=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=d;Ue(b,0);j[c+12>>2]=0;ze(b,c+12|0);Za=c+16|0}function xea(a){a=a|0;var b=0,c=q(0);h[a+4202|0]=1;b=a,c=Gm(q(q(q(xe(j[a+16>>2])>>>0)*q(20938023226335645e-21))+q(-.005025125574320555)),q(0),q(1)),n[b+4272>>2]=c;SG(a);RG(a)}function mba(a){var b=0,c=0;b=Za-32|0;Za=b;vk(b);c=zg(b);j[114626]=0;I(9,a|0,0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){Je(b);Za=b+32|0;return}a=D()|0;C()|0;Je(b);G(a|0);z()}function dG(a){var b=0,c=0;b=Za-16|0;Za=b;j[114626]=0;j[b+12>>2]=0;K(2161,a|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function bP(a){var b=0;b=j[a+4>>2];if(!b){if(!Qg(a)){while(1){a=j[a+8>>2];if(!Qg(a)){continue}break}}return j[a+8>>2]}a=b;while(1){b=a;a=j[a>>2];if(a){continue}break}return b}function bG(a){var b=0,c=0;b=Za-16|0;Za=b;j[114626]=0;j[b+12>>2]=0;K(2162,a|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function aG(a){var b=0,c=0;b=Za-16|0;Za=b;j[114626]=0;j[b+12>>2]=0;K(2163,a|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function _wa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-80|0;Za=d;c=d;e=Ewa(a,d);if(!e){PP(c)}c=-1;a:{if(!e){break a}c=0;if(!JM(d)){break a}c=Le(a,b,IM(d),ab)}Za=d+80|0;return c|0}function PX(a,b){var c=0,d=0,e=0;c=Za-1040|0;Za=c;e=j[114600];d=OX(TX(b,c+16|0),c+16|0);if(!k[d|0]){j[c>>2]=b;cv(c+16|0,1024,70940,c);d=c+16|0}j[114600]=e;Eb(a,d);Za=c+1040|0}function tia(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(1616,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function koa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(1378,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function fL(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;if(l[a+28>>1]!=(b|0)){es(a+12|0);i[a+28>>1]=b}c=a+12|0;if(ad(c)){hL(c,Gx(a,l[ac(Jo(a),b)>>1]))}rra(c,d+12|0);Za=d+16|0}function doa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(1382,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function WAa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Za-128|0;Za=d;c=d;e=CAa(a,d);if(!e){dO(c)}c=-1;a:{if(!e){break a}c=0;if(!iO(d)){break a}c=Le(a,b,256,0)}Za=d+128|0;return c|0}function Mqa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(1253,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Kla(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(1520,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Jta(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(1163,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Hya(a){var b=0,c=0;b=Za-16|0;Za=b;j[114626]=0;j[b+12>>2]=0;K(83,a|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Bya(a){var b=0,c=0;b=Za-16|0;Za=b;j[114626]=0;j[b+12>>2]=0;K(84,a|0,b+12|0,b+8|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function yQ(a,b){var c=0;c=Za-32|0;Za=c;j[c+24>>2]=a;j[c+28>>2]=b;j[c+16>>2]=0;j[c+20>>2]=0;j[c+8>>2]=-1;j[c+12>>2]=0;a=tQ(c+16|0,iz(c+24|0,c+8|0));Za=c+32|0;return j[a>>2]}function yB(a){var b=0;a:{if(!(m[a>>2]<=18285140|m[a>>2]>=18350592)){b=1;if(j[a>>2]!=18350080){break a}}a=j[a>>2];b=0;if(a>>>0<=18350592){break a}b=(a|0)!=(a&-256)}return b}function x8(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(2194,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function v8(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(2196,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function sC(a){a=a|0;var b=0,c=0;j[a>>2]=62464;b=a+16|0;while(1){if(sb(b)>>>0>c>>>0){if(j[xb(b,c)>>2]){Hl(j[xb(b,c)>>2])}c=c+1|0;continue}break}gb(a+176|0);HC(b);return a|0}function gx(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(1424,a|0,c+12|0,c+8|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function aza(a,b){a=a|0;b=b|0;var c=0,d=0;c=1;d=a;a=b+47|0;b=Mc(d,k[a|0]&4?16:8,1,0,0);a:{b:{if(k[a|0]&8){break b}c=2;if(k[a|0]&16){break b}if(k[a|0]&127){break a}}dj(b,c)}}function Zo(a,b,c){var d=0;d=b;b=k[a|0]|k[a+1|0]<<8;if((d|0)<=((b<<24|b<<8&16711680)>>>16|0)){a=k[a|0]|k[a+1|0]<<8;a=((a<<24|a<<8&16711680)>>>16|0)<=(c|0)}else{a=0}return a}function Wfa(a,b,c){var d=0;d=Za-16|0;Za=d;kga(d,b,c);j[114626]=0;I(13,a|0,0,d|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(d);Za=d+16|0;return}a=D()|0;C()|0;gb(d);G(a|0);z()}function TH(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;d=zc(c+8|0,b);Os(d);if(j[a>>2]==(b|0)){j[a>>2]=j[d>>2]}e=hb(a);j[e>>2]=j[e>>2]-1;qia(j[Rb(a)>>2],b);Za=c+16|0;return j[d>>2]}function MQ(a){a:{if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=-28163770){break a}if(Yc(a+44|0,12960,3)){break a}a=a+47|0;return(k[a|0]|k[a+1|0]<<8)>>>0>97}return 0}function Kra(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c>>2]=b;j[c+8>>2]=a;if(rb(c+8|0,c)){while(1){d=o[j[c+8>>2]>>3]+d;Jx(c+8|0);if(rb(c+8|0,c)){continue}break}}Za=c+16|0;return d}function CFa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(730,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function CCa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(829,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Baa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;Cc(a+12|0,0,0);d=a+20|0;c=d;e=c+16|0;while(1){c=ck(c)+4|0;if((e|0)!=(c|0)){continue}break}oJ(d+16|0,b);j[a+40>>2]=1;return a|0}function zaa(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(2132,a|0,c+12|0,c+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function xFa(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;if(c){while(1){f=Zm(hb(a),c+16|0,b);d=f?d:c;c=j[(f?4:0)+c>>2];if(c){continue}break}}a=j[zc(e+8|0,d)>>2];Za=e+16|0;return a}function wia(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;if(c){while(1){f=Br(hb(a),c+16|0,b);d=f?d:c;c=j[(f?4:0)+c>>2];if(c){continue}break}}a=j[zc(e+8|0,d)>>2];Za=e+16|0;return a}function tsa(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(1195,a|0,c+12|0,c+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function nna(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(1416,a|0,c+12|0,c+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function mga(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(1751,a|0,c+12|0,c+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function jV(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(280,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function gp(a){var b=0,c=0;c=j[a+4>>2];b=j[c>>2];j[a+4>>2]=b;if(b){Ym(b,a)}j[c+8>>2]=j[a+8>>2];a:{if(Qg(a)){b=j[a+8>>2];break a}b=j[a+8>>2]+4|0}j[b>>2]=c;j[c>>2]=a;Ym(a,c)}function fp(a){var b=0,c=0;c=j[a>>2];b=j[c+4>>2];j[a>>2]=b;if(b){Ym(b,a)}j[c+8>>2]=j[a+8>>2];a:{if(Qg(a)){b=j[a+8>>2];break a}b=j[a+8>>2]+4|0}j[b>>2]=c;j[c+4>>2]=a;Ym(a,c)}function cga(a,b,c){var d=0;d=Za-16|0;Za=d;lH(d,b,c);j[114626]=0;I(13,a|0,0,d|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(d);Za=d+16|0;return}a=D()|0;C()|0;gb(d);G(a|0);z()}function Xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-16|0;Za=c;j[c+12>>2]=b;d=c,e=jR(Lb(a),Mb(a),c+12|0),j[d+8>>2]=e;d=c,e=Mb(a),j[d>>2]=e;a=rb(c+8|0,c);Za=c+16|0;return a|0}function UU(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(286,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Pfa(a,b,c){var d=0;d=Za-16|0;Za=d;rw(d,b,c);j[114626]=0;I(13,a|0,0,d|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(d);Za=d+16|0;return}a=D()|0;C()|0;gb(d);G(a|0);z()}function Pda(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(1996,a|0,c+12|0,c+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Ifa(a,b,c){var d=0;d=Za-16|0;Za=d;wr(d,b,c);j[114626]=0;I(13,a|0,0,d|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(d);Za=d+16|0;return}a=D()|0;C()|0;gb(d);G(a|0);z()}function EV(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;K(274,a|0,d+12|0,c|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Doa(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(1369,a|0,c+12|0,c+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Caa(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(2130,a|0,c+12|0,c+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Aba(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;if(c){while(1){f=as(hb(a),c+16|0,b);d=f?d:c;c=j[(f?4:0)+c>>2];if(c){continue}break}}a=j[zc(e+8|0,d)>>2];Za=e+16|0;return a}function Aaa(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(2131,a|0,c+12|0,c+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function zga(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-16|0;Za=c;j[c+12>>2]=0;d=c+12|0;h[d|0]=b;h[d+1|0]=b>>>8;h[d+2|0]=b>>>16;h[d+3|0]=b>>>24;a=pH(a,c+12|0);Za=c+16|0;return a|0}function m3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=Nn(d,a);rC(a,c);j[114626]=0;F(2305,b|0,1);a=j[114626];j[114626]=0;if((a|0)==1){a=D()|0;C()|0;wb(d);G(a|0);z()}}function fe(a,b){var c=0;c=j[a>>2];j[a>>2]=b;a:{if(!c){break a}a=j[Rb(a)>>2];j[114626]=0;N(a|0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){break a}a=J(0)|0;C()|0;ib(a);z()}}function _3(a,b){a=a|0;b=b|0;j[a+4>>2]=b;h[a|0]=0;if(mf(j[j[b>>2]-12>>2]+b|0)){if(j[(j[j[b>>2]-12>>2]+b|0)+72>>2]){Jq(j[(j[j[b>>2]-12>>2]+b|0)+72>>2])}h[a|0]=1}return a|0}function VJ(a,b,c){a=a|0;b=b|0;c=c|0;a=j[c+4>>2];j[b>>2]=j[c>>2];j[b+4>>2]=a;a=j[c+20>>2];j[b+16>>2]=j[c+16>>2];j[b+20>>2]=a;a=j[c+12>>2];j[b+8>>2]=j[c+8>>2];j[b+12>>2]=a}function UDa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=bb[j[j[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Rea(a){var b=0,c=0;b=j[a+16>>2];c=b-1|0;j[a+16>>2]=c;if((b|0)<=0){j[a+16>>2]=c+j[a+12>>2]}b=j[a+20>>2];c=b-1|0;j[a+20>>2]=c;if((b|0)<=0){j[a+20>>2]=c+j[a+12>>2]}}function J9(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(2169,a|0,c+12|0,c+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function In(a,b){var c=0,d=0,e=0;c=0;a:{if(!a){break a}d=OMa(a,0,b,0);e=ab;c=d;if((a|b)>>>0<65536){break a}c=e?-1:d}b=c;a=_c(b);if(!(!a|!(k[a-4|0]&3))){Ab(a,0,b)}return a}function F3(a,b){a=a|0;b=b|0;j[a+4>>2]=b;h[a|0]=0;if(mf(j[j[b>>2]-12>>2]+b|0)){if(j[(j[j[b>>2]-12>>2]+b|0)+72>>2]){aE(j[(j[j[b>>2]-12>>2]+b|0)+72>>2])}h[a|0]=1}return a|0}function Ex(a,b,c){var d=0,e=0,f=0;d=Za-32|0;Za=d;j[d+16>>2]=c;j[d+24>>2]=b;e=d,f=nd(a),j[e+8>>2]=f;b=a;a=En(d+24|0,d+8|0);PV(b,a,En(d+16|0,d+24|0));$e(d+8|0,a);Za=d+32|0}function iba(a){var b=0;b=Za-16|0;Za=b;hn(b,0,7349);j[114626]=0;I(9,a|0,0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(b);Za=b+16|0;return}a=D()|0;C()|0;gb(b);G(a|0);z()}function gba(a){var b=0;b=Za-16|0;Za=b;hn(b,0,9345);j[114626]=0;I(9,a|0,0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(b);Za=b+16|0;return}a=D()|0;C()|0;gb(b);G(a|0);z()}function g_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=j[b>>2];if(a>>>0<=127){a=j[nq()+(j[b>>2]<<2)>>2]}j[d>>2]=a;b=b+4|0;continue}break}return c|0}function e_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=j[b>>2];if(a>>>0<=127){a=j[mq()+(j[b>>2]<<2)>>2]}j[d>>2]=a;b=b+4|0;continue}break}return c|0}function Yua(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(97,a|0,c+12|0,c+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Vxa(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(90,a|0,c+12|0,c+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function QV(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;j[c+12>>2]=b;K(268,a|0,c+12|0,c+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=c+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Ez(a,b,c){var d=0;d=k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24);b=k[b+4|0]|k[b+5|0]<<8|(k[b+6|0]<<16|k[b+7|0]<<24);j[a>>2]=d;j[a+4>>2]=b;Cl(a+8|0,c);return a}function uM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;if((b|0)!=(c|0)){while(1){j[d+12>>2]=j[b>>2];ay(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}Za=d+16|0}function kha(a,b){var c=0;c=Za-16|0;Za=c;Oia(c,b);j[114626]=0;I(13,a|0,0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(c);Za=c+16|0;return}a=D()|0;C()|0;gb(c);G(a|0);z()}function fx(a){var b=0;b=Za-16|0;Za=b;j[114626]=0;j[b+12>>2]=0;K(1425,a|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function eo(a){var b=0;b=Za-16|0;Za=b;j[114626]=0;j[b+12>>2]=0;K(2168,a|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Rta(a,b,c){var d=0;a:{if(c>>>0>=256){break a}if(k[a+31|0]==17){a=l[(p(c,896)+b|0)+1075792>>1];return(a?a-1|0:c)&15}if(!ci(a)){break a}d=k[a+31|0]-1&15}return d}function Fwa(a,b){a=a|0;b=b|0;var c=0,d=0;c=ue(2500);j[114626]=0;b=K(92,c|0,b|0,0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){Yua(a,b);return}a=D()|0;C()|0;Cb(c);G(a|0);z()}function Eha(a,b){var c=0;c=Za-16|0;Za=c;oja(c,b);j[114626]=0;I(13,a|0,0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(c);Za=c+16|0;return}a=D()|0;C()|0;gb(c);G(a|0);z()}function ywa(a,b){var c=0;c=Za-16|0;Za=c;oh(c+8|0,b);j[114626]=0;a=E(1055,a|0,c+8|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function wha(a,b){var c=0;c=Za-16|0;Za=c;cI(c,b);j[114626]=0;I(13,a|0,0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(c);Za=c+16|0;return}a=D()|0;C()|0;gb(c);G(a|0);z()}function sha(a,b){var c=0;c=Za-16|0;Za=c;Hw(c,b);j[114626]=0;I(13,a|0,0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(c);Za=c+16|0;return}a=D()|0;C()|0;gb(c);G(a|0);z()}function s7(a,b){a:{switch(j[a+40>>2]){case 0:q7(b,a);return;case 2:Rv(b,hb(a));return;case 3:p7(b,zg(a));return;case 1:Rv(b,hb(a));return;default:break a}}Rv(b,hb(a))}function r7(a,b){a:{switch(j[a+40>>2]){case 0:j7(b,a);return;case 2:Qv(b,hb(a));return;case 3:i7(b,zg(a));return;case 1:Qv(b,hb(a));return;default:break a}}Qv(b,hb(a))}function nc(a,b){var c=0,d=0;c=Za-16|0;Za=c;if(j[a+4>>2]==j[b+4>>2]){d=j[b+4>>2];b=j[b>>2];j[c>>2]=b;j[c+4>>2]=d;j[c+8>>2]=b;j[c+12>>2]=d;d=!D8(a,c)}Za=c+16|0;return d}function mV(a){var b=0;b=Za-16|0;Za=b;j[114626]=0;j[b+12>>2]=0;K(278,a|0,b+12|0,b+8|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function hna(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;j[114626]=0;a=E(1418,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a|0}a=D()|0;C()|0;G(a|0);z()}function c7(a,b){a:{switch(j[a+40>>2]){case 0:_q(b,a);return;case 2:_q(b,hb(a));return;case 3:a7(b,zg(a));return;case 1:_q(b,hb(a));return;default:break a}}_q(b,hb(a))}function b7(a,b){a:{switch(j[a+40>>2]){case 0:X6(b,a);return;case 2:Ov(b,hb(a));return;case 3:W6(b,zg(a));return;case 1:Ov(b,hb(a));return;default:break a}}Ov(b,hb(a))}function ZE(a){var b=0,c=0;a:{if(k[a|0]!=255){break a}b=k[a+1|0];if(!(b&6)|(b&240)!=240&(b&254)!=226){break a}a=k[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function U7(a,b){a:{switch(j[a+40>>2]){case 0:S7(b,a);return;case 2:Uv(b,hb(a));return;case 3:R7(b,zg(a));return;case 1:Uv(b,hb(a));return;default:break a}}Uv(b,hb(a))}function T7(a,b){a:{switch(j[a+40>>2]){case 0:N7(b,a);return;case 2:Tv(b,hb(a));return;case 3:M7(b,zg(a));return;case 1:Tv(b,hb(a));return;default:break a}}Tv(b,hb(a))}function Sia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-16|0;Za=c;d=c,e=Hs(j[b>>2]),j[d+12>>2]=e;j[c+8>>2]=0;d=a,e=j[cs(c+12|0,c+8|0,32408)>>2],j[d+36>>2]=e;io(a);Za=c+16|0}function KH(a,b){var c=0;c=Za-16|0;Za=c;Eja(c,b);j[114626]=0;I(13,a|0,0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(c);Za=c+16|0;return}a=D()|0;C()|0;gb(c);G(a|0);z()}function Jla(a,b){var c=0;c=Za-16|0;Za=c;oh(c+8|0,b);j[114626]=0;a=E(1521,a|0,c+8|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function F7(a,b){a:{switch(j[a+40>>2]){case 0:$q(b,a);return;case 2:$q(b,hb(a));return;case 3:C7(b,zg(a));return;case 1:$q(b,hb(a));return;default:break a}}$q(b,hb(a))}function E7(a,b){a:{switch(j[a+40>>2]){case 0:z7(b,a);return;case 2:Sv(b,hb(a));return;case 3:y7(b,zg(a));return;case 1:Sv(b,hb(a));return;default:break a}}Sv(b,hb(a))}function CT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;j[a>>2]=0;j[a+4>>2]=0;j[d+12>>2]=0;Ic(a+8|0,d+12|0,d+8|0);if(b){Gp(a,b);pA(a,b,k[c|0])}Za=d+16|0;return a|0}function $8(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if((Ui(Fb(j[a>>2]+484360|0))|0)<=(b|0)){break a}c=l[ac(Fb(j[a>>2]+484360|0),b)>>1]}return c|0}function wsa(a,b){a=a|0;b=b|0;var c=0;c=vsa(a);h[a+530|0]=0;j[114626]=0;F(1192,a|0,b|0);b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;bf(c);G(a|0);z()}function usa(a,b){var c=0,d=0;c=ue(3848);b=j[b>>2];j[114626]=0;b=E(1194,c|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){tsa(a,b);return}a=D()|0;C()|0;Cb(c);G(a|0);z()}function uBa(a,b){var c=0;c=Za-32|0;Za=c;a:{if(yb(a,1024)){uy(c+24|0,b);qd(a,c+24|0);break a}j[c+16>>2]=0;j[c+20>>2]=0;j[c+8>>2]=0;j[c+12>>2]=0;ZAa(b,c+8|0)}Za=c+32|0}function aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=j[b+24>>2];g=j[b+8>>2];h=j[b+4>>2];i=j[b>>2];e=j[b+12>>2]}else{e=0}HG(a,i,h,g,e,f,b,c,d)}function Yh(a,b,c){var d=0;d=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=d;d=j[b+12>>2];j[a+8>>2]=j[b+8>>2];j[a+12>>2]=d;o[a>>3]=o[a>>3]-o[c>>3];o[a+8>>3]=o[a+8>>3]-o[c+8>>3]}function Yc(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=k[a|0];e=k[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function O6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){e=j[d>>2];while(1){Wy(a,e,b);e=j[d>>2]+12|0;j[d>>2]=e;b=b+12|0;if((c|0)!=(b|0)){continue}break}}}function NKa(a,b){var c=0;c=Za-16|0;Za=c;Za=c+16|0;return(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))>>>0<(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))>>>0?b:a}function xna(a,b){var c=0,d=0;c=ue(532);b=j[b>>2];j[114626]=0;b=E(1412,c|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){nna(a,b);return}a=D()|0;C()|0;Cb(c);G(a|0);z()}function rFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;Zy(a,b,c);a=j[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function qaa(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;j[e+8>>2]=j[b+8>>2];f=j[b+4>>2];j[e>>2]=j[b>>2];j[e+4>>2]=f;paa(a,e,c);n[a+24>>2]=d;j[a>>2]=84200;Za=e+16|0;return a}function oaa(a,b,c,d){var e=0,f=0;e=Za-16|0;Za=e;j[e+8>>2]=j[b+8>>2];f=j[b+4>>2];j[e>>2]=j[b>>2];j[e+4>>2]=f;naa(a,e,c);n[a+24>>2]=d;j[a>>2]=84272;Za=e+16|0;return a}function EU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;c=0;a=j[a+16>>2];if(a>>>0>b>>>0){j[d+8>>2]=a-b;c=j[tb(d+12|0,d+8|0)>>2]}Za=d+16|0;return c|0}function E2(a,b,c){var d=0,e=0,f=0;e=j[a+84>>2];d=c+256|0;f=Tq(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;Vb(b,e,c);b=e+d|0;j[a+84>>2]=b;j[a+8>>2]=b;j[a+4>>2]=c+e;return c}function yra(a,b){var c=0,d=0,e=0;d=a;c=j[a+4>>2];e=c>>>8|0;a=j[a>>2];c=(c&255)<<24|a>>>8;a=(((a^b)&255)<<3)+85568|0;b=j[a>>2];a=j[a+4>>2]^e;j[d>>2]=b^c;j[d+4>>2]=a}function yM(a){var b=0,c=0;a:{if(k[a|0]!=255){break a}b=k[a+1|0];if(!(b&6)|(b&224)!=224|(b&24)==8){break a}a=k[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function wV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;c=0;a=j[a+8>>2];if(a>>>0>b>>>0){j[d+8>>2]=a-b;c=j[tb(d+12|0,d+8|0)>>2]}Za=d+16|0;return c|0}function wJa(a,b,c){var d=0;if((b|0)>=1){while(1){d=j[c>>2];h[a|0]=d;h[a+1|0]=d>>>8;h[a+2|0]=d>>>16;h[a+3|0]=d>>>24;a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function tra(a,b){var c=0,d=0,e=0;ira(a);el(a,b);j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];c=j[hb(b)>>2];d=hb(a),e=c,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function ssa(a){var b=0,c=0,d=0,e=0;b=Za-16|0;Za=b;d=b,e=OMa(j[a>>2],j[a+4>>2],1e3,0),j[d>>2]=e;j[b+4>>2]=ab;c=Sj(b+8|0,b);a=j[c>>2];Za=b+16|0;ab=j[c+4>>2];return a}function rxa(a,b){var c=0,d=0,e=0;c=qxa(a,hb(b));j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];a=j[hb(b)>>2];d=hb(c),e=a,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function r4(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;b=n4(b);Za=d+16|0;j[c+8>>2]=b;j[c+12>>2]=ab;b=j[c+12>>2];j[a>>2]=j[c+8>>2];j[a+4>>2]=b;Za=c+16|0;return a}function o4(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=Za-16|0;Za=d;b=m4(b);Za=d+16|0;j[c+8>>2]=b;j[c+12>>2]=ab;b=j[c+12>>2];j[a>>2]=j[c+8>>2];j[a+4>>2]=b;Za=c+16|0;return a}function fba(a){var b=0;b=Za-16|0;Za=b;cq(b,0);j[114626]=0;I(9,a|0,0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(b);Za=b+16|0;return}a=D()|0;C()|0;gb(b);G(a|0);z()}function eba(a){var b=0;b=Za-16|0;Za=b;cq(b,2);j[114626]=0;I(9,a|0,0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(b);Za=b+16|0;return}a=D()|0;C()|0;gb(b);G(a|0);z()}function dba(a){var b=0;b=Za-16|0;Za=b;cq(b,3);j[114626]=0;I(9,a|0,0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(b);Za=b+16|0;return}a=D()|0;C()|0;gb(b);G(a|0);z()}function _ya(a,b){var c=0,d=0,e=0;Zya(a);el(a,b);j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];c=j[hb(b)>>2];d=hb(a),e=c,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function _Z(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=h[b|0];if((a|0)>=0){a=j[nq()+(h[b|0]<<2)>>2]}h[d|0]=a;b=b+1|0;continue}break}return c|0}function YZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=h[b|0];if((a|0)>=0){a=j[mq()+(h[b|0]<<2)>>2]}h[d|0]=a;b=b+1|0;continue}break}return c|0}function Ila(a,b){a:{if(k[a+4|0]){a=j[a>>2];j[114626]=0;F(1518,a|0,b+16|0);a=j[114626];j[114626]=0;if((a|0)==1){break a}}if(b){QI(b)}return}a=J(0)|0;C()|0;ib(a);z()}function Gka(a,b){var c=0,d=0,e=0;Fka(a);el(a,b);j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];c=j[hb(b)>>2];d=hb(a),e=c,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function DN(a){if(!((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))!=541938512|(k[a+8|0]|k[a+9|0]<<8|(k[a+10|0]<<16|k[a+11|0]<<24))!=1162627398)){return 1}return 0}function A4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;a=Oq(ta(j[a+60>>2],b|0,c|0,d&255,e+8|0)|0);Za=e+16|0;ab=a?-1:j[e+12>>2];return(a?-1:j[e+8>>2])|0}function zo(a){var b=0,c=0;b=Za-16|0;Za=b;a:{if(!(j[a+480208>>2]&16)){break a}mb(b+8|0,a+1074308|0,7);if(!kb(b+8|0)){break a}c=j[a+480180>>2]!=4}Za=b+16|0;return c}function xG(a,b){var c=0,d=0,e=0,f=0;c=j[a+24>>2];if((c|0)==j[a+28>>2]){return e=a,f=gg(b),d=j[j[a>>2]+52>>2],bb[d](e|0,f|0)|0}j[a+24>>2]=c+1;h[c|0]=b;return gg(b)}function vpa(a,b){var c=0,d=0,e=0;NK(a);el(a,b);j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];c=j[hb(b)>>2];d=hb(a),e=c,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function rja(a,b){var c=0;qja(a,b);j[a+20>>2]=j[b+20>>2];c=j[b+16>>2];j[a+12>>2]=j[b+12>>2];j[a+16>>2]=c;pja(a+24|0,b+24|0);Nc(a+36|0,b+36|0);j[a+48>>2]=j[b+48>>2]}function qja(a,b){var c=0,d=0,e=0;c=iI(a,hb(b));j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];a=j[hb(b)>>2];d=hb(c),e=a,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function pja(a,b){var c=0,d=0,e=0;c=ES(a,hb(b));j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];a=j[hb(b)>>2];d=hb(c),e=a,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function n4(a){var b=0,c=0,d=0,e=0;b=Za-16|0;Za=b;d=b,e=OMa(j[a>>2],j[a+4>>2],1e6,0),j[d>>2]=e;j[b+4>>2]=ab;c=Sj(b+8|0,b);a=j[c>>2];Za=b+16|0;ab=j[c+4>>2];return a}function m4(a){var b=0,c=0,d=0,e=0;b=Za-16|0;Za=b;d=b,e=OMa(j[a>>2],j[a+4>>2],1e9,0),j[d>>2]=e;j[b+4>>2]=ab;c=Sj(b+8|0,b);a=j[c>>2];Za=b+16|0;ab=j[c+4>>2];return a}function gka(a,b){var c=0,d=0,e=0;sI(a);el(a,b);j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];c=j[hb(b)>>2];d=hb(a),e=c,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function Sta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=op(k[a|0]+b|0),h[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Ora(a,b){var c=0,d=0,e=0;c=lL(a,hb(b));j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];a=j[hb(b)>>2];d=hb(c),e=a,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function Me(a){var b=0,c=0;b=Za-16|0;Za=b;j[114626]=0;K(114,a|0,b+8|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Hm(a);Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Lsa(a,b){var c=0,d=0,e=0;c=QL(a,hb(b));j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];a=j[hb(b)>>2];d=hb(c),e=a,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function Lk(a){a=a>>>1&1431655765|a<<1&-1431655766;a=a>>>2&858993459|a<<2&-858993460;a=a>>>4&252645135|a<<4&-252645136;return TMa(a>>>8&16711935|a<<8&-16711936,16)}function Jma(a,b){var c=0,d=0,e=0;XO(a);el(a,b);j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];c=j[hb(b)>>2];d=hb(a),e=c,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function Gaa(a,b){var c=0,d=0,e=0;Z7(a);el(a,b);j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];c=j[hb(b)>>2];d=hb(a),e=c,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function yd(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=b;j[114626]=0;Pn(a,d+12|0,c);b=j[114626];j[114626]=0;if((b|0)!=1){Za=d+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function tta(a,b,c){a:{if(!ks(b,c)){break a}while(1){if(l[rta(b)>>1]!=65535){break a}TL(b+4|0);if(ks(b,c)){continue}break}}c=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=c}function tG(a){a=a|0;var b=0,c=0,d=0;b=ue(1304568);j[114626]=0;c=H(2126,b|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){Caa(a,c);return}a=D()|0;C()|0;Cb(b);G(a|0);z()}function oba(a){var b=0;b=Za-16|0;Za=b;bW(b);j[114626]=0;I(9,a|0,0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(b);Za=b+16|0;return}a=D()|0;C()|0;gb(b);G(a|0);z()}function mN(a,b){var c=0,d=0,e=0;c=oN(a,hb(b));j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];a=j[hb(b)>>2];d=hb(c),e=a,j[d>>2]=e;d=hb(b),e=0,j[d>>2]=e;j[b>>2]=0;j[b+4>>2]=0}function kba(a){var b=0;b=Za-16|0;Za=b;mW(b);j[114626]=0;I(9,a|0,0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(b);Za=b+16|0;return}a=D()|0;C()|0;gb(b);G(a|0);z()}function jba(a){var b=0;b=Za-16|0;Za=b;lW(b);j[114626]=0;I(9,a|0,0,b|0);a=j[114626];j[114626]=0;if((a|0)!=1){gb(b);Za=b+16|0;return}a=D()|0;C()|0;gb(b);G(a|0);z()}function iua(a,b,c,d){var e=0;a:{if(d==q(1)){break a}c=p(b,c);if(!c){break a}e=+d;b=0;while(1){o[a>>3]=o[a>>3]*e;a=a+8|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Xb(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=Za-16|0;Za=c;d=j[a>>2];a=(f=d,g=j[a+8>>2],h=Kb(c+8|0,b),e=j[j[d>>2]+32>>2],bb[e](f|0,g|0,h|0)|0);Za=c+16|0;return a}function Nwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Sm(a);j[114626]=0;I(91,a|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;Ud(d);G(a|0);z()}function Jb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=yb(a,b);if(c){j[a+8>>2]=j[a+8>>2]+b;return c|0}b=a;a=j[a>>2];d=b,e=bb[j[j[a>>2]+24>>2]](a)|0,j[d+8>>2]=e;return c|0}function HJ(a){j[a>>2]=0;j[a+4>>2]=0;j[a+88>>2]=0;j[a+8>>2]=0;j[a+12>>2]=0;kL(a+112|0,48e3);j[a+668>>2]=0;cx(a+724|0);cx(a+736|0);cx(a+748|0);bj(a+810|0);return a}function Db(a){var b=0,c=0;b=Za-16|0;Za=b;j[114626]=0;K(14,a|0,b+8|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Hm(a);Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function ue(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=_c(a);if(b){break a}b=j[115935];if(b){bb[b|0]();continue}break}a=R(4)|0;zk(a);Y(a|0,71396,2001);z()}return b|0}function tba(a,b,c,d,e){var f=0,g=0;f=Za-16|0;Za=f;g=j[a+12>>2];j[f+8>>2]=j[a+8>>2];j[f+12>>2]=g;g=j[a+4>>2];j[f>>2]=j[a>>2];j[f+4>>2]=g;gua(f,b,c,d,e);Za=f+16|0}function iX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;j[d+12>>2]=j[c>>2];a=bb[j[j[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){j[c>>2]=j[d+12>>2]}Za=d+16|0;return a|0}function gY(a,b){a=a|0;b=b|0;pm(a);j[a>>2]=71436;b=zb(b);j[114626]=0;E(2829,a+4|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;G(a|0);z()}function ew(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;K(150,a|0,c+8|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Hm(a);Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function _E(a,b){var c=0;c=Za-16|0;Za=c;j[114626]=0;K(197,a|0,c+8|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){Hm(a);Za=c+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function Xs(a){var b=0;b=Za-16|0;Za=b;Cc(b+8|0,a,0);j[114626]=0;I(671,b+8|0,110,0);a=j[114626];j[114626]=0;if((a|0)!=1){Za=b+16|0;return}a=J(0)|0;C()|0;ib(a);z()}function Uo(a){j[a+8>>2]=0;j[a+12>>2]=0;j[a>>2]=128;j[a+4>>2]=256;j[a+32>>2]=363;j[a+36>>2]=952;j[a+16>>2]=48e3;j[a+20>>2]=2;j[a+24>>2]=128;j[a+28>>2]=0;return a}function SS(a){var b=0,c=0;a:{if(Yc(a,12061,3)){break a}b=a+3|0;if(k[b|0]<8|k[b|0]>14){break a}a=a+40|0;if(k[b|0]>9?!(k[a|0]<33?k[a|0]:0):0){break a}c=1}return c}function Qc(a){var b=0,c=0;b=Za-16|0;Za=b;j[114626]=0;K(1,a|0,b+8|0,b|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){Hm(a);Za=b+16|0;return a}a=J(0)|0;C()|0;ib(a);z()}function qta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;i[d+12>>1]=c;i[d+14>>1]=b;Sf(d+14|0,l[j[j[a+24>>2]+8>>2]+12>>1]);pta(a,l[d+14>>1],d+12|0);Za=d+16|0}function gAa(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-80|0;Za=d;c=-1;a:{if(!qR(a,d+8|0)){break a}c=0;if(!XN(d+8|0)){break a}c=Le(a,b,WN(d+8|0),ab)}Za=d+80|0;return c|0}function tO(a){if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))==1297239878){return(k[a+8|0]|k[a+9|0]<<8|(k[a+10|0]<<16|k[a+11|0]<<24))==1279545165}return 0}function sH(a,b){var c=0;c=Za-16|0;Za=c;j[c+12>>2]=b;j[c+8>>2]=127;b=tb(c+12|0,c+8|0);n[j[a+20>>2]+144>>2]=q(q(m[b>>2])*q(-.007874015718698502))+q(1);Za=c+16|0}function _V(a,b,c,d){var e=0,f=0;f=-1;a:{if(!b){break a}e=b;b=a;e=e+b|0;while(1){if(An(c,d,b)){b=b+1|0;if((e|0)!=(b|0)){continue}break a}break}f=b-a|0}return f}function Sla(a){TI();Pe(219776,285312,a+131112|0);Pe(285312,350848,a+196648|0);Pe(350848,416384,a+262184|0);Pe(88688,219776,a+24|0);Vb(a+327720|0,416384,40960)}function JX(a,b,c){a=a|0;b=b|0;c=c|0;b=c;a:{if((c|0)>=257){SB();c=85368;break a}b:{if(h[463724]&1){break b}if(!fd(463724)){break b}ed(463724)}c=85364}Cc(a,b,c)}function Cp(a,b,c){a=a|0;b=b|0;c=c|0;h[a+11|0]=c;h[a+10|0]=b;h[a+12|0]=k[a+12|0]&251;i[a+8>>1]=65535;j[a>>2]=0;j[a+4>>2]=0;h[a+12|0]=k[a+12|0]&252|1;return a|0}function qga(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-16|0;Za=c;d=b+1304396|0;if(!bd(d)){pga(c+8|0);GJ(d,ud(c+8|0));Mr(c+8|0)}a=oga(j[d>>2],a,b);Za=c+16|0;return a|0}function pla(a,b,c){var d=0,e=0,f=0;d=Za-16|0;Za=d;f=me(b);e=j[c+4>>2];c=j[c>>2];j[d>>2]=c;j[d+4>>2]=e;j[d+8>>2]=c;j[d+12>>2]=e;nla(a,b,f-1&65535,d);Za=d+16|0}function pka(a,b,c){a:{if(!b){break a}if(m[j[vm(a)+8>>2]+40>>2]<b>>>0|b>>>0>c>>>0){break a}if(m[j[vm(a)+8>>2]+40>>2]<c>>>0){break a}j[a+20>>2]=c;j[a+16>>2]=b}}function dY(a,b){var c=0,d=0;c=Za-16|0;Za=c;a:{if(qe(a)){d=j[a>>2];h[c+15|0]=0;Td(b+d|0,c+15|0);ee(a,b);break a}h[c+14|0]=0;Td(a+b|0,c+14|0);Ue(a,b)}Za=c+16|0}function dEa(a,b){a=a|0;b=b|0;var c=0;CP(a);c=b+4|0;_Da(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];_j(a);jl(a);jl(a)}function NC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Za-16|0;Za=a;j[a+8>>2]=b;while(1){if(c>>>0<d>>>0){MC(a+8|0,c);c=c+1|0;continue}break}Za=a+16|0;return j[a+8>>2]}function LMa(a,b,c){var d=0,e=0;d=b>>31;e=a^d;a=b>>31;MMa(e-d|0,(b^a)-((d>>>0>e>>>0)+a|0)|0,c,0);ab=$a;b=d^_a;c=b-d|0;ab=(a^ab)-((b>>>0<d>>>0)+a|0)|0;return c}function Jya(a,b){a=a|0;b=b|0;var c=0;wN(a);c=b+4|0;Eya(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Vj(a);Tm(a);Tm(a)}function FM(a,b){var c=0;c=j[a+4>>2];a:{if((b|0)>=0){b=b+c|0;j[a>>2]=j[a>>2]+(b>>>3&536870908);break a}b=b+c|0;j[a>>2]=j[a>>2]+((b-31|0)/32<<2)}j[a+4>>2]=b&31}function BIa(a,b){a=a|0;b=b|0;var c=0;YQ(a);c=b+4|0;zIa(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];ni(a);nl(a);nl(a)}function $A(a){a=a|0;var b=0,c=0;b=Qc(a);j[114626]=0;H(277,a+12|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){mV(a+28|0);return a|0}a=D()|0;C()|0;gb(b);G(a|0);z()}function z_(){var a=0,b=0;td(463184);j[115796]=62536;j[114626]=0;a=T(2437)|0;b=j[114626];j[114626]=0;if((b|0)!=1){j[115798]=a;return}a=D()|0;C()|0;G(a|0);z()}function tha(a,b){a=a|0;b=b|0;var c=0;CH(a);c=b+4|0;uh(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Te(a);Hj(a);Hj(a)}function g2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=j[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function bDa(a,b,c){var d=0,e=0;d=Za-16|0;Za=d;LCa(b,c);c=yb(a,c<<1);if(c){e=Za-16|0;Za=e;Qb(d+8|0,j[b>>2],bc(b)<<1);Za=e+16|0;qd(a,d+8|0)}Za=d+16|0;return c}function ULa(a,b,c){var d=0,e=0;d=Za-16|0;Za=d;BLa(b,c);c=yb(a,c<<1);if(c){e=Za-16|0;Za=e;Qb(d+8|0,j[b>>2],bc(b)<<1);Za=e+16|0;qd(a,d+8|0)}Za=d+16|0;return c}function Sl(a){a=a|0;var b=0;b=R(8)|0;j[114626]=0;E(2055,b|0,a|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Y(b|0,71724,265);z()}a=D()|0;C()|0;S(b|0);G(a|0);z()}function RG(a){a=a|0;var b=0;j[a+4240>>2]=0;j[a+4244>>2]=0;b=a+4264|0;j[b>>2]=0;j[b+4>>2]=0;b=a+4256|0;j[b>>2]=0;j[b+4>>2]=0;a=a+4248|0;j[a>>2]=0;j[a+4>>2]=0}function JIa(a,b){a=a|0;b=b|0;h[b|0]=0;h[b+1|0]=0;h[b+2|0]=0;h[b+3|0]=0;h[b+4|0]=0;h[b+5|0]=0;h[b+4|0]=6;h[b+5|0]=0;h[b|0]=0;h[b+1|0]=0;h[b+2|0]=8;h[b+3|0]=4}function IZ(a){a=a|0;var b=0;a=j[a+8>>2];if(!a){return 1}j[114626]=0;a=H(2568,a|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=J(0)|0;C()|0;ib(a);z()}function DAa(a,b,c){var d=0,e=0;d=Za-16|0;Za=d;pAa(b,c);c=yb(a,c<<3);if(c){e=Za-16|0;Za=e;Qb(d+8|0,j[b>>2],fg(b)<<3);Za=e+16|0;qd(a,d+8|0)}Za=d+16|0;return c}function qua(a,b,c,d,e){var f=0;if(d){while(1){n[b>>2]=q(j[a>>2])*e;n[c>>2]=q(j[a+4>>2])*e;c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;if((f|0)!=(d|0)){continue}break}}}function o0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=bb[j[j[a+8>>2]+20>>2]](a+8|0)|0;return Ei(g,b,c,d,e,f,zb(a),zb(a)+(nb(a)<<2)|0)|0}function kT(a,b){var c=0,d=0;c=Za-16|0;Za=c;a:{if(!b){break a}if(!yb(a,b)){break a}h[c+15|0]=0;Df(a,c+15|0);h[c+8|0]=k[c+15|0];d=k[c+8|0]}Za=c+16|0;return d}function jT(a,b){var c=0,d=0;c=Za-16|0;Za=c;a:{if(!b){break a}if(!yb(a,b)){break a}h[c+15|0]=0;Df(a,c+15|0);h[c+8|0]=k[c+15|0];d=h[c+8|0]}Za=c+16|0;return d}function j2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=h[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function hh(a){var b=0,c=0;b=a*a;c=b*a;return q(c*(b*b)*(b*2718311493989822e-21+ -.00019839334836096632)+(c*(b*.008333329385889463+ -.16666666641626524)+a))}function h4(a,b,c,d){var e=0;e=Za-16|0;Za=e;j[e+12>>2]=d;d=nb(b);if(d>>>0<c>>>0){Pl();z()}b=zb(b);j[e+4>>2]=d-c;Wo(a,b+c|0,j[tb(e+12|0,e+4|0)>>2]);Za=e+16|0}function oya(a,b){var c=0,d=0;if(me(a)>>>0>b>>>0){while(1){if(th(te(a,c))){nya(Lb(te(a,c)),Mb(te(a,c)))}d=d+1|0;c=d&65535;if(c>>>0<=b>>>0){continue}break}}}function eB(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0;h[a+8|0]=0;h[a+9|0]=0;Za=b+16|0}function dm(a,b){var c=0;c=j[j[b>>2]-12>>2];j[114626]=0;b=j[(b+c|0)+24>>2];c=j[114626];j[114626]=0;if((c|0)!=1){j[a>>2]=b;return a}a=J(0)|0;C()|0;ib(a);z()}function ak(a,b,c,d){j[d+8>>2]=b;j[d>>2]=0;j[d+4>>2]=0;j[c>>2]=d;if(j[j[a>>2]>>2]){j[a>>2]=j[j[a>>2]>>2]}BFa(j[Rb(a)>>2],j[c>>2]);a=hb(a);j[a>>2]=j[a>>2]+1}function SO(a){var b=0;a:{if(Yc(a,15547,3)){break a}b=a+4|0;if((k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))>>>0<423){break a}return k[a+3|0]<6}return 0}function Kt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;h[d+15|0]=b;h[d+14|0]=127;e=a,f=k[Yb(d+15|0,d+14|0)|0]|(c?-128:0),h[e+21|0]=f;Za=d+16|0}function Jt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Za-16|0;Za=d;h[d+15|0]=b;h[d+14|0]=127;e=a,f=k[Yb(d+15|0,d+14|0)|0]|(c?-128:0),h[e+22|0]=f;Za=d+16|0}function E5(a,b,c,d){var e=0,f=0,g=q(0);if((b|0)>=1){while(1){f=(e<<2)+a|0;g=n[f>>2];n[f+2304>>2]=g*d;n[f>>2]=g*c;e=e+1|0;if((e|0)!=(b|0)){continue}break}}}function BL(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;j[c+12>>2]=b;a:{if(Ti(a)){usa(c+8|0,c+12|0);ps(a,c+8|0);bf(c+8|0);break a}IL(j[a>>2],b)}AL(a);Za=c+16|0}function yfa(a,b,c){a=a|0;b=b|0;c=q(c);var d=0;d=Za-16|0;Za=d;n[d+12>>2]=c;if((b|0)<=4){Kd(d+12|0,q(0));n[((b<<2)+a|0)+4208>>2]=n[d+12>>2];aH(a)}Za=d+16|0}function yea(a,b,c){a=a|0;b=b|0;c=q(c);var d=0;d=Za-16|0;Za=d;n[d+12>>2]=c;if((b|0)<=2){Kd(d+12|0,q(0));n[((b<<2)+a|0)+4208>>2]=n[d+12>>2];SG(a)}Za=d+16|0}function taa(a,b,c){dr(a);j[a+8>>2]=c;j[a+4>>2]=0;j[a>>2]=84080;c=j[b+4>>2];j[a+12>>2]=j[b>>2];j[a+16>>2]=c;c=j[b+12>>2];j[a+20>>2]=j[b+8>>2];j[a+24>>2]=c}function rea(a,b,c){a=a|0;b=b|0;c=q(c);var d=0;d=Za-16|0;Za=d;n[d+12>>2]=c;if((b|0)<=3){Kd(d+12|0,q(0));n[((b<<2)+a|0)+4208>>2]=n[d+12>>2];QG(a)}Za=d+16|0}function raa(a,b,c){dr(a);j[a+8>>2]=c;j[a+4>>2]=0;j[a>>2]=84176;c=j[b+4>>2];j[a+12>>2]=j[b>>2];j[a+16>>2]=c;c=j[b+12>>2];j[a+20>>2]=j[b+8>>2];j[a+24>>2]=c}function dsa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+8>>2]=c;j[d>>2]=b;if(rb(d,d+8|0)){while(1){tL(a,k[j[d>>2]]);Xf(d);if(rb(d,d+8|0)){continue}break}}Za=d+16|0}function bFa(a,b){var c=0,d=0;c=Za-16|0;Za=c;OP(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}



function _8(a,b){a=a|0;b=b|0;var c=0;a:{if(!er(b)){break a}a=a+24|0;if(!tg(j[a>>2]+484344|0,b&65535)){break a}c=j[Ib(j[a>>2]+484344|0,b)+12>>2]}return c|0}function Tj(a,b){var c=0,d=0;a:{b=Uj(a,b);if((b|0)==255){break a}if(Ti(a)){break a}c=a+4|0;d=Pb(c,b);h[d|0]=k[d|0]&223;Og(j[a>>2],gs(b)|176,k[Pb(c,b)|0])}}function Soa(a){var b=0,c=0;b=250;c=a;a:{while(1){if(j[c>>2]){break a}c=c+4|0;b=b-32|0;if(b>>>0>31){continue}break}return(j[a+28>>2]&67108863)!=0}return 1}function Kfa(a,b,c){a=a|0;b=b|0;c=q(c);var d=0;d=Za-16|0;Za=d;n[d+12>>2]=c;if((b|0)<=5){Kd(d+12|0,q(0));n[((b<<2)+a|0)+4208>>2]=n[d+12>>2];dH(a)}Za=d+16|0}function JK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(j[a+480180>>2]&2){break a}}j[b+56>>2]=0;d=Go(a,l[b+60>>1],j[b+48>>2],c,0)}return d|0}function FU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=j[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Eaa(a,b){var c=0,d=0;c=ue(44);j[114626]=0;b=E(2127,c|0,b|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){Aaa(a,b);return}a=D()|0;C()|0;Cb(c);G(a|0);z()}function D1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;j[e+12>>2]=b;j[e+8>>2]=d;b=ch(e,e+12|0);a=yD(a,c,j[e+8>>2]);pe(b);Za=e+16|0;return a|0}function xV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=j[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function ro(a,b){var c=0;j[a>>2]=76736;j[a>>2]=77152;c=j[b+8>>2];j[a+4>>2]=j[b+4>>2];j[a+8>>2]=c;c=j[b+16>>2];j[a+12>>2]=j[b+12>>2];j[a+16>>2]=c;return a}function rf(a,b,c){a:{switch(b-1|0){case 0:if(c){return ai(a,1)}return ai(a,0);case 1:if(c){return ai(a,3)}return ai(a,2);default:break a}}return ai(a,4)}function br(a){var b=0,c=0,d=0;b=TMa(j[a>>2],1)^270549120;c=j[a+4>>2];d=(b+(c<<2)|0)+2019860093|0;j[a>>2]=d;b=a;a=p(TMa(d,16),5)+c|0;j[b+4>>2]=a;return a}function aC(a,b){a=a|0;b=b|0;pm(a);j[a>>2]=71436;j[114626]=0;E(2829,a+4|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a|0}a=D()|0;C()|0;G(a|0);z()}function Yk(a){var b=0,c=0,d=0;b=Za-16|0;Za=b;c=j[a+1074400>>2];d=j[a+1074416>>2];j[b+12>>2]=1;a=j[Gc(a+1074396|0,b+12|0)>>2];Za=b+16|0;return p(a,c+d|0)}function KEa(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-16|0;Za=d;c=-1;a:{if(!hj(a,d+8|0)){break a}c=0;if(!JEa(d+8|0)){break a}c=Le(a,b,36,0)}Za=d+16|0;return c|0}function Iv(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=q(q(n[((c&3)<<2)+43568>>2]*a)*q(1073741824>>>(c>>2)|0));b=b-c|0;if((b|0)>0){continue}break}return a}function Ai(a,b,c,d){var e=0,f=0;e=p(b,c);f=e;a:{if(j[d+76>>2]<=-1){a=yu(a,e,d);break a}a=yu(a,e,d)}if((f|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function xma(a){var b=0;a:{if(!j[a+16>>2]){break a}b=j[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=j[a+28>>2];if(a>>>0>4){break a}return 23>>>a&1}return 0}function wxa(a,b){a=a|0;b=b|0;var c=0;Lh(a);c=b+4|0;uxa(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];bm(a,cc(a))}function wE(a){var b=0,c=0,d=0;if(Ig(h[j[a>>2]])){while(1){b=j[a>>2];d=h[b|0];j[a>>2]=b+1;c=(p(c,10)+d|0)-48|0;if(Ig(h[b+1|0])){continue}break}}return c}function uja(a,b){a=a|0;b=b|0;var c=0;rJ(a);c=b+4|0;sja(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];jI(a,df(a))}function spa(a){if(!(a<q(2147483648))){return 2147483647}if(!(a>q(-2147483648))){return-2147483648}if(q(r(a))<q(2147483648)){return~~a}return-2147483648}function sk(a,b){var c=0;c=j[j[b>>2]-12>>2];j[114626]=0;b=H(27,b+c|0)|0;c=j[114626];j[114626]=0;if((c|0)!=1){j[a>>2]=b;return a}a=J(0)|0;C()|0;ib(a);z()}function rY(a,b,c){var d=0;d=Za-16|0;Za=d;m2(d,b,c,Wd());b=j[d+4>>2];j[a>>2]=j[d>>2];j[a+4>>2]=b;b=j[d+12>>2];j[a+8>>2]=j[d+8>>2];j[a+12>>2]=b;Za=d+16|0}function pga(a){var b=0,c=0,d=0;b=ue(12);j[114626]=0;c=H(1745,b|0)|0;d=j[114626];j[114626]=0;if((d|0)!=1){mga(a,c);return}a=D()|0;C()|0;Cb(b);G(a|0);z()}function im(a,b){var c=0,d=0;b=b+7&-8;d=j[a+80>>2];a:{if(d){b=j[a+92>>2]-b|0;c=0;if((b|0)<j[a+88>>2]){break a}j[a+92>>2]=b;return b+d|0}c=_c(b)}return c}function era(a,b){a=a|0;b=b|0;var c=0;Lh(a);c=b+4|0;cra(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];bm(a,cc(a))}function Z2(a,b){a=a|0;b=b|0;var c=0,d=0;b=hv(b);j[a+36>>2]=b;c=a,d=so(b),j[c+44>>2]=d;c=a,d=am(j[a+36>>2]),h[c+53|0]=d;if(j[a+44>>2]>=9){Sl(56996);z()}}function Wha(a,b){a=a|0;b=b|0;var c=0;af(a);c=b+4|0;Vha(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Oj(a,sb(a))}function V2(a,b){a=a|0;b=b|0;var c=0,d=0;b=gv(b);j[a+36>>2]=b;c=a,d=so(b),j[c+44>>2]=d;c=a,d=am(j[a+36>>2]),h[c+53|0]=d;if(j[a+44>>2]>=9){Sl(56996);z()}}function Nsa(a,b){a=a|0;b=b|0;var c=0;Dl(a);c=b+4|0;Ksa(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Wp(a,de(a))}function LDa(a,b){a=a|0;b=b|0;var c=0;sh(a);c=b+4|0;JDa(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];pt(a,pd(a))}function Jxa(a,b){a=a|0;b=b|0;var c=0;Lh(a);c=b+4|0;oxa(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];bm(a,cc(a))}function HE(a,b,c,d,e,f){var g=0,i=0;g=j[a+32>>2];i=g+(c<<2)|0;a:{if(!k[a+23|0]){break a}i=g;g=d<<2;j[i+g>>2]=b;h[j[a+8>>2]+d|0]=e;b=c;i=f+g|0}j[i>>2]=b}function CHa(a,b){a=a|0;b=b|0;var c=0;wk(a);c=b+4|0;AHa(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Ml(a,Xc(a))}function xc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(m[a+8>>2]<b>>>0){d=j[a>>2];c=0;if(bb[j[j[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}j[a+8>>2]=b;c=1}return c|0}function xL(a){var b=0,c=0,d=0;b=a+26|0;c=k[b|0]+27|0;if(k[b|0]){while(1){c=k[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<k[b|0]){continue}break}}return c&65535}function rp(a,b){a=a|0;b=b|0;var c=0;sh(a);c=b+4|0;HJa(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];pt(a,pd(a))}function qoa(a,b){a=a|0;b=b|0;var c=0;Dl(a);c=b+4|0;uh(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Wp(a,de(a))}function jAa(a,b){a=a|0;b=b|0;var c=0;Zp(a);c=b+4|0;uh(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];eu(a,fg(a))}function b_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=j[b>>2];h[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function _Ea(a,b){a=a|0;b=b|0;var c=0;ft(a);c=b+4|0;IP(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];jt(a,Kf(a))}function Jda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-32|0;Za=c;d=c,e=WK(b),j[d+16>>2]=e;Gda(c+24|0,a,b,c+16|0,c+8|0);a=Rg(c+24|0);Za=c+32|0;return a+12|0}function I0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=bb[j[j[a+8>>2]+20>>2]](a+8|0)|0;return Fi(g,b,c,d,e,f,zb(a),zb(a)+nb(a)|0)|0}function zya(a,b){var c=0,d=0;c=Za-16|0;Za=c;kN(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function zMa(a,b){var c=0,d=0;c=Za-16|0;Za=c;$S(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function wKa(a,b){var c=0,d=0;c=Za-16|0;Za=c;NR(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function vY(a,b){a=a|0;b=b|0;var c=0;wC(a);c=b+4|0;uh(Ck(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(kq(a),Ob(b));j[b>>2]=j[b+4>>2];gC(a,sb(a))}function vKa(a,b){var c=0,d=0;c=Za-16|0;Za=c;NR(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function uka(a,b){var c=0,d=0;c=Za-16|0;Za=c;CI(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function tya(a,b){var c=0,d=0;c=Za-16|0;Za=c;gN(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function tka(a,b){var c=0,d=0;c=Za-16|0;Za=c;CI(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function tIa(a,b){var c=0,d=0;c=Za-16|0;Za=c;Zz(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function tHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;IQ(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function tAa(a,b){var c=0,d=0;c=Za-16|0;Za=c;bO(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function sya(a,b){var c=0,d=0;c=Za-16|0;Za=c;gN(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function sHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;IQ(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function rIa(a,b){var c=0,d=0;c=Za-16|0;Za=c;xS(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function qHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;GQ(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function qFa(a,b){var c=0,d=0;c=Za-16|0;Za=c;tt(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function pFa(a,b){var c=0,d=0;c=Za-16|0;Za=c;tt(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function oV(a,b){a=a|0;b=b|0;var c=0;Dl(a);c=b+4|0;eV(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Wp(a,de(a))}function oJa(a,b){var c=0,d=0;c=Za-16|0;Za=c;rR(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function mJa(a,b){var c=0,d=0;c=Za-16|0;Za=c;rR(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function mHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;CQ(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function mDa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-32|0;Za=c;d=c,e=$g(b),j[d+16>>2]=e;aDa(c+24|0,a,b,c+16|0,c+8|0);a=Ps(c+24|0);Za=c+32|0;return a+2|0}function lHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;CQ(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function kpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-32|0;Za=c;d=c,e=WK(b),j[d+16>>2]=e;Yoa(c+24|0,a,b,c+16|0,c+8|0);a=Ps(c+24|0);Za=c+32|0;return a+4|0}function kIa(a,b){var c=0,d=0;c=Za-16|0;Za=c;qz(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function jIa(a,b){var c=0,d=0;c=Za-16|0;Za=c;qz(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function ih(a,b,c){j[b+12>>2]=j[b+12>>2]+c;j[b+8>>2]=j[b+8>>2]-c;c=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=c;c=j[b+12>>2];j[a+8>>2]=j[b+8>>2];j[a+12>>2]=c}function iIa(a,b){var c=0,d=0;c=Za-16|0;Za=c;Az(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function iBa(a,b){var c=0,d=0;c=Za-16|0;Za=c;pO(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function gBa(a,b){var c=0,d=0;c=Za-16|0;Za=c;uy(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function g8(a,b){a=a|0;b=b|0;var c=0;wk(a);c=b+4|0;f8(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Ml(a,Xc(a))}function fya(a,b){var c=0,d=0;c=Za-16|0;Za=c;pk(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function fpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-32|0;Za=c;d=c,e=$g(b),j[d+16>>2]=e;Uoa(c+24|0,a,b,c+16|0,c+8|0);a=Rg(c+24|0);Za=c+32|0;return a+8|0}function eya(a,b){var c=0,d=0;c=Za-16|0;Za=c;nO(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function eBa(a,b){var c=0,d=0;c=Za-16|0;Za=c;pO(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function dBa(a,b){var c=0,d=0;c=Za-16|0;Za=c;nO(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function cFa(a,b){var c=0,d=0;c=Za-16|0;Za=c;Ty(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function bsa(a,b){var c=0,d=0;c=Za-16|0;Za=c;sL(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function bHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;wQ(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function aya(a,b){var c=0,d=0;c=Za-16|0;Za=c;GQ(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function aHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;wQ(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function aBa(a,b){var c=0,d=0;c=Za-16|0;Za=c;lO(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function aA(a,b){a=a|0;b=b|0;var c=0;Ap(a);c=b+4|0;uh(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];lS(a,tc(a))}function a8(a,b){a=a|0;b=b|0;var c=0;sh(a);c=b+4|0;$7(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];pt(a,pd(a))}function _S(a,b){a=a|0;b=b|0;var c=0;wl(a);c=b+4|0;uh(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Rt(a,bc(a))}function _Ka(a,b,c){var d=0,e=0;d=Za-16|0;Za=d;UT(b,c);c=yb(a,c);if(c){e=Za-16|0;Za=e;Qb(d+8|0,j[b>>2],tc(b));Za=e+16|0;qd(a,d+8|0)}Za=d+16|0;return c}function _Aa(a,b){var c=0,d=0;c=Za-16|0;Za=c;lO(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function YCa(a,b){var c=0,d=0;c=Za-16|0;Za=c;$O(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function XDa(a,b){var c=0,d=0;c=Za-16|0;Za=c;Py(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function VCa(a,b){var c=0,d=0;c=Za-16|0;Za=c;$O(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function RHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;at(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function REa(a,b){var c=0,d=0;c=Za-16|0;Za=c;GP(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function RDa(a,b){var c=0,d=0;c=Za-16|0;Za=c;Nz(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function QHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;at(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function PLa(a,b){var c=0,d=0;c=Za-16|0;Za=c;AS(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function OLa(a,b){var c=0,d=0;c=Za-16|0;Za=c;AS(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function Ng(a,b){a=a|0;b=b|0;var c=0;af(a);c=b+4|0;uh(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Oj(a,sb(a))}function Mwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;a:{if(k[d|0]){Hwa(a,vd(e+8|0,b),ei(c,b));break a}Gwa(a,vd(e,b),ei(c,b))}Za=e+16|0}function LLa(a,b){var c=0,d=0;c=Za-16|0;Za=c;yS(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function LFa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-32|0;Za=c;d=c,e=$g(b),j[d+16>>2]=e;GFa(c+24|0,a,b,c+16|0,c+8|0);a=Rg(c+24|0);Za=c+32|0;return a+4|0}function KLa(a,b){var c=0,d=0;c=Za-16|0;Za=c;yS(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function KKa(a,b){var c=0,d=0;c=Za-16|0;Za=c;Nz(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function JKa(a,b){var c=0,d=0;c=Za-16|0;Za=c;XR(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function IKa(a,b){var c=0,d=0;c=Za-16|0;Za=c;XR(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function Hza(a,b){var c=0,d=0;c=Za-16|0;Za=c;IN(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function Gza(a,b){var c=0,d=0;c=Za-16|0;Za=c;IN(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function GW(a,b){a=a|0;b=b|0;var c=0;wk(a);c=b+4|0;uh(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];Ml(a,Xc(a))}function G3(a,b){a=a|0;b=b|0;var c=0;Lh(a);c=b+4|0;r3(hb(a),j[a>>2],j[a+4>>2],c);Hb(a,c);Hb(a+4|0,b+8|0);Hb(hb(a),Ob(b));j[b>>2]=j[b+4>>2];bm(a,cc(a))}function Ewa(a,b){var c=0,d=0;c=Za-16|0;Za=c;OP(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function EIa(a,b){var c=0,d=0;c=Za-16|0;Za=c;et(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function DKa(a,b){var c=0,d=0;c=Za-16|0;Za=c;Tp(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function DIa(a,b){var c=0,d=0;c=Za-16|0;Za=c;et(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function Cxa(a,b){var c=0,d=0;c=Za-16|0;Za=c;SM(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function Cwa(a,b){var c=0,d=0;c=Za-16|0;Za=c;Jy(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function CKa(a,b){var c=0,d=0;c=Za-16|0;Za=c;Lz(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function CAa(a,b){var c=0,d=0;c=Za-16|0;Za=c;cO(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function Bxa(a,b){var c=0,d=0;c=Za-16|0;Za=c;SM(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function BKa(a,b){var c=0,d=0;c=Za-16|0;Za=c;Lz(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function Aya(a,b){var c=0,d=0;c=Za-16|0;Za=c;kN(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function AMa(a,b){var c=0,d=0;c=Za-16|0;Za=c;$S(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function AAa(a,b){var c=0,d=0;c=Za-16|0;Za=c;cO(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function $Aa(a,b){var c=0,d=0;c=Za-16|0;Za=c;uy(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function zU(a,b){var c=0,d=0;c=Za-16|0;Za=c;bu(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function zJ(a){if(j[a+480224>>2]==2){return+m[a+1074420>>2]*1e-4}return+m[a+24620>>2]*60/(+m[a+1074404>>2]*+(p(j[a+1074408>>2],j[a+1074416>>2])>>>0))}function z8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<2;a=0;while(1){if(d){Ab(j[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function y8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<3;a=0;while(1){if(d){Ab(j[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function vV(a,b){var c=0,d=0;c=Za-16|0;Za=c;dB(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function uV(a,b){var c=0,d=0;c=Za-16|0;Za=c;bB(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function rV(a,b){var c=0,d=0;c=Za-16|0;Za=c;dB(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function qV(a,b){var c=0,d=0;c=Za-16|0;Za=c;bB(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function pP(a,b){var c=0,d=0;c=Za-16|0;Za=c;oz(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function n2(a,b,c){var d=0;d=Za-16|0;Za=d;Zu(d,b,c,2);b=j[d+4>>2];j[a>>2]=j[d>>2];j[a+4>>2]=b;b=j[d+12>>2];j[a+8>>2]=j[d+8>>2];j[a+12>>2]=b;Za=d+16|0}function mU(a,b){var c=0,d=0;c=Za-16|0;Za=c;Qp(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function lU(a,b){var c=0,d=0;c=Za-16|0;Za=c;Qp(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function hY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ne(b);d=ue(c+13|0);j[d+8>>2]=0;j[d+4>>2]=c;j[d>>2]=c;e=a,f=Vb(d+12|0,b,c+1|0),j[e>>2]=f;return a|0}function gU(a,b,c){a=a+4|0;a=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);return!c&b>>>0>=(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))-8>>>0|(c|0)!=0}function cu(a,b){var c=0,d=0;c=Za-16|0;Za=c;bu(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function aN(a,b){var c=0,d=0;c=Za-16|0;Za=c;ah(c+8|0,b);b=pb(c+8|0);d=Vc(a,Kb(c,c+8|0));if((b|0)==(d|0)){Fc(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function aI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Za-32|0;Za=c;d=c,e=$g(b),j[d+16>>2]=e;Yia(c+24|0,a,b,c+16|0,c+8|0);a=Rg(c+24|0);Za=c+32|0;return a+4|0}function Zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(dq(a)>>>0<b>>>0){Jc();z()}hb(a);c=MF(b);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=(b<<4)+c|0,j[d>>2]=e;Ml(a,0)}function ZV(a,b,c,d){var e=0;if(!d){return-1}b=a+b|0;e=-1;a:{while(1){if((a|0)==(b|0)){break a}b=b-1|0;if(!An(c,d,b)){continue}break}e=b-a|0}return e}function Vp(a,b){var c=0,d=0;c=Za-16|0;Za=c;ah(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function Vc(a,b){var c=0,d=0,e=0,f=0,g=0;c=Za-16|0;Za=c;a=(e=a,f=j[a+12>>2],g=Kb(c+8|0,b),d=j[j[a>>2]+32>>2],bb[d](e|0,f|0,g|0)|0);Za=c+16|0;return a}function VZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=h[b|0];h[e|0]=(a|0)>-1?a:d;e=e+1|0;b=b+1|0;continue}break}return c|0}function Tna(a){j[a>>2]=0;j[a+4>>2]=0;j[a+32>>2]=0;j[a+36>>2]=1072693248;j[a+24>>2]=0;j[a+28>>2]=0;j[a+16>>2]=0;j[a+20>>2]=0;j[a+8>>2]=0;j[a+12>>2]=0}function Su(a){var b=0,c=0;j[114626]=0;c=T(2558)|0;b=j[114626];j[114626]=0;if((b|0)!=1){b=a;a=j[c>>2];j[b>>2]=a;Il(a);return}a=J(0)|0;C()|0;ib(a);z()}function SLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(dq(a)>>>0<b>>>0){Jc();z()}hb(a);c=oS(b);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=(b<<4)+c|0,j[d>>2]=e;Ml(a,0)}function QAa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=hf(b);hf(b);break a}a=Of(b);Of(b)}if(a){while(1){if(a&1){Jb(b,260)}a=a>>>1|0;if(a){continue}break}}}function Jza(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Jm(a)>>>0<b>>>0){Jc();z()}hb(a);c=GN(b);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=(b<<2)+c|0,j[d>>2]=e;Oj(a,0)}function Ip(a,b){var c=0,d=0;c=Za-16|0;Za=c;pk(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function Df(a,b){var c=0,d=0;c=Za-16|0;Za=c;Tp(c+8|0,b);b=pb(c+8|0);d=Xb(a,Kb(c,c+8|0));if((b|0)==(d|0)){Jb(a,pb(c+8|0))}Za=c+16|0;return(b|0)==(d|0)}function Ci(a){var b=0;b=R(8)|0;j[114626]=0;E(214,b|0,a|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Y(b|0,71656,24);z()}a=D()|0;C()|0;S(b|0);G(a|0);z()}function CEa(a,b){var c=0;HGa(a);j[a>>2]=76620;c=j[b+4>>2];j[a+24>>2]=j[b>>2];j[a+28>>2]=c;c=j[b+12>>2];j[a+32>>2]=j[b+8>>2];j[a+36>>2]=c;h[a+40|0]=0}function B9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(SK(a)>>>0<b>>>0){Jc();z()}hb(a);c=RK(b);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=p(b,12)+c|0,j[d>>2]=e;bm(a,0)}function rya(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-96|0;Za=d;c=-1;a:{if(!QN(a,d)){break a}c=0;if(!fN(d)){break a}c=Le(a,b,eN(d),ab)}Za=d+96|0;return c|0}function ry(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(St(a)>>>0<b>>>0){Jc();z()}hb(a);c=YS(b);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=(b<<1)+c|0,j[d>>2]=e;Rt(a,0)}function oc(a){var b=0;b=R(8)|0;j[114626]=0;E(23,b|0,a|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){Y(b|0,71604,24);z()}a=D()|0;C()|0;S(b|0);G(a|0);z()}function jQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(vz(a)>>>0<b>>>0){Jc();z()}hb(a);c=MP(b);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=p(b,6)+c|0,j[d>>2]=e;jt(a,0)}function ixa(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-48|0;Za=d;c=-1;a:{if(!$M(a,d)){break a}c=0;if(!OM(d)){break a}c=Le(a,b,NM(d),ab)}Za=d+48|0;return c|0}function dya(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-48|0;Za=d;c=-1;a:{if(!$M(a,d)){break a}c=0;if(!_M(d)){break a}c=Le(a,b,ZM(d),ab)}Za=d+48|0;return c|0}function dma(a,b,c){var d=0,e=0;d=b-a|0;if((d|0)>=3){d=d>>>1|0;while(1){ZI(a,b-2|0);Ww(a,c,d-1|0,a);b=b-2|0;e=(d|0)>2;d=d-1|0;if(e){continue}break}}}function Qza(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-96|0;Za=d;c=-1;a:{if(!QN(a,d)){break a}c=0;if(!PN(d)){break a}c=Le(a,b,ON(d),ab)}Za=d+96|0;return c|0}function Ksa(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=j[d>>2];while(1){c=c-32|0;NL(a,e-32|0,c);e=j[d>>2]-32|0;j[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function KS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Jm(a)>>>0<b>>>0){Jc();z()}hb(a);c=QK(b);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=(b<<2)+c|0,j[d>>2]=e;Oj(a,0)}function JDa(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=j[d>>2];while(1){c=c-24|0;rP(a,e-24|0,c);e=j[d>>2]-24|0;j[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function HJa(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=j[d>>2];while(1){c=c-24|0;sp(a,e-24|0,c);e=j[d>>2]-24|0;j[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function G$(a){var b=0,c=0;b=Za-16|0;Za=b;a:{if(qe(a)){c=j[a>>2];j[b+12>>2]=0;ze(c,b+12|0);ee(a,0);break a}j[b+8>>2]=0;ze(a,b+8|0);Ue(a,0)}Za=b+16|0}function De(a){var b=0,c=0;b=Za-16|0;Za=b;a:{if(qe(a)){c=j[a>>2];h[b+15|0]=0;Td(c,b+15|0);ee(a,0);break a}h[b+14|0]=0;Td(a,b+14|0);Ue(a,0)}Za=b+16|0}function B_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(iC(a)>>>0<b>>>0){Jc();z()}c=hC(Ck(a),b);j[a>>2]=c;j[a+4>>2]=c;d=kq(a),e=(b<<2)+c|0,j[d>>2]=e;gC(a,0)}function yU(a,b){a=a|0;b=b|0;var c=0;b=Za-48|0;Za=b;c=-1;a:{if(!KA(a,b+8|0)){break a}c=0;if(!MI(b+8|0)){break a}c=zla(a,b+8|0)}Za=b+48|0;return c|0}function vJa(a){var b=0;b=j[a+4>>2];a=j[a>>2];j[114626]=0;a=E(532,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a}a=J(0)|0;C()|0;ib(a);z()}function r3(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=j[d>>2];while(1){c=c-12|0;Iq(a,e-12|0,c);e=j[d>>2]-12|0;j[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function pY(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+8>>2]=c;while(1){if((a|0)!=(b|0)){WD(d+8|0,j[a>>2]);a=a+4|0;continue}break}Za=d+16|0;return j[d+8>>2]}function pJa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=yb(a,64);a:{if(d){Az(c+8|0,b);qd(a,c+8|0);break a}a=Za-16|0;Za=a;lJa(b);Za=a+16|0}Za=c+16|0;return d}function kaa(a){a=a|0;var b=0,c=0;b=Za-16|0;Za=b;c=j[a+4>>2];a=j[a>>2];j[b>>2]=a;j[b+4>>2]=c;j[b+8>>2]=a;j[b+12>>2]=c;a=Yla(b);Za=b+16|0;return a|0}function kX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Rf(a,j[b+8>>2],f)){Bu(b,c,d,e);return}a=j[a+8>>2];bb[j[j[a>>2]+20>>2]](a,b,c,d,e,f)}function f8(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=j[d>>2];while(1){c=c-16|0;LF(a,e-16|0,c);e=j[d>>2]-16|0;j[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function esa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=yb(a,27);a:{if(d){sL(c+8|0,b);qd(a,c+8|0);break a}a=Za-16|0;Za=a;Xra(b);Za=a+16|0}Za=c+16|0;return d}function eV(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=j[d>>2];while(1){c=c-32|0;WA(a,e-32|0,c);e=j[d>>2]-32|0;j[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function ZLa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=yb(a,16);a:{if(d){xS(c+8|0,b);qd(a,c+8|0);break a}a=Za-16|0;Za=a;JLa(b);Za=a+16|0}Za=c+16|0;return d}function WHa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=yb(a,64);a:{if(d){Az(c+8|0,b);qd(a,c+8|0);break a}a=Za-16|0;Za=a;JHa(b);Za=a+16|0}Za=c+16|0;return d}function Sx(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(!ke(a)){break a}Nm(a);if(c){qka(a,b)}if((Op(a)|0)==2){Dta(a,b);return}if((Op(a)|0)!=1){break a}Cta(a,b)}}function $Ka(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;c=0;if(Df(a,d+8|0)){j[d+4>>2]=k[d+8|0];c=FKa(a,b,j[tb(d+4|0,d+12|0)>>2])}Za=d+16|0;return c}function yza(a){var b=0;b=j[a+4>>2];a=j[a>>2];j[114626]=0;a=E(79,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a}a=J(0)|0;C()|0;ib(a);z()}function x_(){var a=0;td(463408);j[114626]=0;H(2552,463416)|0;a=j[114626];j[114626]=0;if((a|0)!=1){j[115852]=65532;return}a=D()|0;C()|0;G(a|0);z()}function w_(){var a=0;td(463424);j[114626]=0;H(2552,463432)|0;a=j[114626];j[114626]=0;if((a|0)!=1){j[115856]=65688;return}a=D()|0;C()|0;G(a|0);z()}function uv(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=d&1?a*c:c;if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function rwa(a){var b=0,c=0;fQ(a);a:{while(1){c=a+b|0;if(k[c|0]){b=b+1|0;if((b|0)!=32){continue}break a}break}if(b>>>0>31){break a}Ab(c,0,32-b|0)}}function qY(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+8>>2]=c;while(1){if((a|0)!=(b|0)){XD(d+8|0,h[a|0]);a=a+1|0;continue}break}Za=d+16|0;return j[d+8>>2]}function k4(a,b){a=a|0;b=b|0;var c=0,d=0;c=j[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;bb[j[j[a+32>>2]+d>>2]](b,a,j[d+j[a+36>>2]>>2]);continue}break}}function cla(a,b){a=a|0;b=b|0;var c=0;if(!(k[b+14|0]&48|k[b+17|0]!=173)){Mc(a,8,1,0,11);return}c=a;a=b+14|0;Mc(c,k[a|0]&16?16:8,k[a|0]&32?3:1,0,2)}function cLa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;c=0;if(Df(a,d+8|0)){j[d+4>>2]=k[d+8|0];c=aS(a,b,j[tb(d+4|0,d+12|0)>>2])}Za=d+16|0;return c}function bLa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;c=0;if(Df(a,d+8|0)){j[d+4>>2]=k[d+8|0];c=WR(a,b,j[tb(d+4|0,d+12|0)>>2])}Za=d+16|0;return c}function aLa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;c=0;if(Df(a,d+8|0)){j[d+4>>2]=k[d+8|0];c=VR(a,b,j[tb(d+4|0,d+12|0)>>2])}Za=d+16|0;return c}function aCa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=yb(a,2);a:{if(d){pk(c+8|0,b);qd(a,c+8|0);break a}a=Za-16|0;Za=a;PBa(b);Za=a+16|0}Za=c+16|0;return d}function ZW(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;return Nda(a,b,c,d,e,f,g,h,i,j,k,l)|0}function XJa(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;c=0;if(Df(a,d+8|0)){j[d+4>>2]=k[d+8|0];c=BR(a,b,j[tb(d+4|0,d+12|0)>>2])}Za=d+16|0;return c}function SJa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=yb(a,8);a:{if(d){bu(c+8|0,b);qd(a,c+8|0);break a}a=Za-16|0;Za=a;xJa(b);Za=a+16|0}Za=c+16|0;return d}function RLa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=yb(a,3);a:{if(d){Zz(c+8|0,b);qd(a,c+8|0);break a}a=Za-16|0;Za=a;uLa(b);Za=a+16|0}Za=c+16|0;return d}function R8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=Za-32|0;Za=h;TF(h+8|0,b,c,d,e,f,g);Nc(a,h+20|0);Im(h+8|0);Za=h+32|0}function OA(a){var b=0;b=j[a+4>>2];a=j[a>>2];j[114626]=0;a=E(288,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a}a=J(0)|0;C()|0;ib(a);z()}function Mx(a,b,c){var d=0,e=0,f=0;d=Uj(a,b);if((d|0)!=255){e=Oc(a+22|0,d),f=c,i[e>>1]=f;a=a+58|0;e=Pb(a,b),f=255,h[e|0]=f;e=Pb(a,c),f=d,h[e|0]=f}}function Lra(a,b){var c=0,d=0,e=0;while(1){d=d<<1|c>>>31;c=a&1|c<<1;a=(b&1)<<31|a>>>1;b=b>>>1|0;e=e+1|0;if((e|0)!=64){continue}break}ab=d;return c}function GO(a){var b=0;b=j[a+4>>2];a=j[a>>2];j[114626]=0;a=E(878,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a}a=J(0)|0;C()|0;ib(a);z()}function GAa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=yb(a,6);a:{if(d){oz(c+8|0,b);qd(a,c+8|0);break a}a=Za-16|0;Za=a;yAa(b);Za=a+16|0}Za=c+16|0;return d}function F8(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-32|0;Za=c;d=j[b+4>>2];j[c+8>>2]=j[b>>2];j[c+12>>2]=d;Wo(a,j[c+8>>2],j[c+12>>2]);Za=c+32|0;return a|0}function rv(a,b,c,d){var e=0;e=em(a,b,c);if(rd(d,c)){Hb(c,d);if(!rd(c,b)){return e+1|0}Hb(b,c);if(!rd(b,a)){return e+2|0}Hb(a,b);e=e+3|0}return e}function pb(a){var b=0;b=j[a+4>>2];a=j[a>>2];j[114626]=0;a=E(34,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a}a=J(0)|0;C()|0;ib(a);z()}function n6(a,b,c){a:{if((a|0)==(b|0)){break a}c=l[c>>1];while(1){if((c|0)==l[a>>1]){break a}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function YG(a){var b=0;b=(xe(j[a+16>>2])>>>0)/(di(q(n[a+4208>>2]*q(999)))+1>>>0)|0;b=b>>>0>2?b:2;j[a+4216>>2]=b;j[a+4220>>2]=b>>>1;kc(a+4224|0,b)}function Xg(a){var b=0;b=j[a+4>>2];a=j[a>>2];j[114626]=0;a=E(29,a|0,b|0)|0;b=j[114626];j[114626]=0;if((b|0)!=1){return a}a=J(0)|0;C()|0;ib(a);z()}function Vha(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=j[d>>2];while(1){c=c-4|0;QH(a,e-4|0,c);e=j[d>>2]-4|0;j[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function VBa(a,b,c){var d=0;d=ri(a+8|0);j[114626]=0;I(421,a|0,b|0,c|0);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=D()|0;C()|0;wg(d);G(a|0);z()}function T8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=Za-32|0;Za=h;TF(h+8|0,b,c,d,e,f,g);Nc(a,h+8|0);Im(h+8|0);Za=h+32|0}function Gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=d;d=j[b+12>>2];j[a+8>>2]=j[b+8>>2];j[a+12>>2]=d;Kx(a,o[c>>3])}function GE(a,b){a:{b:{if(k[a+23|0]){a=1;if((b|0)!=255){break b}X(52190,50496,1165,52205);z()}if((b|0)!=255){break a}a=0}return a}return b>>>0>10}function DK(a,b){var c=0,d=0;c=Vb(a,b,602);a=0;while(1){d=p(a,896);Rr((d+c|0)+608|0,(b+d|0)+608|0);a=a+1|0;if((a|0)!=256){continue}break}return c}function yD(a,b,c){var d=0;d=Za-144|0;Za=d;d=Ab(d,0,144);j[d+76>>2]=-1;j[d+44>>2]=a;j[d+32>>2]=2406;j[d+84>>2]=a;a=G2(d,b,c);Za=d+144|0;return a}function t5(a,b){var c=0;b=b<<1;c=a+1092|0;a:{b:{if((b|0)==j[a+112>>2]){break b}c=0;if((b|0)!=j[a+116>>2]){break a}c=a+1096|0}c=j[c>>2]}return c}function kv(a){var b=0,c=0;b=Za-16|0;Za=b;c=-1;a:{if(SD(a)){break a}if((bb[j[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=k[b+15|0]}Za=b+16|0;return c}function ema(a,b,c){var d=0,e=0;b=b-a|0;if((b|0)>=3){d=b>>1;b=(d-2|0)/2|0;while(1){Ww(a,c,d,(b<<1)+a|0);e=(b|0)>0;b=b-1|0;if(e){continue}break}}}function bo(a,b){var c=0;a:{if(!ZE(b)|(k[b+1|0]^k[a+1|0])>>>0>1){break a}b=k[b+2|0];a=k[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function _ma(a,b,c){h[a+6|0]=255;j[a+16>>2]=0;i[a+4>>1]=0;j[a>>2]=0;if(!((b|0)==65535|(c|0)==-1)){j[a+8>>2]=c;j[a+16>>2]=2;i[a+12>>1]=b}return a}function Cg(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;h[c+15|0]=0;a=xk(a,c+15|0,1);h[c+8|0]=k[c+15|0];h[b|0]=k[c+8|0];Za=c+16|0;return!ab&(a|0)==1}function zy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;i[d+14>>1]=b;i[d+12>>1]=c;if((b|0)!=(c|0)){hBa(Lb(a),Mb(a),d+14|0,d+12|0)}Za=d+16|0}function zu(a,b,c,d,e,f){var g=0,h=0,i=0;g=j[a+4>>2];h=g>>8;a=j[a>>2];i=a;if(g&1){h=j[j[d>>2]+h>>2]}bb[j[j[a>>2]+20>>2]](i,b,c,d+h|0,g&2?e:2,f)}function xm(a,b,c){a:{if((a|0)==(b|0)){break a}c=k[c|0];while(1){if((c|0)==k[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function r8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=j[b>>2];j[a>>2]=d;j[j[d-12>>2]+a>>2]=j[b+4>>2];j[a+4>>2]=0;nr(j[j[a>>2]-12>>2]+a|0,c);return a|0}function qp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if($R(a)>>>0<b>>>0){Jc();z()}hb(a);c=Sh(b);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=b+c|0,j[d>>2]=e;lS(a,0)}function lIa(a,b){a=a|0;b=b|0;var c=0;a=Mc(a,8,1,0,1);c=2;b=b+13|0;a:{if(!(k[b|0]&64)){c=0;if(!(k[b|0]&2)){break a}}dj(a,c)}if(k[b|0]&4){rz(a)}}function gJa(a){a=a|0;var b=0,c=0,d=0;b=Za-16|0;Za=b;i[b+14>>1]=1;c=b,d=nt(a),i[c+12>>1]=d;a=l[ui(b+14|0,b+12|0)>>1];Za=b+16|0;return a-1&65535}function Xoa(a,b,c){var d=0;d=Sm(a);j[114626]=0;I(109,a|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){return a}a=D()|0;C()|0;Ud(d);G(a|0);z()}function Q5(a,b,c,d){if(d){WE(a,b,48784,d);b=p(d,36)+b|0;a=p(d,72)+a|0}if((c|0)==2){F5(a,b,32-d|0);return}WE(a,b,p((c|0)==3,72)+48784|0,32-d|0)}function Jo(a){var b=0,c=0,d=0;c=k[a+30|0];d=rh(j[a+24>>2]+484360|0);b=j[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Fb(b)}return gi(b,k[a+30|0])}function Fn(a,b){var c=0;c=a;a=b+4|0;return LV(c,k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24),k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))}function nwa(a,b,c){var d=0;d=Sm(a);j[114626]=0;I(93,a|0,b|0,c|0);b=j[114626];j[114626]=0;if((b|0)!=1){return a}a=D()|0;C()|0;Ud(d);G(a|0);z()}function Bwa(a,b,c){a=a|0;b=b|0;c=c|0;a=k[c|0]|k[c+1|0]<<8|(k[c+2|0]<<16|k[c+3|0]<<24);h[b|0]=a;h[b+1|0]=a>>>8;h[b+2|0]=a>>>16;h[b+3|0]=a>>>24}function x2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=j[a+20>>2];d=j[a+16>>2]-e|0;d=c>>>0<d>>>0?c:d;Vb(e,b,d);j[a+20>>2]=d+j[a+20>>2];return c|0}function pGa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=yb(a,12);a:{if(d){qz(c+8|0,b);qd(a,c+8|0);break a}h[c+7|0]=0;cj(b,12,c+7|0)}Za=c+16|0;return d}function oLa(a,b){var c=0;c=Za-16|0;Za=c;j[a>>2]=0;j[a+4>>2]=0;j[c+12>>2]=0;Ic(a+8|0,c+12|0,c+8|0);if(b){Gp(a,b);pA(a,b,0)}Za=c+16|0;return a}function m2(a,b,c,d){d=Za-16|0;Za=d;n2(d,b,c);b=j[d+4>>2];j[a>>2]=j[d>>2];j[a+4>>2]=b;b=j[d+12>>2];j[a+8>>2]=j[d+8>>2];j[a+12>>2]=b;Za=d+16|0}function iw(a){a=a|0;var b=0,c=0;j[a>>2]=81632;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;xf(b);if((b|0)!=(c|0)){continue}break}we(a);return a|0}function ioa(a,b){var c=0,d=0,e=0;d=k[a|0];e=k[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=l[a+2>>1]<l[b+2>>1]}return c}function Rga(a){a=a|0;var b=0;b=Za-16|0;Za=b;xH(b+8|0,a,0);if(Xg(b+8|0)){a=j[a+20>>2];j[a+148>>2]=-1;nJ(a+4|0,j[b+8>>2],j[b+12>>2])}Za=b+16|0}function OX(a,b){a:{b:{switch(a+1|0){case 0:a=j[114600];break;case 1:break a;default:break b}}b=70736;if((a|0)==28){break a}Fa();z()}return b}function xP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;return(e=a,f=j[c>>2],g=b,h=pb(c),d=j[j[a>>2]+28>>2],bb[d](e|0,f|0,g|0,h|0)|0)|0}function qla(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;i[a+4>>1]=0;j[a>>2]=b;mb(c+8|0,b+1074308|0,0);d=a,e=kb(c+8|0),h[d+6|0]=e;Za=c+16|0;return a}function eT(a){var b=0,c=0;c=OMa(k[a+111|0],0,1536,0);b=ab;a=OMa(k[a+110|0],0,25,0);c=c+a|0;b=ab+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;ab=b;return a}function cX(a,b,c,d){var e=0,f=0;f=d&65535;d=d>>>16&32767;a:{if((d|0)!=32767){e=4;if(d){break a}return a|c|(b|f)?3:2}e=!(a|c|(b|f))}return e}function b5(a,b,c){var d=0,e=0;if((b|0)>=1){d=(b<<2)+a|0;while(1){j[(e<<2)+a>>2]=d;d=c+d|0;e=e+1|0;if((e|0)!=(b|0)){continue}break}}return a}function yBa(a){var b=0,c=0,d=0;c=a+20|0;while(1){d=b;b=h[a|0];b=d+((b&255)!=0&(b|0)<32)|0;a=a+1|0;if((c|0)!=(a|0)){continue}break}return b}function xr(a){var b=0;b=o[a+4248>>3]/+(xe(j[a+16>>2])>>>0);o[a+4264>>3]=b;if(k[a+4240|0]){o[a+4264>>3]=b*.016666666666666666*o[a+4288>>3]}}function xBa(a){var b=0,c=0,d=0;c=a+22|0;while(1){d=b;b=h[a|0];b=d+((b&255)!=0&(b|0)<32)|0;a=a+1|0;if((c|0)!=(a|0)){continue}break}return b}function uxa(a,b,c,d){if((b|0)!=(c|0)){a=j[d>>2];while(1){c=c-12|0;rxa(a-12|0,c);a=j[d>>2]-12|0;j[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function sja(a,b,c,d){if((b|0)!=(c|0)){a=j[d>>2];while(1){c=c-52|0;rja(a-52|0,c);a=j[d>>2]-52|0;j[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function jia(a){a=a|0;var b=0,c=0,d=0;b=Za-16|0;Za=b;if(!gd(a,4)){Nu(a)}c=b,d=Lb(a+44|0),j[c>>2]=d;a=j[Cd(b+8|0,b)>>2];Za=b+16|0;return a|0}function iia(a){a=a|0;var b=0,c=0,d=0;b=Za-16|0;Za=b;if(!gd(a,4)){Nu(a)}c=b,d=Mb(a+44|0),j[c>>2]=d;a=j[Cd(b+8|0,b)>>2];Za=b+16|0;return a|0}function hq(a,b,c,d,e){var f=0,g=0,h=0;f=j[a+4>>2];g=f>>8;a=j[a>>2];h=a;if(f&1){g=j[j[c>>2]+g>>2]}bb[j[j[a>>2]+24>>2]](h,b,c+g|0,f&2?d:2,e)}function XN(a){a:{if(Yc(a,16624,3)|k[a+3|0]>31|(h[a+27|0]<0|k[a+32|0]>64)){break a}a=a+33|0;if(k[a|0]>32){break a}return k[a|0]!=0}return 0}function Vi(a){if(!(a<2147483647)){return 2147483647}if(!(a>-2147483648)){return-2147483648}if(r(a)<2147483648){return~~a}return-2147483648}function Eya(a,b,c,d){if((b|0)!=(c|0)){a=j[d>>2];while(1){c=c-56|0;Dya(a-56|0,c);a=j[d>>2]-56|0;j[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function $ra(){var a=0,b=0,c=0,d=0;while(1){b=(a<<3)+85568|0;c=b,d=Tra(a&255),j[c>>2]=d;j[b+4>>2]=ab;a=a+1|0;if((a|0)!=256){continue}break}}function uJa(a,b){a=a|0;b=b|0;var c=0,d=0;b=Za-624|0;Za=b;d=-1;c=a;a=b+8|0;c=oJa(c,a);if(!c){sR(a)}if(c){d=tR(b+8|0)}Za=b+624|0;return d|0}function psa(a){var b=0,c=0;b=Za-16|0;Za=b;c=j[a+4>>2];j[b>>2]=j[a>>2];j[b+4>>2]=c;c=Sj(b+8|0,b);a=j[c>>2];Za=b+16|0;ab=j[c+4>>2];return a}function mua(a,b){var c=0,d=0;if(b){while(1){d=c<<3;j[(c<<2)+a>>2]=(j[(d|4)+a>>2]+j[a+d>>2]|0)/2;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function lMa(a,b){var c=0,d=0;c=Za-16|0;Za=c;a:{if(yb(a,256)){d=Za-16|0;Za=d;Qb(c+8|0,b,256);Za=d+16|0;qd(a,c+8|0);break a}uC(b)}Za=c+16|0}function gya(a){var b=0,c=0;b=Za-16|0;Za=b;if(fya(a,b+8|0)){a=b+8|0;a=k[a|0]|k[a+1|0]<<8;c=(a<<24|a<<8&16711680)>>>16|0}Za=b+16|0;return c}function gh(a){var b=0;a=a*a;b=a*a;return q(a*-.499999997251031+1+b*.04166662332373906+a*b*(a*2439044879627741e-20+ -.001388676377460993))}function eza(a,b){a=a|0;b=b|0;var c=0,d=0;b=Za-160|0;Za=b;d=-1;c=a;a=b+8|0;c=Aya(c,a);if(!c){lN(a)}if(c){d=vN(b+8|0)}Za=b+160|0;return d|0}function cra(a,b,c,d){if((b|0)!=(c|0)){a=j[d>>2];while(1){c=c-12|0;hy(a-12|0,c);a=j[d>>2]-12|0;j[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function Wxa(a,b){a=a|0;b=b|0;var c=0;c=cc(a);if(c>>>0<b>>>0){Kxa(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+p(b,12)|0;cc(a);RM(a,b);ts(a)}}function Wc(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;j[c+8>>2]=a;j[c+12>>2]=b;j[c>>2]=-1;j[c+4>>2]=0;a=bA(c+8|0,c);Za=c+16|0;return j[a>>2]}function UZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=Za-16|0;Za=a;j[a+12>>2]=e;j[a+8>>2]=d-c;b=tb(a+12|0,a+8|0);Za=a+16|0;return j[b>>2]}function Oha(a,b){a=a|0;b=b|0;var c=0;c=Te(a);if(c>>>0<b>>>0){vha(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+(b<<11)|0;Te(a);DH(a,b);HH(a)}}function MGa(a,b){a=a|0;b=b|0;var c=0;c=ni(a);if(c>>>0<b>>>0){sGa(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+p(b,48)|0;ni(a);aR(a,b);kR(a)}}function Lja(a,b){var c=0,d=0,e=0;if(kI(a)>>>0<b>>>0){Jc();z()}hb(a);c=hI(b);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=p(b,52)+c|0,j[d>>2]=e;jI(a,0)}function AHa(a,b,c,d){if((b|0)!=(c|0)){a=j[d>>2];while(1){c=c-16|0;Cl(a-16|0,c);a=j[d>>2]-16|0;j[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function zK(a){a=50-(p(k[(a>>>4|0)+20368|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return ic((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function zEa(a,b){a=a|0;b=b|0;var c=0;c=Xc(a);if(c>>>0<b>>>0){lEa(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+(b<<4)|0;Xc(a);nS(a,b);EB(a)}}function jta(a,b){var c=0,d=0,e=0;if(YA(a)>>>0<b>>>0){Jc();z()}hb(a);c=OL(b);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=(b<<5)+c|0,j[d>>2]=e;Wp(a,0)}function hoa(a,b){var c=0;c=Za-16|0;Za=c;j[c+8>>2]=b;b=j[c+8>>2];b=l[b>>1]|l[b+2>>1]<<16;i[a+4>>1]=0;i[a>>1]=b;i[a+2>>1]=b>>>16;Za=c+16|0}function VGa(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1042;j[c+4>>2]=2;Wfa(a,b,c);Za=c+32|0}function Tia(a,b){var c=0,d=0,e=0;if(Jm(a)>>>0<b>>>0){Jc();z()}hb(a);c=VH(b);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=(b<<2)+c|0,j[d>>2]=e;Oj(a,0)}function Nha(a,b){a=a|0;b=b|0;var c=0;c=sb(a);if(c>>>0<b>>>0){uha(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+(b<<2)|0;sb(a);AH(a,b);xg(a)}}function NCa(a,b){var c=0,d=0,e=0;if(Jm(a)>>>0<b>>>0){Jc();z()}hb(a);c=iA(b);j[a>>2]=c;j[a+4>>2]=c;d=hb(a),e=(b<<2)+c|0,j[d>>2]=e;Oj(a,0)}function Ju(a,b){pm(a);j[a>>2]=71416;j[114626]=0;E(2829,a+4|0,b|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){return}a=D()|0;C()|0;G(a|0);z()}function Dc(a){var b=0;b=Za-16|0;Za=b;j[b+12>>2]=a;j[b+8>>2]=-32768;j[b+4>>2]=32767;a=i[zf(b+8|0,Pd(b+12|0,b+4|0))>>1];Za=b+16|0;return a}function C4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=j[b>>2]+15&-16;j[c>>2]=b+16;d=a,e=tv(j[b>>2],j[b+4>>2],j[b+8>>2],j[b+12>>2]),o[d>>3]=e}function $i(a){a=a|0;var b=0;b=Za-16|0;Za=b;j[b+12>>2]=a;j[b+8>>2]=0;j[b+4>>2]=255;a=k[zf(b+8|0,Pd(b+12|0,b+4|0))|0];Za=b+16|0;return a|0}function wya(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1042;j[c+4>>2]=2;Oz(a,b,c);Za=c+32|0}function wGa(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1042;j[c+4>>2]=2;Zq(a,b,c);Za=c+32|0}function vwa(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1058;j[c+4>>2]=3;LO(a,b,c);Za=c+32|0}function tp(a){var b=0,c=0;b=Za-16|0;Za=b;if(Ip(a,b+8|0)){a=b+8|0;a=k[a|0]|k[a+1|0]<<8;c=(a<<24|a<<8&16711680)>>>16|0}Za=b+16|0;return c}function lE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){j[d>>2]=j[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function hIa(a,b){a=a|0;b=b|0;var c=0,d=0;b=Za-32|0;Za=b;d=-1;c=a;a=b+8|0;c=RHa(c,a);if(!c){QQ(a)}if(c){d=TQ(b+8|0)}Za=b+32|0;return d|0}function dpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;if(b>>>0>=250){Ci(20452);z()}mb(d+8|0,a,b);Qd(d+8|0,c);Za=d+16|0;return a|0}function bKa(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1058;j[c+4>>2]=2;wr(a,b,c);Za=c+32|0}function aja(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1058;j[c+4>>2]=1;Zq(a,b,c);Za=c+32|0}function XKa(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1025;j[c+4>>2]=2;Oz(a,b,c);Za=c+32|0}function W8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Za-32|0;Za=g;UF(g+8|0,b,c,d,e,f);Nc(a,g+20|0);Im(g+8|0);Za=g+32|0}function KG(a){var b=0,c=q(0);if(!a){return q(1)}if((a|0)>=-99999){b=+(a|0)*.0016609640474436812;c=q(Bg(b-x(b+.5)))}else{c=q(0)}return c}function IEa(a,b){a=a|0;b=b|0;var c=0,d=0;b=Za-16|0;Za=b;d=-1;c=a;a=b+8|0;c=RDa(c,a);if(!c){ZR(a)}if(c){d=EP(b+8|0)}Za=b+16|0;return d|0}function I6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Vv(a+8|0,b,c,d,2);if(a>>>0<16){a=k[a+32240|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function H6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Vv(a+8|0,b,c,d,3);if(a>>>0<43){a=k[a+32192|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function x6(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1025;j[c+4>>2]=4;Zq(a,b,c);Za=c+32|0}function vb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;if(b>>>0>=110){Ci(12352);z()}mb(d+8|0,a,b);Qd(d+8|0,c);Za=d+16|0;return a|0}function uba(a,b,c,d,e){var f=0,g=0;f=Za-16|0;Za=f;j[f+8>>2]=j[a+8>>2];g=j[a+4>>2];j[f>>2]=j[a>>2];j[f+4>>2]=g;hua(f,b,c,d,e);Za=f+16|0}function uB(a){a=a|0;var b=0;a=Qc(a);j[114626]=0;E(238,a|0,7090)|0;b=j[114626];j[114626]=0;if((b|0)==1){b=D()|0;C()|0;gb(a);G(b|0);z()}}function t_(a,b){a=a|0;b=b|0;var c=0;c=sb(a);if(c>>>0<b>>>0){r_(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+(b<<2)|0;sb(a);eC(a,b);DC(a)}}function q6(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1025;j[c+4>>2]=2;Zq(a,b,c);Za=c+32|0}function ppa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;if(b>>>0>=43){Ci(20452);z()}mb(d+8|0,a,b);Qd(d+8|0,c);Za=d+16|0;return a|0}function pKa(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=274;j[c+4>>2]=0;Oz(a,b,c);Za=c+32|0}function opa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;if(b>>>0>=16){Ci(20452);z()}rj(d+8|0,a,b);Qd(d+8|0,c);Za=d+16|0;return a|0}function fj(a){var b=0;b=a+28|0;a=b;if((k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))>>>0>=128){a=k[b|0]^-128}else{a=255}return a&255}function dHa(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=257;j[c+4>>2]=0;Mw(a,b,c);Za=c+32|0}function X8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Za-32|0;Za=g;UF(g+8|0,b,c,d,e,f);Nc(a,g+8|0);Im(g+8|0);Za=g+32|0}function Vg(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=j[a>>2];return f=d,g=lb(b),h=j[a+8>>2],i=c,e=j[j[d>>2]+28>>2],bb[e](f|0,g|0,h|0,i|0)|0}function U8(a,b,c){b=Mf(a,b);j[114626]=0;E(120,a+12|0,c|0)|0;a=j[114626];j[114626]=0;if((a|0)!=1){return}a=D()|0;C()|0;gb(b);G(a|0);z()}function Jd(a,b){a=a|0;b=b|0;return(k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24))==(k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))|0}function Is(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1058;j[c+4>>2]=2;lH(a,b,c);Za=c+32|0}function Gy(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1058;j[c+4>>2]=2;LO(a,b,c);Za=c+32|0}function Fc(a,b){var c=0,d=0,e=0;c=jf(a,b);if(c){j[a+12>>2]=j[a+12>>2]+b;return c}d=a,e=bb[j[j[a>>2]+24>>2]](a)|0,j[d+12>>2]=e;return c}function AW(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1058;j[c+4>>2]=2;Mw(a,b,c);Za=c+32|0}function nia(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=0;j[d+8>>2]=c;j[d+4>>2]=4;xk(a,d+12|0,j[tb(d+8|0,d+4|0)>>2]);j[b>>2]=0;Za=d+16|0}function epa(a,b){a=a|0;b=b|0;var c=0,d=0;d=Za-16|0;Za=d;if(!(!a|!b)){c=Sr(a);a=Toa(a,b);c=p(Sr(b),(c|0)/(a|0)|0)}Za=d+16|0;return c|0}function Uga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Ld(c&255))){zH(a,8,q(0))}a=Ki(a);if(a){bb[j[j[a>>2]+88>>2]](a,b,c,d,e)}}function Rq(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=j[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=j[c>>2];j[a+4>>2]=d>>>b;j[a>>2]=d<<32-b|c>>>b}function F4(a,b,c,d){if(a|b){while(1){c=c-1|0;h[c|0]=k[(a&15)+55632|0]|d;a=(b&15)<<28|a>>>4;b=b>>>4|0;if(a|b){continue}break}}return c}function BW(a,b){a=a|0;b=b|0;var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=290;j[c+4>>2]=0;Mw(a,b,c);Za=c+32|0}function xB(){var a=0,b=0,c=0;a=Za-16|0;Za=a;b=Eb(a,10940);c=0;a:{if(!nb(b)){break a}c=(Ff(b,10950)|0)!=-1}gb(b);Za=a+16|0;return c|0}function hf(a){var b=0,c=0;b=Za-16|0;Za=b;if(Vp(a,b+8|0)){a=b+8|0;c=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24)}Za=b+16|0;return c}function Xla(a,b){var c=0;c=78928;while(1){if(j[c>>2]==(b|0)){hn(a,0,j[c+8>>2]);return}c=c+12|0;if((c|0)!=78976){continue}break}Qc(a)}function UR(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;Za=b+16|0}function UBa(a){var b=0;b=Za-16|0;Za=b;j[b+12>>2]=a;j[b+8>>2]=-128;j[b+4>>2]=127;a=h[zf(b+8|0,Pd(b+12|0,b+4|0))|0];Za=b+16|0;return a}function Fp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;a:{if(!b){break a}if(c){pT(vd(d+8|0,a),b);break a}oT(vd(d,a),b)}Za=d+16|0}function BBa(a,b,c){var d=0;if((a|0)!=(b|0)){while(1){d=k[a|0];h[c|0]=d>>>0>32?d:32;c=c+1|0;a=a+1|0;if((b|0)!=(a|0)){continue}break}}}function wn(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=j[a>>2];if(d>>>0<b>>>0){j[a>>2]=b;return}if(c>>>0>=d>>>0){break a}j[a>>2]=c}}function vfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=j[b>>2];j[a>>2]=d;j[j[d-12>>2]+a>>2]=j[b+4>>2];nr(j[j[a>>2]-12>>2]+a|0,c);return a|0}function VV(a,b,c,d){var e=0;e=a+b|0;b=-1;a:{while(1){if((a|0)==(e|0)){break a}e=e-1|0;if(An(c,d,e)){continue}break}b=e-a|0}return b}function Md(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=j[a>>2];if((d|0)<(b|0)){j[a>>2]=b;return}if((c|0)>=(d|0)){break a}j[a>>2]=c}}function Kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=df(a);if(d>>>0<b>>>0){Ija(a,b-d|0,c);return}if(b>>>0<d>>>0){pI(a,j[a>>2]+p(b,52)|0)}}function Ke(a,b,c,d,e){var f=0;f=Za-16|0;Za=f;j[f+12>>2]=c;j[f+8>>2]=e;c=ch(f,f+12|0);a=xq(a,b,d,j[f+8>>2]);pe(c);Za=f+16|0;return a}function Ioa(a,b){h[a+860|0]=b;h[a+832|0]=b;h[a+831|0]=b;h[a+829|0]=b;h[a+828|0]=b;i[a+800>>1]=b;h[a+846|0]=b>>>4;h[a+847|0]=b<<2&60}function A5(a){j[a+1420>>2]=0;j[a+992>>2]=0;j[a+1504>>2]=0;j[a+1508>>2]=0;j[a+1412>>2]=0;j[a+1416>>2]=0;h[a+1377|0]=0;j[a+1064>>2]=0}function yGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Kf(a);if(d>>>0<b>>>0){hGa(a,b-d|0,c);return}if(b>>>0<d>>>0){az(a,j[a>>2]+p(b,6)|0)}}function xKa(a,b){var c=0;c=Za-16|0;Za=c;a:{if(yb(a,512)){Kz(c+8|0,b);qd(a,c+8|0);break a}a=Za-16|0;Za=a;uKa(b);Za=a+16|0}Za=c+16|0}function pAa(a,b){var c=0;c=fg(a);if(c>>>0<b>>>0){oAa(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+(b<<3)|0;fg(a);_N(a,b);wi(a);fg(a)}}function ov(a){a=a|0;var b=0;b=j[a+12>>2];if((b|0)==j[a+16>>2]){return bb[j[j[a>>2]+40>>2]](a)|0}j[a+12>>2]=b+1;return gg(h[b|0])|0}function nW(){var a=0,b=0;a=Za-16|0;Za=a;j[a+8>>2]=19465728;a:{if(yB(a+8|0)){break a}if(xB()){break a}b=wB()^1}Za=a+16|0;return b|0}function dAa(a,b){var c=0;c=Za-16|0;Za=c;a:{if(yb(a,128)){GP(c+8|0,b);qd(a,c+8|0);break a}a=Za-16|0;Za=a;cAa(b);Za=a+16|0}Za=c+16|0}function Wsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=de(a);if(d>>>0<b>>>0){Tsa(a,b-d|0,c);return}if(b>>>0<d>>>0){WL(a,j[a>>2]+(b<<5)|0)}}function Pq(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=j[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=j[c>>2];j[a>>2]=d<<b;j[a+4>>2]=c<<b|d>>>32-b}function Bha(a){a=a|0;a=Za-16|0;Za=a;j[a+12>>2]=1869112133;Za=a+16|0;a=a+12|0;return k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24)}function t8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;j[d>>2]=c;j[d+8>>2]=b;Yp(j[d+8>>2]);s8(a,j[d>>2]);Za=d+16|0;return a|0}function pR(a){var b=0;b=a;if((k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))==1179468868){return(k[a+4|0]-1&255)>>>0<10}return 0}function o8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;j[d>>2]=c;j[d+8>>2]=b;Yp(j[d+8>>2]);n8(a,j[d>>2]);Za=d+16|0;return a|0}function eI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=sb(a);if(d>>>0<b>>>0){ija(a,b-d|0,c);return}if(b>>>0<d>>>0){Bw(a,j[a>>2]+(b<<2)|0)}}function Ln(a,b){a=a|0;b=b|0;var c=0;c=tc(a);if(c>>>0<b>>>0){yY(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+b|0;tc(a);BB(a,b);ap(a)}}function CV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;j[d>>2]=c;j[d+8>>2]=b;Yp(j[d+8>>2]);BV(a,j[d>>2]);Za=d+16|0;return a|0}function vT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;return(c=TMa(0-TMa(b^1230262859,25)|0,4)^1247037516,d=b,e=(a&4088)>>>0>=520,e?c:d)|0}function pe(a){a:{a=j[a>>2];if(a){j[114626]=0;$u(a);a=j[114626];j[114626]=0;if((a|0)==1){break a}}return}a=J(0)|0;C()|0;ib(a);z()}function Xqa(a,b){var c=0;c=Za-16|0;Za=c;a:{if(yb(a,7)){Lz(c+8|0,b);qd(a,c+8|0);break a}a=Za-16|0;Za=a;Uqa(b);Za=a+16|0}Za=c+16|0}function Wia(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+8>>2]=b;b=j[c+8>>2];d=TH(a,b);a=Rb(a);Ts(Rg(c+8|0));Zg(a,b,1);Za=c+16|0;return d}function paa(a,b,c){dr(a);j[a+8>>2]=c;j[a+4>>2]=0;j[a>>2]=84248;c=j[b+4>>2];j[a+12>>2]=j[b>>2];j[a+16>>2]=c;j[a+20>>2]=j[b+8>>2]}function oE(a,b,c,d,e){if(b>>>0>=d>>>0){if(!e){return d}b=a+b|0;c=b4(a+d|0,b,c,c+e|0);a=(b|0)==(c|0)?-1:c-a|0}else{a=-1}return a}function naa(a,b,c){dr(a);j[a+8>>2]=c;j[a+4>>2]=0;j[a>>2]=84320;c=j[b+4>>2];j[a+12>>2]=j[b>>2];j[a+16>>2]=c;j[a+20>>2]=j[b+8>>2]}function hy(a,b){var c=0,d=0;j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];j[a+8>>2]=j[b+8>>2];j[b>>2]=0;j[b+4>>2]=0;c=hb(b),d=0,j[c>>2]=d}function Lt(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;e=j[b+4>>2];d=j[b>>2];h[c+15|0]=0;d=xm(d,d+e|0,c+15|0);Zh(a,j[b>>2],d);Za=c+16|0}function Jna(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=j[a>>2];if(b){Iga(b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function E3(a,b){var c=0;c=j[a+24>>2];if((c|0)==j[a+28>>2]){return bb[j[j[a>>2]+52>>2]](a,b)|0}j[a+24>>2]=c+4;j[c>>2]=b;return b}function uL(a,b,c){a=a|0;b=b|0;c=c|0;if((b|0)!=(c|0)){while(1){tL(a,k[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function sM(a){var b=0;b=j[a+16>>2];a=j[a+32>>2];b=OMa(b,b>>31,a,a>>31)+5e5|0;a=ab;return ic(PMa(b,b>>>0<5e5?a+1|0:a,1e6,0),ab)}function rg(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;if(b>>>0>=110){Ci(12596);z()}mb(c+8|0,a,b);Qd(c+8|0,0);Za=c+16|0;return a|0}function rM(a){var b=0;b=j[a+16>>2];a=j[a+36>>2];b=OMa(b,b>>31,a,a>>31)+5e5|0;a=ab;return ic(PMa(b,b>>>0<5e5?a+1|0:a,1e6,0),ab)}function d_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){j[d>>2]=h[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function dD(a,b,c,d,e,f){a=bb[j[j[a+8>>2]+4>>2]](a+8|0)|0;a=wq(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){j[b>>2]=((a|0)/12|0)%12}}function aD(a,b,c,d,e,f){a=bb[j[j[a+8>>2]+4>>2]](a+8|0)|0;a=uq(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){j[b>>2]=((a|0)/12|0)%12}}function ZX(a,b,c){a:{if(c){j[114626]=0;_B(a,b,c);a=j[114626];j[114626]=0;if((a|0)==1){break a}}return}a=J(0)|0;C()|0;ib(a);z()}function YX(a,b,c){a:{if(b){j[114626]=0;$B(a,c,b);a=j[114626];j[114626]=0;if((a|0)==1){break a}}return}a=J(0)|0;C()|0;ib(a);z()}function Ki(a){var b=0,c=0;b=fj(j[a+20>>2]);if(!(b>>>0>249|k[a+4200|0]>=b>>>0)){c=j[(j[a+16>>2]+p(b,160)|0)+906300>>2]}return c}function Jh(a,b,c){a:{if(c){j[114626]=0;lE(a,b,c);a=j[114626];j[114626]=0;if((a|0)==1){break a}}return}a=J(0)|0;C()|0;ib(a);z()}function Fv(a,b,c){var d=0;d=j[a+32>>2];if(m[a+40>>2]<d+c>>>0){j[a+96>>2]=1;return 0}Vb(b,d,c);j[a+32>>2]=j[a+32>>2]+c;return 1}function woa(a){var b=0,c=0;if(j[a>>2]){pd(a);YJ(a);Xo(a);xo(hb(a),j[a>>2],Ce(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function vra(a,b){var c=0;c=cc(a);if(c>>>0<b>>>0){sra(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+p(b,12)|0;cc(a);_K(a,b);ts(a)}}function pHa(a,b){a=a|0;b=b|0;var c=0,d=0;b=Za-160|0;Za=b;c=-1;d=b;a=mHa(a,b);if(!a){DQ(d)}if(a){c=FQ(b)}Za=b+160|0;return c|0}function kta(a){var b=0,c=0;if(j[a>>2]){de(a);SL(a);nu(a);Zg(hb(a),j[a>>2],_g(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function kna(a){var b=0,c=0;if(j[a>>2]){tc(a);xA(a);ap(a);Yf(hb(a),j[a>>2],Af(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function ira(a){var b=0,c=0;if(j[a>>2]){cc(a);$K(a);ts(a);fh(hb(a),j[a>>2],Hf(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function c5(a){a:{if((he(a)|0)!=79){break a}if((he(a)|0)!=103){break a}if((he(a)|0)!=103){break a}return(he(a)|0)==83}return 0}function Zya(a){var b=0,c=0;if(j[a>>2]){pd(a);uN(a);Xo(a);Ef(hb(a),j[a>>2],Ce(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function XZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){h[d|0]=k[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function XW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return Mda(a,b,c,d,e,f,g,h,i,j)|0}function WW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return Lda(a,b,c,d,e,f,g,h,i,j)|0}function NB(a){j[114626]=0;M(a|0);a=j[114626];j[114626]=0;if((a|0)!=1){j[114626]=0;z()}a=J(0)|0;C()|0;O(a|0)|0;j[114626]=0;z()}function Mja(a){var b=0,c=0;if(j[a>>2]){df(a);qJ(a);lI(a);bx(hb(a),j[a>>2],Mi(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function JL(a,b,c,d,e){j[a+12>>2]=e;j[a+8>>2]=d;j[a+4>>2]=c;j[a>>2]=b;if(b){ee(b,a)}if(c){ee(c,a)}if(d){ee(d,a)}if(e){ee(e,a)}}function IMa(a,b,c,d){if((nk(11872)|0)==(b|0)){Jb(d,c);return}if(!nT(a,b,c,d)){Jb(d,c);return}if((nk(11877)|0)==(b|0)){HMa(a)}}function Fka(a){var b=0,c=0;if(j[a>>2]){pd(a);GI(a);Xo(a);Ef(hb(a),j[a>>2],Ce(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function CGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=tc(a);if(d>>>0<b>>>0){nGa(a,b-d|0,c);return}if(b>>>0<d>>>0){Tt(a,j[a>>2]+b|0)}}function $xa(a,b){a=a|0;b=b|0;var c=0,d=0;b=Za-208|0;Za=b;c=-1;d=b;a=Cxa(a,b);if(!a){TM(d)}if(a){c=YM(b)}Za=b+208|0;return c|0}function rpa(a){h[a+26|0]=0;i[a+24>>1]=0;j[a+16>>2]=0;j[a+20>>2]=-1;j[a+8>>2]=-1;j[a+12>>2]=-1;j[a>>2]=0;j[a+4>>2]=0;return a}function rX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Rf(a,j[b+8>>2],0)){Cu(b,c,d);return}a=j[a+8>>2];bb[j[j[a>>2]+28>>2]](a,b,c,d)}function nFa(a,b){var c=0;c=sb(a);if(c>>>0<b>>>0){mFa(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+(b<<2)|0;sb(a);SP(a,b);xg(a)}}function f4(a){a=a|0;var b=0;if((bb[j[j[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=j[a+12>>2];j[b+12>>2]=a+1;return gg(h[a|0])|0}function cU(a,b,c,d){var e=0,f=0;e=(b|0)/8|0;a=e+a|0;f=dg(d,a);return(dg(d,a+1|0)<<8|f<<16|dg(d,a+2|0))<<(b-(e<<3)|0)+8>>32-c}function Z7(a){var b=0,c=0;if(j[a>>2]){pd(a);JF(a);Xo(a);xo(hb(a),j[a>>2],Ce(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function Xj(a,b){var c=0;a:{if(m[a+12>>2]<b>>>0){c=0;if(bb[j[j[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}j[a+12>>2]=b;c=1}return c}function UCa(a,b){var c=0;c=sb(a);if(c>>>0<b>>>0){TCa(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+(b<<2)|0;sb(a);_O(a,b);xg(a)}}function TX(a,b){var c=0;a=fY(a,j[21215]);c=ne(a);if(c>>>0>=1024){Vb(b,a,1023);h[b+1023|0]=0;return 68}Vb(b,a,c+1|0);return 0}function Pj(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;c=j[b>>2];j[d+8>>2]=j[b+4>>2];Cc(a,c,j[tb(d+12|0,d+8|0)>>2]);Za=d+16|0}function LCa(a,b){var c=0;c=bc(a);if(c>>>0<b>>>0){KCa(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+(b<<1)|0;bc(a);VO(a,b);Bt(a)}}function Fza(a,b){var c=0;c=sb(a);if(c>>>0<b>>>0){Eza(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+(b<<2)|0;sb(a);FN(a,b);xg(a)}}function BLa(a,b){var c=0;c=bc(a);if(c>>>0<b>>>0){ALa(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+(b<<1)|0;bc(a);rS(a,b);Bt(a)}}function kMa(a,b){a=a|0;b=b|0;var c=0,d=0;b=Za-48|0;Za=b;c=-1;d=b;a=LLa(a,b);if(!a){zS(d)}if(a){c=SS(b)}Za=b+48|0;return c|0}function fE(a){j[a>>2]=55840;Su(a+4|0);j[a+24>>2]=0;j[a+28>>2]=0;j[a+16>>2]=0;j[a+20>>2]=0;j[a+8>>2]=0;j[a+12>>2]=0;return a}function eD(a,b,c,d,e,f){a=bb[j[j[a+8>>2]>>2]](a+8|0)|0;a=wq(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){j[b>>2]=((a|0)/12|0)%7}}function e6(a){a=a|0;var b=0;if(!a){return-2}b=j[a+28>>2];if(!b){return 0}bb[j[a+36>>2]](j[a+40>>2],b);j[a+28>>2]=0;return 0}function bD(a,b,c,d,e,f){a=bb[j[j[a+8>>2]>>2]](a+8|0)|0;a=uq(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){j[b>>2]=((a|0)/12|0)%7}}function ZM(a){var b=0,c=0;b=k[a+33|0];c=b>>>24|0;a=k[a+31|0]?1120:1056;b=a+(b<<8)|0;c=a>>>0>b>>>0?c+1|0:c;a=b;ab=c;return a}function Y8(a,b){var c=0;c=Za-32|0;Za=c;h[c+16|0]=44;j[c+8>>2]=-1;j[c+12>>2]=0;j[c>>2]=1058;j[c+4>>2]=1;eha(a,b,c);Za=c+32|0}function Mq(a){j[a>>2]=55776;Su(a+4|0);j[a+24>>2]=0;j[a+28>>2]=0;j[a+16>>2]=0;j[a+20>>2]=0;j[a+8>>2]=0;j[a+12>>2]=0;return a}function MJ(a){a=a|0;j[a>>2]=0;ri(a+4|0);j[a+152>>2]=0;j[a+156>>2]=0;j[a+144>>2]=0;j[a+148>>2]=0;Ab(a+16|0,0,128);return a|0}function Fma(a,b){var c=0,d=0;j[a>>2]=j[b>>2];c=b+4|0;d=a+4|0;if((c|0)!=(d|0)){nJ(d,j[c>>2],j[c+4>>2])}Vb(a+16|0,b+16|0,144)}function Cna(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+1304392|0;if(!bd(c)){xna(b+8|0,a+24620|0);FJ(c,ud(b+8|0));Lr(b+8|0)}Za=b+16|0}function Cf(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=dg(d,a);return((dg(d,a+1|0)<<8|e<<16|dg(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function Bb(a,b){var c=0,d=0,e=0;c=a;d=j[b>>2];e=d+j[a>>2]|0;a=j[a+4>>2]+j[b+4>>2]|0;j[c>>2]=e;j[c+4>>2]=e>>>0<d>>>0?a+1|0:a}function mI(a){a=a|0;var b=0,c=0;b=me(a);while(1){c=b;if(c&65535){b=c-1|0;if(!tg(a,b&65535)){continue}}break}return c&65535}function i3(a,b){j[a+20>>2]=0;j[a+24>>2]=b;j[a+12>>2]=0;j[a+4>>2]=4098;j[a+8>>2]=6;j[a+16>>2]=!b;Ab(a+32|0,0,40);Su(a+28|0)}function hZ(a,b){var c=0;c=Xc(a);if(c>>>0<b>>>0){CY(a,b-c|0);return}if(b>>>0<c>>>0){b=j[a>>2]+(b<<4)|0;Xc(a);FB(a,b);EB(a)}}function QU(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=a;a=tk(c+8|0,j[b>>2]);MU(d,a,j[j[b+4>>2]>>2],j[j[b+8>>2]>>2]);jb(a);Za=c+16|0}function Nxa(a,b){var c=0;c=Za-16|0;Za=c;b=k[b|0]|k[b+1|0]<<8;i[c+14>>1]=(b<<24|b<<8&16711680)>>>16;wha(a,c+14|0);Za=c+16|0}function Hs(a){a=a|0;var b=0;b=Za-16|0;Za=b;j[b+12>>2]=a;j[b+8>>2]=2147483647;a=j[tb(b+12|0,b+8|0)>>2];Za=b+16|0;return a|0}function Gr(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(b*1e-7<c){continue}break}return+b}function zza(a,b){var c=0;c=Za-16|0;Za=c;a:{if(yb(a,5)){Nz(c+8|0,b);qd(a,c+8|0);break a}h[c+7|0]=0;cj(b,5,c+7|0)}Za=c+16|0}function yHa(a,b){var c=0;c=Za-16|0;Za=c;a:{if(yb(a,6)){oz(c+8|0,b);qd(a,c+8|0);break a}h[c+7|0]=0;cj(b,6,c+7|0)}Za=c+16|0}function sy(a){j[a>>2]=0;j[a+4>>2]=0;j[a+24>>2]=0;j[a+28>>2]=0;j[a+16>>2]=0;j[a+20>>2]=0;j[a+8>>2]=0;j[a+12>>2]=0;return a}function sw(a){var b=0,c=0;o[a+4272>>3]=o[a+4280>>3];b=a,c=+q(q(aha(a+4296|0)|0)*q(-4.656612873077393e-10)),o[b+4280>>3]=c}function qMa(a,b){var c=0;c=Za-16|0;Za=c;a:{if(yb(a,3)){Zz(c+8|0,b);qd(a,c+8|0);break a}h[c+7|0]=0;cj(b,3,c+7|0)}Za=c+16|0}function qM(a){a=a|0;j[a+700>>2]=0;i[a+862>>1]=0;j[a+688>>2]=0;j[a>>2]=0;j[a+4>>2]=0;j[a+8>>2]=0;j[a+12>>2]=0;j[a+16>>2]=0}function p2(a,b){var c=0,d=q(0);c=Za-16|0;Za=c;Zu(c,a,b,0);d=AD(j[c>>2],j[c+4>>2],j[c+8>>2],j[c+12>>2]);Za=c+16|0;return d}function oEa(a){var b=0;b=_j(a);if(b>>>0<64){jEa(a,64-b|0);return}if(b>>>0>64){b=j[a>>2]+2112|0;_j(a);zP(a,b);jl(a);_j(a)}}function UI(a,b){var c=0;if(!(k[a|0]!=k[b|0]|o[a+8>>3]!=o[b+8>>3]|k[a+16|0]!=k[b+16|0])){c=j[a+20>>2]==j[b+20>>2]}return c}function OEa(a,b){var c=0;a:{if(!b){break a}if(!yb(a,b)){break a}if(b>>>0<=3){return NEa(a,b)}c=hf(a);Jb(a,b-4|0)}return c}function MLa(a,b){var c=0;c=Za-16|0;Za=c;a:{if(yb(a,4)){ah(c+8|0,b);qd(a,c+8|0);break a}h[c+7|0]=0;cj(b,4,c+7|0)}Za=c+16|0}function $B(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){j[d>>2]=b;d=d+4|0;c=c-1|0;if(c){continue}break}}return a|0}function qx(a,b){var c=0;c=Za-16|0;Za=c;mb(c+8|0,a+1074308|0,7);a=kb(c+8|0);Za=c+16|0;return j[(b<<2)+(a?25312:26336)>>2]}function px(a,b){var c=0;c=Za-16|0;Za=c;mb(c+8|0,a+1074308|0,7);a=kb(c+8|0);Za=c+16|0;return j[(b<<2)+(a?26336:25312)>>2]}function dua(a){if(!(a<q(4294967296))){return-1}if(!(a>q(0))){return 0}if(a<q(4294967296)&a>=q(0)){return~~a>>>0}return 0}function cK(a,b){var c=0;c=Za-16|0;Za=c;mb(c+8|0,a+1074308|0,7);a=kb(c+8|0);Za=c+16|0;return j[(b<<2)+(a?25184:25248)>>2]}function bK(a,b){var c=0;c=Za-16|0;Za=c;mb(c+8|0,a+1074308|0,7);a=kb(c+8|0);Za=c+16|0;return j[(b<<2)+(a?25248:25184)>>2]}function Tu(a,b,c){c=j[c>>2];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=j[a>>2]){break a}}else{a=b}return a}a=a+4|0;continue}}function QEa(a,b){var c=0;a:{if(!b){break a}if(!yb(a,b)){break a}if(b>>>0<=3){return dA(a,b)}c=hf(a);Jb(a,b-4|0)}return c}function Pna(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+128e3|0;while(1){Ima(a);a=a+32|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function PEa(a,b){var c=0;a:{if(!b){break a}if(!yb(a,b)){break a}if(b>>>0<=1){return cA(a,1)}c=Of(a);Jb(a,b-2|0)}return c}function FAa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=yb(a,32);a:{if(d){bO(c+8|0,b);qd(a,c+8|0);break a}aO(b)}Za=c+16|0;return d}function zoa(a,b){j[114626]=0;I(25,a|0,p(b,24)|0,8);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function yIa(a,b){j[114626]=0;I(25,a|0,p(b,48)|0,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function xpa(a){if(!(a<q(65535))){return 65535}if(!(a>q(0))){return 0}if(a<q(4294967296)&a>=q(0)){return~~a>>>0}return 0}function eM(a,b,c,d,e,f,g){h[a+17|0]=g;h[a+16|0]=f;j[a+12>>2]=e;j[a+8>>2]=d;j[a+4>>2]=c;j[a>>2]=b;if(d){cM(a,1);cM(a,0)}}function dM(a,b,c,d,e,f,g){h[a+17|0]=g;h[a+16|0]=f;j[a+12>>2]=e;j[a+8>>2]=d;j[a+4>>2]=c;j[a>>2]=b;if(d){bM(a,1);bM(a,0)}}function cpa(a,b){var c=0,d=0,e=0;while(1){d=(c<<2)+a|0,e=nua(b),j[d>>2]=e;c=c+1|0;if((c|0)!=12){continue}break}return a}function a4(a){a=a|0;var b=0;if((bb[j[j[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=j[a+12>>2];j[b+12>>2]=a+4;return j[a>>2]}function ZDa(a,b){j[114626]=0;I(25,a|0,p(b,33)|0,1);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function Yra(a){var b=0,c=0;a=a<<24;while(1){b=a<<1;a=(a|0)>-1?b:b^79764919;c=c+1|0;if((c|0)!=8){continue}break}return a}function YD(a){var b=0;b=j[a+12>>2];if((b|0)==j[a+16>>2]){return bb[j[j[a>>2]+40>>2]](a)|0}j[a+12>>2]=b+4;return j[b>>2]}function YAa(a,b){var c=0;c=Za-16|0;Za=c;a:{if(jf(a,2)){pk(c+8|0,b);ty(a,c+8|0);break a}h[c+7|0]=0;wS(b,c+7|0)}Za=c+16|0}function UFa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=yb(a,4);a:{if(d){ah(c+8|0,b);qd(a,c+8|0);break a}HP(b)}Za=c+16|0;return d}function SU(a){a=a|0;var b=0;a:{if(!ce(-1,j[a+76>>2])){a=j[a+76>>2];break a}b=a;a=rH(a,32);j[b+76>>2]=a}return a<<24>>24}function PS(a,b){a=a|0;b=b|0;var c=0;c=bc(a);if(c>>>0<b>>>0){YLa(a,b-c|0);return}if(b>>>0<c>>>0){Bp(a,j[a>>2]+(b<<1)|0)}}function PF(a,b){j[114626]=0;I(25,a|0,p(b,324)|0,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function Oma(a,b){j[114626]=0;I(25,a|0,p(b,52)|0,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function MCa(a,b){j[114626]=0;I(25,a|0,p(b,20)|0,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function Kj(a,b,c){var d=0;d=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=d;d=j[b+12>>2];j[a+8>>2]=j[b+8>>2];j[a+12>>2]=d;Pw(a,c)}function KJa(a){a=a+4|0;a=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function KI(a){var b=0;b=a;if((k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))==1179011410){return my(a)>>>0>80}return 0}function JM(a){var b=0;b=a+68|0;if(!(!(k[b|0]|k[b+1|0]<<8)|(k[b|0]|k[b+1|0]<<8)>>>0>127)){return!Yc(a,17965,17)}return 0}function ILa(a,b){var c=0;c=Za-16|0;Za=c;a:{if(yb(a,2)){pk(c+8|0,b);qd(a,c+8|0);break a}h[c+7|0]=0;wS(b,c+7|0)}Za=c+16|0}function tR(a){var b=0;a:{if(Yc(a,12667,20)){break a}b=a+25|0;if(!k[b|0]|k[b|0]>8){break a}return h[a+47|0]>-1}return 0}function sN(a,b){j[114626]=0;I(25,a|0,p(b,56)|0,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function ona(a,b){a=a|0;b=b|0;if(b>>>0>255){return 20525}a=j[((b<<2)+a|0)+900380>>2];if(!a){return 20525}return a+492|0}function o2(a,b){var c=0,d=0;c=Za-16|0;Za=c;Zu(c,a,b,1);d=tv(j[c>>2],j[c+4>>2],j[c+8>>2],j[c+12>>2]);Za=c+16|0;return d}function nV(a){j[a>>2]=0;j[a+4>>2]=0;j[a+24>>2]=0;j[a+28>>2]=0;j[a+16>>2]=0;j[a+20>>2]=0;j[a+8>>2]=0;j[a+12>>2]=0;$A(a)}function ld(a){var b=0;b=Za-16|0;Za=b;j[b+12>>2]=83664;j[b+8>>2]=83768;j[a>>2]=j[b+12>>2];j[a+4>>2]=j[b+8>>2];Za=b+16|0}function jxa(a,b){j[114626]=0;I(25,a|0,p(b,9)|0,1);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function hB(a,b){j[114626]=0;I(25,a|0,p(b,24)|0,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function bi(a,b,c){a:{if((Uj(a,b)|0)==255){break a}Tj(a,b);No(a,b,0,0);if(!c){break a}a=Pb(a+58|0,b);h[a|0]=k[a|0]|128}}function Zsa(a,b,c){var d=0;PS(c,j[a>>2]);if(j[a>>2]){while(1){LL(b,ac(c,d));d=d+1|0;if(d>>>0<m[a>>2]){continue}break}}}function T2(a,b){j[114626]=0;I(25,a|0,p(b,12)|0,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function Rxa(a,b){a=a|0;b=b|0;var c=0;i[a+34>>1]=0;c=Za-16|0;Za=c;Dxa(a+43|0);Za=c+16|0;j[a+20>>2]=0;md(a,b);return a|0}function Nf(a,b){a=a|0;b=b|0;var c=0;c=sb(a);if(c>>>0<b>>>0){HT(a,b-c|0);return}if(b>>>0<c>>>0){Pt(a,j[a>>2]+(b<<2)|0)}}function Kna(a,b){ob(a,b);ob(a+12|0,b+12|0);ob(a+24|0,b+24|0);ob(a+36|0,b+36|0);ob(a+48|0,b+48|0);j[a+60>>2]=j[b+60>>2]}function Kd(a,b){var c=q(0);a:{if(b>q(1)){break a}c=n[a>>2];if(!(c>=b)){n[a>>2]=b;return}if(c<=q(1)){break a}n[a>>2]=1}}function HIa(a,b){j[114626]=0;I(25,a|0,p(b,6)|0,1);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function EP(a){var b=0;b=a;if((k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))==1279544644){return k[a+4|0]<32}return 0}function wz(a){a=a|0;var b=0;b=Za-16|0;Za=b;j[b+12>>2]=a;j[b+8>>2]=65535;a=l[tb(b+12|0,b+8|0)>>1];Za=b+16|0;return a|0}function tY(a){var b=0,c=0,d=0;c=j[a+4>>2];b=j[a>>2];a=j[a+8>>2];b=b+(a>>1)|0;d=b;if(a&1){c=j[c+j[b>>2]>>2]}bb[c|0](d)}function lJa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a- -64|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function he(a){var b=0;b=j[a+32>>2];a:{if(b>>>0>=m[a+40>>2]){j[a+96>>2]=1;a=0;break a}j[a+32>>2]=b+1;a=k[b|0]}return a}function eua(a,b,c){var d=0;d=64;j[a+764>>2]=64;if(b){d=l[b+32>>1];j[a+764>>2]=d}if(c){j[a+764>>2]=p(j[c+4>>2],d)>>>6}}function Zra(){var a=0,b=0,c=0;while(1){b=(a<<2)+87632|0,c=Yra(a&255),j[b>>2]=c;a=a+1|0;if((a|0)!=256){continue}break}}function JHa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a- -64|0;while(1){Vz(a);a=a+2|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function E4(a,b,c){if(a|b){while(1){c=c-1|0;h[c|0]=a&7|48;a=(b&7)<<29|a>>>3;b=b>>>3|0;if(a|b){continue}break}}return c}function uKa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+512|0;while(1){Jz(a);a=a+4|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function sS(a,b){a=a|0;b=b|0;var c=0;c=j[b+4>>2];if(c){Qb(a,c,j[b>>2]);return}b=b+8|0;if(!ad(b)){xi(a,b);return}wf(a)}function oY(a){var b=0;b=a+8|0;if(!j[b>>2]){bb[j[j[a>>2]+16>>2]](a);return}if((ku(b)|0)==-1){bb[j[j[a>>2]+16>>2]](a)}}function eP(a){a=a|0;var b=0;b=Za-16|0;Za=b;i[b+14>>1]=a;i[b+12>>1]=255;a=k[gf(b+14|0,b+12|0)|0];Za=b+16|0;return a|0}function cAa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+128|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function XAa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+512|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function Wb(a,b){var c=0;pm(a);j[a+4>>2]=0;j[a>>2]=83620;c=a;a=_c(nb(b)+1|0);j[c+4>>2]=a;if(a){Vb(a,zb(b),nb(b)+1|0)}}function MR(a){var b=0;b=a;if((k[b|0]|k[b+1|0]<<8|(k[b+2|0]<<16|k[b+3|0]<<24))==810369604){return k[a+4|0]<4}return 0}function AKa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+120|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function zZ(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+256|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function wMa(a,b){var c=0;c=Za-16|0;Za=c;i[c+12>>1]=65535;i[c+14>>1]=b;vMa(a,l[gf(12e3,c+14|0)>>1],c+12|0);Za=c+16|0}function wAa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+32|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function jha(a,b){j[114626]=0;I(25,a|0,b<<11,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function Xra(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+27|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function Uj(a,b){a=a+58|0;if(h[Pb(a,b)|0]<0){return 255}if(k[Pb(a,b)|0]!=255){a=k[Pb(a,b)|0]&127}else{a=255}return a}function Sma(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+20|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function Mra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;d=Up(e,a,d);kn(hb(a),b,c,d+4|0);ub(d);Za=e+16|0}function JLa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+16|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function HBa(a){var b=0,c=0;b=Za-16|0;Za=b;if(Ip(a,b+8|0)){a=b+8|0;c=(k[a|0]|k[a+1|0]<<8)<<16>>16}Za=b+16|0;return c}function Gna(a,b){var c=0;c=Za-16|0;Za=c;Jn(c+8|0,bh(c,b));Fna(a,c+8|0);j[a+16>>2]=0;j[a+12>>2]=0;Za=c+16|0;return a}function Foa(a){if(!(a<q(255))){return 255}if(!(a>q(0))){return 0}if(a<q(4294967296)&a>=q(0)){return~~a>>>0}return 0}function Dxa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+22|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function zra(a,b){j[114626]=0;I(25,a|0,b<<4,8);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function yp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;d=_d(e,a,d);kn(hb(a),b,c,d+4|0);ub(d);Za=e+16|0}function yAa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+6|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function xJa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+8|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function uLa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+3|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function ou(a,b){var c=0,d=0,e=0;c=Za-16|0;Za=c;j[c>>2]=j[b>>2];d=c,e=j[b>>2]+OA(b)|0,j[d+4>>2]=e;JV(a,c);Za=c+16|0}function oFa(a,b){j[114626]=0;I(25,a|0,b<<2,1);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function iy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;d=rl(e,a,d);kn(hb(a),b,c,d+4|0);ub(d);Za=e+16|0}function ek(a,b){a=a|0;b=b|0;var c=0;c=tc(a);if(c>>>0<b>>>0){VIa(a,b-c|0);return}if(b>>>0<c>>>0){gR(a,j[a>>2]+b|0)}}function bY(a,b){var c=0,d=0;c=Za-16|0;Za=c;h[c+15|0]=0;d=-1;if(b){b=An(a,b,c+15|0);d=b?b-a|0:-1}Za=c+16|0;return d}function bBa(a,b){j[114626]=0;I(25,a|0,b<<5,8);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function Uqa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+7|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function SEa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+4|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function PL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;d=yh(e,a,d);kn(hb(a),b,c,d+4|0);ub(d);Za=e+16|0}function PBa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a+2|0;while(1){Oe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Za=b+16|0}function Jga(a){a=a|0;var b=0,c=0;j[j[a+20>>2]>>2]=a;c=j[a+12>>2];b=j[c>>2];j[a+4>>2]=b;if(b){j[b+8>>2]=a}j[c>>2]=a}function HD(a,b,c,d,e,f,g,h,i){j[a>>2]=b;j[a+4>>2]=c;j[a+8>>2]=d;j[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function Fw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Za-16|0;Za=e;d=np(e,a,d);rI(hb(a),b,c,d+4|0);ub(d);Za=e+16|0}function Fra(a,b){j[114626]=0;I(25,a|0,b<<3,8);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function Dn(a,b,c){var d=0;d=Za-16|0;Za=d;Jn(d+8|0,bh(d,b));lu(a,d+8|0);j[a+12>>2]=c;j[a+8>>2]=0;Za=d+16|0;return a}function CLa(a,b){j[114626]=0;I(25,a|0,b<<1,1);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function Bsa(a,b){j[114626]=0;I(25,a|0,b<<2,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function xga(a,b){var c=0;c=Za-16|0;Za=c;WH(c+8|0,Kb(c,b));lu(a,c+8|0);j[a+12>>2]=0;j[a+8>>2]=0;Za=c+16|0;return a}function sga(a,b,c){var d=0;if((b|0)>=1){while(1){n[a>>2]=n[c>>2];a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function rT(a,b){j[114626]=0;I(25,a|0,b<<2,2);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function hpa(a,b,c){var d=0;if((b|0)>=1){while(1){j[a>>2]=j[c>>2];a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function YU(a,b){j[114626]=0;I(25,a|0,b<<3,1);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function VA(a,b){j[114626]=0;I(25,a|0,b<<5,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function Uja(a){var b=0,c=0;if(j[a>>2]){es(a);ye(hb(a),j[a>>2],jd(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function Uia(a){var b=0,c=0;if(j[a>>2]){Xh(a);ye(hb(a),j[a>>2],jd(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function OT(a,b){j[114626]=0;I(25,a|0,b<<1,2);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function Iha(a,b,c){a=a|0;b=b|0;c=q(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=$J(q(c*q(255))),h[d|0]=e;Ar(a)}}function Esa(a){j[a+16>>2]=0;j[a+20>>2]=0;j[a+36>>2]=0;h[a+40|0]=1;j[a+24>>2]=0;j[a+28>>2]=0;i[a+32>>1]=0;return a}function DR(a,b,c,d,e){h[a+4|0]=b;h[a|0]=69;h[a+1|0]=99;h[a+2|0]=104;h[a+3|0]=111;h[a+7|0]=e;h[a+6|0]=d;h[a+5|0]=c}function CB(a,b){j[114626]=0;I(25,a|0,b<<4,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function $ha(a,b){a=a|0;b=b|0;var c=0;a:{if(sb(a)>>>0>511){break a}if(!bd(b)){break a}c=j[b>>2];RH(a,b)}return c|0}function x4(a,b){j[114626]=0;I(25,a|0,b|0,1);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function vMa(a,b,c){var d=0;d=bc(a);if(d>>>0<b>>>0){uMa(a,b-d|0,c);return}if(b>>>0<d>>>0){Bp(a,j[a>>2]+(b<<1)|0)}}function tGa(a,b,c){var d=0;d=Za-16|0;Za=d;nFa(b,c);c=yb(a,c<<2);if(c){Uy(d+8|0,b);qd(a,d+8|0)}Za=d+16|0;return c}function swa(a){a=a|0;var b=0;b=zM(a);if((b|0)!=(a|0)){while(1){rwa(a);a=a+32|0;if((b|0)!=(a|0)){continue}break}}}function sI(a){var b=0,c=0;if(j[a>>2]){vI(a);it(hb(a),j[a>>2],mi(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function hDa(a,b,c){var d=0;d=Za-16|0;Za=d;UCa(b,c);c=yb(a,c<<2);if(c){Uy(d+8|0,b);qd(a,d+8|0)}Za=d+16|0;return c}function gla(a,b){a=a|0;b=b|0;h[b+38|0]=k[a+202|0];h[b+39|0]=k[a+203|0];h[b+40|0]=k[a+204|0];h[b+41|0]=k[a+205|0]}function cja(a){var b=0;b=Za-16|0;Za=b;i[b+14>>1]=a;i[b+12>>1]=32767;a=i[gf(b+14|0,b+12|0)>>1];Za=b+16|0;return a}function XO(a){var b=0,c=0;if(j[a>>2]){vP(a);It(hb(a),j[a>>2],jd(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function XD(a,b){a=a|0;b=b|0;var c=0;c=j[a>>2];a:{if(!c){break a}if(!ce(xG(c,b),-1)){break a}j[a>>2]=0}return a|0}function WD(a,b){a=a|0;b=b|0;var c=0;c=j[a>>2];a:{if(!c){break a}if(!ce(E3(c,b),-1)){break a}j[a>>2]=0}return a|0}function QFa(a,b,c){var d=0;d=sb(a);if(d>>>0<b>>>0){uFa(a,b-d|0,c);return}if(b>>>0<d>>>0){YP(a,j[a>>2]+(b<<2)|0)}}function Nj(a,b){var c=0;c=b&15;if(c){h[a+844|0]=c<<2}b=b&240;if(b){h[a+843|0]=b>>>4}j[a+88>>2]=j[a+88>>2]|131072}function NK(a){var b=0,c=0;if(j[a>>2]){_r(a);Yf(hb(a),j[a>>2],Af(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function LV(a,b,c){a:{if(tc(a)>>>0<=b>>>0){break a}if(tc(a)>>>0<c>>>0){break a}return tc(a)-b>>>0>=c>>>0}return 0}function L0(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}Tg(a,b);a=a+1|0;continue}}}function K0(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}Hb(a,b);a=a+4|0;continue}}}function Iza(a,b,c){var d=0;d=Za-16|0;Za=d;Fza(b,c);c=yb(a,c<<2);if(c){Uy(d+8|0,b);qd(a,d+8|0)}Za=d+16|0;return c}function HK(a,b){var c=0;c=b&15;if(c){h[a+847|0]=c<<2}b=b&240;if(b){h[a+846|0]=b>>>4}j[a+88>>2]=j[a+88>>2]|262144}function $L(a){var b=0,c=0;if(j[a>>2]){wp(a);un(hb(a),j[a>>2],Pf(a));b=hb(a),c=0,j[b>>2]=c;j[a>>2]=0;j[a+4>>2]=0}}function $G(a){a=a|0;j[a+4244>>2]=0;j[a+4248>>2]=0;j[a+4228>>2]=0;j[a+4232>>2]=0;a=a+4252|0;j[a>>2]=0;j[a+4>>2]=0}function zka(a,b,c){var d=0;if((b|0)>=1){while(1){h[a|0]=k[c|0];a=a+1|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function pf(a,b,c){var d=0;a:{if(b>c){break a}d=o[a>>3];if(!(d>=b)){o[a>>3]=b;return}if(c>=d){break a}o[a>>3]=c}}function Qra(a){var b=0,c=0;while(1){b=a&1|b<<1;a=(a&254)>>>1|0;c=c+1|0;if((c|0)!=8){continue}break}return b&255}function OCa(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;Za=b+16|0}function BE(a,b,c){var d=0,e=0,f=0;e=c*c;o[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;o[b>>3]=d*d+(c*c-e+(c+c)*d)}function nq(){var a=0;j[114626]=0;a=j[114626];j[114626]=0;if((a|0)!=1){return j[14764]}a=J(0)|0;C()|0;ib(a);z()}function nk(a){a=k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function mq(){var a=0;j[114626]=0;a=j[114626];j[114626]=0;if((a|0)!=1){return j[15152]}a=J(0)|0;C()|0;ib(a);z()}function mda(a){a=a|0;var b=0,c=0;b=Za-16|0;Za=b;c=Eb(b,38147);Wb(a,c);gb(c);j[a>>2]=83600;Za=b+16|0;return a|0}function iG(a){var b=0;a:{while(1){if(!j[(b<<2)+a>>2]){break a}b=b+1|0;if((b|0)!=4){continue}break}b=4}return b}function hJa(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(m[a+4>>2]<m[hb(a)>>2]){YIa(a,b,c);break a}XIa(a,b,c)}return mt(a)|0}function Zr(a){var b=0;b=1;a:{switch(k[a+3|0]-4|0){default:b=k[a+2|0]==11;break;case 0:case 2:break a}}return b}function So(a,b){var c=0;c=Za-16|0;Za=c;j[c+8>>2]=j[a>>2];j[c+8>>2]=j[c+8>>2]+(b<<2);Za=c+16|0;return j[c+8>>2]}function Q2(a,b){a=a|0;b=b|0;var c=0,d=0;bb[j[j[a>>2]+24>>2]](a)|0;b=hv(b);j[a+36>>2]=b;c=a,d=am(b),h[c+44|0]=d}function N2(a,b){a=a|0;b=b|0;var c=0,d=0;bb[j[j[a>>2]+24>>2]](a)|0;b=gv(b);j[a+36>>2]=b;c=a,d=am(b),h[c+44|0]=d}function Mn(){var a=0;j[114626]=0;a=j[114626];j[114626]=0;if((a|0)!=1){return j[14568]}a=J(0)|0;C()|0;ib(a);z()}function Hz(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;j[c+12>>2]=b;b=a;a=Eb(c,j[c+12>>2]);vy(b,a);gb(a);Za=c+16|0}function Dg(a){a:{a=j[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function DX(a){var b=0,c=0,d=0;b=Za-16|0;Za=b;c=j[zc(b+8|0,j[a+4>>2])>>2],d=1,h[c|0]=d;h[j[a+8>>2]]=1;Za=b+16|0}function Cda(a){a=a|0;var b=0,c=0;b=Za-16|0;Za=b;c=Eb(b,38128);Wb(a,c);gb(c);j[a>>2]=83580;Za=b+16|0;return a|0}function AJa(a,b,c){if((a|0)!=(b|0)){while(1){vR(c,a);c=c+2|0;a=a+2|0;if((b|0)!=(a|0)){continue}break}}return c}function kt(a,b){var c=0;c=Za-16|0;Za=c;j[c+12>>2]=(p(a,b)>>>0)/255;Md(c+12|0,0,15);Za=c+16|0;return k[c+12|0]}function ks(a,b){var c=0;c=Za-16|0;Za=c;j[c+8>>2]=j[a+4>>2];j[c>>2]=j[b+4>>2];a=rb(c+8|0,c);Za=c+16|0;return a}function gQ(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(c+1|0){case 0:case 2:dh(a,b);return;default:break a}}WEa(a,b,c)}function dI(a){var b=0;b=Za-16|0;Za=b;j[b+12>>2]=a;j[b+8>>2]=32767;a=i[tb(b+12|0,b+8|0)>>1];Za=b+16|0;return a}function UL(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(c+1|0){case 0:case 3:LL(a,b);return;default:break a}}Isa(a,b,c)}function Rf(a,b,c){if(!c){return j[a+4>>2]==j[b+4>>2]}if((a|0)==(b|0)){return 1}return!Mh(j[a+4>>2],j[b+4>>2])}function Qd(a,b){var c=0;c=j[a+4>>2];if(b){a=j[a>>2];j[a>>2]=j[a>>2]|c;return}a=j[a>>2];j[a>>2]=j[a>>2]&(c^-1)}function QI(a){j[114626]=0;I(25,a|0,28,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function EX(a){var b=0;a:{a=j[a+8>>2];b=k[a|0];if((b|0)!=1){if(b&2){break a}h[a|0]=2;a=1}else{a=0}return a}z()}function DY(a,b){j[114626]=0;mv(a,b<<2,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function Bx(a){j[114626]=0;I(25,a|0,40,4);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function yO(a,b){h[a+6|0]=255;j[a+16>>2]=0;i[a+4>>1]=0;j[a>>2]=0;if(!(b<0)){o[a+8>>3]=b;j[a+16>>2]=3}return a}function wm(a){var b=0;while(1){if(k[b+32256|0]==(a|0)){return b}b=b+1|0;if(b>>>0<43){continue}break}return 0}function fC(a,b,c){j[114626]=0;dC(a,b,c);a=j[114626];j[114626]=0;if((a|0)!=1){return}a=J(0)|0;C()|0;ib(a);z()}function aJ(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+736|0;case 1:break a}}return a+748|0}function SBa(a){if(!(a<4294967295)){return-1}if(!(a>0)){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function Gma(a,b,c){var d=0;if((b|0)>=1){while(1){Fma(a,c);a=a+160|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function wpa(a){if(!(a<65535)){return 65535}if(!(a>0)){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function toa(a,b){var c=0;if(!b){return a}while(1){c=b;b=(a>>>0)%(b>>>0)|0;a=c;if(b){continue}break}return c}function iP(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;i[c+14>>1]=b;if((nt(a)|0)!=65535){dS(a,c+14|0)}Za=c+16|0}function dE(a){var b=0;b=j[a+12>>2];if((b|0)==j[a+16>>2]){return bb[j[j[a>>2]+36>>2]](a)|0}return gg(h[b|0])}function cD(a,b,c,d,e){b=Fh(b,c,d,e,4);if(!(k[d|0]&4)){j[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function Sk(a,b){var c=0;c=sb(a);if(c>>>0<b>>>0){eja(a,b-c|0);return}if(b>>>0<c>>>0){Bw(a,j[a>>2]+(b<<2)|0)}}function Qma(a,b,c){var d=0;if((b|0)>=1){while(1){Rr(a,c);a=a+896|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function Po(a,b){a=a|0;b=b|0;if(bc(a)>>>0>b>>>0){a=tg(j[a+24>>2]+484344|0,l[mk(a,b)>>1])}else{a=0}return a|0}function Bba(a,b){var c=0;c=Za-16|0;Za=c;j[c+8>>2]=b;b=j[c+8>>2];TH(a,b);Rb(a);Im(Rg(c+8|0));Bx(b);Za=c+16|0}function $C(a,b,c,d,e){b=Eh(b,c,d,e,4);if(!(k[d|0]&4)){j[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function pwa(a){var b=0;b=zM(a);if((b|0)!=(a|0)){while(1){qwa(a);a=a+32|0;if((b|0)!=(a|0)){continue}break}}}function cMa(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;j[c>>2]=b;j[c+8>>2]=a;tLa(j[c+8>>2],j[c>>2]);Za=c+16|0}function Zta(a){var b=0,c=0;b=a+108|0;a=0;while(1){c=Pb(b,a);a=a+1|0;h[c|0]=a;if(a>>>0<128){continue}break}}function Vm(a){var b=0;b=Za-16|0;Za=b;j[b+12>>2]=a;j[b+8>>2]=255;a=k[tb(b+12|0,b+8|0)|0];Za=b+16|0;return a}function UE(a,b,c,d){n[d+4>>2]=c+a;a=q(a+q(c*q(-.5)));b=q(b*q(.8660253882408142));n[d+8>>2]=a-b;n[d>>2]=a+b}function Kg(a,b){var c=0;c=a;b=j[a+16>>2]+b|0;a=j[a+12>>2];b=(b|0)%(a|0)|0;return n[jc(c,(b>>31&a)+b|0)>>2]}function xCa(a,b){a=a|0;b=b|0;var c=0;b=Za-16|0;Za=b;c=-1;if(hj(a,b+8|0)){c=SO(b+8|0)}Za=b+16|0;return c|0}function tKa(a,b){a=a|0;b=b|0;var c=0;b=Za-16|0;Za=b;c=-1;if(hj(a,b+8|0)){c=MR(b+8|0)}Za=b+16|0;return c|0}function kJa(a,b){a=a|0;b=b|0;var c=0;b=Za-80|0;Za=b;c=-1;if(qR(a,b+8|0)){c=pR(b+8|0)}Za=b+80|0;return c|0}function iY(a){a=a|0;a=Za-16|0;Za=a;if(Ga(a+12|0,4)|0){QB(j[114600],68603);z()}Za=a+16|0;return j[a+12>>2]}function boa(a,b){var c=0,d=0;c=Za-16|0;Za=c;j[c+8>>2]=b;d=o[j[c+8>>2]>>3];j[a+8>>2]=0;o[a>>3]=d;Za=c+16|0}function bF(a){var b=0;b=j[(k[a+2|0]&12)+42468>>2];a=k[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function Lv(a,b){var c=0;c=(p(p(Jv(a),Kv(a)),125)>>>0)/(bF(a)>>>0)|0;a=(k[a+1|0]&6)==6?c&-4:c;return a?a:b}function Gt(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function Ao(a){var b=0,c=0,d=0;b=a;a=j[a>>2];c=b,d=lb(p(a,214013)+2531011|0),j[c>>2]=d;return a>>>16&32767}function $e(a,b){var c=0;c=Za-16|0;Za=c;j[c+8>>2]=j[a>>2];j[c+8>>2]=j[c+8>>2]+b;Za=c+16|0;return j[c+8>>2]}function yoa(a){var b=0,c=0;Or(a,se(a));b=hb(a),c=0,j[b>>2]=c;b=a,c=Rb(a),j[b>>2]=c;b=Rb(a),c=0,j[b>>2]=c}function sBa(a,b){var c=0;c=Za-16|0;Za=c;a:{if(jf(a,512)){Kz(c+8|0,b);ty(a,c+8|0);break a}kO(b)}Za=c+16|0}function qBa(a,b){var c=0;c=Za-16|0;Za=c;a:{if(yb(a,512)){Kz(c+8|0,b);qd(a,c+8|0);break a}kO(b)}Za=c+16|0}function oC(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j[e>>2]=c;j[h>>2]=f;return 3}function g5(a,b,c,d,e){var f=0;e=e-d|0;f=e>>31;a=(p(a-b|0,f^e+f)|0)/(c-b|0)|0;return((e|0)<0?0-a|0:a)+d|0}function ZD(a){var b=0;b=j[a+12>>2];if((b|0)==j[a+16>>2]){return bb[j[j[a>>2]+36>>2]](a)|0}return j[b>>2]}function Of(a){var b=0,c=0;b=Za-16|0;Za=b;if(Ip(a,b+8|0)){a=b+8|0;c=k[a|0]|k[a+1|0]<<8}Za=b+16|0;return c}function H1(a){j[a>>2]=0;j[a+4>>2]=0;j[a+20>>2]=0;i[a+16>>1]=65535;j[a+8>>2]=0;j[a+12>>2]=0;j[a+24>>2]=11}function Gs(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;nn(c+8|0,a);j[c+4>>2]=j[c+8>>2];Fs(c+4|0,b);Za=c+16|0}function Fta(a,b){var c=0;a=Eta(a,b);a:{if(!a){break a}b=lY(a);if(!b){break a}c=Ab(b,0,a)- -64|0}return c}function F2(a,b){var c=0;c=Za-16|0;j[c+12>>2]=a;a=b>>>0>1?((b<<2)+a|0)-4|0:a;j[c+8>>2]=a+4;return j[a>>2]}function Ew(a,b){cz(a);j[a+20>>2]=0;j[a+12>>2]=0;j[a+16>>2]=0;nx(a+24|0);Db(a+36|0);j[a+48>>2]=b;return a}function DU(a,b){a=a|0;b=b|0;var c=0;b=Za-16|0;Za=b;c=-1;if(hj(a,b+8|0)){c=NA(b+8|0)}Za=b+16|0;return c|0}function vM(a,b,c){if((b|0)!=(c|0)){while(1){yra(a,lb(k[b|0]));b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function nh(a,b,c){var d=0,e=0,f=0,g=0;d=o[c>>3];e=o[b>>3];f=o[c+8>>3];g=o[b+8>>3];cl(a,d*e-f*g,e*f+d*g)}function dz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;QFa(a,b,d+12|0);dx(a);Za=d+16|0}function b$(a,b,c){var d=0;d=Za-16|0;Za=d;if(b>>>0>=12){Ci(6934);z()}rj(d+8|0,a,b);Qd(d+8|0,c);Za=d+16|0}function aha(a){var b=0,c=0,d=0;while(1){b=Ao(a)^b<<15;d=c>>>0<17;c=c+15|0;if(d){continue}break}return b}function ZCa(a){if(!(a<255)){return 255}if(!(a>0)){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function Tx(a){Qta(a);h[a+12|0]=0;h[a+13|0]=0;h[a+14|0]=0;h[a+15|0]=0;h[a+16|0]=0;h[a+17|0]=255;return a}function Qf(a,b){var c=0,d=0;c=j[a>>2];d=j[b>>2];ab=j[a+4>>2]-(j[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function LGa(a,b){a=a|0;b=b|0;var c=0;a=cFa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,4896);Za=c+16|0}return a|0}function JAa(a,b){a=a|0;b=b|0;var c=0;a=zAa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,1030);Za=c+16|0}return a|0}function DL(a){i[a+70>>1]=k[((l[j[a+4>>2]+22>>1]<<4|l[j[a+4>>2]+20>>1]>>>6)&65535)+19968|0]>>>l[a+68>>1]}function x3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return bb[j[j[a>>2]+20>>2]](a,b,c,d,e,f)|0}function tCa(a,b){a=a|0;b=b|0;var c=0;a=QBa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,422);Za=c+16|0}return a|0}function nCa(a,b){a=a|0;b=b|0;var c=0;a=NBa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,826);Za=c+16|0}return a|0}function iu(a,b){a=a|0;b=b|0;var c=0;b=b-1|0;c=1085;a:{if(b>>>0>4){break a}c=j[(b<<2)+76420>>2]}Eb(a,c)}function ZI(a,b){var c=0;c=Za-16|0;Za=c;i[c+14>>1]=l[a>>1];i[a>>1]=l[b>>1];i[b>>1]=l[c+14>>1];Za=c+16|0}function X3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return bb[j[j[a>>2]+16>>2]](a,b,c,d,e,f)|0}function Vka(a,b){a=a|0;b=b|0;var c=0;a=xka(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,225);Za=c+16|0}return a|0}function U3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return bb[j[j[a>>2]+24>>2]](a,b,c,d,e,f)|0}function TAa(a,b){a=a|0;b=b|0;var c=0;a=xAa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,274);Za=c+16|0}return a|0}function Rka(a,b){a=a|0;b=b|0;var c=0;a=wka(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,326);Za=c+16|0}return a|0}function RO(a,b){var c=0;c=m[b>>2]>m[a>>2];a=j[a+4>>2];b=j[b+4>>2];return(a|0)<(b|0)?1:(a|0)<=(b|0)?c:0}function P3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return bb[j[j[a>>2]+28>>2]](a,b,c,d,e,f)|0}function OAa(a,b){a=a|0;b=b|0;var c=0;a=vAa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,106);Za=c+16|0}return a|0}function K3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return bb[j[j[a>>2]+44>>2]](a,b,c,d,e,f)|0}function Hb(a,b){var c=0;c=Za-16|0;Za=c;j[c+12>>2]=j[a>>2];j[a>>2]=j[b>>2];j[b>>2]=j[c+12>>2];Za=c+16|0}function EBa(a,b){var c=0;c=Za-16|0;Za=c;a:{if(jf(a,4)){ah(c+8|0,b);ty(a,c+8|0);break a}HP(b)}Za=c+16|0}function Cn(a,b,c){var d=0;d=Za-16|0;Za=d;a=wf(a);j[a+4>>2]=c;j[a>>2]=b;j[d+4>>2]=b;j[d>>2]=b;Za=d+16|0}function BJa(a,b,c){if((a|0)!=(b|0)){while(1){c=c-2|0;b=b-2|0;vR(c,b);if((a|0)!=(b|0)){continue}break}}}function y_(a,b,c){var d=0;if(j[a>>2]){while(1){dh(b,c+d|0);d=d+1|0;if(d>>>0<m[a>>2]){continue}break}}}function oDa(a,b){a=a|0;b=b|0;var c=0;a=FCa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,42);Za=c+16|0}return a|0}function lP(a,b){a=a|0;b=b|0;var c=0;a=WCa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,284);Za=c+16|0}return a|0}function gM(a){var b=0,c=0;while(1){c=(b<<2)+a|0;b=b+1|0;j[c+68>>2]=b<<11;if((b|0)!=9){continue}break}}function aIa(a,b){a=a|0;b=b|0;var c=0;a=GHa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,34);Za=c+16|0}return a|0}function Yka(a,b){a=a|0;b=b|0;var c=0;a=yka(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,73);Za=c+16|0}return a|0}function Uwa(a,b){a=a|0;b=b|0;var c=0;a=Cwa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,40);Za=c+16|0}return a|0}function UT(a,b){var c=0;c=tc(a);if(c>>>0<b>>>0){NT(a,b-c|0);return}if(b>>>0<c>>>0){Tt(a,j[a>>2]+b|0)}}function Pka(a,b){a=a|0;b=b|0;var c=0;a=vka(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,60);Za=c+16|0}return a|0}function NAa(a,b){a=a|0;b=b|0;var c=0;a=uAa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,72);Za=c+16|0}return a|0}function Mza(a,b){a=a|0;b=b|0;var c=0;a=Aza(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,71);Za=c+16|0}return a|0}function Gxa(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;j[a+4>>2]=0;j[b+12>>2]=0;qs(a+8|0);Za=b+16|0;return a}function FX(a){var b=0,c=0;b=Za-16|0;Za=b;if(!k[j[zc(b+8|0,j[a+4>>2])>>2]]){c=EX(a)}Za=b+16|0;return c}function EEa(a,b){a=a|0;b=b|0;var c=0;a=HDa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,91);Za=c+16|0}return a|0}function Ay(a,b,c){var d=0,e=0;d=Za-1024|0;Za=d;if(gBa(a,d)){e=wy(d,c)>>>0<=b>>>0}Za=d+1024|0;return e}function Ata(a,b){if((a|0)!=(b|0)){zta(a,Lb(b),Mb(b));yi(a+12|0,b+12|0);i[a+28>>1]=l[b+28>>1]}return a}function ACa(a,b){var c=0;c=Za-16|0;Za=c;j[c+8>>2]=b;b=l[j[c+8>>2]>>1];i[a+2>>1]=0;i[a>>1]=b;Za=c+16|0}function $u(a){a=a|0;var b=0;b=j[21215];if(a){j[21215]=(a|0)==-1?458444:a}return((b|0)==458444?-1:b)|0}function n_(a,b){var c=0,d=0;c=Za-16|0;Za=c;if(j[a>>2]!=-1){d=c+8|0;zc(d,b);zc(c,d);nY(a,c)}Za=c+16|0}function mp(a,b){a=a|0;b=b|0;var c=0;a=iIa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,64);Za=c+16|0}return a|0}function Kv(a){var b=0;b=k[a+1|0];return k[(p(b>>>1&3,15)+p(b>>>3&1,45)+(k[a+2|0]>>>4)|0)+42465|0]<<1}function KR(a,b){a=a|0;b=b|0;var c=0;a=EJa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,50);Za=c+16|0}return a|0}function Gx(a,b){if(tg(j[a+24>>2]+484344|0,b)){a=j[Ib(j[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}function $9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;Jn(d+8|0,bh(d,b));Dn(a,d+8|0,c);Za=d+16|0}function ZR(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;Za=b+16|0}function Yta(a){var b=0;a:{b=h[a|0];if((b|0)<-32){h[a|0]=224;return}if((b|0)<=32){break a}h[a|0]=32}}function YFa(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;a=j[zc(c+8|0,JFa(a,b))>>2];Za=c+16|0;return a|0}function V0(a){var b=0;b=Za-16|0;Za=b;j[a>>2]=0;a=a+32|0;fD(a,32);h[b+15|0]=0;G0(a,b+15|0);Za=b+16|0}function Jha(a,b){a=a|0;b=b|0;return q((b|0)<=3?q(q(k[(a+b|0)+4264|0])*q(.003921568859368563)):q(0))}function Bl(a){h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;h[a+6|0]=0;h[a+7|0]=0}function zw(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;a=j[zc(c+8|0,$ia(a,b))>>2];Za=c+16|0;return a|0}function y0(a,b,c,d,e){b=Fh(b,c,d,e,2);c=j[d>>2];if(!(c&4|(b|0)>12)){j[a>>2]=b-1;return}j[d>>2]=c|4}function pH(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;ah(c+8|0,b);a=yga(a,c+8|0);Za=c+16|0;return a|0}function i0(a,b,c,d,e){b=Eh(b,c,d,e,2);c=j[d>>2];if(!(c&4|b-1>>>0>30)){j[a>>2]=b;return}j[d>>2]=c|4}function g0(a,b,c,d,e){b=Eh(b,c,d,e,2);c=j[d>>2];if(!(c&4|b-1>>>0>11)){j[a>>2]=b;return}j[d>>2]=c|4}function e0(a,b,c,d,e){b=Eh(b,c,d,e,2);c=j[d>>2];if(!(c&4|(b|0)>12)){j[a>>2]=b-1;return}j[d>>2]=c|4}function _z(a,b){var c=0,d=0;c=j[a+4>>2];d=j[b+4>>2];return(c|0)==(d|0)&m[b>>2]>m[a>>2]|c>>>0<d>>>0}function Wta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;Nta(d+8|0,b,c,c);iM(a,d+8|0);Za=d+16|0}function VS(a){var b=0;b=k[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;if(b>>>0<2624){a=a+1|0}ab=a;return b}function Ula(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;Ola(d+8|0,b,c,c);iM(a,d+8|0);Za=d+16|0}function Qo(a){a=a|0;var b=0;Om(a);b=Fta(j[a>>2],xn(a));j[a+20>>2]=b;if(!b){return 0}return ik(a)|0}function Qja(a,b){a=a|0;b=b|0;h[b|0]=0;h[b+1|0]=0;h[b+2|0]=0;h[b+3|0]=0;h[b+4|0]=0;h[b+5|0]=0;bj(b)}function Nc(a,b){var c=0;c=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=c;j[a+8>>2]=j[b+8>>2];Hm(b);return a}function HV(a,b,c,d){if(!d|!b){a=-1}else{b=a+b|0;c=_U(a,b,c,c+d|0);a=(b|0)==(c|0)?-1:c-a|0}return a}function Gba(a,b){a=a|0;b=b|0;var c=0;c=j[a+4>>2];b=zb(b);if(c){bb[c|0](b,j[a+8>>2]);return}mr(b,a)}function C0(a,b,c,d,e){b=Fh(b,c,d,e,2);c=j[d>>2];if(!(c&4|b-1>>>0>30)){j[a>>2]=b;return}j[d>>2]=c|4}function A0(a,b,c,d,e){b=Fh(b,c,d,e,2);c=j[d>>2];if(!(c&4|b-1>>>0>11)){j[a>>2]=b;return}j[d>>2]=c|4}function z0(a,b,c,d,e){b=Fh(b,c,d,e,3);c=j[d>>2];if(!(c&4|(b|0)>365)){j[a>>2]=b;return}j[d>>2]=c|4}function wDa(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;i[c+14>>1]=b;Ky(a+236|0,128,c+14|0);Za=c+16|0}function pBa(a,b){a=a|0;b=b|0;var c=0;b=Za-16|0;Za=b;c=-1;if(tz(a,b)){c=tO(b)}Za=b+16|0;return c|0}function l_(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(l[Mn()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function hma(a,b,c,d,e){a:{if((e|0)==128|c>>>0<2){break a}_I(a,d,e);if(c>>>0<4){break a}_I(b,d,e)}}function f0(a,b,c,d,e){b=Eh(b,c,d,e,3);c=j[d>>2];if(!(c&4|(b|0)>365)){j[a>>2]=b;return}j[d>>2]=c|4}function bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;bb[j[j[b>>2]+8>>2]](b,c);d=a;a=b+4|0;Nn(d,a);rC(a,c)}function ag(a){var b=0;b=a+44|0;wk(b);if(j[b>>2]){FB(b,j[b>>2]);zi(hb(b),j[b>>2],Ah(b))}UA(a+32|0)}function _h(a){a=a|0;var b=0,c=0;while(1){c=b&65535;Ina(a,c);b=b+1|0;if(c>>>0<126){continue}break}}function Sga(a,b,c){a=a|0;b=b|0;c=c|0;a=Ki(a);if(!a){return 0}return bb[j[j[a>>2]+96>>2]](a,b,c)|0}function KW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return bb[a|0](b,c,d,e,f,g)|0}function Iba(a,b){if(a){b=bb[j[j[b>>2]+8>>2]](b)|0;a:{if(b){b=Gd(b);break a}b=Gd(34181)}j[a>>2]=b}}function xGa(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;nA(c,a);a=Ze(c,b);gb(c);Za=c+16|0;return a|0}function x0(a,b,c,d,e){b=Fh(b,c,d,e,2);c=j[d>>2];if(!(c&4|(b|0)>59)){j[a>>2]=b;return}j[d>>2]=c|4}function u0(a,b,c,d,e){b=Fh(b,c,d,e,2);c=j[d>>2];if(!(c&4|(b|0)>60)){j[a>>2]=b;return}j[d>>2]=c|4}function nH(a){a=a|0;var b=0;b=j[a>>2];if(b){bb[j[j[b>>2]+8>>2]](b);j[a>>2]=0}a=a+4|0;_r(a);lR(a)}function mxa(a,b,c){a=a|0;b=b|0;c=c|0;a=j[c+4>>2];j[b>>2]=j[c>>2];j[b+4>>2]=a;j[b+8>>2]=j[c+8>>2]}function mfa(a,b){a=a|0;b=b|0;Mq(a);j[a>>2]=76896;Db(a+32|0);j[a+48>>2]=b;j[a+44>>2]=0;return a|0}function jya(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;DT(c,a);a=Ze(c,b);gb(c);Za=c+16|0;return a|0}function hg(a,b,c){a=a|0;b=b|0;c=c|0;ze(a,b);b=j[c+4>>2];j[a+4>>2]=j[c>>2];j[a+8>>2]=b;return a|0}function h0(a,b,c,d,e){b=Eh(b,c,d,e,2);c=j[d>>2];if(!(c&4|(b|0)>23)){j[a>>2]=b;return}j[d>>2]=c|4}function d0(a,b,c,d,e){b=Eh(b,c,d,e,2);c=j[d>>2];if(!(c&4|(b|0)>59)){j[a>>2]=b;return}j[d>>2]=c|4}function a0(a,b,c,d,e){b=Eh(b,c,d,e,2);c=j[d>>2];if(!(c&4|(b|0)>60)){j[a>>2]=b;return}j[d>>2]=c|4}function Tg(a,b){var c=0;c=Za-16|0;Za=c;h[c+15|0]=k[a|0];h[a|0]=k[b|0];h[b|0]=k[c+15|0];Za=c+16|0}function Pra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=o[b+8>>3];d=zv(o[b>>3]);e=Kh(c);cl(a,d*ge(c),d*e)}function BMa(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;bT(c+8|0,a);Hp(c+8|0,b);Za=c+16|0;return a|0}function B0(a,b,c,d,e){b=Fh(b,c,d,e,2);c=j[d>>2];if(!(c&4|(b|0)>23)){j[a>>2]=b;return}j[d>>2]=c|4}function yT(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;mA(c+8|0,a);Hp(c+8|0,b);Za=c+16|0;return a|0}function wI(a,b){var c=0;c=Za-16|0;Za=c;j[c+8>>2]=j[a>>2];pQ(c+8|0,b);Za=c+16|0;return j[c+8>>2]}function t0(a,b,c,d,e){b=Fh(b,c,d,e,1);c=j[d>>2];if(!(c&4|(b|0)>6)){j[a>>2]=b;return}j[d>>2]=c|4}function rN(a){Cya(a,j[a+4>>2]);if(j[a>>2]){jy(j[a+16>>2],j[a>>2],(j[Ob(a)>>2]-j[a>>2]|0)/56|0)}}function hla(a){var b=0;a:{b=k[a|0];if(b>>>0<1){h[a|0]=1;return}if(b>>>0<=16){break a}h[a|0]=16}}function gO(a){var b=0,c=0;b=1;c=j[a>>2];a:{if((c|0)>=1){b=120;if((c|0)<121){break a}}j[a>>2]=b}}function gI(a){nja(a,j[a+4>>2]);if(j[a>>2]){bx(j[a+16>>2],j[a>>2],(j[Ob(a)>>2]-j[a>>2]|0)/52|0)}}function dt(a){xIa(a,j[a+4>>2]);if(j[a>>2]){XQ(j[a+16>>2],j[a>>2],(j[Ob(a)>>2]-j[a>>2]|0)/48|0)}}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bb[j[j[b>>2]+16>>2]](a,b,j[c+8>>2],j[c+12>>2],0,d)}function NM(a){var b=0;b=k[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;if(b>>>0<259){a=a+1|0}ab=a;return b}function FT(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;Nt(c+8|0,a);Hp(c+8|0,b);Za=c+16|0;return a|0}function AP(a){YDa(a,j[a+4>>2]);if(j[a>>2]){yP(j[a+16>>2],j[a>>2],(j[Ob(a)>>2]-j[a>>2]|0)/33|0)}}function AFa(a,b){var c=0;c=Za-16|0;Za=c;j[c+8>>2]=b;i[a>>1]=l[j[c+8>>2]>>1];Qc(a+4|0);Za=c+16|0}function $r(a){Kqa(a,j[a+4>>2]);if(j[a>>2]){fh(j[a+16>>2],j[a>>2],(j[Ob(a)>>2]-j[a>>2]|0)/12|0)}}function $$(a,b,c,d,e){b=Eh(b,c,d,e,1);c=j[d>>2];if(!(c&4|(b|0)>6)){j[a>>2]=b;return}j[d>>2]=c|4}function zJa(a,b){var c=0;c=Za-16|0;Za=c;j[c>>2]=b;j[c+8>>2]=a;a=vp(c,c+8|0);Za=c+16|0;return a}function wBa(a){var b=0,c=0;b=Za-1024|0;Za=b;if($Aa(a,b)){c=wy(b,0)>>>0<17}Za=b+1024|0;return c}function ula(a,b){a=a|0;b=b|0;mh(a);mh(a);a:{if(b>>>0>=60){Jb(a,4);break a}mh(a)}return mh(a)|0}function rta(a){var b=0;b=Za-16|0;Za=b;j[b+8>>2]=j[a+4>>2];a=j[TL(b+8|0)>>2];Za=b+16|0;return a}function qKa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;bb[j[j[b>>2]+16>>2]](a,b,c,d,e,f)}function pfa(a){a=a|0;var b=0,c=0;h[a+4202|0]=1;b=a,c=xe(j[a+16>>2]),j[b+4256>>2]=c;_G(a);ZG(a)}function no(a,b,c){a=j[a>>2]+1074984|0;return j[(a+p(b,896)|0)+680>>2]>j[(a+p(c,896)|0)+680>>2]}function mra(a){var b=0;b=Za-16|0;Za=b;j[b+8>>2]=j[a+4>>2];a=j[aL(b+8|0)>>2];Za=b+16|0;return a}function k7(a,b){var c=0;c=j[a+4>>2];j[a+8>>2]=j[a+8>>2]-b;j[a>>2]=j[a>>2]+(p(b,c)<<1);return a}function jX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Rf(a,j[b+8>>2],f)){Bu(b,c,d,e)}}function ika(a,b,c){var d=0;d=Za-16|0;Za=d;j[d>>2]=b;j[d+8>>2]=a;Rja(a,Dr(d,d+8|0),c);Za=d+16|0}function Y6(a,b){var c=0;c=j[a+4>>2];j[a+8>>2]=j[a+8>>2]-b;j[a>>2]=j[a>>2]+(p(b,c)<<2);return a}function Sz(a,b){a=a|0;b=b|0;var c=0;a=Ip(a,b);if(!a){c=Za-16|0;Za=c;Vz(b);Za=c+16|0}return a|0}function Qs(a){YEa(a,j[a+4>>2]);if(j[a>>2]){it(j[a+16>>2],j[a>>2],(j[Ob(a)>>2]-j[a>>2]|0)/6|0)}}function Qga(a,b){a=a|0;b=b|0;b=Za-16|0;Za=b;xi(b,j[a+20>>2]+4|0);wH(a,vd(b+8|0,b),0);Za=b+16|0}function QE(a){var b=0;b=+((a&2097151)>>>0);return q(Bh(+q((a|0)>-1?b:-b),(a>>>21&1023)-788|0))}function Ota(a,b){var c=0;c=Za-16|0;Za=c;j[c>>2]=b;j[c+8>>2]=a;a=Ms(c,c+8|0);Za=c+16|0;return a}function Hha(a){a=a|0;var b=0,c=0;h[a+4202|0]=1;b=a,c=xe(j[a+16>>2]),j[b+4232>>2]=c;Ar(a);JH(a)}function DGa(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;oQ(c,b);Nc(a,c);gb(c);Za=c+16|0;return a|0}function tja(a,b,c){var d=0;j[a>>2]=j[b>>2];d=j[b>>2];j[a+8>>2]=b;j[a+4>>2]=p(c,52)+d;return a}function mr(a,b){a=a|0;b=b|0;b=Za-16|0;Za=b;j[b>>2]=a;a=j[13922];tE(a,34267,b);Sq(a);Za=b+16|0}function ls(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=j[a+24>>2];d=a,e=Yj(Bg(b)*+(c>>>0)),j[d+24>>2]=e}function lha(a,b,c){var d=0;j[a>>2]=j[b>>2];d=j[b>>2];j[a+8>>2]=b;j[a+4>>2]=(c<<11)+d;return a}function iR(a,b){return(Gb((p(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Gb((p(a&15,b)>>>0)/15|0,1,15))&255}function dFa(a,b,c){var d=0;j[a>>2]=j[b>>2];d=j[b>>2];j[a+8>>2]=b;j[a+4>>2]=p(c,48)+d;return a}function GBa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Za-16|0;Za=c;d=a;a=Nc(c,b);vy(d,a);gb(a);Za=c+16|0}function $Da(a,b,c){var d=0;j[a>>2]=j[b>>2];d=j[b>>2];j[a+8>>2]=b;j[a+4>>2]=p(c,33)+d;return a}function zIa(a,b,c,d){a=c-b|0;c=j[d>>2]+p((a|0)/-48|0,48)|0;j[d>>2]=c;if((a|0)>=1){Vb(c,b,a)}}function tj(a){var b=0;b=Za-16|0;Za=b;a=j[zc(b+8|0,zb(a)+(nb(a)<<2)|0)>>2];Za=b+16|0;return a}function oxa(a,b,c,d){a=c-b|0;c=j[d>>2]+p((a|0)/-12|0,12)|0;j[d>>2]=c;if((a|0)>=1){Vb(c,b,a)}}function kea(a,b){if(!j[a+4116>>2]){Rm(a+8|0,b,a+4104|0,a+4108|0)}j[a+4116>>2]=1;return a+8|0}function jka(a){var b=0,c=0;b=Za-16|0;Za=b;c=Lb(a);a=Mb(a);Ug(b+8|0);ika(c,a,b+8|0);Za=b+16|0}function iAa(a,b,c){var d=0;j[a>>2]=j[b>>2];d=j[b>>2];j[a+8>>2]=b;j[a+4>>2]=(c<<3)+d;return a}function _Da(a,b,c,d){a=c-b|0;c=j[d>>2]+p((a|0)/-33|0,33)|0;j[d>>2]=c;if((a|0)>=1){Vb(c,b,a)}}function ZEa(a,b,c){var d=0;j[a>>2]=j[b>>2];d=j[b>>2];j[a+8>>2]=b;j[a+4>>2]=p(c,6)+d;return a}function QX(a,b,c){a=a|0;b=b|0;c=c|0;if(ce(a,j[b+4>>2])){a=j[b>>2]==(c|0)}else{a=0}return a|0}function QW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=bb[a|0](b,c,d,e)|0;ea(ab|0);return a|0}function PM(a,b,c){var d=0;j[a>>2]=j[b>>2];d=j[b>>2];j[a+8>>2]=b;j[a+4>>2]=p(c,12)+d;return a}function Gsa(a,b,c){var d=0;j[a>>2]=j[b>>2];d=j[b>>2];j[a+8>>2]=b;j[a+4>>2]=(c<<5)+d;return a}function B3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return bb[j[j[a>>2]+16>>2]](a,b,c,d,e)|0}function A3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return bb[j[j[a>>2]+24>>2]](a,b,c,d,e)|0}function yo(a,b,c){a=Yk(a)-j[a+1074392>>2]|0;if(a>>>0>=2){c=q(q(q(c-b)/q(a>>>0))+b)}return c}function yga(a,b){var c=0;c=Za-16|0;Za=c;Jn(c+8|0,bh(c,b));a=rga(a,c+8|0);Za=c+16|0;return a}function xk(a,b,c){var d=0;d=Za-16|0;Za=d;Qb(d+8|0,lb(b),c);a=GR(a,d+8|0);Za=d+16|0;return a}function wh(a,b,c){var d=0;j[a>>2]=j[b>>2];d=j[b>>2];j[a+8>>2]=b;j[a+4>>2]=(c<<2)+d;return a}function w3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return bb[j[j[a>>2]+32>>2]](a,b,c,d,e)|0}function vl(a,b,c){var d=0;j[a>>2]=j[b>>2];d=j[b>>2];j[a+8>>2]=b;j[a+4>>2]=(c<<1)+d;return a}function uD(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(j[b>>2]){continue}break}return b-a>>2}function sp(a,b,c){a=a|0;b=b|0;c=c|0;a=j[c+4>>2];j[b>>2]=j[c>>2];j[b+4>>2]=a;Cl(b+8|0,c+8|0)}function rE(a){var b=0;b=NMa(j[a>>2]-1|0);if(!b){a=NMa(j[a+4>>2]);return a?a+32|0:0}return b}function qC(a){a=a|0;var b=0;j[a>>2]=62484;b=j[a+8>>2];if(!(!b|!k[a+12|0])){Cb(b)}return a|0}function oia(a,b){var c=0;c=Za-16|0;Za=c;j[c+8>>2]=0;ho(a,c+8|0);n[b>>2]=n[c+8>>2];Za=c+16|0}function ip(a,b){var c=0;c=nb(a);if((c|0)==(nb(b)|0)){a=!zm(zb(a),zb(b),c)}else{a=0}return a}function gT(a){var b=0;b=Za-16|0;Za=b;a=Df(a,b+15|0);Za=b+16|0;return(a?k[b+15|0]:0)<<24>>24}function Zna(a){a=a|0;var b=0;j[a>>2]=0;b=Za-16|0;Za=b;Sma(a+9|0);Za=b+16|0;vg(a);return a|0}function Yma(a){var b=0;b=Za-16|0;Za=b;j[b+12>>2]=0;Kr(b+12|0,a);Za=b+16|0;return j[b+12>>2]}function TMa(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}



function Qda(a,b,c){a=a|0;b=b|0;c=c|0;dw(a);j[a+8>>2]=c;j[a+4>>2]=b;j[a>>2]=83548;return a|0}function NJ(a,b){a=a|0;b=b|0;IJ(a);IJ(a+368680|0);if(b){VI(a,1);return a|0}Sla(a);return a|0}function Kia(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=-1?(c|0)!=4:0)){oia(a,b);return}nia(a,b,c)}function Ina(a,b){if(b>>>0<=126){vg(((b<<5)+a|0)+480280|0);Pm((p(b,896)+a|0)+1074984|0,a,b)}}function DB(a,b,c){var d=0;j[a>>2]=j[b>>2];d=j[b>>2];j[a+8>>2]=b;j[a+4>>2]=(c<<4)+d;return a}function $7(a,b,c,d){a=c-b|0;c=j[d>>2]+p((a|0)/-24|0,24)|0;j[d>>2]=c;if((a|0)>=1){Vb(c,b,a)}}function zr(a){iha(a,j[a+4>>2]);if(j[a>>2]){BH(j[a+16>>2],j[a>>2],j[Ob(a)>>2]-j[a>>2]>>11)}}function yb(a,b){a=a|0;b=b|0;var c=0;c=j[a>>2];return bb[j[j[c>>2]+36>>2]](c,j[a+8>>2],b)|0}function wx(a){var b=0;j[a+72>>2]=0;j[a+76>>2]=0;b=j[a+68>>2];j[a+80>>2]=b;j[a+84>>2]=b<<12}function rI(a,b,c,d){a=c-b|0;if((a|0)>=1){Vb(j[d>>2],b,a);j[d>>2]=j[d>>2]+p((a>>>0)/6|0,6)}}function dKa(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;ug(c,1,a);tA(c,b);Za=c+16|0;return a|0}function cKa(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;qt(c,1,a);tA(c,b);Za=c+16|0;return a|0}function Xz(a,b,c){a=a|0;b=b|0;c=c|0;b=Za-16|0;Za=b;h[b+15|0]=k[c|0];KH(a,b+15|0);Za=b+16|0}function XG(a,b){var c=0;c=j[a+12>>2];if((c|0)>=1){j[a+20>>2]=(j[a+16>>2]+(b+c|0)|0)%(c|0)}}function UA(a){var b=0;Ap(a);b=a;if(j[b>>2]){BB(b,j[b>>2]);Yf(hb(b),j[b>>2],Af(b))}return a}function Sda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;HG(a,b,c,d,e,0,0,f,g)}function Qwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;Wo(a,b,c);Za=d+16|0;return a|0}function Nea(a){var b=0;b=j[19205];j[a>>2]=b;j[j[b-12>>2]+a>>2]=j[19208];lr(a+4|0);return a}function MA(a){a=a|0;var b=0;b=j[a>>2];return lb((bb[j[j[b>>2]+20>>2]](b)|0)+j[a+8>>2]|0)|0}function IJ(a){j[a+20>>2]=0;h[a+16|0]=7;j[a+8>>2]=1889785610;j[a+12>>2]=1072630333;h[a|0]=3}function Eta(a,b){if(a-1>>>0<=268435455){a=a+208|0;OMa(b,0,a,0);return ab?0:p(a,b)}return 0}function xi(a,b){a=a|0;b=b|0;var c=0,d=0;j[a>>2]=j[b>>2];c=a,d=j[b>>2]+tc(b)|0,j[c+4>>2]=d}function gj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;lJ(a,b,c);Za=d+16|0;return a|0}function fja(a,b,c){var d=0;d=Za-16|0;Za=d;j[zc(d+8|0,kz(ll(a),ll(b),ll(c)))>>2];Za=d+16|0}function fB(a,b){var c=0,d=0;up(a);j[a>>2]=77152;j[a+4>>2]=j[b>>2];c=a,d=Xg(b),j[c+8>>2]=d}function c8(a){var b=0;b=j[19251];j[a>>2]=b;j[j[b-12>>2]+a>>2]=j[19254];lr(a+8|0);return a}function Zh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Za-16|0;Za=d;SI(a,b,c);Za=d+16|0;return a|0}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=-1?(c|0)!=4:0)){ii(a,b);return}rD(a,b,c)}function YN(a){hAa(a,j[a+4>>2]);if(j[a>>2]){du(j[a+16>>2],j[a>>2],j[Ob(a)>>2]-j[a>>2]>>3)}}function Xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ki(a);if(a){bb[j[j[a>>2]+76>>2]](a,b,c,d)}}function Wga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ki(a);if(a){bb[j[j[a>>2]+80>>2]](a,b,c,d)}}function Vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ki(a);if(a){bb[j[j[a>>2]+84>>2]](a,b,c,d)}}function UD(a){var b=0;b=j[a>>2];if(b){if(!ce(dE(b),-1)){return!j[a>>2]}j[a>>2]=0}return 1}function TD(a){var b=0;b=j[a>>2];if(b){if(!ce(ZD(b),-1)){return!j[a>>2]}j[a>>2]=0}return 1}function Ska(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+38|0;Mc(c,(k[a|0]|k[a+1|0]<<8)&4?16:8,1,0,0)}function Mka(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+40|0;Mc(c,(k[a|0]|k[a+1|0]<<8)&4?16:8,1,0,0)}function IP(a,b,c,d){a=c-b|0;c=j[d>>2]+p((a|0)/-6|0,6)|0;j[d>>2]=c;if((a|0)>=1){Vb(c,b,a)}}function Dk(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function yH(a){a=a|0;var b=0;b=o[a+4264>>3]*+m[j[a+16>>2]+1074376>>2];o[a+4256>>3]=b-x(b)}function vt(a){var b=0;b=Za-16|0;Za=b;a=DKa(a,b+15|0);Za=b+16|0;return(a?k[b+15|0]:0)&255}function uHa(a,b){var c=0;a=rHa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,771);Za=c+16|0}return a}function pia(a,b,c){if(b){while(1){n[a>>2]=n[c>>2];a=a+4|0;b=b-1|0;if(b){continue}break}}}function pE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;j[a>>2]=d;j[a+4>>2]=b-p(c,d)}function p3(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){Iu(a,c);return}Eb(a,56097)}function gd(a,b){var c=0;c=Za-16|0;Za=c;rj(c+8|0,a+24|0,b);a=kb(c+8|0);Za=c+16|0;return a}function fw(a){a=a|0;var b=0;j[a>>2]=83620;b=j[a+4>>2];if(b){Cb(b);j[a+4>>2]=0}return a|0}function cv(a,b,c,d){var e=0;e=Za-16|0;Za=e;j[e+12>>2]=d;a=xq(a,b,c,d);Za=e+16|0;return a}function cHa(a,b){var c=0;a=$Ga(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,384);Za=c+16|0}return a}function _Ca(a,b,c){if(b){while(1){i[a>>1]=l[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function ZGa(a,b){var c=0;a=sFa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,554);Za=c+16|0}return a}function TW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;bb[a|0](b,c,d,e,f,g)}function Dba(a,b){var c=0;c=Za-16|0;Za=c;j[c+8>>2]=b;Nc(a,j[c+8>>2]);Db(a+12|0);Za=c+16|0}function nHa(a,b){var c=0;a=kHa(a,b);if(!a){c=Za-16|0;Za=c;Ab(b,0,62);Za=c+16|0}return a}function km(a,b,c){b=k7(b,c);c=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=c;j[a+8>>2]=j[b+8>>2]}function ho(a,b){var c=0;c=Za-16|0;Za=c;ah(c+8|0,b);Hia(a,c+8|0);ah(c,b);pb(c);Za=c+16|0}function dd(a){var b=0;b=Za-16|0;Za=b;a=Df(a,b+15|0);Za=b+16|0;return(a?k[b+15|0]:0)&255}function co(a,b,c){b=Y6(b,c);c=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=c;j[a+8>>2]=j[b+8>>2]}function _qa(a,b,c){var d=0;d=Za-16|0;Za=d;if(!st(a,b)){b=st(c,a)?c:a}Za=d+16|0;return b}function _e(a){var b=0;b=Za-16|0;Za=b;a=j[zc(b+8|0,zb(a)+nb(a)|0)>>2];Za=b+16|0;return a}function Zga(a,b){a=a|0;b=b|0;a=Ki(a);if(!a){return 1}return bb[j[j[a>>2]+68>>2]](a,b)|0}function Msa(a,b){Lsa(a,b);Nc(a+12|0,b+12|0);i[a+28>>1]=l[b+28>>1];j[a+24>>2]=j[b+24>>2]}function Bga(a,b,c){a=a|0;b=b|0;c=c|0;vd(a,b);b=j[c+4>>2];j[a+8>>2]=j[c>>2];j[a+12>>2]=b}function vD(a,b){var c=0;c=Za-16|0;Za=c;j[c+12>>2]=b;a=yD(a,62416,b);Za=c+16|0;return a}function tL(a,b){var c=0;b=lb(b);c=a;a=j[a>>2];j[c>>2]=a<<8^j[((b^a>>>24)<<2)+87632>>2]}function sP(a,b,c){a=a|0;b=b|0;c=c|0;a=l[c>>1]|l[c+2>>1]<<16;i[b>>1]=a;i[b+2>>1]=a>>>16}function pMa(a,b,c){if(b){while(1){h[a|0]=k[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}}function iT(a){var b=0,c=0;b=Za-16|0;Za=b;if(Df(a,b+8|0)){c=k[b+8|0]}Za=b+16|0;return c}function hK(a,b){var c=0;c=k[a+872|0];if(c&1){h[a+872|0]=c|8;j[a+876>>2]=j[a+876>>2]+b}}function bj(a){h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;return a}function bh(a,b){var c=0,d=0;j[a>>2]=j[b>>2];c=a,d=j[b>>2]+Xg(b)|0,j[c+4>>2]=d;return a}function Zia(a,b){var c=0;c=Za-16|0;Za=c;j[zc(c+8|0,Wia(a,j[zc(c,b)>>2]))>>2];Za=c+16|0}function MO(a,b){var c=0,d=0;j[a>>2]=j[b>>2];c=a,d=j[b>>2]+GO(b)|0,j[c+4>>2]=d;return a}function Kb(a,b){var c=0,d=0;j[a>>2]=j[b>>2];c=a,d=j[b>>2]+pb(b)|0,j[c+4>>2]=d;return a}function Js(a,b,c){var d=0;j[a>>2]=j[b>>2];d=j[b>>2];j[a+8>>2]=b;j[a+4>>2]=c+d;return a}function Ie(a,b){var c=0;tk(a,b);c=j[b+12>>2];j[a+8>>2]=j[b+8>>2];j[a+12>>2]=c;return a}function Hr(a,b){if(!(j[a+480180>>2]==8?h[b+872|0]&1:0)){Xw(a,b,0);Xw(a,b,1);Xw(a,b,2)}}function Hl(a){var b=0;b=ku(a+4|0);if((b|0)==-1){bb[j[j[a>>2]+8>>2]](a)}return(b|0)==-1}function HU(a){a=a|0;var b=0;b=j[a+4>>2];return(bb[j[j[b>>2]+20>>2]](b)|0)+j[a+12>>2]|0}function Ed(a,b){var c=0;IV(a,b);c=j[b+12>>2];j[a+8>>2]=j[b+8>>2];j[a+12>>2]=c;return a}function zB(a){var b=0;b=a+48|0;while(1){b=gb(b-12|0);if((b|0)!=(a|0)){continue}break}}function yL(a,b){return(a>>>0<=62?63-(p((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function nQ(a){var b=0;b=Za-16|0;Za=b;j[b+12>>2]=-1;a=iGa(a,b+12|0);Za=b+16|0;return a}function dC(a,b,c){a=a|0;b=b|0;c=c|0;if((a|0)==(b|0)){h[a+112|0]=0;return}mv(b,c<<2,4)}function Zd(a){var b=0,c=0,d=0;b=Za-16|0;Za=b;c=j[Gu(b,a)+8>>2],d=0,h[c|0]=d;Za=b+16|0}function XM(a){var b=0;b=44325e5/+(a>>>0);if(b<4294967296&b>=0){return~~b>>>0}return 0}function SMa(a){var b=0,c=0;while(1){c=b;if(a){a=a-1&a;b=b+1|0;continue}break}return c}function RFa(a){var b=0;b=Za-16|0;Za=b;a=Vp(a,b+8|0);Za=b+16|0;return a?n[b+8>>2]:q(0)}function QR(a,b,c){h[a+2|0]=1;b=b&15;if(c){b=k[b+12336|0]}else{b=(b<<2)+4|0}h[a+4|0]=b}function Ne(a){var b=0;b=a+24|0;while(1){b=gb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Mu(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;$X(a,b,uD(b));Za=c+16|0;return a|0}function LJ(a){Qc(a);Qc(a+12|0);Qc(a+24|0);Qc(a+36|0);Qc(a+48|0);j[a+60>>2]=0;return a}function Kl(a){var b=0;b=a+36|0;while(1){b=gb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Eb(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;Wo(a,b,ne(b));Za=c+16|0;return a|0}function vs(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function sG(a,b){a=a|0;b=b|0;var c=0;c=ue(8);jG(c);j[c+4>>2]=b;j[c>>2]=83992;zaa(a,c)}function rua(a){a=a+1|0;if((a&255)>>>0<=5){return j[(a<<24>>24<<2)+18440>>2]}return 0}function jZ(a){a=a|0;a=462280;while(1){a=gb(a-12|0);if((a|0)!=462112){continue}break}}function j5(a,b){a=a|0;b=b|0;a=l[a>>1];b=l[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function fZ(a){a=a|0;a=462456;while(1){a=pc(a-12|0);if((a|0)!=462288){continue}break}}function eha(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=k[b|0];rw(a,d+12|0,c);Za=d+16|0}function e9(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;bT(c+8|0,b);Lt(a,c+8|0);Za=c+16|0}function cZ(a){a=a|0;a=462752;while(1){a=gb(a-12|0);if((a|0)!=462464){continue}break}}function YY(a){a=a|0;a=463096;while(1){a=gb(a-12|0);if((a|0)!=463072){continue}break}}function W4(a,b){a=a|0;b=b|0;a=j[a>>2];b=j[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function VY(a){a=a|0;a=463128;while(1){a=pc(a-12|0);if((a|0)!=463104){continue}break}}function Uza(a,b){var c=0;c=Za-16|0;Za=c;a=SN(vd(c+8|0,a),vd(c,b));Za=c+16|0;return a}function R$(a,b,c){a=a|0;b=b|0;c=c|0;c=ov(j[b>>2])<<24;j[a+4>>2]=j[b>>2];h[a|0]=c>>24}function Ql(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function Haa(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;om(c,a);Gaa(b,c);Ye(c);Za=c+16|0}function $Y(a){a=a|0;a=463056;while(1){a=pc(a-12|0);if((a|0)!=462768){continue}break}}function u_(a,b){var c=0;c=Za-16|0;Za=c;j[c+12>>2]=b;ze(a,c+12|0);Za=c+16|0;return a}function ef(a){a=a|0;var b=0;b=j[a>>2];return(bb[j[j[b>>2]+24>>2]](b)|0)-j[a+8>>2]|0}function ZZ(a,b){a=a|0;b=b|0;if((b|0)>=0){b=j[mq()+((b&255)<<2)>>2]}return b<<24>>24}function Ug(a){h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0;bj(a)}function Qe(a){a=a|0;var b=0;b=Za-16|0;Za=b;a=j[zc(b+8|0,a)>>2];Za=b+16|0;return a|0}function Eda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return AG(a,b,c,d,0,0,0,0,e)|0}function $Z(a,b){a=a|0;b=b|0;if((b|0)>=0){b=j[nq()+((b&255)<<2)>>2]}return b<<24>>24}function z1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return y1(b,c,d,e,f)|0}function x1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return w1(b,c,d,e,f)|0}function v1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return u1(b,c,d,e,f)|0}function tMa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=vn(c+8|0,b,a);Za=c+16|0;return d?b:a}function t1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return s1(b,c,d,e,f)|0}function ska(a,b){a=a|0;b=b|0;if(b>>>0<=42){return k[j[a+84>>2]+b|0]!=63|0}return 0}function r1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return q1(b,c,d,e,f)|0}function p1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return o1(b,c,d,e,f)|0}function m1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return l1(b,c,d,e,f)|0}function k1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return j1(b,c,d,e,f)|0}function jD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return bb[j[j[a>>2]+32>>2]](a,b,c,d)|0}function ima(a,b,c,d){var e=0;e=Za-16|0;Za=e;j[e+8>>2]=d;fma(a,b,c,e+8|0);Za=e+16|0}function iEa(a,b){var c=0;a=XDa(a,b);if(!a){c=Za-16|0;Za=c;wP(b);Za=c+16|0}return a}function hD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return bb[j[j[a>>2]+48>>2]](a,b,c,d)|0}function eJa(a,b){a=a|0;b=b|0;WIa(a,b);h[a+16|0]=6;j[a+12>>2]=2015363072;return a|0}function d2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return c2(b,c,d,e,f)|0}function a2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return $1(b,c,d,e,f)|0}function Ye(a){var b=0;sh(a);b=a;if(j[b>>2]){JF(b);xo(hb(b),j[b>>2],Ce(b))}return a}function Y1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return X1(b,c,d,e,f)|0}function V1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return U1(b,c,d,e,f)|0}function T1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return S1(b,c,d,e,f)|0}function R1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return Q1(b,c,d,e,f)|0}function O1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return N1(b,c,d,e,f)|0}function NW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=bb[a|0](b,c,d)|0;ea(ab|0);return a|0}function L1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return K1(b,c,d,e,f)|0}function I1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return G1(b,c,d,e,f)|0}function HAa(a){var b=0;b=Za-16|0;Za=b;a=cu(a,b+8|0);Za=b+16|0;return a?o[b+8>>3]:0}function Gl(a,b){j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];j[b>>2]=0;j[b+4>>2]=0;return a}function GV(a,b){var c=0;c=Za-16|0;Za=c;FV(c+8|0,b);Gl(a,c+8|0);jb(c+8|0);Za=c+16|0}function FLa(a){a=a|0;var b=0;b=Za-16|0;Za=b;tS(b+8|0,a);Za=b+16|0;return j[b+8>>2]}function BY(a,b){if(!(k[a+112|0]|b>>>0>28)){h[a+112|0]=1;return a}return $b(b<<2,4)}function BV(a,b){var c=0;c=Za-16|0;Za=c;j[c+8>>2]=b;fB(a,bh(c,j[c+8>>2]));Za=c+16|0}function B1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return A1(b,c,d,e,f)|0}function vx(a,b){var c=0;h[a|0]=k[b|0];c=j[b+8>>2];j[a+4>>2]=j[b+4>>2];j[a+8>>2]=c}function oha(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+(c<<11);return a}function mk(a,b){a=a|0;b=b|0;if(bc(a)>>>0<=b>>>0){PB();z()}return j[a>>2]+(b<<1)|0}function cy(a){if(j[a>>2]){ee(a,j[a>>2]);jxa(j[a>>2],(j[hb(a)>>2]-j[a>>2]|0)/9|0)}}function cP(a){var b=0;b=Za-16|0;Za=b;a=j[zc(b+8|0,j[a>>2])>>2];Za=b+16|0;return a}function cEa(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+p(c,33);return a}function bba(a){var b=0;b=Za-16|0;Za=b;j[b+12>>2]=38235;Eb(a,j[b+12>>2]);Za=b+16|0}function YT(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=vn(c+8|0,a,b);Za=c+16|0;return d?b:a}function RE(a,b){b=j[a+32>>2]+b|0;j[a+32>>2]=b;if(b>>>0>=m[a+40>>2]){j[a+96>>2]=1}}function LBa(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+p(c,20);return a}function JBa(a){var b=0,c=0;b=Za-16|0;Za=b;c=a;a=zh(b);QO(c,a,0,0);jb(a);Za=b+16|0}function GK(a,b){var c=0;c=b&15;if(c){h[a+850|0]=c}b=b&240;if(b){h[a+849|0]=b>>>4}}function Dja(a,b,c){if(b){while(1){uI(a,c);a=a+52|0;b=b-1|0;if(b){continue}break}}}function Cja(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+p(c,52);return a}function BI(a,b){a=a|0;b=b|0;if(b>>>0<=15){return k[j[a+88>>2]+b|0]!=63|0}return 0}function $g(a){var b=0,c=0;b=Za-16|0;Za=b;c=b+8|0;gB(c,a);Za=b+16|0;return j[c>>2]}function rka(a,b){var c=0;c=Za-16|0;Za=c;j[c+12>>2]=k[b|0];Hw(a,c+12|0);Za=c+16|0}function nza(a,b){a=a|0;b=b|0;if(j[a+4>>2]!=j[hb(a)>>2]){gza(a,b);return}fza(a,b)}function mpa(a,b){a=a|0;b=b|0;if(j[a+4>>2]!=j[hb(a)>>2]){$oa(a,b);return}_oa(a,b)}function kxa(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+p(c,9);return a}function jB(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){a=Rb(a);Ef(j[a>>2],b,j[a+4>>2])}}function hk(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+p(c,24);return a}function hga(a,b){a=a|0;b=b|0;if(j[a+4>>2]!=j[hb(a)>>2]){fga(a,b);return}ega(a,b)}function by(a,b){a=Vb(a,b,34);i[a+34>>1]=l[b+34>>1];Vb(a+36|0,b+36|0,68);return a}function au(a,b){var c=0;j[a>>2]=j[b>>2];c=a;a=j[b+4>>2];j[c+4>>2]=a;if(a){Il(a)}}function ama(a,b){a=a|0;b=b|0;if(j[a+4>>2]!=j[hb(a)>>2]){_la(a,b);return}Zla(a,b)}function _A(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){a=Rb(a);zi(j[a>>2],b,j[a+4>>2])}}function VFa(a,b){a=a|0;b=b|0;if(j[a+4>>2]!=j[hb(a)>>2]){IFa(a,b);return}HFa(a,b)}function Un(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+p(c,12);return a}function UHa(a,b){a=a|0;b=b|0;if(j[a+4>>2]!=j[hb(a)>>2]){FHa(a,b);return}EHa(a,b)}function Txa(a,b){a=a|0;b=b|0;if(j[a+4>>2]!=j[hb(a)>>2]){Ixa(a,b);return}Hxa(a,b)}function QA(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){a=Rb(a);Zg(j[a>>2],b,j[a+4>>2])}}function OF(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){a=Rb(a);jy(j[a>>2],b,j[a+4>>2])}}function Iia(a,b){a=a|0;b=b|0;if(j[a+4>>2]!=j[hb(a)>>2]){Gia(a,b);return}Fia(a,b)}function Cz(a,b,c){a=a|0;b=b|0;c=c|0;a=k[c|0]|k[c+1|0]<<8;h[b|0]=a;h[b+1|0]=a>>>8}function CG(a,b){var c=0;c=j[a>>2];j[a>>2]=b;if(c){if(c){bb[j[j[c>>2]+4>>2]](c)}}}function $Q(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+p(c,48);return a}function yn(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+(c<<5);return a}function yh(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+(c<<1);return a}function rEa(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){QDa(a,b);return}PDa(a,b)}function oR(a,b){a=a|0;b=b|0;if(j[a+4>>2]!=j[hb(a)>>2]){_Ia(a,b);return}ZIa(a,b)}function np(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+p(c,6);return a}function nd(a){var b=0;b=Za-16|0;Za=b;a=j[zc(b+8|0,zb(a))>>2];Za=b+16|0;return a}function ki(a){var b=0;b=Za-16|0;Za=b;a=j[zc(b+8|0,_i(a))>>2];Za=b+16|0;return a}function jza(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){Tya(a,b);return}Sya(a,b)}function hta(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){gta(a,b);return}fta(a,b)}function dS(a,b){a=a|0;b=b|0;if(j[a+4>>2]!=j[hb(a)>>2]){RKa(a,b);return}QKa(a,b)}function _i(a){var b=0;b=Za-16|0;Za=b;a=j[zc(b+8|0,Rb(a))>>2];Za=b+16|0;return a}function _d(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+(c<<2);return a}function XHa(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){PHa(a,b);return}OHa(a,b)}function Wm(a){var b=0;b=Za-16|0;Za=b;a=j[zc(b+8|0,cP(a))>>2];Za=b+16|0;return a}function Vaa(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){Uaa(a,b);return}Taa(a,b)}function Up(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+(c<<3);return a}function Twa(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){Kwa(a,b);return}Jwa(a,b)}function RBa(a,b){var c=0;c=Za-16|0;Za=c;jq(a,j[b>>2],j[b>>2]+GO(b)|0);Za=c+16|0}function Nl(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+(c<<4);return a}function Lka(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){Dka(a,b);return}Cka(a,b)}function Laa(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){Jaa(a,b);return}Iaa(a,b)}function Hia(a,b){var c=0;c=Za-16|0;Za=c;WH(c+8|0,Kb(c,b));GR(a,c+8|0);Za=c+16|0}function Dia(a,b){var c=0;c=Za-16|0;Za=c;jq(a,j[b>>2],j[b>>2]+pb(b)|0);Za=c+16|0}function Ana(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){una(a,b);return}tna(a,b)}function $Ja(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){NJa(a,b);return}MJa(a,b)}function sIa(a){var b=0;b=Za-16|0;Za=b;h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;Za=b+16|0}function rO(a,b){var c=0;jBa(a,b);c=j[b+12>>2];j[a+8>>2]=j[b+8>>2];j[a+12>>2]=c}function lV(a){var b=0;b=Za-16|0;Za=b;kV(b+8|0);Gl(a,b+8|0);jb(b+8|0);Za=b+16|0}function h2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Za-16|0;Za=b;lD(a,c,d);Za=b+16|0}function ay(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){Ova(a,b);return}Dva(a,b)}function XK(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){Qqa(a,b);return}Pqa(a,b)}function UX(a,b){var c=0;c=Za-16|0;Za=c;jq(a,j[b>>2],j[b>>2]+Xg(b)|0);Za=c+16|0}function RH(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){Zha(a,b);return}Yha(a,b)}function OR(a,b){a=a|0;b=b|0;return j[b+8>>2]==j[a+8>>2]&j[a+12>>2]==j[b+12>>2]}function MW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;bb[a|0](b,c,d,e,f)}function JV(a,b){var c=0;c=Za-16|0;Za=c;jq(a,j[b>>2],j[b>>2]+OA(b)|0);Za=c+16|0}function vU(a,b){a=a|0;b=b|0;if(j[a+4>>2]!=j[hb(a)>>2]){qU(a,b);return}pU(a,b)}function tE(a,b,c){var d=0;d=Za-16|0;Za=d;j[d+12>>2]=c;xE(a,b,c,0,0);Za=d+16|0}function ms(a,b){return Yj(Bg((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function m6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return eF(a-88|0,b,c,d,e)|0}function jpa(a){var b=0;if(!(k[a+2|0]|(k[a|0]|k[a+1|0]))){b=!k[a+3|0]}return b}function jBa(a,b){var c=0;c=Za-16|0;Za=c;b=tk(c+8|0,b);kB(b,a);jb(b);Za=c+16|0}function Toa(a,b){var c=0;c=Za-16|0;Za=c;a=toa(Sr(a),Sr(b));Za=c+16|0;return a}function PW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return bb[a|0](b,c,d,e)|0}function MX(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Eb(a,70561);return}Iu(a,c)}function MU(a,b,c,d){up(a);j[a>>2]=77360;tk(a+4|0,b);j[a+16>>2]=d;j[a+12>>2]=c}function Kea(a,b){a=a|0;b=b|0;return q((b|0)<=12?n[((b<<2)+a|0)+4208>>2]:q(0))}function KX(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Eb(a,70639);return}Iu(a,c)}function Cl(a,b){var c=0;Gl(a,b);c=j[b+12>>2];j[a+8>>2]=j[b+8>>2];j[a+12>>2]=c}function Axa(a,b){a=a|0;b=b|0;Lh(b);if(j[b>>2]){VM(b);fh(hb(b),j[b>>2],Hf(b))}}function As(a){h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0;h[a+4|0]=0;h[a+5|0]=0}function zfa(a,b){a=a|0;b=b|0;return q((b|0)<=4?n[((b<<2)+a|0)+4208>>2]:q(0))}function zea(a,b){a=a|0;b=b|0;return q((b|0)<=2?n[((b<<2)+a|0)+4208>>2]:q(0))}function yMa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=_z(b,a);Za=c+16|0;return d?b:a}function yCa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=RO(a,b);Za=c+16|0;return d?b:a}function tk(a,b){j[a>>2]=j[b>>2];b=j[b+4>>2];j[a+4>>2]=b;if(b){Il(b)}return a}function t7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cr(b,c,d,n[a+24>>2]);zF(a,b,c,d)}function sea(a,b){a=a|0;b=b|0;return q((b|0)<=3?n[((b<<2)+a|0)+4208>>2]:q(0))}function sX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Rf(a,j[b+8>>2],0)){Cu(b,c,d)}}function sU(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){oU(a,b);return}nU(a,b)}function rfa(a,b){a=a|0;b=b|0;return q((b|0)<=4?n[((b<<2)+a|0)+4220>>2]:q(0))}function pna(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946300|0:20525)|0}function pCa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=RO(b,a);Za=c+16|0;return d?b:a}function eY(a,b){var c=0;c=nb(a);if(c>>>0<b>>>0){ws(a,b-c|0,0);return}dY(a,b)}function d7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cr(b,c,d,n[a+24>>2]);xF(a,b,c,d)}function Zma(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=_z(a,b);Za=c+16|0;return d?b:a}function Zfa(a,b){a=a|0;b=b|0;return q((b|0)<=6?n[((b<<2)+a|0)+4208>>2]:q(0))}function Yea(a,b){a=a|0;b=b|0;return q((b|0)<=1?n[((b<<2)+a|0)+4208>>2]:q(0))}function V7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cr(b,c,d,n[a+28>>2]);FF(a,b,c,d)}function Uya(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=DS(a,b);Za=c+16|0;return d?b:a}function U4(a,b){a=a|0;b=b|0;if(m[a+4>>2]<m[hb(a)>>2]){u4(a,b);return}l4(a,b)}function Rna(a){var b=0;b=Za-16|0;Za=b;a=j[oJ(b+8|0,a)>>2];Za=b+16|0;return a}function PKa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=st(b,a);Za=c+16|0;return d?b:a}function Nh(a,b,c){if(j[a+80>>2]){j[a+92>>2]=j[a+92>>2]+(c+7&-8);return}Cb(b)}function Lfa(a,b){a=a|0;b=b|0;return q((b|0)<=5?n[((b<<2)+a|0)+4208>>2]:q(0))}function LKa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=st(a,b);Za=c+16|0;return d?b:a}function IV(a,b){var c=0;c=Za-16|0;Za=c;b=Gl(c+8|0,b);kB(b,a);jb(b);Za=c+16|0}function Hfa(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=mH(b,a);Za=c+16|0;return d?b:a}function G7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cr(b,c,d,n[a+28>>2]);CF(a,b,c,d)}function Dga(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=mH(a,b);Za=c+16|0;return d?b:a}function yi(a,b){a=a|0;b=b|0;if((a|0)!=(b|0)){a=UN(a,zb(b),nb(b))}return a|0}function uh(a,b,c,d){a=c-b|0;c=j[d>>2]-a|0;j[d>>2]=c;if((a|0)>=1){Vb(c,b,a)}}function my(a){a=a+4|0;return k[a|0]|k[a+1|0]<<8|(k[a+2|0]<<16|k[a+3|0]<<24)}function ll(a){var b=0;b=Za-16|0;Za=b;j[b+8>>2]=a;Za=b+16|0;return j[b+8>>2]}function kn(a,b,c,d){a=c-b|0;if((a|0)>=1){Vb(j[d>>2],b,a);j[d>>2]=j[d>>2]+a}}function hG(a,b,c,d){j[a+12>>2]=0;j[a+8>>2]=d;j[a+4>>2]=c;j[a>>2]=b;return a}function gV(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=rd(b,a);Za=c+16|0;return d?b:a}function cd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=j[b+8>>2];Jb(b,c);mu(a,b,d,c)}function Z1(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=bC(b,a);Za=c+16|0;return d?b:a}function WK(a){var b=0;b=Za-16|0;Za=b;gB(b+8|0,a);Za=b+16|0;return j[b+8>>2]}function TC(a,b){var c=0,d=0;fe(a,ud(b));b=j[Rb(b)>>2];c=Rb(a),d=b,j[c>>2]=d}function SB(){a:{if(h[463728]&1){break a}if(!fd(463728)){break a}ed(463728)}}function ET(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=bC(a,b);Za=c+16|0;return d?b:a}function $V(a,b){var c=0,d=0;c=Za-16|0;Za=c;d=rd(a,b);Za=c+16|0;return d?b:a}function zI(a,b){a=a|0;b=b|0;return(b>>>0<=42?h[j[a+84>>2]+b|0]:63)<<24>>24}function yq(a,b,c,d,e,f,g,h){return bb[j[j[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function tB(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;fi(a,c+8|0,b);Za=c+16|0}function rl(a,b,c){j[a>>2]=b;b=j[b+4>>2];j[a+4>>2]=b;j[a+8>>2]=b+c;return a}function qW(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;Ll(a,c+8|0,b);Za=c+16|0}function RR(a,b){a=a|0;b=b|0;a=j[a>>2];return bb[j[j[a>>2]+36>>2]](a,0,b)|0}function RF(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){a=Rb(a);a;PF(b,j[a+4>>2])}}function OM(a){if((k[a+14|0]-49&255)>>>0<=3){return!Yc(a,17504,14)}return 0}function LM(a,b){pN(a,b);h[a+16|0]=k[b+16|0];j[a+12>>2]=j[b+12>>2];return a}function LD(a,b,c,d,e,f,g,h){return bb[j[j[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function Jn(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;UX(a,bh(c,b));Za=c+16|0}function AI(a,b){a=a|0;b=b|0;return(b>>>0<=15?h[j[a+88>>2]+b|0]:63)<<24>>24}function tm(a,b){a=j[a+4276>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function tg(a,b){a=a|0;b=b|0;if(xp(a,b)){a=th(te(a,b))}else{a=0}return a|0}function sg(a,b,c){j[a+8>>2]=b;j[a+12>>2]=c;j[a>>2]=0;j[a+4>>2]=0;return a}function mGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=QEa(a,b),j[d>>2]=e}function jGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=PEa(a,b),i[d>>1]=e}function h_(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=j[nq()+(b<<2)>>2]}return b|0}function f_(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=j[mq()+(b<<2)>>2]}return b|0}function csa(a){var b=0;b=Za-288|0;Za=b;a=msa(a,wL(b));Za=b+288|0;return a}function cg(a,b){var c=0;c=a;a=j[a+8>>2];b=a-b|0;j[c+8>>2]=a>>>0<b>>>0?0:b}function YK(a,b,c){var d=0;d=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=d;FM(a,c)}function Vla(a){var b=0;b=Za-16|0;Za=b;Tla(a,b+8|0);Za=b+16|0;return a}



function Gu(a,b){j[a+12>>2]=0;j[a+4>>2]=b;j[a>>2]=b;j[a+8>>2]=b+1;return a}function zl(a,b,c){a=a|0;b=b|0;c=c|0;return bb[j[j[a>>2]+48>>2]](a,b,c)|0}function zj(a,b,c){a=a|0;b=b|0;c=c|0;return bb[j[j[a>>2]+12>>2]](a,b,c)|0}function zO(a,b){h[a+6|0]=255;j[a+16>>2]=b;i[a+4>>1]=0;j[a>>2]=0;return a}function yr(a){fha(a,j[a+4>>2]);if(j[a>>2]){ye(j[a+16>>2],j[a>>2],_f(a))}}function xR(a){GJa(a,j[a+4>>2]);if(j[a>>2]){Ef(j[a+16>>2],j[a>>2],ol(a))}}function um(a){Aia(a,j[a+4>>2]);if(j[a>>2]){ye(j[a+16>>2],j[a>>2],_f(a))}}function tN(a){Qya(a,j[a+4>>2]);if(j[a>>2]){Ef(j[a+16>>2],j[a>>2],ol(a))}}function ss(a){nxa(a,j[a+4>>2]);if(j[a>>2]){fh(j[a+16>>2],j[a>>2],Bq(a))}}function sr(a){bga(a,j[a+4>>2]);if(j[a>>2]){ye(j[a+16>>2],j[a>>2],_f(a))}}function rt(a){yJa(a,j[a+4>>2]);if(j[a>>2]){ln(j[a+16>>2],j[a>>2],tn(a))}}function qS(a){wLa(a,j[a+4>>2]);if(j[a>>2]){ln(j[a+16>>2],j[a>>2],tn(a))}}function qP(a){IDa(a,j[a+4>>2]);if(j[a>>2]){Ef(j[a+16>>2],j[a>>2],ol(a))}}function nA(a,b){var c=0;c=Za-16|0;Za=c;mA(c+8|0,b);Lt(a,c+8|0);Za=c+16|0}function mJ(a){Cma(a,j[a+4>>2]);if(j[a>>2]){ye(j[a+16>>2],j[a>>2],_f(a))}}function lk(a){rMa(a,j[a+4>>2]);if(j[a>>2]){un(j[a+16>>2],j[a>>2],tn(a))}}function hs(a){Jsa(a,j[a+4>>2]);if(j[a>>2]){Zg(j[a+16>>2],j[a>>2],gu(a))}}function cka(a,b,c){a=a|0;b=b|0;c=c|0;if(nb(b)>>>0>c>>>0){qm(b,c)}Nc(a,b)}function ZO(a){PCa(a,j[a+4>>2]);if(j[a>>2]){Zi(j[a+16>>2],j[a>>2],_f(a))}}function ZK(a){bra(a,j[a+4>>2]);if(j[a>>2]){fh(j[a+16>>2],j[a>>2],Bq(a))}}function WQ(a){uIa(a,j[a+4>>2]);if(j[a>>2]){Ef(j[a+16>>2],j[a>>2],ol(a))}}function UO(a){GCa(a,j[a+4>>2]);if(j[a>>2]){ln(j[a+16>>2],j[a>>2],tn(a))}}function UJ(a){noa(a,j[a+4>>2]);if(j[a>>2]){Es(j[a+16>>2],j[a>>2],gu(a))}}function Sj(a,b){var c=0;c=j[b+4>>2];j[a>>2]=j[b>>2];j[a+4>>2]=c;return a}function RP(a){hFa(a,j[a+4>>2]);if(j[a>>2]){Zi(j[a+16>>2],j[a>>2],_f(a))}}function RI(a){Pla(a,j[a+4>>2]);if(j[a>>2]){ye(j[a+16>>2],j[a>>2],_f(a))}}function Qj(a){pqa(a,j[a+4>>2]);if(j[a>>2]){ye(j[a+16>>2],j[a>>2],_f(a))}}function QM(a){pxa(a,j[a+4>>2]);if(j[a>>2]){fh(j[a+16>>2],j[a>>2],Bq(a))}}function PQ(a){LHa(a,j[a+4>>2]);if(j[a>>2]){Ef(j[a+16>>2],j[a>>2],ol(a))}}function PH(a){Uha(a,j[a+4>>2]);if(j[a>>2]){ye(j[a+16>>2],j[a>>2],_f(a))}}function Mna(a){af(a);if(j[a>>2]){Lma(a,j[a>>2]);ye(hb(a),j[a>>2],jd(a))}}function Mc(a,b,c,d,e){h[a+3|0]=e;h[a+2|0]=d;h[a+1|0]=c;h[a|0]=b;return a}function LW(a,b,c){a=a|0;b=b|0;c=c|0;a=bb[a|0](b,c)|0;ea(ab|0);return a|0}function J3(a,b,c){a=a|0;b=b|0;c=c|0;return bb[j[j[a>>2]+32>>2]](a,b,c)|0}function Gga(a,b){a=a|0;b=b|0;a=j[a+20>>2]+24|0;h[a|0]=k[a|0]&253|(b?2:0)}function Et(a){fLa(a,j[a+4>>2]);if(j[a>>2]){Yf(j[a+16>>2],j[a>>2],Tz(a))}}function EN(a){Bza(a,j[a+4>>2]);if(j[a>>2]){Zi(j[a+16>>2],j[a>>2],_f(a))}}function EI(a){Aka(a,j[a+4>>2]);if(j[a>>2]){Ef(j[a+16>>2],j[a>>2],ol(a))}}function DT(a,b){var c=0;c=Za-16|0;Za=c;Nt(c+8|0,b);Lt(a,c+8|0);Za=c+16|0}function DM(a){zwa(a,j[a+4>>2]);if(j[a>>2]){Zi(j[a+16>>2],j[a>>2],_f(a))}}function $s(a){zHa(a,j[a+4>>2]);if(j[a>>2]){zi(j[a+16>>2],j[a>>2],wu(a))}}function xh(a){qT(a,j[a+4>>2]);if(j[a>>2]){It(j[a+16>>2],j[a>>2],_f(a))}}function uA(a){JT(a,j[a+4>>2]);if(j[a>>2]){un(j[a+16>>2],j[a>>2],tn(a))}}function qCa(a){a=a|0;u3(a,rH(j[j[a>>2]-12>>2]+a|0,10));Jq(a);return a|0}function pz(a){sh(a);if(j[a>>2]){SHa(a,j[a>>2]);Ef(hb(a),j[a>>2],Ce(a))}}function ow(a){af(a);if(j[a>>2]){aga(a,j[a>>2]);ye(hb(a),j[a>>2],jd(a))}}function nR(a){sh(a);if(j[a>>2]){FIa(a,j[a>>2]);Ef(hb(a),j[a>>2],Ce(a))}}function mQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=eQ(a,b),j[d>>2]=e}function kGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=eQ(a,b),h[d|0]=e}function iE(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;sg(a,-1,-1)}function hl(a){Dl(a);if(j[a>>2]){cBa(a,j[a>>2]);Es(hb(a),j[a>>2],_g(a))}}function cC(a){uY(a,j[a+4>>2]);if(j[a>>2]){fC(j[a+16>>2],j[a>>2],_f(a))}}function bW(a){var b=0;b=Za-16|0;Za=b;j[b+8>>2]=53;iW(a,b+8|0);Za=b+16|0}function bE(a,b){b=!j[a+24>>2]|b;j[a+16>>2]=b;if(b&j[a+20>>2]){k3();z()}}function Xp(a){bV(a,j[a+4>>2]);if(j[a>>2]){Zg(j[a+16>>2],j[a>>2],gu(a))}}function Uy(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,j[b>>2],sb(b)<<2);Za=c+16|0}function Ul(a){YW(a,j[a+4>>2]);if(j[a>>2]){Yf(j[a+16>>2],j[a>>2],Tz(a))}}function Tw(a){af(a);if(j[a>>2]){Rla(a,j[a>>2]);ye(hb(a),j[a>>2],jd(a))}}function Rp(a){iU(a,j[a+4>>2]);if(j[a>>2]){ye(j[a+16>>2],j[a>>2],_f(a))}}function Qy(a){sh(a);if(j[a>>2]){SDa(a,j[a>>2]);Ef(hb(a),j[a>>2],Ce(a))}}function KF(a){e8(a,j[a+4>>2]);if(j[a>>2]){zi(j[a+16>>2],j[a>>2],wu(a))}}function Jp(a){LT(a,j[a+4>>2]);if(j[a>>2]){Yf(j[a+16>>2],j[a>>2],Tz(a))}}function IF(a){_7(a,j[a+4>>2]);if(j[a>>2]){xo(j[a+16>>2],j[a>>2],ol(a))}}function Gz(a){sh(a);if(j[a>>2]){OJa(a,j[a>>2]);Ef(hb(a),j[a>>2],Ce(a))}}function Gq(a){K2(a,j[a+4>>2]);if(j[a>>2]){fh(j[a+16>>2],j[a>>2],Bq(a))}}function GB(a){EW(a,j[a+4>>2]);if(j[a>>2]){zi(j[a+16>>2],j[a>>2],wu(a))}}function DS(a,b){return(k[a|0]|k[a+1|0]<<8)>>>0<(k[b|0]|k[b+1|0]<<8)>>>0}function AN(a){wN(a);if(j[a>>2]){Pya(a,j[a>>2]);jy(hb(a),j[a>>2],Tm(a))}}function AJ(a){af(a);if(j[a>>2]){Ema(a,j[a>>2]);ye(hb(a),j[a>>2],jd(a))}}function zL(a){if(a>>>0<=8){return k[a+20096|0]}return k[a+20087|0]|256}function wZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return vZ(c,d,e)|0}function ng(a,b,c){return(c|0)>=0?(l[j[a+8>>2]+((c&255)<<1)>>1]&b)!=0:0}function nF(a){a=a|0;return+(+m[j[a+32>>2]+480240>>2]*152587890625e-16)}function li(a){af(a);if(j[a>>2]){SP(a,j[a>>2]);Zi(hb(a),j[a>>2],jd(a))}}function jx(a,b){a=a|0;b=b|0;j[a+1074368>>2]=b;YI(a+1074328|0,b);Jna(a)}function jk(a){wl(a);if(j[a>>2]){rS(a,j[a>>2]);ln(hb(a),j[a>>2],Pf(a))}}function hP(a){wl(a);if(j[a>>2]){VO(a,j[a>>2]);ln(hb(a),j[a>>2],Pf(a))}}function fO(a){Zp(a);if(j[a>>2]){_N(a,j[a>>2]);du(hb(a),j[a>>2],wi(a))}}function dP(a){af(a);if(j[a>>2]){_O(a,j[a>>2]);Zi(hb(a),j[a>>2],jd(a))}}function aw(a,b){a=a|0;b=b|0;bb[b|0](j[j[a>>2]-12>>2]+a|0)|0;return a|0}function Zb(a,b){var c=0,d=0;j[a>>2]=b;c=a,d=ne(b),j[c+4>>2]=d;return a}function Xm(a){CP(a);if(j[a>>2]){zP(a,j[a>>2]);yP(hb(a),j[a>>2],jl(a))}}function Woa(a,b,c){a=a|0;b=b|0;c=c|0;Roa(a,b);j[a+112>>2]=0;return a|0}function WM(a){Lh(a);if(j[a>>2]){RM(a,j[a>>2]);fh(hb(a),j[a>>2],Hf(a))}}function Qu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;j[e>>2]=c;return 3}function Ok(a){Lh(a);if(j[a>>2]){z2(a,j[a>>2]);fh(hb(a),j[a>>2],Hf(a))}}function JA(a){af(a);if(j[a>>2]){jU(a,j[a>>2]);ye(hb(a),j[a>>2],jd(a))}}function IL(a,b){j[a+4>>2]=0;j[a+8>>2]=0;j[a>>2]=b?b:49716;j[a+12>>2]=0}function IC(a){i[a+12>>1]=0;j[a+8>>2]=-1;j[a>>2]=0;j[a+4>>2]=0;return a}function EO(a){j[a+8>>2]=0;j[a>>2]=0;j[a+4>>2]=40;i[a+12>>1]=0;return a}function DZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return CZ(c,d,e)|0}function CA(a){wl(a);if(j[a>>2]){PT(a,j[a>>2]);un(hb(a),j[a>>2],Pf(a))}}function Bv(a){return((pg(a)+(pg(a)<<8)|0)+(pg(a)<<16)|0)+(pg(a)<<24)|0}function Ac(a){if((a|0)>=-32768){return(a|0)>32767?32767:a}return-32768}function zx(a,b,c){a:{if(a<b){break a}b=c;if(b<a){break a}b=a}return b}function s0(a,b,c,d,e){b=Fh(b,c,d,e,4);if(!(k[d|0]&4)){j[a>>2]=b-1900}}function qj(a,b){a=a|0;b=b|0;h[a|0]=2;h[a+1|0]=3;h[a+2|0]=0;h[a+3|0]=4}function qDa(a){var b=0;b=Za-16|0;Za=b;dDa(a,b+8|0);Za=b+16|0;return a}function lja(a){var b=0;b=Za-16|0;Za=b;jja(a,b+8|0);Za=b+16|0;return a}function jc(a,b){if(sb(a)>>>0<=b>>>0){PB();z()}return j[a>>2]+(b<<2)|0}function gpa(a){var b=0;b=Za-16|0;Za=b;Voa(a,b+8|0);Za=b+16|0;return a}function gD(a,b,c){var d=0;d=Za-16|0;Za=d;VX(a,b,c);Za=d+16|0;return a}function fd(a){var b=0;b=Za-16|0;Za=b;a=FX(Gu(b,a));Za=b+16|0;return a}function apa(a){var b=0;b=Za-16|0;Za=b;Boa(a,b+8|0);Za=b+16|0;return a}function _$(a,b,c,d,e){b=Eh(b,c,d,e,4);if(!(k[d|0]&4)){j[a>>2]=b-1900}}function Z3(a){a=a|0;j[a+16>>2]=j[a+16>>2]|1;if(h[a+20|0]&1){pa();z()}}function Xta(a){var b=0;b=Za-16|0;Za=b;Uta(a,b+8|0);Za=b+16|0;return a}function Pw(a,b){o[a>>3]=o[b>>3]+o[a>>3];o[a+8>>3]=o[b+8>>3]+o[a+8>>3]}function M8(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;rka(a,b);Za=c+16|0}function LA(a){j[a>>2]=0;j[a+4>>2]=0;j[a+8>>2]=0;j[a+12>>2]=0;return a}function K8(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;ria(a,b);Za=c+16|0}function I8(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;_ha(a,b);Za=c+16|0}function HGa(a){up(a);j[a>>2]=76504;ri(a+4|0);h[a+20|0]=0;j[a+16>>2]=0}function Gm(a,b,c){a:{if(a<b){break a}b=c;if(b<a){break a}b=a}return b}function GR(a,b){Aj(a,lb(j[b>>2]),pb(b));a=j[a+4>>2];ab=a>>31;return a}function FJ(a,b){var c=0;c=j[a>>2];j[a>>2]=b;if(c){if(c){bf(c);Cb(c)}}}function Au(a,b,c){if(!(j[a+28>>2]==1|j[a+4>>2]!=(b|0))){j[a+28>>2]=c}}function $Fa(a){var b=0;b=Za-16|0;Za=b;NFa(a,b+8|0);Za=b+16|0;return a}function tu(a){a:{if(m[a+4>>2]<m[hb(a)>>2]){SV(a);break a}RV(a)}yg(a)}function rra(a,b){if(j[a+4>>2]!=j[hb(a)>>2]){lra(a,b);return}kra(a,b)}function qG(a,b){var c=0;c=j[a>>2];j[a>>2]=b;if(c){if(c){Cb(Ona(c))}}}function ir(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;eO(a,b);Za=c+16|0}function hX(a){a=a|0;if(!a){return 0}return(Du(a,71928,72072)|0)!=0|0}function hW(a,b){a=a|0;b=b|0;var c=0;c=Za-16|0;Za=c;AB(a,b);Za=c+16|0}function ei(a,b){return(j[a+4>>2]-j[b+4>>2]|0)+(j[a>>2]-j[b>>2]<<3)|0}function dQ(a,b){var c=0;c=j[a>>2];j[a>>2]=b;if(c){if(c){Cb(wFa(c))}}}function bs(a){var b=0;b=Za-16|0;Za=b;Rqa(a,b+8|0);Za=b+16|0;return a}function Sja(a,b,c){b=b-a|0;if(b){Bi(c,a,b)}return p((b|0)/6|0,6)+c|0}function SFa(a,b){if(!REa(a,b)){a=Za-16|0;Za=a;Ab(b,0,128);Za=a+16|0}}function RK(a){if(a>>>0>357913941){oc(20272);z()}return $b(p(a,12),4)}function QJa(a,b){if(!PJa(a,b)){a=Za-16|0;Za=a;Ab(b,0,136);Za=a+16|0}}function OB(a){return(j[a>>2]&-256)==1126902528&j[a+4>>2]==1129074247}function KDa(a,b){j[a>>2]=j[b>>2];i[a+4>>1]=l[b+4>>1];Cl(a+8|0,b+8|0)}function GJ(a,b){var c=0;c=j[a>>2];j[a>>2]=b;if(c){if(c){Cb(dga(c))}}}function Fna(a,b){var c=0;c=Za-16|0;Za=c;Hma(a,bh(c+8|0,b));Za=c+16|0}function w4(a,b){a=a|0;b=b|0;if(!j[114626]){j[114627]=b;j[114626]=a}}function rla(a,b){var c=0;c=Za-16|0;Za=c;qt(c,1,b);qc(a,c);Za=c+16|0}function oy(a,b){Hb(a,b);Hb(a+4|0,b+4|0);Hb(hb(a),hb(b));hb(a);hb(b)}function o_(a){a=a|0;var b=0;b=j[115465]+1|0;j[115465]=b;j[a+4>>2]=b}function nB(a,b){var c=0;c=j[a>>2];j[a>>2]=b;if(c){if(c){Cb(UA(c))}}}function joa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;hoa(b,j[d>>2])}function hI(a){if(a>>>0>82595524){oc(32335);z()}return $b(p(a,52),4)}function coa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;boa(b,j[d>>2])}function XA(a,b){if(b>>>0>134217727){oc(11120);z()}return $b(b<<5,4)}function Rx(a,b){mn(a);Qc(a+12|0);i[a+28>>1]=0;j[a+24>>2]=b;return a}function OW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return bb[a|0](b,c,d)|0}function MP(a){if(a>>>0>715827882){oc(14480);z()}return $b(p(a,6),1)}function LF(a,b,c){a=a|0;b=b|0;c=c|0;j[b>>2]=j[c>>2];Nc(b+4|0,c+4|0)}function Hn(a,b,c,d,e){b=za(a|0,b|0,c|0,d|0,e|0)|0;ab=C()|0;return b}function Hma(a,b){var c=0;c=Za-16|0;Za=c;fB(a,bh(c+8|0,b));Za=c+16|0}function Fk(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function Eba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;Dba(b,j[d>>2])}function BCa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ACa(b,j[d>>2])}function wFa(a){$P(a+52|0);gb(a+40|0);xf(a+16|0);xf(a+4|0);return a}function lu(a,b){var c=0;c=Za-16|0;Za=c;GV(a,bh(c+8|0,b));Za=c+16|0}function lBa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return kBa(a,b,c,d)|0}function kd(a,b,c){if(a>>>0>=b>>>0){return a>>>0>c>>>0?c:a}return b}function jL(a){if(j[a>>2]){Ara(a,j[a>>2]);hb(a);zra(j[a>>2],Ah(a))}}function iA(a){if(a>>>0>1073741823){oc(11804);z()}return $b(a<<2,2)}function hV(a,b,c){a=a|0;b=b|0;c=c|0;up(a);j[a>>2]=77256;return a|0}function bQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;AFa(b,j[d>>2])}function bCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return TBa(a,b,c,d)|0}function YS(a){if(a>>>0>2147483647){oc(11932);z()}return $b(a<<1,2)}function VH(a){if(a>>>0>1073741823){oc(32462);z()}return $b(a<<2,4)}function VDa(a,b){if(m[a+4>>2]<m[hb(a)>>2]){tP(a,b);return}TDa(a,b)}function TS(a,b){if(!NLa(a,b)){a=Za-16|0;Za=a;Ab(b,0,37);Za=a+16|0}}function Pn(a,b,c){a=a|0;b=b|0;c=c|0;ze(a,b);ze(a+4|0,c);return a|0}function Oy(a){a=a|0;j[a>>2]=76448;wg(a+28|0);wg(a+12|0);return a|0}function Om(a){var b=0;b=j[a+20>>2];if(b){Cb(b+ -64|0)}j[a+20>>2]=0}function JB(a,b,c,d,e,f,g){return ya(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function Ix(a){if(j[a>>2]){Gra(a,j[a>>2]);hb(a);Fra(j[a>>2],wi(a))}}function GN(a){if(a>>>0>1073741823){oc(16711);z()}return $b(a<<2,1)}function EJ(a,b,c,d){j[a+12>>2]=0;j[a+8>>2]=d;j[a+4>>2]=c;j[a>>2]=b}function B5(a){a=a|0;var b=0;b=j[a+100>>2];j[a+100>>2]=0;return b|0}function Ak(a){if(a>>>0>1073741823){oc(68280);z()}return $b(a<<2,4)}function oS(a){if(a>>>0>268435455){oc(12065);z()}return $b(a<<4,4)}function oD(a,b,c){a=a|0;b=b|0;c=c|0;return Qn(0,a,b,c?c:461664)|0}function lm(a,b,c){return j[j[a>>2]+(b<<2)>>2]+(j[a+12>>2]+c<<1)|0}function jC(a,b,c){a=a|0;b=b|0;c=c|0;qs(a);h[a+128|0]=0;return a|0}function gK(a,b){j[a+876>>2]=j[a+876>>2]+b;h[a+872|0]=k[a+872|0]|8}function c_(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function cR(a){if(j[a>>2]){IIa(a,j[a>>2]);it(hb(a),j[a>>2],mi(a))}}function UW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return jca(a,b,c,d)|0}function TJ(a){if(a>>>0>134217727){oc(20384);z()}return $b(a<<5,8)}function Se(a,b,c){a=a|0;b=b|0;c=c|0;return wc(a,p(Jj(a),b)+c|0)|0}function Qm(a,b,c){return j[j[a>>2]+(b<<2)>>2]+(j[a+12>>2]+c<<2)|0}function QK(a){if(a>>>0>1073741823){oc(1447);z()}return $b(a<<2,4)}function PIa(a){a=a|0;return j[a+16>>2]+(j[a+8>>2]-j[a+20>>2]|0)|0}function OL(a){if(a>>>0>134217727){oc(18648);z()}return $b(a<<5,4)}function MF(a){if(a>>>0>268435455){oc(39501);z()}return $b(a<<4,4)}function KO(a){if(j[a>>2]){OBa(a,j[a>>2]);Zi(hb(a),j[a>>2],jd(a))}}function KM(a,b){hy(a,b);h[a+16|0]=k[b+16|0];j[a+12>>2]=j[b+12>>2]}function JO(a){if(j[a>>2]){IBa(a,j[a>>2]);$o(hb(a),j[a>>2],_o(a))}}function Gj(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){if(b){Cb(Ye(b))}}}function Gb(a,b,c){if((a|0)>=(b|0)){return(a|0)>(c|0)?c:a}return b}function yEa(a,b){a=a|0;b=b|0;a=FDa(a,b);if(!a){EDa(b)}return a|0}function wG(a){if(j[a>>2]){i8(a,j[a>>2]);zi(hb(a),j[a>>2],Ah(a))}}function oJ(a,b){var c=0,d=0;c=a,d=I5(b),j[c>>2]=d;Ao(a);return a}function nLa(a,b){a=a|0;b=b|0;a=HKa(a,b);if(!a){GKa(b)}return a|0}function mB(a){if(j[a>>2]){ZU(a,j[a>>2]);du(hb(a),j[a>>2],wi(a))}}function lsa(a,b){a=a|0;b=b|0;a=bsa(a,b);if(!a){asa(b)}return a|0}function lF(a){a=a|0;return+(+j[j[a+32>>2]+1074444>>2]*.00390625)}function iN(a){a=a+34|0;a=OMa(k[a|0]|k[a+1|0]<<8,0,80,0);return a}function fJa(a,b){a=a|0;b=b|0;a=tIa(a,b);if(!a){sIa(b)}return a|0}function ch(a,b){var c=0,d=0;c=a,d=$u(j[b>>2]),j[c>>2]=d;return a}function bJa(a,b){a=a|0;b=b|0;a=rIa(a,b);if(!a){qIa(b)}return a|0}function bIa(a,b){a=a|0;b=b|0;a=IHa(a,b);if(!a){HHa(b)}return a|0}function Wi(a){a=j[a+656>>2];if(!a){return 0}return j[a+44>>2]!=0}function MAa(a,b){a=a|0;b=b|0;a=rAa(a,b);if(!a){qAa(b)}return a|0}function LQ(a){ab=0;a=a+47|0;a=(k[a|0]|k[a+1|0]<<8)-98|0;return a}function KN(a){if(j[a>>2]){FN(a,j[a>>2]);Zi(hb(a),j[a>>2],jd(a))}}function Jv(a){a=k[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function JU(a){a=a|0;a=j[a+4>>2];return bb[j[j[a>>2]+12>>2]](a)|0}function IU(a){a=a|0;a=j[a+4>>2];return bb[j[j[a>>2]+16>>2]](a)|0}function HA(a){if(j[a>>2]){kU(a,j[a>>2]);fh(hb(a),j[a>>2],Hf(a))}}function G0(a,b){if(m[a+4>>2]<m[hb(a)>>2]){q0(a,b);return}j0(a,b)}function FS(a){if(j[a>>2]){nS(a,j[a>>2]);zi(hb(a),j[a>>2],Ah(a))}}function BA(a){if(j[a>>2]){QT(a,j[a>>2]);Yf(hb(a),j[a>>2],Af(a))}}function xw(a){a=a|0;j[a>>2]=79464;xf(a+4208|0);we(a);return a|0}function xDa(a,b){a=a|0;b=b|0;a=pP(a,b);if(!a){OCa(b)}return a|0}function tLa(a,b){var c=0;c=Za-16|0;Za=c;sv(a,b,c+8|0);Za=c+16|0}function rr(a){a=a|0;j[a>>2]=80352;xf(a+4260|0);we(a);return a|0}function qw(a){a=a|0;j[a>>2]=79668;wg(a+4208|0);we(a);return a|0}function qL(a,b){b=1/(564505.8718779281/b+1);nL(a,b,0,0,b+ -1,0)}function mw(a){a=a|0;j[a>>2]=80584;xf(a+4256|0);we(a);return a|0}function lb(a){a=a|0;var b=0;b=Za-16|0;Za=b;Za=b+16|0;return a|0}function laa(a,b,c){a=a|0;b=b|0;c=c|0;return S6(ll(a),ll(b),c)|0}function kw(a){a=a|0;j[a>>2]=80992;xf(a+4208|0);we(a);return a|0}function gsa(a,b){a=a|0;b=b|0;uL(a,j[b>>2],j[b+4>>2]);return a|0}function dy(a,b){var c=0;c=j[a>>2];j[a>>2]=b;if(c){if(c){Cb(c)}}}function WH(a,b){var c=0;c=Za-16|0;Za=c;Dia(a,Kb(c,b));Za=c+16|0}function Tda(a,b){a=a|0;b=b|0;if(!b){return 3}j[b>>2]=a;return 0}function Nr(a){gb(a+48|0);gb(a+36|0);gb(a+24|0);gb(a+12|0);gb(a)}function KU(a){a=a|0;a=j[a+4>>2];return bb[j[j[a>>2]+8>>2]](a)|0}function Fm(a){var b=0;b=Za-16|0;Za=b;Za=b+16|0;return a<<24>>24}function Ds(a,b){a=a|0;b=b|0;a=tAa(a,b);if(!a){sAa(b)}return a|0}function AY(a){a=a|0;var b=0,c=0;b=a,c=Wd(),j[b>>2]=c;return a|0}function xs(a,b){a=a|0;b=b|0;a=Gza(a,b);if(!a){JN(b)}return a|0}function xf(a){af(a);if(j[a>>2]){_P(a);ye(hb(a),j[a>>2],jd(a))}}function ur(a){af(a);if(j[a>>2]){FH(a);ye(hb(a),j[a>>2],jd(a))}}function tr(a){CH(a);if(j[a>>2]){IH(a);BH(hb(a),j[a>>2],Hj(a))}}function qk(a,b){a=a|0;b=b|0;return bb[j[j[a>>2]+28>>2]](a,b)|0}function po(a){a=a|0;return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function nr(a,b){a=a|0;b=b|0;i3(a,b);j[a+72>>2]=0;j[a+76>>2]=-1}function lx(a){YQ(a);if(j[a>>2]){mR(a);XQ(hb(a),j[a>>2],nl(a))}}function kx(a){rJ(a);if(j[a>>2]){qJ(a);bx(hb(a),j[a>>2],Mi(a))}}function js(a){Dl(a);if(j[a>>2]){SL(a);Zg(hb(a),j[a>>2],_g(a))}}function jj(a){a=a|0;a=j[a>>2];return bb[j[j[a>>2]+24>>2]](a)|0}function iL(a){Lh(a);if(j[a>>2]){$K(a);fh(hb(a),j[a>>2],Hf(a))}}function hx(a){Dl(a);if(j[a>>2]){oB(a);Zg(hb(a),j[a>>2],_g(a))}}function gl(a){sh(a);if(j[a>>2]){uN(a);Ef(hb(a),j[a>>2],Ce(a))}}function gH(a){a=a|0;return q(q(q(n[a+4228>>2]*q(198))+q(-99)))}function eS(a,b){a=a|0;b=b|0;a=BKa(a,b);if(!a){UR(b)}return a|0}function dv(a,b){a=a|0;b=b|0;return(Ig(a)|0)!=0|(a|32)-97>>>0<6}function ct(a,b){a=a|0;b=b|0;a=jIa(a,b);if(!a){UQ(b)}return a|0}function an(a,b){a=a|0;b=b|0;a=bFa(a,b);if(!a){PP(b)}return a|0}function aj(a,b,c){a=a|0;b=b|0;c=c|0;return kz(ll(a),ll(b),c)|0}function Xu(a,b){a=a|0;b=b|0;return bb[j[j[a>>2]+12>>2]](a,b)|0}function Xd(a,b,c,d){j[a+8>>2]=d;j[a+4>>2]=c;j[a>>2]=b;return a}function WS(a){if(!Yc(a,12035,25)){return k[a+34|0]<65}return 0}function Vk(a){sh(a);if(j[a>>2]){GI(a);Ef(hb(a),j[a>>2],Ce(a))}}function Uz(a,b){a=a|0;b=b|0;a=IKa(a,b);if(!a){YR(b)}return a|0}function Um(a){af(a);if(j[a>>2]){uP(a);It(hb(a),j[a>>2],jd(a))}}function SW(a,b){a=a|0;b=b|0;a=bb[a|0](b)|0;ea(ab|0);return a|0}function Rz(a,b){a=a|0;b=b|0;a=KKa(a,b);if(!a){ZR(b)}return a|0}function RS(a,b){a=a|0;b=b|0;a=KLa(a,b);if(!a){zS(b)}return a|0}function QO(a,b,c,d){Ie(a,b);i[a+18>>1]=d;i[a+16>>1]=c;return a}function HM(a){af(a);if(j[a>>2]){GM(a);Zi(hb(a),j[a>>2],jd(a))}}function Gd(a){var b=0;b=In(ne(a)+1|0,1);if(b){R4(b,a)}return b}function FR(a){wl(a);if(j[a>>2]){AR(a);ln(hb(a),j[a>>2],Pf(a))}}function Eq(a,b){a=a|0;b=b|0;return bb[j[j[a>>2]+44>>2]](a,b)|0}function BK(a){sh(a);if(j[a>>2]){YJ(a);xo(hb(a),j[a>>2],Ce(a))}}function zh(a){a=a|0;lV(a);j[a+8>>2]=0;j[a+12>>2]=0;return a|0}function uy(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,1024);Za=c+16|0}function uG(a,b,c,d){i[a+4>>1]=c;h[a+6|0]=b;j[a>>2]=d;return a}function qu(a,b){a=a|0;b=b|0;a=aV(a,b);if(!a){$U(b)}return a|0}function qc(a,b){a=a|0;b=b|0;Ela(a,k[b+8|0],j[b>>2],j[b+4>>2])}function qB(a,b){a=a|0;b=b|0;a=rV(a,b);if(!a){eB(b)}return a|0}function pB(a,b){a=a|0;b=b|0;a=qV(a,b);if(!a){cB(b)}return a|0}function lr(a){a=a|0;j[a>>2]=76896;gb(a+32|0);Jk(a);return a|0}function kf(a,b){a=a|0;b=b|0;a=cu(a,b);if(!a){SA(b)}return a|0}function jf(a,b){return bb[j[j[a>>2]+36>>2]](a,j[a+12>>2],b)|0}function hM(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){Ita(Rb(a),b)}}function aQ(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){yFa(Rb(a),b)}}function _t(a,b){a=a|0;b=b|0;a=lU(a,b);if(!a){GA(b)}return a|0}function Ws(a,b){a=a|0;b=b|0;a=Vp(a,b);if(!a){TP(b)}return a|0}function VK(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){Lqa(Rb(a),b)}}function UH(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){sia(Rb(a),b)}}function Ty(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,4896);Za=c+16|0}function TO(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){zCa(Rb(a),b)}}function Sp(a){a=a|0;a=j[a>>2];return bb[j[j[a>>2]+8>>2]](a)|0}function SJ(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){goa(Rb(a),b)}}function Qaa(a,b,c){a=a|0;b=b|0;c=c|0;CJ(a,0,_y(j[b+24>>2]),c)}function QJ(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){aoa(Rb(a),b)}}function OI(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){Ila(Rb(a),b)}}function NR(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,1954);Za=c+16|0}function Lp(a,b){var c=0;c=b+1|0;j[a>>2]=j[a>>2]>(c|0)?c:b+2|0}function KHa(a,b){if(!Df(a,b)){a=Za-16|0;Za=a;Oe(b);Za=a+16|0}}function I$(a,b,c){a=a|0;b=b|0;c=c|0;Cc(a,YD(j[b>>2]),j[b>>2])}function Hna(a,b){a=a|0;b=b|0;Ju(a,b);j[a>>2]=71516;return a|0}function EQ(a){a=a|0;a=k[a|0];return Ld(a)^1|(a-49&255)>>>0<36}function wQ(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,576);Za=c+16|0}function vd(a,b){j[a>>2]=j[b>>2];j[a+4>>2]=j[b+4>>2];return a}function tt(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,192);Za=c+16|0}function rR(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,610);Za=c+16|0}function r6(a,b){a=a|0;b=b|0;Ju(a,b);j[a>>2]=71572;return a|0}function p8(a){a=a|0;var b=0;b=Za-16|0;Za=b;PF(a,1);Za=b+16|0}function nO(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,130);Za=c+16|0}function mX(a,b){a=a|0;b=b|0;Ju(a,b);j[a>>2]=71624;return a|0}function lO(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,600);Za=c+16|0}function l8(a){a=a|0;var b=0;b=Za-16|0;Za=b;sN(a,1);Za=b+16|0}function kN(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,146);Za=c+16|0}function kDa(a,b,c){a=a|0;b=b|0;c=c|0;Nc(a,ZB(c,zb(b),nb(b)))}function gz(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function gN(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,608);Za=c+16|0}function fV(a){a=a|0;var b=0;b=Za-16|0;Za=b;CB(a,1);Za=b+16|0}function cO(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,126);Za=c+16|0}function cL(a,b){return j[a>>2]==j[b>>2]&j[a+4>>2]==j[b+4>>2]}function bta(a,b,c){a=a|0;b=b|0;c=c|0;return Sg(a,b,c,1180)|0}function ata(a,b,c){a=a|0;b=b|0;c=c|0;return Sg(a,b,c,1181)|0}function _ja(a,b,c){a=a|0;b=b|0;c=c|0;return Sg(a,b,c,1571)|0}function Xsa(a,b,c){a=a|0;b=b|0;c=c|0;return Sg(a,b,c,1186)|0}function VP(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,674);Za=c+16|0}function SM(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,204);Za=c+16|0}function Oo(a,b){a=a|0;b=b|0;if(de(a)>>>0>b>>>0){h[a+16|0]=b}}function Ol(a,b){if(nb(a)>>>0<=b>>>0){Pl();z()}return Ub(a,b)}function OU(a){a=a|0;var b=0;b=Za-16|0;Za=b;VA(a,1);Za=b+16|0}function Nq(a,b){b=j[b>>2];j[a>>2]=b;j[a+4>>2]=b>>31;return a}function Mia(a,b,c){a=a|0;b=b|0;c=c|0;return Sg(a,b,c,1607)|0}function Lia(a,b,c){a=a|0;b=b|0;c=c|0;return Sg(a,b,c,1608)|0}function Kz(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,512);Za=c+16|0}function IB(a,b,c){b=va(2071,a|0,b|0,c|0)|0;ab=C()|0;return b}function GP(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,128);Za=c+16|0}function EM(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,263);Za=c+16|0}function CQ(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,157);Za=c+16|0}function AV(a){a=a|0;var b=0;b=Za-16|0;Za=b;hB(a,1);Za=b+16|0}function $S(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,497);Za=c+16|0}function yS(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,41);Za=c+16|0}function xS(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,16);Za=c+16|0}function uw(a){a=a|0;j[a+32>>2]=0;j[a+28>>2]=j[a+28>>2]&-7|2}function tA(a,b){Oka(k[a+8|0],j[a>>2],j[a+4>>2],zb(b),nb(b))}function sL(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,27);Za=c+16|0}function qz(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,12);Za=c+16|0}function pO(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,30);Za=c+16|0}function pF(a){a=a|0;return+(65536/+m[j[a+32>>2]+480244>>2])}function et(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,66);Za=c+16|0}function eGa(a,b,c){a=a|0;b=b|0;c=c|0;return Sg(a,b,c,709)|0}function dV(a,b){Nc(a,b);Cl(a+12|0,b+12|0);cV(a+28|0,b+28|0)}function dB(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,10);Za=c+16|0}function cJa(a,b,c){a=a|0;b=b|0;c=c|0;return WR(a,b,c)|0}



function bO(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,32);Za=c+16|0}function bB(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,14);Za=c+16|0}function at(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,22);Za=c+16|0}function XR(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,11);Za=c+16|0}function Tga(a){a=a|0;a=Ki(a);if(a){bb[j[j[a>>2]+92>>2]](a)}}function Qp(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,36);Za=c+16|0}function Py(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,33);Za=c+16|0}function PR(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,1954);Za=b+16|0}function OP(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,80);Za=c+16|0}function Jy(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,40);Za=c+16|0}function JJ(a){a=a|0;var b=0;b=Za-16|0;Za=b;Pna(a);Za=b+16|0}function IQ(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,98);Za=c+16|0}function IN(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,96);Za=c+16|0}function GQ(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,48);Za=c+16|0}function Dna(a,b,c){a=a|0;b=b|0;c=c|0;Gma(a,(b-a|0)/160|0,c)}function CI(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,24);Za=c+16|0}function Az(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,64);Za=c+16|0}function An(a,b,c){if(!b){return 0}return Tq(a,gg(h[c|0]),b)}function Ama(a,b){a=a|0;b=b|0;qma(nd(b),_e(b),nd(b));Nc(a,b)}function AS(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,38);Za=c+16|0}function $O(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,52);Za=c+16|0}function xQ(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,576);Za=b+16|0}function tI(a,b){if((a|0)!=(b|0)){Vja(a,j[b>>2],j[b+4>>2])}}function sR(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,610);Za=b+16|0}function pk(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,2);Za=c+16|0}function oz(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,6);Za=c+16|0}function oO(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,130);Za=b+16|0}function mO(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,600);Za=b+16|0}function lN(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,146);Za=b+16|0}function ku(a){var b=0;b=a;a=j[a>>2]-1|0;j[b>>2]=a;return a}function hsa(a,b){a=a|0;b=b|0;dsa(a,Lb(b),Mb(b));return a|0}function hN(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,608);Za=b+16|0}function ed(a){var b=0;b=Za-16|0;Za=b;DX(Gu(b,a));Za=b+16|0}function dO(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,126);Za=b+16|0}function bu(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,8);Za=c+16|0}function ah(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,4);Za=c+16|0}function aT(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,497);Za=b+16|0}function Zz(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,3);Za=c+16|0}function Yp(a){var b=0;b=Za-16|0;Za=b;j[b+8>>2]=a;Za=b+16|0}function WZ(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>-1?b:c)|0}function VW(a,b){a=a|0;b=b|0;a=oca(a,b);ea(ab|0);return a|0}function UP(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,192);Za=b+16|0}function Tp(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,1);Za=c+16|0}function TM(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,204);Za=b+16|0}function Paa(a){a=a|0;vG(a,2,100);Oo(j[a+24>>2]+484360|0,0)}function Nz(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,5);Za=c+16|0}function Lz(a,b){var c=0;c=Za-16|0;Za=c;Qb(a,b,7);Za=c+16|0}function DQ(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,157);Za=b+16|0}function zS(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,41);Za=b+16|0}function vf(a,b){a=PMa(j[a>>2],j[a+4>>2],b,b>>31);return a}function u9(a){a=a|0;return m[j[a+24>>2]+1074420>>2]/1e4|0}function sm(a,b,c,d){j[a+16>>2]=d;j[a+12>>2]=c;j[a+8>>2]=b}function op(a){if((a|0)>=1){return(a|0)<120?a:120}return 1}function nb(a){if(qe(a)){return j[a+4>>2]}return k[a+11|0]}function g3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ab=0;return 0}function bR(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,66);Za=b+16|0}function aP(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,52);Za=b+16|0}function RW(a,b,c){a=a|0;b=b|0;c=c|0;return bb[a|0](b,c)|0}function PP(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,80);Za=b+16|0}function MB(a){a=j[a>>2]-12|0;if((ku(a+8|0)|0)<=-1){Cb(a)}}function Ku(){var a=0;a=R(4)|0;zk(a);Y(a|0,71396,2001);z()}function JQ(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,98);Za=b+16|0}function JN(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,96);Za=b+16|0}function HQ(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,48);Za=b+16|0}function GA(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,36);Za=b+16|0}function CS(a){var b=0;b=Za-16|0;Za=b;Ab(a,0,38);Za=b+16|0}function zDa(a,b,c){a=a|0;b=b|0;c=c|0;return hDa(a,b,c)|0}function xt(a){if(j[a>>2]){vS(a);un(hb(a),j[a>>2],Pf(a))}}function vEa(a,b,c){a=a|0;b=b|0;c=c|0;return kEa(a,b,c)|0}function vDa(a,b,c){a=a|0;b=b|0;c=c|0;return gDa(a,b,c)|0}function uf(a,b,c){return j[a>>2]+(p(j[a+4>>2],c)+b<<2)|0}function sDa(a,b,c){a=a|0;b=b|0;c=c|0;return eDa(a,b,c)|0}function rn(a,b,c){Cc(a,j[b>>2]+(c>>>3&536870908)|0,c&31)}function pDa(a,b,c){a=a|0;b=b|0;c=c|0;return bDa(a,b,c)|0}function os(a){if(j[a>>2]){VL(a);ye(hb(a),j[a>>2],jd(a))}}function oKa(a,b,c){a=a|0;b=b|0;c=c|0;return ZJa(a,b,c)|0}function lLa(a,b,c){a=a|0;b=b|0;c=c|0;return cLa(a,b,c)|0}function ke(a){if(!j[a+20>>2]){return 0}return j[a>>2]!=0}function kLa(a,b,c){a=a|0;b=b|0;c=c|0;return bLa(a,b,c)|0}function jm(a,b,c){return j[a>>2]+(p(j[a+4>>2],c)+b<<1)|0}function jLa(a,b,c){a=a|0;b=b|0;c=c|0;return aLa(a,b,c)|0}function iLa(a,b,c){a=a|0;b=b|0;c=c|0;return $Ka(a,b,c)|0}function i9(a){a=a|0;return Ui(Fb(j[a+24>>2]+484360|0))|0}function hw(a,b,c){j[a+28>>2]=c;j[a+20>>2]=b;j[a+24>>2]=b}function hva(a,b,c){a=a|0;b=b|0;c=c|0;Dpa(a,b);return a|0}function gMa(a,b,c){a=a|0;b=b|0;c=c|0;return WLa(a,b,c)|0}function gLa(a,b,c){a=a|0;b=b|0;c=c|0;return _Ka(a,b,c)|0}function gKa(a,b,c){a=a|0;b=b|0;c=c|0;return XJa(a,b,c)|0}function fMa(a,b,c){a=a|0;b=b|0;c=c|0;return ULa(a,b,c)|0}function eia(a,b,c){a=a|0;b=b|0;c=c|0;return cia(a,b,c)|0}function cba(a,b,c){a=a|0;b=b|0;c=c|0;Nc(a,ZB(c,b,ne(b)))}function aU(a){a=a|0;lB(a,11650);j[a>>2]=77436;return a|0}function Yxa(a,b,c){a=a|0;b=b|0;c=c|0;return Lxa(a,b,c)|0}function YHa(a,b,c){a=a|0;b=b|0;c=c|0;return THa(a,b,c)|0}function Xwa(a,b,c){a=a|0;b=b|0;c=c|0;return Owa(a,b,c)|0}function XS(a){if(j[a>>2]){JS(a);Yf(hb(a),j[a>>2],Af(a))}}function Vs(a){if(j[a>>2]){XP(a);it(hb(a),j[a>>2],mi(a))}}function Vd(a){if(j[a>>2]){ye(hb(a),j[a>>2],j[hb(a)>>2])}}function Rwa(a,b,c){a=a|0;b=b|0;c=c|0;return Iwa(a,b,c)|0}function Qi(a){a=j[a+656>>2];if(!a){return 0}return ci(a)}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;return Oga(a,b,c)|0}function OE(a){while(1){if((Xq(a)|0)!=-1){continue}break}}function Nza(a,b,c){a=a|0;b=b|0;c=c|0;return Iza(a,b,c)|0}function Nd(a,b,c){Cc(a,j[b>>2]+(c>>>3&536870908)|0,1<<c)}function NGa(a,b,c){a=a|0;b=b|0;c=c|0;return tGa(a,b,c)|0}function Mp(a){if(j[a>>2]){xA(a);Yf(hb(a),j[a>>2],Af(a))}}function LAa(a,b,c){a=a|0;b=b|0;c=c|0;return DAa(a,b,c)|0}function KV(a){a=a|0;lB(a,11072);j[a>>2]=77092;return a|0}function KGa(a,b,c){a=a|0;b=b|0;c=c|0;return rGa(a,b,c)|0}function Jg(a,b,c){return j[a>>2]+(p(j[a+4>>2],c)+b<<3)|0}function Gv(a,b){return j[((a>>>24^b)<<2)+457376>>2]^a<<8}function FC(a){if(j[a>>2]){EC(a);fC(Ck(a),j[a>>2],Bk(a))}}function CJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;zna(a,b,c,d)}function $Ia(a,b,c){a=a|0;b=b|0;c=c|0;return RIa(a,b,c)|0}function zQ(a){a=a|0;if(!k[a|0]){return 1}return Lf(a)|0}function yl(a,b,c){a=PMa(j[a>>2],j[a+4>>2],b,c);return a}function tU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mu(a,b,c,d)}function rC(a,b){Il(j[b>>2]);Hl(j[a>>2]);j[a>>2]=j[b>>2]}function mC(a){a=a|0;j[a>>2]=62584;gb(a+12|0);return a|0}function lQ(a,b,c){a=a|0;b=b|0;c=c|0;return PFa(a,b,c)|0}function lC(a){a=a|0;j[a>>2]=62624;gb(a+16|0);return a|0}function j6(a,b,c){a=a|0;b=b|0;c=c|0;return _c(p(b,c))|0}function hE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;sg(a,-1,-1)}function fGa(a,b){a=a|0;b=b|0;Eb(a,b?b:14548);return a|0}function dT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;He(a,c,d,b)}function cs(a,b,c){a=a|0;b=b|0;c=c|0;return _qa(a,b,c)|0}function Wq(a){if(!c5(a)){Nb(a,30);return 0}return ME(a)}function Wea(a){a=a|0;YG(a);h[a+4202|0]=1;j[a+4224>>2]=0}function VEa(a,b){a=a|0;b=b|0;return fI(a,zb(b),nb(b))|0}function Uq(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;h4(a,b,c,d)}function TV(a,b,c){a=a|0;b=b|0;c=c|0;mu(a,b,j[b+8>>2],c)}function QF(a){a=a|0;j[a>>2]=83912;Oy(a+12|0);return a|0}function PGa(a,b,c){a=a|0;b=b|0;c=c|0;return Tq(a,b,c)|0}function PA(a){a=a|0;j[a>>2]=77320;$t(a+12|0);return a|0}function Oh(a){return he(a)|he(a)<<8|he(a)<<16|he(a)<<24}function OS(a,b,c){a=a|0;b=b|0;c=c|0;return XLa(a,b,c)|0}function Ns(a){Um(a+88|0);Um(a+68|0);Um(a+48|0);return a}function NF(a){a=a|0;j[a>>2]=83952;Ny(a+12|0);return a|0}function Kx(a,b){o[a>>3]=o[a>>3]*b;o[a+8>>3]=o[a+8>>3]*b}function Jz(a){h[a|0]=0;h[a+1|0]=0;h[a+2|0]=0;h[a+3|0]=0}function HB(a,b,c){b=sa(a|0,b|0,c|0)|0;ab=C()|0;return b}function DEa(a,b,c){a=a|0;b=b|0;c=c|0;return VR(a,b,c)|0}function wIa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Ez(b,c,d)}function wD(a){return(a|0)!=0&(a|0)!=57968&(a|0)!=57992}function u2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return d|0}function tC(a){var b=0;b=j[a>>2];j[a>>2]=0;if(b){Hl(b)}}function sc(a){if(qe(a)){a=Lj(a)-1|0}else{a=10}return a}function npa(a,b){a=a|0;b=b|0;return m[a+12>>2]>b>>>0|0}function mD(a,b,c,d){a=nD(a,b,c,0,-2147483648);return a}function lea(a){a=a|0;return Hd(j[j[a>>2]-12>>2]+a|0)|0}function kz(a,b,c){b=b-a|0;if(b){Bi(c,a,b)}return b+c|0}function iq(a){a=a|0;j[a>>2]=71436;MB(a+4|0);return a|0}function hr(a){a=a|0;j[a>>2]=83784;$v(a+4|0);return a|0}function gS(a){if(k[a+1|0]==2){return k[a|0]<3}return 0}function aF(a,b,c){j[a+4>>2]=0;j[a>>2]=b;j[a+8>>2]=c<<3}function XC(a,b,c){a=a|0;b=b|0;c=c|0;return M$(a,b,c)|0}function Wn(a){a=a|0;j[a>>2]=55840;wb(a+4|0);return a|0}function Vq(a,b,c){return oE(zb(a),nb(a),zb(b),c,nb(b))}function VG(a){return q(q(n[a+4208>>2]*q(1e4))+q(-1e4))}function UG(a){return q(q(n[a+4252>>2]*q(19980))+q(20))}function SC(a,b,c){a=a|0;b=b|0;c=c|0;return D$(a,b,c)|0}function Pz(a,b,c){a=a|0;b=b|0;c=c|0;return aS(a,b,c)|0}function O$(a,b,c){a=a|0;b=b|0;c=c|0;return N$(a,b,c)|0}function Ny(a){a=a|0;j[a>>2]=76504;wg(a+4|0);return a|0}function Jk(a){a=a|0;j[a>>2]=55776;wb(a+4|0);return a|0}function Iz(a,b,c){a=a|0;b=b|0;c=c|0;return BR(a,b,c)|0}function Ic(a,b,c){a=a|0;b=b|0;c=c|0;ze(a,b);return a|0}function HN(a,b,c){a=a|0;b=b|0;c=c|0;return ws(a,b,c)|0}function Fu(a){a=a|0;j[a>>2]=71416;MB(a+4|0);return a|0}function F$(a,b,c){a=a|0;b=b|0;c=c|0;return E$(a,b,c)|0}function D2(a,b,c){a=a|0;b=b|0;c=c|0;return E2(a,b,c)|0}function $t(a){a=a|0;j[a>>2]=77360;jb(a+4|0);return a|0}function t3(a){a=a|0;return Rn(j[j[a>>2]-12>>2]+a|0)|0}function pg(a){var b=0;b=Xq(a);j[a+1396>>2]=0;return b}function lq(a){if(qe(a)){a=Lj(a)-1|0}else{a=1}return a}function kO(a){var b=0;b=Za-16|0;Za=b;XAa(a);Za=b+16|0}function k2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Zh(a,c,d)}function eH(a){a=a|0;return di(q(n[a+4224>>2]*q(4)))|0}function ao(a){return k[a+2|0]&2?(k[a+1|0]&6)==6?4:1:0}function aO(a){var b=0;b=Za-16|0;Za=b;wAa(a);Za=b+16|0}function Zt(a,b){a=OMa(j[a>>2],j[a+4>>2],b,0);return a}function Uf(a,b){a=a|0;b=b|0;bb[j[j[b>>2]+20>>2]](a,b)}function Os(a){var b=0,c=0;b=a,c=bP(j[a>>2]),j[b>>2]=c}function K7(a){a=a|0;return Xe(j[j[a>>2]-12>>2]+a|0)|0}function I3(a){a=a|0;return Vn(j[j[a>>2]-12>>2]+a|0)|0}function Hi(a,b){j[a+16>>2]=!j[a+24>>2]|(j[a+16>>2]|b)}function HP(a){var b=0;b=Za-16|0;Za=b;SEa(a);Za=b+16|0}function H9(a,b){a=a|0;b=b|0;j[j[a+24>>2]+480272>>2]=b}function Gha(a,b,c){a=a|0;b=b|0;c=c|0;ml(a,b+4260|0,8)}function Gg(a,b){a=a|0;b=b|0;bb[j[j[b>>2]+24>>2]](a,b)}function Fg(a,b){a=a|0;b=b|0;bb[j[j[b>>2]+28>>2]](a,b)}function EL(a,b){i[a+20>>1]=l[a+20>>1]&768|b&255;Nx(a)}function $b(a,b){if(PE(b)){return kY(a,b)}return ue(a)}function yba(a){a=a|0;a=j[a+4>>2];return(a?a:38169)|0}function xp(a,b){a=a|0;b=b|0;return me(a)>>>0>b>>>0|0}function wW(a,b){a=a|0;b=b|0;j[a>>2]=b;j[a+4>>2]=b+48}function uC(a){var b=0;b=Za-16|0;Za=b;zZ(a);Za=b+16|0}function so(a){a=a|0;return bb[j[j[a>>2]+24>>2]](a)|0}function jW(a,b){a=a|0;b=b|0;j[a>>2]=b;j[a+4>>2]=b+36}function jO(a,b){a=a|0;b=b|0;j[a>>2]=b;j[a+4>>2]=b+12}function hia(a,b){a=a|0;b=b|0;y3(a,j[b>>2],j[b+4>>2])}function h9(a){a=a|0;return mI(j[a+24>>2]+484344|0)|0}function gb(a){if(qe(a)){Yf(a,j[a>>2],Lj(a))}return a}function ec(a,b,c){a=a|0;b=b|0;c=c|0;qs(a);return a|0}function eKa(a,b,c){a=a|0;b=b|0;c=c|0;wJa(a,b-a>>2,c)}function cma(a){a=a|0;n[a+12>>2]=1;YI(a,4);return a|0}function _ga(a){a=a|0;h[a+4202|0]=1;xr(a);sw(a);yH(a)}function ZN(a,b){a=a|0;b=b|0;j[a>>2]=b;j[a+4>>2]=b+24}function ZA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function Vl(a,b){return bb[j[j[a>>2]+36>>2]](a,b,0)|0}function Tl(a,b){return bb[j[j[a>>2]+52>>2]](a,b,0)|0}function TP(a){var b=0;b=Za-16|0;Za=b;Jz(a);Za=b+16|0}function SA(a){var b=0;b=Za-16|0;Za=b;Bl(a);Za=b+16|0}function R6(a,b){a=a|0;b=b|0;XK(j[a>>2],b);return a|0}function Qfa(a){a=a|0;return q(q(n[a+4232>>2]*q(20)))}function Hh(a){a=a|0;return bb[j[j[a>>2]+12>>2]](a)|0}function He(a,b,c,d){h[a+8|0]=d;j[a+4>>2]=c;j[a>>2]=b}function Gh(a){a=a|0;return bb[j[j[a>>2]+16>>2]](a)|0}function Bia(a,b,c){a=a|0;b=b|0;c=c|0;n[b>>2]=n[c>>2]}function $La(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function zp(a,b,c){a=a|0;b=b|0;c=c|0;i[b>>1]=l[c>>1]}function zn(a){a=a|0;a=a+12|0;bb[j[j[a>>2]>>2]](a)|0}function v9(a){a=a|0;return j[j[a+24>>2]+1074416>>2]}function r9(a){a=a|0;return j[j[a+24>>2]+1074424>>2]}function gHa(a){a=a|0;return yI(k[a+3|0],k[a+5|0])|0}function fH(a){a=a|0;return q(q(n[a+4216>>2]*q(10)))}function afa(a){a=a|0;return q(q(n[a+4232>>2]*q(4)))}function Zja(a,b){a=a|0;b=b|0;a=a+24|0;tI(a,b);dx(a)}function XFa(a,b){a=a|0;b=b|0;return fI(a,b,ne(b))|0}function SQ(a){a=a|0;return j[VHa(j[a>>2],RQ(a))>>2]}function NU(a,b,c,d){zc(a,b);zc(a+4|0,c);zc(a+8|0,d)}function NMa(a){if(a){return 31-s(a-1^a)|0}return 32}function Io(a,b,c){a=a|0;b=b|0;c=c|0;j[b>>2]=j[c>>2]}function zm(a,b,c){if(!c){return 0}return Yc(a,b,c)}function yx(a){a=a|0;return Ur(k[a+2|0],k[a+4|0])|0}function xy(a,b){a=a|0;b=b|0;return Gn(a,b,ne(b))|0}function vc(a,b){a=a|0;b=b|0;return UN(a,b,ne(b))|0}function ud(a){var b=0;b=j[a>>2];j[a>>2]=0;return b}function u6(a,b,c){a=a|0;b=b|0;c=c|0;iF(a-88|0,b,c)}function s6(a,b,c){a=a|0;b=b|0;c=c|0;gF(a-88|0,b,c)}function q9(a){a=a|0;return l[j[a+24>>2]+480214>>1]}function pc(a){if(qe(a)){Kn(j[a>>2],Lj(a))}return a}function oL(a,b){j[a+8>>2]=0;j[a+12>>2]=0;o[a>>3]=b}function ml(a,b,c){j[a>>2]=b;j[a+4>>2]=b+c;return a}function mb(a,b,c){Cc(a,(c>>>3&536870908)+b|0,1<<c)}function fr(a){a=a|0;return l[j[a+24>>2]+480190>>1]}function dka(a,b){a=a|0;b=b|0;yi(a+36|0,b);return 1}function Wr(a){a=a|0;return Ur(k[a+3|0],k[a+5|0])|0}function UM(a,b){return VV(zb(a),nb(a),zb(b),nb(b))}function RA(a,b,c){tk(a,b);j[a+12>>2]=c;j[a+8>>2]=0}function Qk(a){a=a|0;return l[j[a+24>>2]+480188>>1]}function Pk(a){a=a|0;return l[j[a+24>>2]+480192>>1]}function PK(a,b){return HV(zb(a),nb(a),zb(b),nb(b))}function Oq(a){if(!a){return 0}j[114600]=a;return-1}function OC(a,b,c){a=a|0;b=b|0;c=c|0;zb(b);return-1}function Nn(a,b){b=j[b>>2];j[a>>2]=b;Il(b);return a}function Mta(a){a=a|0;bf(85416);bf(85408);gb(85396)}function LC(a){a=a|0;oq(a);j[a>>2]=63596;return a|0}function KC(a){a=a|0;oq(a);j[a>>2]=63692;return a|0}function Jl(a,b){Ie(a,b);Ab(a+16|0,0,1040);return a}function Hra(a,b){a=a|0;b=b|0;j[b>>2]=0;j[b+4>>2]=0}function Hd(a){a=a|0;a=Nea(a);og(a+56|0);return a|0}function G9(a){a=a|0;return j[j[a+24>>2]+480272>>2]}function yta(a,b){a=a|0;b=b|0;return Vb(a,b,116)|0}function xu(a,b,c){a=a|0;b=b|0;c=c|0;h[b|0]=k[c|0]}function xEa(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,16,b)}function w6(a,b,c){a=a|0;b=b|0;c=+c;kF(a-88|0,b,c)}function uz(a,b,c){ml(a,j[b+28>>2]+(c<<12)|0,4096)}function uDa(a,b){a=a|0;b=b|0;fDa(a,j[b>>2],RQ(b))}function t6(a,b){a=a|0;b=b|0;return hF(a-88|0,b)|0}function p6(a,b){a=a|0;b=b|0;return fF(a-88|0,b)|0}function nz(a,b,c){return a>>>0<c>>>0&a>>>0>=b>>>0}function lza(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,33,b)}function jb(a){a=j[a+4>>2];if(a){if(Hl(a)){oY(a)}}}function iH(a){a=a|0;if(a){bb[j[j[a>>2]+4>>2]](a)}}function hi(a,b,c){j[a>>2]=j[b>>2];h[a+4|0]=k[c|0]}function cG(a,b){$F(a,74);j[a+4>>2]=j[a+4>>2]|b&74}function bza(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,24,b)}function _k(a){$h(a+724|0);$h(a+736|0);$h(a+748|0)}function Zs(a){return(j[a+480180>>2]&740327453)!=0}function Xe(a){a=a|0;a=c8(a);og(a+60|0);return a|0}function Rra(a){a=a|0;return+K4(o[a>>3],o[a+8>>3])}function NO(a,b,c){a=a|0;b=b|0;c=c|0;Nc(a,xy(b,c))}function Kp(a,b,c){a=a|0;b=b|0;c=c|0;Nc(a,sO(b,c))}function FK(a){return j[a+16>>2]!=(0-j[a+20>>2]|0)}function $x(a,b,c){a=a|0;b=b|0;c=c|0;FM(vd(a,b),c)}function zz(a,b){a=DIa(a,b);if(!a){bR(b)}return a}function zE(a,b){if(!a){return 0}return Cj(a,b,0)}function yDa(a,b){a=a|0;b=b|0;return bb[b|0](a)|0}function v_(){p$();j[115459]=463456;return 461836}function ug(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,32,b)}function uEa(a,b){a=a|0;b=b|0;return Cr(a,b,17)|0}function tz(a,b){a=kIa(a,b);if(!a){UQ(b)}return a}function sza(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,9,b)}function rG(a,b){Xv(j[j[a>>2]-12>>2]+a|0,j[b>>2])}function qt(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,64,b)}function qR(a,b){a=EIa(a,b);if(!a){bR(b)}return a}function on(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,22,b)}function ol(a){return(j[Ob(a)>>2]-j[a>>2]|0)/24|0}function nl(a){return(j[hb(a)>>2]-j[a>>2]|0)/48|0}function mP(a,b){a=YCa(a,b);if(!a){aP(b)}return a}function lz(a,b){a=qHa(a,b);if(!a){HQ(b)}return a}function kb(a){return(j[a+4>>2]&j[j[a>>2]>>2])!=0}function jl(a){return(j[hb(a)>>2]-j[a>>2]|0)/33|0}function hLa(a,b){a=a|0;b=b|0;return Cr(a,b,11)|0}function en(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,20,b)}function dk(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,12,b)}function cl(a,b,c){o[a+8>>3]=c;o[a>>3]=b;return a}function ce(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function bt(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,28,b)}function _o(a){return(j[hb(a)>>2]-j[a>>2]|0)/20|0}function Tm(a){return(j[hb(a)>>2]-j[a>>2]|0)/56|0}function QN(a,b){a=Hza(a,b);if(!a){JN(b)}return a}function Ot(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,26,b)}function Mi(a){return(j[hb(a)>>2]-j[a>>2]|0)/52|0}function KQ(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,40,b)}function JR(a,b,c){a=a|0;b=b|0;c=c|0;He(a,c,30,b)}function Hf(a){return(j[hb(a)>>2]-j[a>>2]|0)/12|0}function HF(a,b,c,d){jua(a,b,c,qh(q(d*q(65536))))}function Ff(a,b){return oE(zb(a),nb(a),b,0,ne(b))}function Ce(a){return(j[hb(a)>>2]-j[a>>2]|0)/24|0}function Cc(a,b,c){j[a+4>>2]=c;j[a>>2]=b;return a}function CO(a,b){a=eBa(a,b);if(!a){qO(b)}return a}function By(a,b){a=dBa(a,b);if(!a){oO(b)}return a}function Bq(a){return(j[Ob(a)>>2]-j[a>>2]|0)/12|0}function BF(a,b,c){j[a>>2]=b;j[a+4>>2]=c;return a}function Ag(a,b){if(qe(a)){ee(a,b);return}Ue(a,b)}function $M(a,b){a=aya(a,b);if(!a){HQ(b)}return a}function zb(a){if(qe(a)){return j[a>>2]}return a}function yja(a,b){a=a|0;b=b|0;MS(a,b);return a|0}function xI(a,b,c){h[a|0]=k[b|0];h[a+1|0]=k[c|0]}function vR(a,b){h[a|0]=k[b|0];h[a+1|0]=k[b+1|0]}function v6(a,b){a=a|0;b=b|0;return+jF(a-88|0,b)}function ph(a){return j[a+8>>2]!=0|j[a+12>>2]!=0}function mv(a,b,c){a=a|0;b=b|0;c=c|0;PE(c);Cb(a)}function mi(a){return(j[hb(a)>>2]-j[a>>2]|0)/6|0}function mBa(a,b){a=a|0;b=b|0;return pn(a,b,2)|0}function ksa(a){a=a|0;j[a>>2]=0;fsa();return a|0}function kQ(a,b){a=a|0;b=b|0;return Cr(a,b,32)|0}function iM(a,b){zc(a,j[b>>2]);h[a+4|0]=k[b+4|0]}function hj(a,b){a=zU(a,b);if(!a){SA(b)}return a}function ep(a,b,c){h[a+2|0]=c;i[a>>1]=b;return a}function eCa(a,b,c){a=a|0;b=b|0;c=c|0;VBa(a,b,c)}function dfa(a){a=a|0;return n[a+4212>>2]<q(1)|0}function cx(a){j[a+4>>2]=0;j[a+8>>2]=-1;h[a|0]=0}function Yg(a){return(Te(a)|0)!=(0-Te(a+12|0)|0)}function Sfa(a){a=a|0;return n[a+4220>>2]<q(1)|0}function SGa(a,b){a=a|0;b=b|0;return pn(a,b,3)|0}function Nx(a){j[a+24>>2]=l[a+20>>1]<<l[a+22>>1]}function KA(a,b){a=mU(a,b);if(!a){GA(b)}return a}function Jja(a,b){a=a|0;b=b|0;return Cr(a,b,1)|0}function Hm(a){j[a>>2]=0;j[a+4>>2]=0;j[a+8>>2]=0}function CIa(a,b,c){a=a|0;b=b|0;c=c|0;Vb(b,c,48)}function xfa(a){a=a|0;h[a+4202|0]=1;aH(a);$G(a)}function vh(a,b){a=a|0;b=b|0;return pn(a,b,4)|0}function us(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function rCa(a,b){a=a|0;b=b|0;return aCa(a,b)|0}function qJa(a,b){a=a|0;b=b|0;return pJa(a,b)|0}function pd(a){return(j[a+4>>2]-j[a>>2]|0)/24|0}function nj(a){return bb[j[j[a>>2]+36>>2]](a)|0}function ni(a){return(j[a+4>>2]-j[a>>2]|0)/48|0}function n$(a,b){a=a|0;b=b|0;xd(a,b,sd(461668))}function m$(a,b){a=a|0;b=b|0;xd(a,b,sd(461676))}function lT(a,b){a=a|0;b=b|0;ul(a,b);return a|0}function l$(a,b){a=a|0;b=b|0;xd(a,b,sd(461872))}function k$(a,b){a=a|0;b=b|0;xd(a,b,sd(461864))}function jsa(a,b){a=a|0;b=b|0;return esa(a,b)|0}function j$(a,b){a=a|0;b=b|0;xd(a,b,sd(461880))}function is(a,b){a=a|0;b=b|0;Mf(a,b);return a|0}function il(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function ht(a,b,c){b=b-a|0;if(b){Bi(c-b|0,a,b)}}function h$(a,b){a=a|0;b=b|0;xd(a,b,sd(461888))}function g$(a,b){a=a|0;b=b|0;xd(a,b,sd(461896))}function eg(a,b){a=a|0;b=b|0;bE(a,j[a+16>>2]|b)}function eMa(a,b){a=a|0;b=b|0;return TLa(a,b)|0}function e$(a,b){a=a|0;b=b|0;xd(a,b,sd(461904))}function df(a){return(j[a+4>>2]-j[a>>2]|0)/52|0}function dIa(a,b){a=a|0;b=b|0;return WHa(a,b)|0}function d$(a,b){a=a|0;b=b|0;xd(a,b,sd(461912))}function cc(a){return(j[a+4>>2]-j[a>>2]|0)/12|0}function c$(a,b){a=a|0;b=b|0;xd(a,b,sd(461920))}function bMa(a,b){a=a|0;b=b|0;return QLa(a,b)|0}function am(a){return bb[j[j[a>>2]+28>>2]](a)|0}function a$(a,b){a=a|0;b=b|0;xd(a,b,sd(461684))}function _u(a,b,c,d){a=nD(a,b,c,-1,-1);return a}function _j(a){return(j[a+4>>2]-j[a>>2]|0)/33|0}function __(a,b){a=a|0;b=b|0;xd(a,b,sd(461700))}function _W(a){a=a|0;a=Za-a&-16;Za=a;return a|0}function Z_(a,b){a=a|0;b=b|0;xd(a,b,sd(461708))}function X_(a,b){a=a|0;b=b|0;xd(a,b,sd(461748))}function W_(a,b){a=a|0;b=b|0;xd(a,b,sd(461756))}function Vj(a){return(j[a+4>>2]-j[a>>2]|0)/56|0}function V_(a,b){a=a|0;b=b|0;xd(a,b,sd(461764))}function VN(a,b){a=a|0;b=b|0;return pn(a,b,8)|0}function VKa(a,b){a=a|0;b=b|0;return SKa(a,b)|0}function U_(a,b){a=a|0;b=b|0;xd(a,b,sd(461772))}function S_(a,b){a=a|0;b=b|0;xd(a,b,sd(461780))}function Q_(a,b){a=a|0;b=b|0;xd(a,b,sd(461788))}function O_(a,b){a=a|0;b=b|0;xd(a,b,sd(461796))}function Ni(a,b,c){a=a|0;b=b|0;c=c|0;Mma(a,b,c)}function M_(a,b){a=a|0;b=b|0;xd(a,b,sd(461804))}function L_(a,b){a=a|0;b=b|0;xd(a,b,sd(461716))}function L9(a,b){a=a|0;b=b|0;J9(a,K9(ue(12),b))}function K_(a,b){a=a|0;b=b|0;xd(a,b,sd(461724))}function Jfa(a){a=a|0;h[a+4202|0]=1;cH(a);dH(a)}function Ir(a,b,c){a=a|0;b=b|0;c=c|0;dna(a,b,c)}function Iea(a){a=a|0;WG(a);jw(a);h[a+4202|0]=1}function I_(a,b){a=a|0;b=b|0;xd(a,b,sd(461732))}function IGa(a,b){a=a|0;b=b|0;return pGa(a,b)|0}function IAa(a,b){a=a|0;b=b|0;return GAa(a,b)|0}function Hda(a,b){a=a|0;b=b|0;return Fda(a,b)|0}function G_(a,b){a=a|0;b=b|0;xd(a,b,sd(461740))}function GGa(a,b){a=a|0;b=b|0;return oGa(a,b)|0}function Ee(a,b,c){a=a|0;b=b|0;c=c|0;ELa(a,b,c)}function E_(a,b){a=a|0;b=b|0;xd(a,b,sd(461812))}function Dp(a,b){a=a|0;b=b|0;return Se(a,b,0)|0}function D_(a,b){a=a|0;b=b|0;xd(a,b,sd(461820))}function Bj(a){a=a|0;return dE(j[a>>2])<<24>>24}function $_(a,b){a=a|0;b=b|0;xd(a,b,sd(461692))}function zf(a,b){a=a|0;b=b|0;return LKa(a,b)|0}function wL(a){vL(a);Ab(a+27|0,0,255);return a}function ve(a,b,c){if(!(k[a|0]&32)){yu(b,c,a)}}function soa(a,b,c){a=a|0;b=b|0;c=c|0;poa(b,c)}function hO(a,b){a=a|0;b=b|0;return FAa(a,b)|0}function gs(a){return(a>>>0<9?a:a-9|256)&65535}function gf(a,b){a=a|0;b=b|0;return tMa(a,b)|0}function gIa(a){a=a|0;nJa(a);return j[a+12>>2]}function fz(a){a=a|0;return(k[a+1|0]==1?1:2)|0}function bea(a){a=a|0;OG(j[j[a>>2]-12>>2]+a|0)}function bA(a,b){a=a|0;b=b|0;return yMa(a,b)|0}function Yo(a,b){return(p(b,104)+a|0)+484380|0}function V8(a,b,c){a=a|0;b=b|0;c=c|0;U8(a,b,c)}function SX(a,b,c){a=a|0;b=b|0;c=c|0;Cc(a,c,b)}function RQ(a){return j[a>>2]+(j[a+4>>2]<<2)|0}function Qsa(a,b,c){a=a|0;b=b|0;c=c|0;Psa(b,c)}function Qb(a,b,c){a=a|0;b=b|0;c=c|0;ml(a,b,c)}function QS(a,b){a=a|0;b=b|0;return ZLa(a,b)|0}function Pd(a,b){a=a|0;b=b|0;return PKa(a,b)|0}function NS(a,b){a=a|0;b=b|0;return RLa(a,b)|0}function Mya(a,b,c){a=a|0;b=b|0;c=c|0;Iya(b,c)}function Kf(a){return(j[a+4>>2]-j[a>>2]|0)/6|0}function HL(a,b){CL(j[a>>2],b);CL(j[a+4>>2],b)}function Fj(a){return(j[a+4>>2]+j[a>>2]|0)-1|0}function ER(a,b){a=a|0;b=b|0;return SJa(a,b)|0}function Dr(a,b){return(j[a>>2]-j[b>>2]|0)/6|0}function Bn(a){iB(a);j[a+8>>2]=0;j[a>>2]=68484}function Bja(a,b,c){a=a|0;b=b|0;c=c|0;Aja(b,c)}function $m(a,b){a=a|0;b=b|0;return UFa(a,b)|0}function $j(a,b){h[a+4|0]=0;j[a>>2]=b;return a}function zFa(a){a=a|0;iQ(a);return j[a+16>>2]}function yj(a,b){a=a|0;b=b|0;return _D(a,b)|0}function wf(a){j[a>>2]=0;j[a+4>>2]=0;return a}function vu(a,b){a=a|0;b=b|0;return xy(a,b)|0}function ui(a,b){a=a|0;b=b|0;return YT(a,b)|0}function twa(a){a=a|0;Zx(a+288|0);Vo(a+800|0)}function ti(a,b){a=a|0;b=b|0;return US(a,b)|0}function tb(a,b){a=a|0;b=b|0;return gV(a,b)|0}function s3(a){a=a|0;Fq(j[j[a>>2]-12>>2]+a|0)}function rb(a,b){a=a|0;b=b|0;return al(a,b)^1}function rP(a,b,c){a=a|0;b=b|0;c=c|0;KDa(b,c)}function kc(a,b){if(m[a>>2]>b>>>0){j[a>>2]=b}}function ji(a,b){a=a|0;b=b|0;return rb(a,b)|0}function fR(a){h[a+12|0]=k[a+12|0]|2;return a}function dw(a){a=a|0;j[a>>2]=83652;return a|0}function ci(a){return(k[a+31|0]-1&255)>>>0<17}function _sa(a,b,c){a=a|0;b=b|0;c=c|0;v2(a,b)}function Zj(a,b){if(j[a>>2]>(b|0)){j[a>>2]=b}}function Yb(a,b){a=a|0;b=b|0;return Z1(a,b)|0}function Wg(a,b){a=a|0;b=b|0;return ET(a,b)|0}function W3(a,b){a=a|0;b=b|0;return V3(a,b)|0}function Tn(a,b){a=a|0;b=b|0;return eE(a,b)^1}function T3(a,b){a=a|0;b=b|0;return S3(a,b)|0}function Sf(a,b){if(l[a>>1]>b>>>0){i[a>>1]=b}}function RMa(a,b,c,d){a=MMa(a,b,c,d);return a}function R3(a,b){a=a|0;b=b|0;return Q3(a,b)|0}function PMa(a,b,c,d){a=KMa(a,b,c,d);return a}function OMa(a,b,c,d){a=JMa(a,b,c,d);return a}function O3(a,b){a=a|0;b=b|0;return N3(a,b)|0}function NN(a,b){a=a|0;b=b|0;return Zc(a,b)|0}function NL(a,b,c){a=a|0;b=b|0;c=c|0;Msa(b,c)}function M3(a,b){a=a|0;b=b|0;return L3(a,b)|0}function Ll(a,b,c){a=a|0;b=b|0;c=c|0;sha(a,c)}function LK(a,b){if(!(n[a>>2]<=b)){n[a>>2]=b}}function Ii(a,b){a=a|0;b=b|0;return eE(a,b)|0}function Ht(a,b){a=a|0;b=b|0;return Gt(a,b)|0}function Hq(a,b){a=a|0;b=b|0;return _D(a,b)^1}function Hj(a){return j[hb(a)>>2]-j[a>>2]>>11}function H3(a){a=a|0;Kq(j[j[a>>2]-12>>2]+a|0)}function Gc(a,b){a=a|0;b=b|0;return $V(a,b)|0}function Fz(a,b){a=a|0;b=b|0;return cu(a,b)|0}function FP(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function DHa(a,b,c){a=a|0;b=b|0;c=c|0;Ie(b,c)}function D7(a){a=a|0;EF(j[j[a>>2]-12>>2]+a|0)}function Cs(a,b){a=a|0;b=b|0;return sO(a,b)|0}function CK(a){BK(a+20|0);ZJ(a+8|0);bf(a+4|0)}function $N(a,b,c){a=a|0;b=b|0;c=c|0;kha(a,c)}function yaa(a){a=a|0;$F(a,16384);return a|0}function wu(a){return j[Ob(a)>>2]-j[a>>2]>>4}function wi(a){return j[hb(a)>>2]-j[a>>2]>>3}function waa(a){a=a|0;Xv(a,16384);return a|0}function vw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function tn(a){return j[Ob(a)>>2]-j[a>>2]>>1}function t9(a){a=a|0;return XF(j[a+24>>2])|0}function nfa(a,b){a=a|0;b=b|0;return Sh(b)|0}function lw(a){return q(q(a*q(7900))+q(100))}function jd(a){return j[hb(a)>>2]-j[a>>2]>>2}function gu(a){return j[Ob(a)>>2]-j[a>>2]>>5}function fi(a,b,c){a=a|0;b=b|0;c=c|0;ys(a,c)}function ez(a,b,c){a=a|0;b=b|0;c=c|0;cI(a,c)}function eFa(a,b){a=a|0;b=b|0;pp(Ab(b,0,48))}function cfa(a){a=a|0;return q(n[a+4220>>2])}function _g(a){return j[hb(a)>>2]-j[a>>2]>>5}function _f(a){return j[Ob(a)>>2]-j[a>>2]>>2}function Wy(a,b,c){a=a|0;b=b|0;c=c|0;Mf(b,c)}function WA(a,b,c){a=a|0;b=b|0;c=c|0;dV(b,c)}function Rfa(a){a=a|0;return q(n[a+4212>>2])}function Qg(a){return j[j[a+8>>2]>>2]==(a|0)}function QH(a,b,c){a=a|0;b=b|0;c=c|0;hp(b,c)}function Pf(a){return j[hb(a)>>2]-j[a>>2]>>1}function Iq(a,b,c){a=a|0;b=b|0;c=c|0;Nc(b,c)}function DFa(a){a=a|0;iQ(a);return j[a+4>>2]}function Bk(a){return j[kq(a)>>2]-j[a>>2]>>2}function B4(a){a=a|0;return Oa(j[a+60>>2])|0}function Ah(a){return j[hb(a)>>2]-j[a>>2]>>4}function zha(a,b){a=a|0;b=b|0;h[a+4201|0]=b}function wga(a,b,c){a=a|0;b=b|0;c=c|0;wf(a)}function vJ(a){return a>>>0<=255&a>>>0>=251}function sY(a,b){a=a|0;b=b|0;return Ak(b)|0}function qr(a){TG(a);j[a>>2]=56300;return a}function q_(){Nn(461848,vC());return 461848}function ig(a,b,c){return Aa(a|0,b|0,c|0)|0}function hja(a,b){a=a|0;b=b|0;C3(a,i[b>>1])}function hH(a){a=a|0;return q(n[a+4208>>2])}function cm(a){a=a|0;YD(j[a>>2]);return a|0}function Xja(a,b){a=a|0;b=b|0;z3(a,j[b>>2])}function Xia(a,b){a=a|0;b=b|0;lv(a,l[b>>1])}function Wh(a,b){a=a|0;b=b|0;return q(q(0))}function Tz(a){return j[Ob(a)>>2]-j[a>>2]|0}function Te(a){return j[a+4>>2]-j[a>>2]>>11}function Rha(a,b){a=a|0;b=b|0;v3(a,o[b>>3])}function OD(a){TG(a);j[a>>2]=56372;return a}function Ik(a){a=a|0;ov(j[a>>2]);return a|0}function IG(a){return qh(q(KG(a)*q(32768)))}function H4(a,b){a=a|0;b=b|0;return Ig(a)|0}function GL(a,b){i[a+22>>1]=b&7;Nx(a);Ox(a)}function Af(a){return j[hb(a)>>2]-j[a>>2]|0}function Ae(a,b){if(k[a|0]>b>>>0){h[a|0]=b}}function $F(a,b){j[a+4>>2]=j[a+4>>2]&(b^-1)}function zV(a){a=a|0;return j[a+4>>2]!=0|0}function xja(a,b){a=a|0;b=b|0;lv(a,k[b|0])}function w9(a){a=a|0;return+zJ(j[a+24>>2])}function vp(a,b){return j[a>>2]-j[b>>2]>>1}function sb(a){return j[a+4>>2]-j[a>>2]>>2}function pq(a,b){bb[j[j[b>>2]+40>>2]](a,b)}function pj(a,b){bb[j[j[b>>2]+44>>2]](a,b)}function pD(){return(j[j[21215]>>2]?4:1)|0}function oj(a,b){bb[j[j[b>>2]+32>>2]](a,b)}function nv(a){a=a|0;return Eg(a,461864)|0}function nha(a,b){a=a|0;b=b|0;Ab(b,0,2048)}function mKa(a,b){a=a|0;b=b|0;yi(a+12|0,b)}function ly(a){Vd(a+24|0);Od(a+12|0);Od(a)}function hv(a){a=a|0;return Eg(a,461880)|0}function hu(a){$p(a+28|0);jb(a+12|0);gb(a)}function gv(a){a=a|0;return Eg(a,461888)|0}function fg(a){return j[a+4>>2]-j[a>>2]>>3}function er(a){return(a|0)<=65535&(a|0)>=0}function ena(a,b){a=a|0;b=b|0;yi(a+40|0,b)}function de(a){return j[a+4>>2]-j[a>>2]>>5}function bc(a){return j[a+4>>2]-j[a>>2]>>1}function aba(a,b){a=a|0;b=b|0;$aa(a,b+4|0)}function Yu(a){a=a|0;return Eg(a,461912)|0}function YH(a,b){a=a|0;b=b|0;lv(a,j[b>>2])}function Y3(a){a=a|0;return Eg(a,461684)|0}function Xt(a){a=a|0;return Eg(a,461872)|0}function Xk(a){gb(a+36|0);Ud(a+24|0);kl(a)}function Xc(a){return j[a+4>>2]-j[a>>2]>>4}function Vu(a){a=a|0;return Eg(a,461920)|0}function Pja(a,b){a=a|0;b=b|0;Tea(a,b+4|0)}function PG(a){return q(q(a*q(96))+q(-96))}function P8(a,b){a=a|0;b=b|0;return b-a>>3}function Ms(a,b){return j[a>>2]-j[b>>2]>>2}function Lj(a){return j[a+8>>2]&2147483647}function Hja(a,b){a=a|0;b=b|0;Mf(a,b+36|0)}function Gpa(a){a=q(a);return xpa(Sd(a))|0}function FL(a,b){h[a+21|0]=b&3;Nx(a);Ox(a)}function D3(a){a=a|0;return Eg(a,461700)|0}function yc(a,b){return j[a>>2]+p(b,24)|0}function xl(a,b){return j[a>>2]+(b<<11)|0}function vn(a,b,c){return l[b>>1]<l[c>>1]}function vm(a){return j[j[a+48>>2]+12>>2]}function te(a,b){return j[a>>2]+p(b,52)|0}function tc(a){return j[a+4>>2]-j[a>>2]|0}function sO(a,b){return Gn(a,zb(b),nb(b))}function qZ(a,b){a=a|0;b=b|0;Mf(a,b+16|0)}function l6(a,b){a=a|0;b=b|0;dF(a-88|0,b)}function je(a){j[a>>2]=j[a>>2]+2;return a}function hc(a,b){a=a|0;b=b|0;Nn(a,b+28|0)}function fl(a,b){return j[a>>2]+p(b,56)|0}function bn(a){return l[a+480190>>1]<3999}function as(a,b,c){return ywa(b,c)>>>31|0}function aL(a){j[a>>2]=j[a>>2]-4;return a}function Zc(a,b){return j[a>>2]+p(b,12)|0}function WF(a,b){a=a|0;b=b|0;Mf(a,b+12|0)}function Vn(a){a=a|0;og(a+8|0);return a|0}function TL(a){j[a>>2]=j[a>>2]-2;return a}function Rn(a){a=a|0;og(a+4|0);return a|0}function Rl(a,b,c){Zh(a,b,b+c|0);return a}function Qha(a){a=a|0;DR(a,80,150,80,255)}function PI(a,b,c){return Jla(b,c)>>>31|0}function Nv(a){a=a|0;gr(a+8|0);return a|0}function NI(a,b){cl(a,o[b>>3],-o[b+8>>3])}function NG(a){a=a|0;Ab(a+4296|0,0,81928)}function Lu(a){a=a|0;EY(a+8|0);return a|0}function Id(a){j[a>>2]=j[a>>2]+4;return a}function Gk(a){a=a|0;return ZD(j[a>>2])|0}function G6(a,b){a=a|0;b=b|0;sF(a-88|0,b)}function Fy(a,b){return j[a>>2]+p(b,20)|0}function F6(a,b){a=a|0;b=b|0;rF(a-88|0,b)}function En(a,b){return j[a>>2]-j[b>>2]|0}function Eea(a){a=a|0;return j[a+4260>>2]}function DP(a,b){return j[a>>2]+p(b,33)|0}function DA(a){return(k[a+24|0]&16)>>>4|0}function Cd(a,b){j[a>>2]=j[b>>2];return a}function C5(a){a=a|0;if(a){TE(a);Fd(a,a)}}function Br(a,b,c){return i[b>>1]<i[c>>1]}function zC(){td(463360);j[115840]=66640}function z6(a,b){a=a|0;b=+b;mF(a-88|0,b)}function yha(a){a=a|0;return k[a+4201|0]}function yC(){td(463368);j[115842]=66804}function xn(a){return p(Op(a),be(a))&255}function xha(a){a=a|0;return k[a+4202|0]}function xb(a,b){return j[a>>2]+(b<<2)|0}function xC(){td(463440);j[115860]=66968}function wc(a,b){return j[a>>2]+p(b,6)|0}function uk(a,b){return j[a>>2]+(b<<3)|0}function ub(a){j[j[a>>2]+4>>2]=j[a+4>>2]}function rza(a,b){a=a|0;b=b|0;Cc(a,b,10)}function qH(a){return(k[a+24|0]&8)>>>3|0}function pZ(a,b){a=a|0;b=b|0;Eb(a,62656)}function pG(a){return(zb(a)+nb(a)|0)-1|0}function oZ(a,b){a=a|0;b=b|0;Mu(a,62664)}function nZ(a,b){a=a|0;b=b|0;Eb(a,62684)}function mf(a){a=a|0;return!j[a+16>>2]|0}function mZ(a,b){a=a|0;b=b|0;Mu(a,62692)}function kr(a,b){j[a+24>>2]=j[a+24>>2]+b}function kB(a,b){Hb(a,b);Hb(a+4|0,b+4|0)}function jg(a,b){j[a+8>>2]=b|-2147483648}function iB(a){j[a+4>>2]=0;j[a>>2]=68428}function ffa(a){a=a|0;if(a){rr(a);Cb(a)}}function al(a,b){return j[a>>2]==j[b>>2]}function ad(a){return j[a>>2]==j[a+4>>2]}function ac(a,b){return j[a>>2]+(b<<1)|0}function _b(a,b){return j[a>>2]+(b<<4)|0}function Xda(a){a=a|0;return(a|0)==277|0}function Xaa(a){a=a|0;cG(a,2);return a|0}function Ps(a){a=a|0;return j[a>>2]+14|0}function Oaa(a){a=a|0;cG(a,8);return a|0}function Lf(a){a=a|0;return Ld(k[a|0])|0}function K6(a){a=a|0;return Nv(a-88|0)|0}function Jj(a){return l[vm(a)+480188>>1]}function FJa(a,b){a=a|0;b=b|0;Cc(a,b,44)}function Em(a){a=a|0;return AK(k[a|0])|0}function EKa(a,b){a=a|0;b=b|0;Cc(a,b,11)}function E6(a,b){a=a|0;b=+b;qF(a-88|0,b)}function DDa(a,b){a=a|0;b=b|0;Cc(a,b,17)}function Cpa(a){a=+a;return wpa(zd(a))|0}function CC(){td(463312);j[115828]=65816}function BC(){td(463344);j[115836]=66312}function B6(a,b){a=a|0;b=+b;oF(a-88|0,b)}function AC(){td(463352);j[115838]=66476}function $z(a,b){return j[a>>2]+(b<<5)|0}function $l(a){return(a|0)==32|a-9>>>0<5}function vK(a,b){return(Uj(a,b)|0)!=255}function st(a,b){return j[a>>2]<j[b>>2]}function rd(a,b){return m[a>>2]<m[b>>2]}function pea(a){a=a|0;return-2013527448}function pQ(a,b){j[a>>2]=j[a>>2]+p(b,6)}function or(a){a=a|0;if(a){we(a);Cb(a)}}function oA(a,b){a=a|0;b=b|0;return b|0}function nt(a){a=a|0;return wz(bc(a))|0}function mH(a,b){return n[a>>2]<n[b>>2]}function ky(a,b,c){if(b){Ab(a,gg(c),b)}}function jh(a,b,c){Nc(a,b);Nc(a+12|0,c)}function ZC(a,b){a=a|0;b=b|0;gj(a,1,45)}function YO(a,b){j[a>>2]=j[a>>2]+(b<<2)}function YC(a,b){a=a|0;b=b|0;gD(a,1,45)}function Vya(a,b){a=a|0;b=b|0;Cc(a,b,5)}function PJ(a,b){return o[a>>3]<o[b>>3]}function Nt(a,b){a=a|0;b=b|0;Cc(a,b,32)}function Ls(a){a=+a;return ZCa(zd(a))|0}function GLa(a,b){a=a|0;b=b|0;i[b>>1]=0}function Fd(a,b){if(!j[a+80>>2]){Cb(b)}}function Cca(a){a=a|0;return j[a+16>>2]}function Bra(a,b){a=a|0;b=b|0;cl(b,0,0)}function $h(a){j[a+4>>2]=0;j[a+8>>2]=-1}function y6(a){a=a|0;return+lF(a-88|0)}function wfa(a){a=a|0;return-284078960}function wea(a){a=a|0;return 302837129}function vba(a,b){a=a|0;b=b|0;rba(a,b)}function uwa(a){a=a|0;AM(a);return a|0}function ura(a,b){a=a|0;b=b|0;tra(a,b)}function uU(a){a=a|0;return j[a+12>>2]}function tEa(a){a=a|0;return k[a+40|0]}function oQ(a,b){a=a|0;b=b|0;Ir(a,0,b)}function m_(a){a=a|0;tY(j[j[a>>2]>>2])}function lfa(a){a=a|0;if(a){Cb(kw(a))}}function lB(a,b){aC(a,b);j[a>>2]=71676}function kfa(a){a=a|0;return-281111764}function j4(a){a=a|0;return j[a+20>>2]}function isa(a){a=a|0;$ra();return a|0}function ik(a){return p(j[a>>2],xn(a))}function hA(a){hb(a);return 2147483647}function efa(a){a=a|0;return-271958638}function dc(a){j[j[a+8>>2]>>2]=j[a>>2]}function be(a){return k[a+34|0]&64?2:1}function _ra(a){a=a|0;Zra();return a|0}function _Ha(a,b){a=a|0;b=b|0;yHa(b,a)}function ZT(a){a=a|0;return j[a+24>>2]}function YL(a,b){j[a+4>>2]=b;j[a>>2]=b}function Xv(a,b){j[a+4>>2]=j[a+4>>2]|b}function Wma(a,b){a=a|0;b=b|0;Lla(a,b)}function Vea(a){a=a|0;return-620920304}function Vda(a,b){a=a|0;b=b|0;return 3}function Uda(a,b){a=a|0;b=b|0;return 2}function Tfa(a){a=a|0;return-270114148}function TFa(a){a=a|0;return q(RFa(a))}function Sr(a){return(a|0)<=-1?0-a|0:a}function SF(a){return a?(a|0)==2?3:2:1}function Pr(a){a=a|0;return 2147483647}function Mga(a){a=a|0;if(a){Cb(qw(a))}}function Lza(a,b){a=a|0;b=b|0;zza(b,a)}function Li(a,b){return zb(a)+(b<<2)|0}function Lga(a){a=a|0;return 542066252}function Ld(a){return(a-1&255)>>>0<120}function Gea(a){a=a|0;if(a){Cb(iw(a))}}function Ffa(a){a=a|0;if(a){Cb(mw(a))}}function Fea(a){a=a|0;return-275227023}function F9(a){a=a|0;return+o[a+16>>3]}function Efa(a){a=a|0;return-285139079}function Cha(a){a=a|0;if(a){Cb(xw(a))}}function C6(a){a=a|0;return+pF(a-88|0)}function Bta(a,b){a=a|0;b=b|0;sta(a,b)}function A6(a){a=a|0;return+nF(a-88|0)}function zt(a,b){a=a|0;b=b|0;ILa(b,a)}function xO(a,b){if(!iBa(a,b)){qO(b)}}function ww(a,b){a=a|0;b=b|0;return 1}function vga(a,b,c){a=a|0;b=b|0;c=c|0}function vF(a){j[a>>2]=84600;return a}function ut(a){return(k[a+16|0]&5)!=0}function sz(a){a=a|0;return j[a+8>>2]}function qe(a){return k[a+11|0]>>>7|0}function qA(a){return k[a+22|0]>>>7|0}function ot(a){a=a|0;return j[a+4>>2]}function og(a){a=a|0;pv(a);return a|0}function nn(a,b){a=a|0;b=b|0;MLa(b,a)}function nIa(a){a=a|0;return k[a+8|0]}function kM(a){a=a|0;aO(a);return a|0}function jga(a,b){a=a|0;b=b|0;is(a,b)}function jCa(a){a=a|0;return HBa(a)|0}function fua(a){a=a|0;return _ta(a)|0}function eE(a,b){return UD(a)^UD(b)^1}function dp(a){a=a|0;Os(a);return a|0}function cn(a,b){i[a+8>>1]=b;return a}function bv(a){a=a|0;if(wD(a)){Cb(a)}}function bk(a){a=a|0;Ys(a);return a|0}function bg(a,b){a=a|0;b=b|0;wMa(a,b)}function bC(a,b){return k[a|0]<k[b|0]}function _y(a){return j[a+1304496>>2]}function _D(a,b){return TD(a)^TD(b)^1}function Yna(a){a=a|0;return Rna(a)|0}function YB(a){return bY(zb(a),nb(a))}function Y2(a){a=a|0;return MD(a,0)|0}function XF(a){return l[a+1074438>>1]}function X2(a){a=a|0;return MD(a,1)|0}function Vx(a,b,c,d,e){qua(a,b,c,d,e)}function VD(a){a=a|0;Hu(a);return a|0}function U2(a){a=a|0;return JD(a,0)|0}function S2(a){a=a|0;return JD(a,1)|0}function Rs(a){a=a|0;return yb(a,1)^1}function QMa(a,b,c){return LMa(a,b,c)}function Op(a){return h[a+34|0]&1?2:1}function Mt(a){return k[a+21|0]>>>7|0}function Lq(a,b){a=a|0;b=b|0;return-1}function Hu(a){a=a|0;iq(a);return a|0}function GG(a,b){a=a|0;b=b|0;return 0}function Ft(a,b){a=a|0;b=b|0;qMa(b,a)}function Fe(a,b){j[a+4>>2]=b;return a}function Fb(a){return $z(a,k[a+16|0])}function $y(a,b){a=a|0;b=b|0;XEa(a,b)}function zs(a){return j[hb(a)>>2]<<5}function ys(a,b){a=a|0;b=b|0;Mf(a,b)}function yg(a){return j[a+4>>2]-32|0}function vxa(a,b){a=a|0;b=b|0;txa(b)}function uj(a,b){a=a|0;b=b|0;L0(a,b)}function tS(a,b){a=a|0;b=b|0;sS(a,b)}function sZ(a){a=a|0;return h[a+8|0]}function rZ(a){a=a|0;return h[a+9|0]}function qm(a,b){a=a|0;b=b|0;eY(a,b)}function pI(a,b){df(a);pJ(a,b);lI(a)}function nKa(a){a=a|0;return tp(a)|0}function mt(a){return j[a+4>>2]-24|0}function kKa(a){a=a|0;return Sp(a)|0}function hKa(a){a=a|0;return Dz(a)|0}function gR(a,b){tc(a);BS(a,b);ap(a)}function dGa(a){a=a|0;return _y(a)|0}function az(a,b){Kf(a);WP(a,b);JP(a)}function YP(a,b){sb(a);KL(a,b);xg(a)}function YF(a){return j[a+4>>2]-48|0}function Wya(a){a=a|0;return Z8(a)|0}function WL(a,b){de(a);RL(a,b);nu(a)}function VF(a){return j[a+4>>2]-12|0}function Uea(a){a=a|0;j[a+4224>>2]=0}function Tt(a,b){tc(a);wA(a,b);ap(a)}function Rc(a,b){return xl(a+12|0,b)}function RN(a,b){a=a|0;b=b|0;Ut(a,b)}function Pt(a,b){sb(a);kA(a,b);xg(a)}function On(a,b){a=a|0;b=b|0;K0(a,b)}function LG(a){j[a>>2]=0;j[a+4>>2]=0}function KBa(a,b){a=a|0;b=b|0;JBa(b)}function Iqa(a){a=a|0;return jj(a)|0}function Il(a){j[a+4>>2]=j[a+4>>2]+1}function Gw(a,b,c){return Sja(a,b,c)}function Bw(a,b){sb(a);ZP(a,b);xg(a)}function Bp(a,b){bc(a);ZS(a,b);Bt(a)}function Bla(a){a=a|0;return mh(a)|0}function BN(a){return j[a+4>>2]-56|0}function AK(a){return(a+5&255)>>>0<2}function zc(a,b){j[a>>2]=b;return a}function xe(a){return j[a+24620>>2]}function vLa(a,b){a=a|0;b=b|0;zh(b)}function tW(a){a=a|0;return ZF(a)|0}function sA(a){return k[a+21|0]&127}function rA(a){return k[a+22|0]&127}function oi(a,b){return p(b,12)+a|0}function mY(a){a=a|0;return ue(a)|0}function mT(a){a=a|0;return iT(a)|0}function mM(a,b){return So(a,0-b|0)}function m9(a){a=a|0;return ut(a)|0}function lh(a,b,c){if(c){Vb(a,b,c)}}function jra(a,b){a=a|0;b=b|0;Vd(b)}function jA(a){h[a+2|0]=0;i[a>>1]=0}function fc(a,b){return j[a>>2]+b|0}function fP(a){a=a|0;return Ps(a)|0}function fA(a){a=a|0;return gT(a)|0}function dra(a,b){a=a|0;b=b|0;Bs(b)}function bEa(a,b){a=a|0;b=b|0;wP(b)}function Zm(a,b,c){return vn(a,b,c)}function WV(a){a=a|0;return hf(a)|0}function Us(a){a=a|0;return Rg(a)|0}function Tr(a){return Ao(a)<<24>>24}function TB(a){a=a|0;return j[a>>2]}function Rsa(a,b){a=a|0;b=b|0;dl(b)}function Ri(a){return j[a+4>>2]-4|0}function Pe(a,b,c){return kz(a,b,c)}function Oqa(a,b){a=a|0;b=b|0;Im(b)}function Nya(a,b){a=a|0;b=b|0;ly(b)}function Nma(a,b){a=a|0;b=b|0;Xk(b)}function Mb(a){return Qe(j[a+4>>2])}function MC(a,b){ul(j[a>>2],h[b|0])}function L4(a){a=a|0;return A8(a)|0}function Kma(a,b){a=a|0;b=b|0;Jf(b)}function KAa(a){a=a|0;return+HAa(a)}function Fl(a,b,c){if(c){Bi(a,b,c)}}function Ev(a){return!Yc(a,84676,6)}function BU(a){a=a|0;return dd(a)|0}function AA(a){a=a|0;return Of(a)|0}function zk(a){pm(a);j[a>>2]=71308}function uW(a){a=a|0;hn(a,1,10956)}function td(a){iB(a);j[a>>2]=63012}function sj(a,b){a=a|0;b=b|0;Db(a)}function sV(a,b){a=a|0;b=b|0;hu(b)}function sT(a,b){a=a|0;b=b|0;jA(b)}function qq(a,b){a=a|0;b=b|0;Me(a)}function pV(a,b){a=a|0;b=b|0;nV(b)}function pS(a,b){a=a|0;b=b|0;Vz(b)}function oq(a){td(a);j[a>>2]=63480}function oh(a,b){Cc(a,zb(b),nb(b))}function nm(a,b){j[a+1304560>>2]=b}function mg(a,b){j[a>>2]=j[a>>2]|b}function mS(a,b){a=a|0;b=b|0;jb(b)}function jr(a){return ce(a,-1)?0:a}function i6(a,b){a=a|0;b=b|0;Cb(b)}function gn(a,b){a=a|0;b=b|0;Re(b)}function ai(a,b){return(b<<13)+a|0}function _x(a,b){a=a|0;b=b|0;qs(b)}function Yy(a,b){a=a|0;b=b|0;Ts(b)}function Wj(a,b){rn(a,b,j[b+4>>2])}function Vz(a){h[a|0]=0;h[a+1|0]=0}function Vh(a){a=a|0;h[a+4202|0]=0}function VC(a){return Eg(a,461756)}function Ur(a,b){return a<<8|b}



function UC(a){return Eg(a,461748)}function TA(a,b){a=a|0;b=b|0;Bl(b)}function Ss(a,b){a=a|0;b=b|0;Jz(b)}function Rg(a){return j[a>>2]+16|0}function RC(a){return Eg(a,461772)}function Qh(a){return ad(a+36|0)^1}function QC(a){return Eg(a,461764)}function Mv(a){a=a|0;h[a+6152|0]=0}function MK(a,b,c){hpa(a,b-a>>2,c)}function Ly(a,b){a=a|0;b=b|0;Oe(b)}function GD(a,b){a=a|0;b=b|0;qb(b)}function FW(a,b){a=a|0;b=b|0;IC(b)}function Bc(a,b){qs(a);zc(a+4|0,b)}function ym(a){wg(a+4|0);return a}function yf(a){j[a>>2]=j[a>>2]+16}function yX(a){a=a|0;return 71283}function xX(a){a=a|0;return 71320}function vy(a,b){Nc(a,b);return a}function uX(a){a=a|0;return 71832}function uO(a,b){return(b<<4)+a|0}function tH(a){return a+1074328|0}function se(a){return j[Rb(a)>>2]}function rDa(a){a=a|0;Oy(a);Cb(a)}function qi(a){j[a>>2]=1;return a}function q3(a){a=a|0;return 56088}function pl(a,b){Ie(a,b);return a}function oza(a){a=a|0;iP(a,65535)}function mj(a,b,c){b$(a+24|0,b,c)}function me(a){return df(a)&65535}function lDa(a){a=a|0;Ny(a);Cb(a)}function kS(a,b){return Mz(a,b,7)}function jS(a){return k[a+1|0]==1}function hS(a,b){return pn(a,b,7)}function gfa(a){a=a|0;rr(a);Cb(a)}function fk(a){j[a>>2]=j[a>>2]+24}function dn(a){j[a>>2]=2;return a}function dN(a,b){return Mz(a,b,4)}function cw(a,b){return UI(a,b)^1}function cr(a,b,c,d){iua(a,b,c,d)}function ck(a){j[a>>2]=0;return a}function bl(a){i[a>>1]=0;return a}function _s(a,b){return Dd(a,b)^1}function _m(a){j[a>>2]=j[a>>2]+12}function Yt(a){return h[a+24|0]&1}function Wv(a){return a+1304500|0}function Ub(a,b){return zb(a)+b|0}function Rm(a,b,c,d){lua(a,b,c,d)}function Qx(a){j[a>>2]=j[a>>2]+32}function Oc(a,b){return(b<<1)+a|0}function NX(a){a=a|0;return 70553}function Lb(a){return Qe(j[a>>2])}function LX(a){a=a|0;return 70632}function Ig(a){return a-48>>>0<10}function Hx(a){j[a>>2]=j[a>>2]+52}function Hba(a){a=a|0;dw(a);Cb(a)}function Fr(a,b,c){zka(a,b-a|0,c)}function Bm(a){return a+1074324|0}function Be(a,b){return(b<<2)+a|0}function AO(a,b){return pn(a,b,5)}function ze(a,b){j[a>>2]=j[b>>2]}function yz(a){ni(a);mR(a);kR(a)}function yG(a){a=a|0;fw(a);Cb(a)}function wt(a,b){return NKa(a,b)}function wp(a){bc(a);vS(a);Bt(a)}function wl(a){Pf(a);bc(a);Pf(a)}function wk(a){Ah(a);Xc(a);Ah(a)}function wN(a){Tm(a);Vj(a);Tm(a)}function wC(a){Bk(a);sb(a);Bk(a)}function vP(a){sb(a);uP(a);xg(a)}function vI(a){Kf(a);XP(a);JP(a)}function tQ(a,b){return yCa(a,b)}function sh(a){Ce(a);pd(a);Ce(a)}function rJ(a){Mi(a);df(a);Mi(a)}function qh(a){return spa(Sd(a))}function pw(a,b){return Dga(a,b)}function pr(a){a=a|0;we(a);Cb(a)}function pp(a){return Ab(a,0,48)}function kk(a){j[a>>2]=j[a>>2]+6}function ju(a){a=a|0;iq(a);Cb(a)}function jP(a,b){Vb(a,b+4|0,256)}function iz(a,b){return pCa(a,b)}function ib(a){O(a|0)|0;AX();z()}function ft(a){mi(a);Kf(a);mi(a)}function es(a){sb(a);VL(a);xg(a)}function eQ(a,b){return OEa(a,b)}function di(a){return dua(Sd(a))}function cN(a){return k[a|0]<129}function bd(a){return j[a>>2]!=0}function aq(a){de(a);oB(a);nu(a)}function af(a){jd(a);sb(a);jd(a)}function _r(a){tc(a);JS(a);ap(a)}function Zp(a){wi(a);fg(a);wi(a)}function Yj(a){return SBa(zd(a))}function YQ(a){nl(a);ni(a);nl(a)}function Xh(a){sb(a);_P(a);xg(a)}function Xf(a){j[a>>2]=j[a>>2]+1}function Rk(a,b){return Hfa(a,b)}function RJ(a,b){return ioa(a,b)}function PO(a){_o(a);_o(a);JO(a)}function OH(a){Te(a);IH(a);HH(a)}function ND(a){a=a|0;Jk(a);Cb(a)}function MH(a){sb(a);FH(a);xg(a)}function Lh(a){Hf(a);cc(a);Hf(a)}function KD(a){a=a|0;Wn(a);Cb(a)}function Jx(a){j[a>>2]=j[a>>2]+8}function IR(a){bc(a);AR(a);Bt(a)}function GX(a,b){a=a|0;b=b|0;z()}function Eu(a){a=a|0;Fu(a);Cb(a)}function Er(a){return vJ(k[a|0])}function Dl(a){_g(a);de(a);_g(a)}function CP(a){jl(a);_j(a);jl(a)}function CH(a){Hj(a);Te(a);Hj(a)}function Bz(a,b){return zJa(a,b)}function Ax(a){h[a|0]=0;return a}function Ap(a){Af(a);tc(a);Af(a)}function $J(a){return Foa(Sd(a))}function zba(a){a=a|0;Cb(fw(a))}function wd(a,b){return xl(a,b)}function su(a){QV(a,iD(ue(12)))}function si(a,b,c){He(a,c,13,b)}function rq(a){a=a|0;return 127}function rm(a){return a<<24>>24}function rj(a,b,c){Cc(a,b,1<<c)}function rh(a){return de(a)&255}function re(a,b){return Df(a,b)}function oo(a){i[a+480214>>1]=0}function ok(a,b){return dA(a,b)}function ofa(a){a=a|0;Cb(kw(a))}function hC(a,b){return BY(a,b)}function gi(a,b){return $z(a,b)}function eA(a,b){return jT(a,b)}function dl(a){gb(a+12|0);ff(a)}function dJ(a,b){return aJ(a,b)}function Yl(a,b){return g1(a,b)}function Yd(a,b){return P4(a,b)}function Ufa(a){a=a|0;Cb(rr(a))}function Tc(a,b){return kT(a,b)}function TY(a){a=a|0;gb(461976)}function SN(a,b){return ei(b,a)}function Ru(a,b){return Ze(a,b)}function Rda(a){a=a|0;Cb(lr(a))}function Rd(a){a=a|0;return a|0}function RY(a){a=a|0;pc(461992)}function Pi(a){return!j[a+4>>2]}function PY(a){a=a|0;gb(462008)}function Nga(a){a=a|0;Cb(qw(a))}function NY(a){a=a|0;pc(462024)}function Mm(a){return Vi(zd(a))}function LY(a){a=a|0;gb(462040)}function Ks(a,b){return WO(a,b)}function Je(a){gb(a+20|0);gb(a)}function JY(a){a=a|0;pc(462056)}function J6(a){a=a|0;uF(a-88|0)}function Im(a){gb(a+12|0);gb(a)}function Ib(a,b){return te(a,b)}function Hea(a){a=a|0;Cb(iw(a))}function HY(a){a=a|0;gb(462072)}function Gfa(a){a=a|0;Cb(mw(a))}function FY(a){a=a|0;pc(462088)}function Ep(a,b){return cA(a,b)}function Dha(a){a=a|0;Cb(xw(a))}function Dea(a){a=a|0;return 13}function Ch(a,b){return a>>>b&1}function Bo(a){Ud(a+12|0);iL(a)}function zM(a){return a+4896|0}function yt(a){VLa(a);return a}function wba(){return 19465728}function wX(a){a=a|0;Cb(Fu(a))}function vX(a){a=a|0;Cb(iq(a))}function vH(a){uga(a);return a}function uZ(a){a=a|0;Cb(mC(a))}function uH(a){tga(a);return a}function uF(a){a=a|0;Cb(Nv(a))}function tZ(a){a=a|0;Cb(lC(a))}function s_(a){a=a|0;Cb(sC(a))}function q8(a){a=a|0;Cb(QF(a))}function ny(a){$ya(a);return a}function n3(a){a=a|0;Cb(VD(a))}function m8(a){a=a|0;Cb(NF(a))}function l3(a){a=a|0;Cb(pv(a))}function kE(){return(Ma()|0)>0}function kC(a){a=a|0;Cb(Lu(a))}function jp(a){uGa(a);return a}function jE(a){a=a|0;Cb(og(a))}function i4(a){a=a|0;Cb(Jk(a))}function d4(a){a=a|0;Cb(Wn(a))}function cJ(a,b,c){Fx(a,b,c,1)}function bw(a){Kaa(a);return a}function a_(a){a=a|0;Cb(qC(a))}function Xr(a){return a>>>27^a}function WO(a,b){return b-a>>2}function Td(a,b){h[a|0]=k[b|0]}function TZ(a){a=a|0;Cb(JC(a))}function Ry(a){pEa(a);return a}function Qxa(a){a=a|0;return 9}function PU(a){a=a|0;Cb(PA(a))}function PE(a){return a>>>0>16}function Ow(a){Hka(a);return a}function OG(a){a=a|0;Cb(Hd(a))}function Nb(a,b){j[a+100>>2]=b}function LU(a){a=a|0;Cb($t(a))}function Kq(a){a=a|0;Cb(Vn(a))}function Kc(a,b){_X(a,b,uD(b))}function Ij(a){kja(a);return a}function HX(a){a=a|0;Cb(Hu(a))}function Fq(a){a=a|0;Cb(Rn(a))}function EF(a){a=a|0;Cb(Xe(a))}function Dx(a,b){return b-a>>1}function Dfa(a){a=a|0;return 6}function C8(a){a=a|0;Cb(hr(a))}function yN(a,b){Xya(a,b)}



function uN(a){Yya(a,j[a>>2])}function th(a){return ad(a)^1}function tM(a,b){Ab(a,0,b<<2)}function rs(a){return a+256|0}function rk(a){return!j[a>>2]}function ri(a){gA(a);return a}function qn(a){return a>>>0<5}function nx(a){Sm(a);return a}function mx(a){LA(a);return a}function mn(a){Wz(a);return a}function kp(a){HS(a);return a}function kP(a){a=a|0;return 7}function iD(a){n1(a);return a}function gE(a){a=a|0;return-1}function cj(a,b,c){pMa(a,b,c)}function bq(a){a=a|0;return 4}function bS(a,b,c){MKa(a,b,c)}function ae(a){a=a|0;return 1}function aW(a){a=a|0;return 3}function Zq(a,b,c){Pfa(a,b,c)}function Ys(a){ck(a);return a}function Wt(a){Vt(a);return a}function Wk(a,b){j[a+32>>2]=b}function VM(a){zxa(a,j[a>>2])}function US(a,b){return b-a|0}function Ti(a){return bd(a)^1}function Sm(a){Wx(a);return a}function Sh(a){return $b(a,1)}function Sb(a){a=a|0;return 0}function Pb(a,b){return a+b|0}function Oz(a,b,c){cga(a,b,c)}function Mw(a,b,c){Ifa(a,b,c)}function Mg(a){UK(a);return a}function Ky(a,b,c){_Ca(a,b,c)}function Km(a,b){j[a+36>>2]=b}function II(a){a=a|0;return 5}function Ge(a,b){i[a+28>>1]=b}function GM(a){Dwa(a,j[a>>2])}function GI(a){Eka(a,j[a>>2])}function Av(a){y4(a);return a}function Aq(a,b){j[a+72>>2]=b}function AR(a){DJa(a,j[a>>2])}function $d(a){a=a|0;return 2}function zq(a,b){Nn(a,b+4|0)}function zg(a){return a+20|0}function xba(){return 327684}function xN(a,b){He(a,b,8,2)}function xA(a){wA(a,j[a>>2])}function wF(a){j[a>>2]=84576}function vS(a){ZS(a,j[a>>2])}function up(a){j[a>>2]=76736}function uP(a){kA(a,j[a>>2])}function ru(a,b){nB(a,ud(b))}function rD(a,b,c){e2(a,b,c)}function qJ(a){pJ(a,j[a>>2])}function pt(a,b){Ce(a);Ce(a)}function ps(a,b){dy(a,ud(b))}function pm(a){j[a>>2]=71344}function oB(a){tV(a,j[a>>2])}function mo(a,b){n[a+8>>2]=b}function mR(a){aR(a,j[a>>2])}function lS(a,b){Af(a);Af(a)}function kq(a){return a+16|0}function ko(a,b){n[a+4>>2]=b}function jt(a,b){mi(a);mi(a)}function jq(a,b,c){Cc(a,b,c)}function jo(a,b){h[a+36|0]=b}function jI(a,b){Mi(a);Mi(a)}function jG(a){j[a>>2]=83824}function hT(){B2();f3();TI()}function gc(a,b){a=a|0;b=b|0}function gC(a,b){Bk(a);Bk(a)}function eu(a,b){wi(a);wi(a)}function el(a,b){hb(b);hb(a)}function ee(a,b){j[a+4>>2]=b}function dr(a){j[a>>2]=84104}function bm(a,b){Hf(a);Hf(a)}function _P(a){ZP(a,j[a>>2])}function _L(a,b){YL(a,Mb(b))}function ZL(a,b){YL(a,Lb(b))}function Ym(a,b){j[a+8>>2]=b}function YJ(a){XJ(a,j[a>>2])}function XP(a){WP(a,j[a>>2])}function Wp(a,b){_g(a);_g(a)}function Vw(a,b){h[a+37|0]=b}function VL(a){KL(a,j[a>>2])}function Uw(a,b){h[a+38|0]=b}function Ue(a,b){h[a+11|0]=b}function TG(a){j[a>>2]=56200}function SL(a){RL(a,j[a>>2])}function Rt(a,b){Pf(a);Pf(a)}function Oj(a,b){jd(a);jd(a)}function Ob(a){return a+12|0}function Ml(a,b){Ah(a);Ah(a)}function LO(a,b,c){rw(a,b,c)}function JS(a){BS(a,j[a>>2])}function JF(a){d8(a,j[a>>2])}function IH(a){DH(a,j[a>>2])}function FH(a){AH(a,j[a>>2])}function EC(a){eC(a,j[a>>2])}function Ck(a){return a+32|0}function BJ(a){return a+80|0}function $K(a){_K(a,j[a>>2])}function ye(a,b,c){Bsa(b,c)}function yP(a,b,c){ZDa(b,c)}function xo(a,b,c){zoa(b,c)}function vo(a){Ab(a,0,8192)}function pza(){return 65534}function pi(a){return a+3|0}function mA(a,b){Cc(a,b,22)}function ln(a,b,c){CLa(b,c)}function kg(){oc(70540);z()}function it(a,b,c){HIa(b,c)}function hb(a){return a+8|0}function gg(a){return a&255}function fy(a){j[a+12>>2]=0}function dj(a,b){h[a+3|0]=b}function bx(a,b,c){Oma(b,c)}function bT(a,b){Cc(a,b,20)}function Zi(a,b,c){oFa(b,c)}function XQ(a,b,c){yIa(b,c)}function Vo(a){Ab(a,0,4096)}function Rb(a){return a+4|0}function Pl(){Ci(70540);z()}function Pc(a){return a+1|0}function PB(){Ci(70957);z()}function KJ(a){Ab(a,0,1024)}function Jc(){oc(70957);z()}function GIa(){return 65535}function Es(a,b,c){bBa(b,c)}function Ec(a){return!nb(a)}function CX(){return 463732}function Bf(a){return a+2|0}function BH(a,b,c){jha(b,c)}function AE(){return 458400}function $o(a,b,c){MCa(b,c)}function zi(a,b,c){CB(b,c)}function xg(a){jd(a);sb(a)}function xK(a){ox(a,se(a))}function wg(a){Ap(a);XS(a)}function wb(a){Hl(j[a>>2])}function wS(a,b){cj(a,2,b)}function un(a,b,c){OT(b,c)}function uc(a){a=a|0;Cb(a)}function ts(a){Hf(a);cc(a)}function t2(){return 58272}function sf(a){Zp(a);Ix(a)}function s2(){return 59056}function rc(a){j[a+8>>2]=0}function r2(){return 60608}function pu(a){Zp(a);mB(a)}function oW(a){a=a|0;vk(a)}function nu(a){_g(a);de(a)}function lo(a,b){n[a>>2]=b}function lf(a,b){j[a>>2]=b}function lI(a){Mi(a);df(a)}function kl(a){ft(a);Vs(a)}function kR(a){nl(a);ni(a)}function jy(a,b,c){sN(b,c)}function haa(){return 2048}function fh(a,b,c){T2(b,c)}function ff(a){wl(a);xt(a)}function fQ(a){h[a+31|0]=0}function eR(a){ft(a);cR(a)}function du(a,b,c){YU(b,c)}function cp(a){Iy(a,se(a))}function cQ(a){Vy(a,se(a))}function bp(a){Hy(a,se(a))}function ap(a){Af(a);tc(a)}function Zx(a){Ab(a,0,512)}function Zg(a,b,c){VA(b,c)}function ZJ(a){Or(a,se(a))}function Yf(a,b,c){x4(b,c)}function Xo(a){Ce(a);pd(a)}function Xi(a,b){rn(a,b,0)}function WI(a){Rw(a,se(a))}function Ud(a){af(a);os(a)}function Uc(a){Lh(a);HA(a)}function Sc(a){wk(a);FS(a)}function Rj(a){Cx(a,se(a))}function Od(a){Ap(a);Mp(a)}function OO(a){af(a);KO(a)}function Np(a){Ap(a);BA(a)}function MN(a){af(a);KN(a)}function Ko(a){wk(a);jL(a)}function JP(a){mi(a);Kf(a)}function It(a,b,c){rT(b,c)}function HH(a){Hj(a);Te(a)}function HC(a){wC(a);FC(a)}function Ef(a,b,c){hB(b,c)}function EB(a){Ah(a);Xc(a)}function DC(a){Bk(a);sb(a)}function Bt(a){Pf(a);bc(a)}function $v(a){wk(a);wG(a)}function $P(a){Xy(a,se(a))}function wP(a){Ab(a,0,33)}function vO(a,b){uBa(a,b)}function tF(a){Ab(a,0,44)}function ob(a,b){oBa(a,b)}function lA(a){h[a+1|0]=3}function aX(){return Za|0}function _2(a){a=a|0;$2()}function Yz(a,b){lMa(a,b)}function SR(a,b){xKa(a,b)}function PD(a){Xv(a,8192)}function FO(a,b){EBa(a,b)}function $W(a){a=a|0;Za=a}function rz(a){h[a|0]=16}function qs(a){j[a>>2]=0}function lc(a){wg(a+8|0)}function jn(a,b){bE(a,b)}function gB(a,b){zc(a,b)}function f$(){oq(463208)}function eO(a,b){Hw(a,b)}function dh(a,b){Cg(a,b)}function cS(a,b){KH(a,b)}function bL(a,b){ZL(a,b)}function Ts(a){gb(a+4|0)}function Re(a){jb(a+8|0)}function Pg(a){a=a|0;z()}function LL(a,b){cf(a,b)}function Kn(a,b){DY(a,b)}function Iu(a,b){PX(a,b)}function Dh(a,b){C$(a,b)}function Oe(a){h[a|0]=0}function mc(a){fe(a,0)}function kh(a){qG(a,0)}function jJ(a){VI(a,0)}function bf(a){dy(a,0)}function Mr(a){GJ(a,0)}function Lr(a){FJ(a,0)}function Jf(a){dQ(a,0)}function Hc(a){CG(a,0)}function $p(a){nB(a,0)}function qb(a){gb(a)}function oe(a){a=a|0}function LS(a){Id(a)}function i$(){z_()}function Y_(){CC()}function T_(){BC()}function R_(){AC()}function P_(){zC()}function N_(){yC()}function J_(){x_()}function H_(){w_()}function F_(){xC()}function zX(){z()}
// EMSCRIPTEN_END_FUNCS
a=k;var bb=UMa([null,il,Eb,Kp,Mf,aMa,hn,dHa,XFa,Ni,VEa,yDa,qCa,Ir,il,_3,SU,Al,eg,Z3,Q,Xt,qk,r6,Fu,mv,ce,ZT,zl,ti,nfa,ec,gc,tb,ti,LJa,qp,uR,Ly,sl,aA,XCa,Oy,Pg,ae,ae,nIa,gIa,ot,ZHa,xP,UDa,NDa,zX,Ny,Pg,ae,Sb,ae,DFa,zFa,vFa,rFa,lFa,rDa,LEa,lDa,tEa,mEa,Rd,Pg,jO,PAa,RN,NN,Cs,HN,$N,ZN,us,uya,pa,iya,Ic,Ic,Eb,jY,ay,Nwa,Fwa,Ic,sva,hva,uM,ec,Io,Ng,Ic,iY,fua,Oya,Mta,Vta,Bta,yta,oe,Woa,gc,isa,uM,ul,Ut,VB,XX,il,Loa,Wma,po,ul,ola,Mf,Zka,vC,eka,Xja,Pja,vfa,mfa,m3,bfa,xja,hja,Xia,YH,YH,hia,Rha,wr,Kp,vr,Hga,Aga,vr,Xaa,Oaa,yaa,waa,vr,vr,qm,il,Hd,OG,lea,bea,Rn,Fq,t3,s3,lr,Rda,gc,il,Ida,Yca,Sb,Sb,g4,Nca,f4,rca,e4,Oba,T3,m9,r8,j8,W3,O3,M3,aw,R3,W7,Xe,EF,K7,D7,Vn,Kq,I3,H3,x6,Cs,q6,h6,XE,Gn,il,G4,Uq,ys,U4,L4,ec,Iq,G3,GD,ec,ec,aA,xu,HW,GW,CW,mX,gc,FW,gc,Ly,GBa,BW,AW,zW,yW,fi,wW,D5,p5,vW,xB,wB,uW,Uq,tW,qW,vu,oW,yi,vc,kW,Ll,jW,hW,nW,gW,fW,sW,CBa,pW,uB,eW,dW,tB,cW,kf,jj,xc,_p,yb,TV,ij,_p,NV,MV,KV,iq,pV,oV,Ic,ec,TA,TB,XU,DV,hg,CV,sV,zh,Ic,iV,hg,hV,Ic,gc,WU,TU,hg,RU,ti,ju,ot,Rd,uc,zn,GG,AV,uc,zV,ae,ae,ot,sz,yV,xP,xV,wV,Rd,uc,zn,fV,uc,Sb,ae,ae,Sb,Sb,ZA,PA,PU,zn,OU,$t,LU,KU,JU,IU,HU,Cca,GU,FU,EU,Ln,wU,ula,vU,tla,tU,Sp,Jb,Bla,$A,cd,sU,Ng,aY,ec,Io,WA,GD,gc,MA,eU,aU,ju,ec,ec,ec,AA,ST,RT,gc,gc,gc,MT,aA,Ly,xu,tT,Ng,FT,yT,sT,gc,AA,Ht,mT,fA,lT,BMa,sMa,_S,zp,gc,iMa,PS,hMa,md,BU,OS,gMa,WV,Yb,Gc,fMa,eMa,dMa,NS,MS,cMa,bMa,$f,If,Wf,_La,KS,IS,SLa,GS,yp,ec,HLa,Io,FLa,lb,dT,qc,ec,ec,vLa,ec,GLa,DLa,gc,xLa,_S,pS,mS,pLa,nLa,mLa,lLa,kLa,vg,jLa,iLa,hLa,gLa,Yv,CJ,lb,xM,eLa,tg,dLa,Xz,eS,Wc,od,yi,Oi,XKa,WKa,ui,Wg,sJ,VKa,UKa,Rz,ic,qu,TKa,dS,Pd,Pz,Uz,Qo,lb,qp,IT,EKa,Hp,Se,zt,rKa,LR,qB,_h,gf,vb,rg,pKa,Iz,oKa,vc,nKa,ita,mKa,lKa,Oo,kKa,KR,JR,iKa,hKa,gKa,dka,Dp,Cp,Uk,Iw,yI,fKa,ER,nH,eKa,dKa,cKa,ek,Hz,bKa,aKa,Nt,CR,$Ja,TJa,yR,jO,RJa,FJa,ec,Cz,Cz,CJa,RN,NN,Cs,HN,gn,sp,rp,ec,gc,us,sJa,rJa,qJa,iJa,Fz,hJa,xz,ef,gJa,fJa,eJa,nt,dJa,Po,Xx,cJa,bJa,aJa,$Ia,zf,Lf,UIa,TIa,SIa,CIa,BIa,wIa,rp,MIa,LIa,qp,gt,dR,PIa,ec,ec,JIa,gc,xu,gn,gc,Yi,mp,mIa,bt,lIa,eIa,LR,lp,dIa,ct,Yx,KR,cIa,on,bIa,aIa,SQ,Nf,$Ha,_Ha,pE,nn,Fs,YHa,BAa,CR,XHa,UHa,Vg,NQ,gn,sp,rp,ec,DHa,CHa,NQ,EQ,BI,ska,Lw,zQ,hHa,gHa,vh,WGa,VGa,ana,SGa,RGa,QGa,PGa,Ot,OGa,NGa,tb,MGa,kf,wT,LGa,swa,twa,KGa,JGa,_Ga,an,zT,IGa,Ro,xT,sQ,GGa,FGa,Lna,Gc,EGa,DGa,hz,CGa,GMa,BGa,AGa,zGa,qQ,yGa,gy,xGa,wGa,vT,oR,XGa,vGa,oQ,qGa,ez,ZN,vA,Fp,mGa,lGa,mm,Tma,kGa,jGa,mQ,mQ,jQ,bz,Ek,fGa,A_,eGa,dGa,cGa,bGa,Sg,eta,Sg,Fja,aGa,lia,hQ,ec,fFa,_p,$m,TFa,aFa,tS,Jn,Zh,ec,NP,$Ea,_Ea,gQ,_Fa,ZFa,cf,YFa,ji,Us,mia,gna,$ha,VFa,Kp,MFa,LFa,KFa,Ic,bk,Ic,Wy,Rd,bQ,hg,Yy,Rd,Yy,gc,tFa,gc,gc,iFa,Ng,Ss,eFa,GEa,FEa,EEa,ug,en,DEa,BEa,pB,AEa,zEa,yEa,xEa,wEa,vEa,uEa,sEa,rEa,ec,GDa,DDa,eEa,dEa,bEa,gc,sP,gn,rP,LDa,ec,lP,an,ADa,zDa,xDa,wDa,Sta,kf,vDa,uDa,tDa,sDa,KQ,jM,rb,Ps,My,mz,Wc,fA,pDa,oDa,iP,nDa,Ws,wz,mDa,gj,kDa,Kp,kf,Sz,kf,_t,Ft,jDa,ji,fP,ota,Cw,eP,dp,ec,bk,Ic,ec,gc,QCa,Ng,Ss,gc,Rd,gc,gc,HCa,_S,pS,BCa,hg,vCa,xi,uCa,tCa,Gy,Is,sCa,rCa,oCa,nCa,mCa,lCa,RS,kCa,jCa,lb,iCa,hCa,gCa,fCa,owa,Zqa,ZA,eCa,lb,Hs,s5,$y,z5,Hs,dCa,cCa,B5,C5,Uma,bCa,lQ,kQ,nM,fi,_Ba,ZBa,XBa,WBa,ec,Ss,ec,KBa,ti,gc,mS,lt,Gs,$i,Zh,kf,mp,mBa,lBa,DBa,Rs,gc,UAa,eS,_R,TAa,Xma,SAa,RAa,nI,$m,QAa,hO,OAa,NAa,Kt,Jt,Ds,upa,MAa,LAa,ls,KAa,xp,JAa,IAa,ry,Dt,ec,gc,kAa,jAa,TA,kf,$za,bg,_za,Ic,Zza,Yza,TN,Ic,Gp,Xza,Nza,Mza,dk,Nm,Ds,Lza,oka,Jza,LN,ec,Ss,gc,Cza,Ng,vza,uza,xz,VN,CN,Uz,tza,sza,rza,qza,GIa,pza,oza,nza,xs,mza,lza,xs,kza,RR,zN,jza,CT,ec,Wya,Mya,Jya,mp,cza,bza,aza,ec,gn,Vya,sp,rp,Nya,qN,pN,iy,ec,wya,an,vya,pya,AM,hO,an,ara,$qa,jya,Zxa,Yxa,qu,Xxa,Wxa,Uxa,Txa,Sxa,Ls,Rxa,Pxa,Oxa,Jxa,Fxa,ec,xxa,wxa,mxa,Axa,gc,vxa,ec,ec,NO,dxa,qy,bxa,axa,qta,Ywa,Xwa,fla,Wwa,Vwa,Uwa,cla,Twa,dla,gla,Swa,Rwa,Qwa,xW,AB,xta,zy,mna,jna,$x,Mwa,Lwa,ec,_x,Bwa,Ng,gc,BM,vwa,lwa,kwa,jwa,iwa,hwa,gwa,fwa,ewa,dwa,cwa,bwa,awa,$va,_va,Zva,Yva,Xva,Wva,Vva,Uva,Tva,Sva,Rva,Qva,Pva,Nva,Mva,Lva,Kva,Jva,Iva,Hva,Gva,Fva,Eva,Cva,Bva,Ava,zva,yva,xva,wva,vva,uva,tva,rva,qva,pva,ova,nva,mva,lva,kva,jva,iva,gva,fva,eva,dva,cva,bva,ava,$ua,_ua,Zua,Xua,Wua,Vua,Uua,Tua,Sua,Rua,Qua,Pua,Oua,Nua,Mua,Lua,Kua,Jua,Iua,Hua,Gua,Fua,Eua,Dua,Cua,Bua,Aua,zua,yua,xua,wua,vua,uua,tua,sua,bua,aua,Pta,kM,Wta,bk,Ic,ec,zp,hg,Ssa,mk,uta,wta,uS,XL,lta,ec,Qsa,hta,NL,Nsa,dta,bta,ata,$sa,_sa,UL,Xsa,Wsa,Vsa,Usa,gQ,is,Hsa,Rsa,PL,ec,BL,Ic,Fsa,Ic,lsa,ksa,jsa,uL,hsa,sS,gsa,TB,_ra,rL,Hla,Vra,Ura,Gr,Fla,Rra,Dla,Cla,Pra,Nra,Mra,Ira,Dra,Cra,ec,ec,Hra,gc,ec,Bra,gc,Si,ec,fra,era,jra,dra,Mv,d6,cs,Yqa,hna,aj,Hta,Sx,Vqa,yR,zp,zp,Cs,tB,bk,Ic,Iq,G3,Rd,Oqa,hg,ec,fz,Jd,QS,TT,Ee,OKa,Jqa,Iqa,lb,QIa,Hqa,Gqa,Fqa,Eqa,Dqa,Cqa,Bqa,Aqa,zqa,yqa,xqa,wqa,vqa,uqa,tqa,sqa,rqa,qqa,oqa,nqa,mqa,lqa,kqa,jqa,iqa,hqa,gqa,fqa,eqa,dqa,cqa,bqa,aqa,$pa,_pa,Zpa,Ypa,Xpa,Wpa,Vpa,Upa,Tpa,Spa,Rpa,Qpa,Ppa,Opa,Npa,Mpa,Lpa,Kpa,Jpa,Ipa,Hpa,Gpa,Fpa,Epa,Cpa,Bpa,Apa,zpa,ypa,qpa,xra,ppa,opa,npa,eL,dL,mpa,lpa,Em,Wr,yx,kpa,KK,ns,qM,Go,JK,gJ,tJ,_w,Fo,Vr,Eo,ipa,EK,fpa,epa,ji,Us,dp,AL,ji,fP,dpa,dp,ura,ec,soa,qoa,bk,Ic,Ic,bk,Ic,ec,gc,Rd,gc,VJ,joa,hg,Rd,gc,coa,hg,Zna,nta,uwa,MJ,fM,Yna,cma,Xna,JJ,ue,Ic,Ic,ec,Nna,Hna,YV,DU,yU,hU,Dna,fU,CU,XV,xU,qga,Ana,jx,sla,ec,wsa,ec,Io,Ng,Ic,lna,ina,_ia,mja,ena,dja,Sia,Ic,Ic,xy,bna,lM,ec,ec,Nma,Kma,gc,_wa,Zwa,UGa,TGa,rya,qya,dya,cya,CDa,BDa,gAa,fAa,IEa,HEa,tKa,sKa,xHa,wHa,rLa,qLa,ZKa,YKa,bAa,aAa,yya,xya,ixa,hxa,kJa,jJa,pIa,oIa,oMa,nMa,kMa,jMa,xza,wza,eza,dza,WAa,VAa,KEa,FP,pHa,oHa,jHa,iHa,uJa,tJa,hIa,fIa,Qza,Pza,bla,ala,Jka,Ika,pBa,nBa,mya,lya,$xa,_xa,FBa,tBa,rBa,FMa,EMa,zKa,yKa,xCa,wCa,zBa,vBa,ama,ec,Io,Ng,Ula,bk,Ic,NJ,gc,GD,Wy,hg,BM,Gla,Qw,ws,vla,xla,XK,$ka,_ka,xz,Yka,qt,Xka,CN,Wka,Vka,Uka,mp,Tka,Ska,kf,Rka,Qka,Pka,Nka,Mka,zN,Lka,k6,f6,e6,ec,gn,sp,rp,nka,mka,kka,NP,cka,Wja,Sg,$ja,_ja,Sg,dz,Zja,mf,Cg,Hk,Yja,Qja,Nja,Bja,Kja,hka,Jja,vja,uja,Gja,aka,yja,Fw,ec,eI,ec,bk,Ic,Cia,Ng,xia,zw,ji,Us,aja,Ama,Bia,Qia,Pia,Sg,Nia,Mia,Lia,bI,gja,io,UL,Kia,cf,aI,Iia,lj,Cg,_x,bQ,hg,jia,iia,gia,fia,eia,dia,Di,aia,RH,Jia,Ria,QH,Wha,Sha,Qha,Pha,Jga,Oha,Nha,GH,tha,EH,Ng,$H,pha,gha,nha,gc,_x,gc,xw,Dha,Cha,Bha,Sb,oe,Sb,Sb,Sb,gc,bq,Iha,Jha,Lha,Kha,Mha,Wh,ww,ww,vw,vw,vw,$La,oe,FP,Aha,zha,yha,xha,Hha,Vh,JH,Gga,Sb,Sb,ae,uw,$d,$d,ae,Gha,Fha,gc,oe,gc,oe,cha,Pga,qw,Nga,Mga,Lga,Sb,oe,Sb,Sb,Sb,gc,Qxa,zH,$ga,Rga,Qga,bha,Wh,Zga,Yga,Xga,Wga,Vga,Uga,Tga,Sga,_ga,Vh,yH,Sb,Sb,ae,$d,$d,ae,xH,wH,xi,Bga,zga,pH,ec,ec,we,Pg,Cga,oH,Fga,Sb,wga,vga,nga,ys,lga,jga,iga,hga,Ic,Ng,is,ec,Io,gc,$fa,Ofa,Cfa,ufa,jfa,$ea,Qea,Cea,vea,Tha,dha,jH,rr,Ufa,iH,Tfa,Sb,oe,Sb,Sb,Sb,gc,kP,Yfa,Zfa,_fa,Wh,Xfa,Vh,Vfa,Sb,Sb,ae,$d,$d,gc,oe,hH,Sfa,Rfa,gH,Qfa,fH,eH,Nfa,mw,Gfa,Ffa,Efa,Sb,oe,Sb,Sb,Sb,gc,Dfa,Kfa,Lfa,Mfa,Wh,Jfa,Vh,cH,Sb,Sb,ae,$d,$d,Bfa,pr,or,wfa,Sb,oe,Sb,Sb,Sb,gc,II,yfa,zfa,Afa,Wh,xfa,Vh,$G,Sb,Sb,ae,$d,$d,tfa,kw,ofa,lfa,kfa,Sb,oe,Sb,Sb,Sb,gc,II,qfa,rfa,sfa,Wh,pfa,Vh,ZG,Sb,Sb,ae,$d,$d,ifa,gfa,ffa,efa,kP,hfa,hH,dfa,cfa,gH,afa,fH,eH,_ea,pr,or,Vea,Sb,oe,Sb,Sb,Sb,gc,$d,Xea,Yea,Zea,Wh,Wea,Vh,Uea,Sb,Sb,ae,$d,$d,Pea,Sea,iw,Hea,Gea,Fea,Sb,oe,Sb,Sb,Eea,gc,Dea,Jea,Kea,Oea,Wh,Iea,Vh,jw,Sb,Sb,ae,$d,$d,gc,oe,Bea,pr,or,wea,Sb,oe,Sb,Sb,Sb,gc,aW,yea,zea,Aea,Wh,xea,Vh,RG,Sb,Sb,ae,$d,$d,uea,pr,or,pea,Sb,oe,Sb,Sb,Sb,gc,bq,rea,sea,tea,Wh,qea,Vh,NG,Sb,Sb,ae,$d,$d,xba,aea,Jba,Saa,wba,vba,maa,vu,kaa,mr,DG,gaa,Sda,Qda,Ic,Ic,haa,daa,caa,baa,Rd,Y,Jda,Hda,DG,aaa,_9,zG,Cda,fw,_F,sz,H9,G9,M9,E9,F9,I9,gw,Z9,mda,vG,W9,V9,U9,T9,S9,R9,Q9,P9,O9,N9,D9,gw,x9,w9,v9,u9,t9,s9,r9,q9,p9,o9,n9,l9,k9,j9,Qk,i9,h9,Pk,fr,g9,aC,f9,d9,c9,b9,a9,$8,_8,Vv,X8,W8,T8,R8,Q8,O8,N8,L8,J8,G8,Daa,nG,mG,lG,kG,M6,L6,zG,gw,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Sba,Rba,Qba,Pba,Nba,Mba,Lba,Eba,dw,Hba,Gba,yG,yba,yG,zba,vB,ir,cba,Tqa,cq,Zaa,Yaa,ec,k8,Vaa,LF,g8,Yr,Laa,ec,VJ,a8,_na,Baa,UB,NO,Ic,Ic,Ic,M8,F8,K8,I8,Ena,Haa,aba,Raa,iu,ji,Us,dp,bA,uaa,yma,bma,laa,tG,sG,iaa,jaa,Ic,w8,u8,Faa,eG,xaa,Paa,Ic,Ic,Ic,lb,Qb,$9,L9,Ic,Ic,yJ,C9,B9,A9,O6,ona,pna,Qaa,$ma,z9,y9,om,WF,Hja,e9,Ui,mI,V8,Se,uJ,AI,zI,P8,ec,hg,t8,hg,o8,Yy,gc,R6,ec,Pg,hr,C8,Waa,Rd,Pg,Rd,uc,z8,y8,Pg,QF,q8,zn,p8,NF,m8,zn,l8,uc,Y7,Rd,uc,X7,V7,uc,GF,FF,Pg,uc,H7,G7,uc,DF,CF,uc,u7,t7,uc,AF,zF,uc,e7,d7,uc,yF,xF,Nv,uF,I6,H6,sF,rF,qF,pF,oF,nF,mF,lF,kF,jF,iF,hF,gF,fF,eF,dF,K6,J6,G6,F6,E6,C6,B6,A6,z6,y6,w6,v6,u6,t6,s6,p6,m6,l6,Rd,Pg,Rd,Pg,j6,i6,j5,W4,D4,C4,B4,z4,A4,Na,AE,QB,s4,p4,k4,lE,so,Y3,U3,j4,X3,P3,x3,K3,ov,J3,qKa,jKa,OR,F3,so,eg,D3,B3,A3,x3,w3,XD,oe,o3,VD,Jk,i4,iE,hE,gE,Lq,Lq,Wn,d4,gc,il,iE,hE,Sb,Sb,c4,gE,a4,Lq,$3,Lq,Vn,Kq,I3,H3,Rn,Fq,t3,s3,Rd,uc,q3,SX,RX,QX,p3,n3,pv,l3,og,jE,og,jE,h3,Sb,g3,e3,_2,nr,nr,hv,gv,Jq,aE,ND,Z2,Y2,X2,W2,KD,V2,U2,S2,R2,ND,Q2,ID,P2,O2,KD,N2,ID,M2,L2,D2,x2,Yu,Gg,Fg,wq,Cb,Ku,Tn,Ii,Bj,Xu,Ik,Pn,xj,b2,le,Gh,Uf,_1,W1,kD,kD,P1,vq,M1,jD,Hh,J1,F1,hc,Wd,D1,y2,$u,nv,Vu,Gg,Fg,uq,Hq,yj,Gk,qk,cm,wj,Gh,Uf,tq,hD,Hh,d1,uj,_0,Z0,Pn,w2,dv,H4,WD,T0,Eq,On,zl,O0,Wl,Pn,av,oe,T$,Sl,S$,R$,XC,Q$,WC,Pn,O$,Gn,K$,J$,zj,I$,SC,WC,F$,WX,A$,z$,w$,v$,Qe,NC,u2,NC,LC,r$,KC,Qe,q$,bv,o$,n$,m$,l$,k$,j$,i$,h$,g$,f$,e$,d$,c$,a$,$_,__,Z_,Y_,X_,W_,V_,U_,T_,S_,R_,Q_,P_,O_,N_,M_,L_,K_,J_,I_,H_,G_,F_,E_,D_,B_,GC,jC,_x,o_,t_,AY,v_,wY,vY,Rd,q_,p_,m_,t2,s2,r2,tD,Cj,sD,Qn,MZ,LZ,qD,pD,oD,kZ,jZ,gZ,fZ,dZ,cZ,aZ,$Y,ZY,YY,WY,VY,TY,Mu,RY,PY,NY,LY,JY,HY,FY,dC,gc,sC,s_,iH,qC,a_,$Z,_Z,ZZ,YZ,oA,XZ,WZ,VZ,JC,TZ,SZ,QZ,OZ,NZ,Sb,KZ,IZ,mC,uZ,sZ,rZ,WF,pZ,nZ,lC,tZ,sz,uU,qZ,oZ,mZ,Rd,uc,uc,l_,k_,j_,i_,h_,g_,f_,e_,oA,d_,c_,b_,uc,oC,oC,Qu,ae,ae,UZ,ae,uc,HZ,FZ,Qu,Sb,Sb,DZ,bq,uc,BZ,yZ,Qu,Sb,Sb,wZ,bq,uc,uc,Rd,uc,l2,k2,j2,Rd,uc,i2,h2,g2,uc,f2,d2,a2,Y1,V1,T1,R1,O1,L1,I1,E1,uc,C1,B1,z1,x1,v1,t1,r1,p1,m1,k1,i1,uc,f1,e1,c1,b1,a1,$0,Y0,X0,uc,W0,U0,S0,R0,Q0,P0,N0,M0,Rd,uc,$d,J0,I0,H0,F0,E0,D0,lZ,eZ,_Y,MY,IY,UY,QY,Rd,uc,$d,p0,o0,n0,m0,l0,k0,iZ,bZ,XY,KY,GY,SY,OY,Lu,kC,Y$,Lu,kC,X$,uc,rq,rq,sj,sj,sj,ZC,Sb,qj,qj,uc,rq,rq,sj,sj,sj,ZC,Sb,qj,qj,uc,Pr,Pr,sj,qq,qq,YC,Sb,qj,qj,uc,Pr,Pr,sj,qq,qq,YC,Sb,qj,qj,uc,U$,P$,uc,L$,H$,uc,B$,y$,uc,x$,u$,uc,OC,t$,gc,uc,OC,s$,gc,Rd,Pg,Pg,Sb,Sb,Sb,mY,hY,_B,$B,sY,XE,IX,gY,RB,Hu,uc,NX,MX,uc,LX,JX,KX,HX,BX,CX,GX,uc,xX,uc,yX,wX,ot,vX,Eu,Eu,Eu,ju,uc,uX,Rd,uc,oe,oe,tX,jX,nX,sX,uc,kX,oX,rX,uc,lX,pX,qX]);function aNa(){return g.byteLength/65536|0}function bNa(jNa){jNa=jNa|0;var cb=aNa()|0;var db=cb+jNa|0;if(cb<db&&db<65536){var eb=new ArrayBuffer(p(db,65536));var fb=new Int8Array(eb);fb.set(h);h=new Int8Array(eb);i=new Int16Array(eb);j=new Int32Array(eb);k=new Uint8Array(eb);l=new Uint16Array(eb);m=new Uint32Array(eb);n=new Float32Array(eb);o=new Float64Array(eb);g=eb;f.buffer=g;a=k}return cb}return{"ya":bb,"za":hT,"Aa":cea,"Ba":$da,"Ca":uc,"Da":Cb,"Ea":_da,"Fa":Zda,"Ga":Yda,"Ha":mr,"Ia":gc,"Ja":Xda,"Ka":Wda,"La":Vda,"Ma":ww,"Na":Uda,"Oa":GG,"Pa":Tda,"Qa":Rd,"Ra":FG,"Sa":EG,"Ta":FG,"Ua":Oda,"Va":ZW,"Wa":XW,"Xa":WW,"Ya":Kda,"Za":BG,"_a":Eda,"$a":AG,"ab":Dda,"bb":Bda,"cb":Ada,"db":zda,"eb":yda,"fb":xda,"gb":wda,"hb":vda,"ib":uda,"jb":tda,"kb":sda,"lb":rda,"mb":qda,"nb":pda,"ob":oda,"pb":nda,"qb":lda,"rb":kda,"sb":jda,"tb":ida,"ub":hda,"vb":gda,"wb":fda,"xb":eda,"yb":dda,"zb":cda,"Ab":bda,"Bb":ada,"Cb":$ca,"Db":_ca,"Eb":Zca,"Fb":Xca,"Gb":Wca,"Hb":Vca,"Ib":Uca,"Jb":Tca,"Kb":Sca,"Lb":Rca,"Mb":Qca,"Nb":Pca,"Ob":Oca,"Pb":Mca,"Qb":Lca,"Rb":Kca,"Sb":Jca,"Tb":Ica,"Ub":Hca,"Vb":Gca,"Wb":Fca,"Xb":Eca,"Yb":Dca,"Zb":Bca,"_b":Aca,"$b":zca,"ac":yca,"bc":xca,"cc":wca,"dc":vca,"ec":uca,"fc":tca,"gc":sca,"hc":qca,"ic":pca,"jc":VW,"kc":nca,"lc":mca,"mc":lca,"nc":kca,"oc":UW,"pc":ica,"qc":hca,"rc":gca,"sc":fca,"tc":eca,"uc":dca,"vc":cca,"wc":_c,"xc":AE,"yc":aX,"zc":$W,"Ac":_W,"Bc":w4,"Cc":iX,"Dc":hX,"Ec":TW,"Fc":SW,"Gc":RW,"Hc":QW,"Ic":KW,"Jc":PW,"Kc":OW,"Lc":NW,"Mc":MW,"Nc":LW,"Oc":KW}}return $Ma(cNa)}


// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


